"""Generated message classes for compute version alpha.

Creates and runs virtual machines on Google Cloud Platform.
"""
# NOTE: This file is autogenerated and should not be edited by hand.

from apitools.base.protorpclite import messages as _messages
from apitools.base.py import encoding


package = 'compute'


class AcceleratorConfig(_messages.Message):
  r"""A specification of the type and number of accelerator cards attached to
  the instance.

  Fields:
    acceleratorCount: The number of the guest accelerator cards exposed to
      this instance.
    acceleratorType: Full or partial URL of the accelerator type resource to
      attach to this instance. For example: projects/my-project/zones/us-
      central1-c/acceleratorTypes/nvidia-tesla-p100 If you are creating an
      instance template, specify only the accelerator name. See GPUs on
      Compute Engine for a full list of accelerator types.
  """

  acceleratorCount = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  acceleratorType = _messages.StringField(2)


class AcceleratorType(_messages.Message):
  r"""Represents an Accelerator Type resource.  Google Cloud Platform provides
  graphics processing units (accelerators) that you can add to VM instances to
  improve or accelerate performance when working with intensive workloads. For
  more information, read GPUs on Compute Engine. (== resource_for
  {$api_version}.acceleratorTypes ==)

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    deprecated: [Output Only] The deprecation status associated with this
      accelerator type.
    description: [Output Only] An optional textual description of the
      resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] The type of the resource. Always
      compute#acceleratorType for accelerator types.
    maximumCardsPerInstance: [Output Only] Maximum accelerator cards allowed
      per instance.
    name: [Output Only] Name of the resource.
    selfLink: [Output Only] Server-defined fully-qualified URL for this
      resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource's
      resource id.
    zone: [Output Only] The name of the zone where the accelerator type
      resides, such as us-central1-a. You must specify this field as part of
      the HTTP request URL. It is not settable as a field in the request body.
  """

  creationTimestamp = _messages.StringField(1)
  deprecated = _messages.MessageField('DeprecationStatus', 2)
  description = _messages.StringField(3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default=u'compute#acceleratorType')
  maximumCardsPerInstance = _messages.IntegerField(6, variant=_messages.Variant.INT32)
  name = _messages.StringField(7)
  selfLink = _messages.StringField(8)
  selfLinkWithId = _messages.StringField(9)
  zone = _messages.StringField(10)


class AcceleratorTypeAggregatedList(_messages.Message):
  r"""A AcceleratorTypeAggregatedList object.

  Messages:
    ItemsValue: A list of AcceleratorTypesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of AcceleratorTypesScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#acceleratorTypeAggregatedList for aggregated lists of
      accelerator types.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of AcceleratorTypesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of accelerator types.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A AcceleratorTypesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('AcceleratorTypesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#acceleratorTypeAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class AcceleratorTypeList(_messages.Message):
  r"""Contains a list of accelerator types.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of AcceleratorType resources.
    kind: [Output Only] Type of resource. Always compute#acceleratorTypeList
      for lists of accelerator types.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('AcceleratorType', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#acceleratorTypeList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class AcceleratorTypesScopedList(_messages.Message):
  r"""A AcceleratorTypesScopedList object.

  Messages:
    WarningValue: [Output Only] An informational warning that appears when the
      accelerator types list is empty.

  Fields:
    acceleratorTypes: [Output Only] A list of accelerator types contained in
      this scope.
    warning: [Output Only] An informational warning that appears when the
      accelerator types list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] An informational warning that appears when the
    accelerator types list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  acceleratorTypes = _messages.MessageField('AcceleratorType', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class AccessConfig(_messages.Message):
  r"""An access configuration attached to an instance's network interface.
  Only one access config per instance is supported.

  Enums:
    NetworkTierValueValuesEnum: This signifies the networking tier used for
      configuring this access configuration and can only take the following
      values: PREMIUM, STANDARD.  If an AccessConfig is specified without a
      valid external IP address, an ephemeral IP will be created with this
      networkTier.  If an AccessConfig with a valid external IP address is
      specified, it must match that of the networkTier associated with the
      Address resource owning that IP.
    TypeValueValuesEnum: The type of configuration. The default and only
      option is ONE_TO_ONE_NAT.

  Fields:
    kind: [Output Only] Type of the resource. Always compute#accessConfig for
      access configs.
    name: The name of this access configuration. The default and recommended
      name is External NAT, but you can use any arbitrary string, such as My
      external IP or Network Access.
    natIP: An external IP address associated with this instance. Specify an
      unused static external IP address available to the project or leave this
      field undefined to use an IP from a shared ephemeral IP address pool. If
      you specify a static external IP address, it must live in the same
      region as the zone of the instance.
    networkTier: This signifies the networking tier used for configuring this
      access configuration and can only take the following values: PREMIUM,
      STANDARD.  If an AccessConfig is specified without a valid external IP
      address, an ephemeral IP will be created with this networkTier.  If an
      AccessConfig with a valid external IP address is specified, it must
      match that of the networkTier associated with the Address resource
      owning that IP.
    publicDnsName: [Output Only] The public DNS domain name for the instance.
    publicPtrDomainName: The DNS domain name for the public PTR record. You
      can set this field only if the `setPublicPtr` field is enabled.
    setPublicDns: Specifies whether a public DNS 'A' record should be created
      for the external IP address of this access configuration.
    setPublicPtr: Specifies whether a public DNS 'PTR' record should be
      created to map the external IP address of the instance to a DNS domain
      name.
    type: The type of configuration. The default and only option is
      ONE_TO_ONE_NAT.
  """

  class NetworkTierValueValuesEnum(_messages.Enum):
    r"""This signifies the networking tier used for configuring this access
    configuration and can only take the following values: PREMIUM, STANDARD.
    If an AccessConfig is specified without a valid external IP address, an
    ephemeral IP will be created with this networkTier.  If an AccessConfig
    with a valid external IP address is specified, it must match that of the
    networkTier associated with the Address resource owning that IP.

    Values:
      PREMIUM: <no description>
      SELECT: <no description>
      STANDARD: <no description>
    """
    PREMIUM = 0
    SELECT = 1
    STANDARD = 2

  class TypeValueValuesEnum(_messages.Enum):
    r"""The type of configuration. The default and only option is
    ONE_TO_ONE_NAT.

    Values:
      ONE_TO_ONE_NAT: <no description>
    """
    ONE_TO_ONE_NAT = 0

  kind = _messages.StringField(1, default=u'compute#accessConfig')
  name = _messages.StringField(2)
  natIP = _messages.StringField(3)
  networkTier = _messages.EnumField('NetworkTierValueValuesEnum', 4)
  publicDnsName = _messages.StringField(5)
  publicPtrDomainName = _messages.StringField(6)
  setPublicDns = _messages.BooleanField(7)
  setPublicPtr = _messages.BooleanField(8)
  type = _messages.EnumField('TypeValueValuesEnum', 9, default=u'ONE_TO_ONE_NAT')


class Address(_messages.Message):
  r"""Use global external addresses for GFE-based external HTTP(S) load
  balancers in Premium Tier.  Use global internal addresses for reserved
  peering network range.  Use regional external addresses for the following
  resources:  - External IP addresses for VM instances - Regional external
  forwarding rules - Cloud NAT external IP addresses - GFE based LBs in
  Standard Tier - Network LBs in Premium or Standard Tier - Cloud VPN gateways
  (both Classic and HA)  Use regional internal IP addresses for subnet IP
  ranges (primary and secondary). This includes:  - Internal IP addresses for
  VM instances - Alias IP ranges of VM instances (/32 only) - Regional
  internal forwarding rules - Internal TCP/UDP load balancer addresses -
  Internal HTTP(S) load balancer addresses - Cloud DNS inbound forwarding IP
  addresses  For more information, read reserved IP address.  (== resource_for
  {$api_version}.addresses ==) (== resource_for {$api_version}.globalAddresses
  ==)

  Enums:
    AddressTypeValueValuesEnum: The type of address to reserve, either
      INTERNAL or EXTERNAL. If unspecified, defaults to EXTERNAL.
    IpVersionValueValuesEnum: The IP version that will be used by this
      address. Valid options are IPV4 or IPV6. This can only be specified for
      a global address.
    NetworkTierValueValuesEnum: This signifies the networking tier used for
      configuring this address and can only take the following values: PREMIUM
      or STANDARD. Global forwarding rules can only be Premium Tier. Regional
      forwarding rules can be either Premium or Standard Tier. Standard Tier
      addresses applied to regional forwarding rules can be used with any
      external load balancer. Regional forwarding rules in Premium Tier can
      only be used with a network load balancer.  If this field is not
      specified, it is assumed to be PREMIUM.
    PurposeValueValuesEnum: The purpose of this resource, which can be one of
      the following values:   - `GCE_ENDPOINT` for addresses that are used by
      VM instances, alias IP ranges, internal load balancers, and similar
      resources.  - `DNS_RESOLVER` for a DNS resolver address in a subnetwork
      - `VPC_PEERING` for addresses that are reserved for VPC peer networks.
      - `NAT_AUTO` for addresses that are external IP addresses automatically
      reserved for Cloud NAT.
    StatusValueValuesEnum: [Output Only] The status of the address, which can
      be one of RESERVING, RESERVED, or IN_USE. An address that is RESERVING
      is currently in the process of being reserved. A RESERVED address is
      currently reserved and available to use. An IN_USE address is currently
      being used by another resource and is not available.

  Messages:
    LabelsValue: Labels for this resource. These can only be added or modified
      by the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.

  Fields:
    address: The static IP address represented by this resource.
    addressType: The type of address to reserve, either INTERNAL or EXTERNAL.
      If unspecified, defaults to EXTERNAL.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this field
      when you create the resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    ipVersion: The IP version that will be used by this address. Valid options
      are IPV4 or IPV6. This can only be specified for a global address.
    kind: [Output Only] Type of the resource. Always compute#address for
      addresses.
    labelFingerprint: A fingerprint for the labels being applied to this
      Address, which is essentially a hash of the labels set used for
      optimistic locking. The fingerprint is initially generated by Compute
      Engine and changes after every request to modify or update labels. You
      must always provide an up-to-date fingerprint hash in order to update or
      change labels, otherwise the request will fail with error 412
      conditionNotMet.  To see the latest fingerprint, make a get() request to
      retrieve an Address.
    labels: Labels for this resource. These can only be added or modified by
      the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?`. The first character
      must be a lowercase letter, and all following characters (except for the
      last character) must be a dash, lowercase letter, or digit. The last
      character must be a lowercase letter or digit.
    network: The URL of the network in which to reserve the address. This
      field can only be used with INTERNAL type with the VPC_PEERING purpose.
    networkTier: This signifies the networking tier used for configuring this
      address and can only take the following values: PREMIUM or STANDARD.
      Global forwarding rules can only be Premium Tier. Regional forwarding
      rules can be either Premium or Standard Tier. Standard Tier addresses
      applied to regional forwarding rules can be used with any external load
      balancer. Regional forwarding rules in Premium Tier can only be used
      with a network load balancer.  If this field is not specified, it is
      assumed to be PREMIUM.
    prefixLength: The prefix length if the resource reprensents an IP range.
    purpose: The purpose of this resource, which can be one of the following
      values:   - `GCE_ENDPOINT` for addresses that are used by VM instances,
      alias IP ranges, internal load balancers, and similar resources.  -
      `DNS_RESOLVER` for a DNS resolver address in a subnetwork  -
      `VPC_PEERING` for addresses that are reserved for VPC peer networks.  -
      `NAT_AUTO` for addresses that are external IP addresses automatically
      reserved for Cloud NAT.
    region: [Output Only] The URL of the region where the regional address
      resides. This field is not applicable to global addresses. You must
      specify this field as part of the HTTP request URL.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    status: [Output Only] The status of the address, which can be one of
      RESERVING, RESERVED, or IN_USE. An address that is RESERVING is
      currently in the process of being reserved. A RESERVED address is
      currently reserved and available to use. An IN_USE address is currently
      being used by another resource and is not available.
    subnetwork: The URL of the subnetwork in which to reserve the address. If
      an IP address is specified, it must be within the subnetwork's IP range.
      This field can only be used with INTERNAL type with a GCE_ENDPOINT or
      DNS_RESOLVER purpose.
    users: [Output Only] The URLs of the resources that are using this
      address.
  """

  class AddressTypeValueValuesEnum(_messages.Enum):
    r"""The type of address to reserve, either INTERNAL or EXTERNAL. If
    unspecified, defaults to EXTERNAL.

    Values:
      DNS_FORWARDING: <no description>
      EXTERNAL: <no description>
      INTERNAL: <no description>
      UNSPECIFIED_TYPE: <no description>
    """
    DNS_FORWARDING = 0
    EXTERNAL = 1
    INTERNAL = 2
    UNSPECIFIED_TYPE = 3

  class IpVersionValueValuesEnum(_messages.Enum):
    r"""The IP version that will be used by this address. Valid options are
    IPV4 or IPV6. This can only be specified for a global address.

    Values:
      IPV4: <no description>
      IPV6: <no description>
      UNSPECIFIED_VERSION: <no description>
    """
    IPV4 = 0
    IPV6 = 1
    UNSPECIFIED_VERSION = 2

  class NetworkTierValueValuesEnum(_messages.Enum):
    r"""This signifies the networking tier used for configuring this address
    and can only take the following values: PREMIUM or STANDARD. Global
    forwarding rules can only be Premium Tier. Regional forwarding rules can
    be either Premium or Standard Tier. Standard Tier addresses applied to
    regional forwarding rules can be used with any external load balancer.
    Regional forwarding rules in Premium Tier can only be used with a network
    load balancer.  If this field is not specified, it is assumed to be
    PREMIUM.

    Values:
      PREMIUM: <no description>
      SELECT: <no description>
      STANDARD: <no description>
    """
    PREMIUM = 0
    SELECT = 1
    STANDARD = 2

  class PurposeValueValuesEnum(_messages.Enum):
    r"""The purpose of this resource, which can be one of the following
    values:   - `GCE_ENDPOINT` for addresses that are used by VM instances,
    alias IP ranges, internal load balancers, and similar resources.  -
    `DNS_RESOLVER` for a DNS resolver address in a subnetwork  - `VPC_PEERING`
    for addresses that are reserved for VPC peer networks.  - `NAT_AUTO` for
    addresses that are external IP addresses automatically reserved for Cloud
    NAT.

    Values:
      DNS_RESOLVER: <no description>
      GCE_ENDPOINT: <no description>
      NAT_AUTO: <no description>
      PRIVATE_SERVICE_CONNECT: <no description>
      SHARED_LOADBALANCER_VIP: <no description>
      VPC_PEERING: <no description>
    """
    DNS_RESOLVER = 0
    GCE_ENDPOINT = 1
    NAT_AUTO = 2
    PRIVATE_SERVICE_CONNECT = 3
    SHARED_LOADBALANCER_VIP = 4
    VPC_PEERING = 5

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the address, which can be one of
    RESERVING, RESERVED, or IN_USE. An address that is RESERVING is currently
    in the process of being reserved. A RESERVED address is currently reserved
    and available to use. An IN_USE address is currently being used by another
    resource and is not available.

    Values:
      IN_USE: <no description>
      RESERVED: <no description>
      RESERVING: <no description>
    """
    IN_USE = 0
    RESERVED = 1
    RESERVING = 2

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels for this resource. These can only be added or modified by the
    setLabels method. Each label key/value pair must comply with RFC1035.
    Label values may be empty.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  address = _messages.StringField(1)
  addressType = _messages.EnumField('AddressTypeValueValuesEnum', 2)
  creationTimestamp = _messages.StringField(3)
  description = _messages.StringField(4)
  id = _messages.IntegerField(5, variant=_messages.Variant.UINT64)
  ipVersion = _messages.EnumField('IpVersionValueValuesEnum', 6)
  kind = _messages.StringField(7, default=u'compute#address')
  labelFingerprint = _messages.BytesField(8)
  labels = _messages.MessageField('LabelsValue', 9)
  name = _messages.StringField(10)
  network = _messages.StringField(11)
  networkTier = _messages.EnumField('NetworkTierValueValuesEnum', 12)
  prefixLength = _messages.IntegerField(13, variant=_messages.Variant.INT32)
  purpose = _messages.EnumField('PurposeValueValuesEnum', 14)
  region = _messages.StringField(15)
  selfLink = _messages.StringField(16)
  selfLinkWithId = _messages.StringField(17)
  status = _messages.EnumField('StatusValueValuesEnum', 18)
  subnetwork = _messages.StringField(19)
  users = _messages.StringField(20, repeated=True)


class AddressAggregatedList(_messages.Message):
  r"""A AddressAggregatedList object.

  Messages:
    ItemsValue: A list of AddressesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of AddressesScopedList resources.
    kind: [Output Only] Type of resource. Always compute#addressAggregatedList
      for aggregated lists of addresses.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of AddressesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of addresses.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A AddressesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('AddressesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#addressAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class AddressList(_messages.Message):
  r"""Contains a list of addresses.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Address resources.
    kind: [Output Only] Type of resource. Always compute#addressList for lists
      of addresses.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Address', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#addressList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class AddressesScopedList(_messages.Message):
  r"""A AddressesScopedList object.

  Messages:
    WarningValue: [Output Only] Informational warning which replaces the list
      of addresses when the list is empty.

  Fields:
    addresses: [Output Only] A list of addresses contained in this scope.
    warning: [Output Only] Informational warning which replaces the list of
      addresses when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning which replaces the list of
    addresses when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  addresses = _messages.MessageField('Address', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class AliasIpRange(_messages.Message):
  r"""An alias IP range attached to an instance's network interface.

  Fields:
    ipCidrRange: The IP alias ranges to allocate for this interface. This IP
      CIDR range must belong to the specified subnetwork and cannot contain IP
      addresses reserved by system or used by other network interfaces. This
      range may be a single IP address (such as 10.2.3.4), a netmask (such as
      /24) or a CIDR-formatted string (such as 10.1.2.0/24).
    subnetworkRangeName: The name of a subnetwork secondary IP range from
      which to allocate an IP alias range. If not specified, the primary range
      of the subnetwork is used.
  """

  ipCidrRange = _messages.StringField(1)
  subnetworkRangeName = _messages.StringField(2)


class AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk(_messages.Message):
  r"""A AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk
  object.

  Enums:
    InterfaceValueValuesEnum: Specifies the disk interface to use for
      attaching this disk, which is either SCSI or NVME. The default is SCSI.
      For performance characteristics of SCSI over NVMe, see Local SSD
      performance.

  Fields:
    diskSizeGb: Specifies the size of the disk in base-2 GB.
    interface: Specifies the disk interface to use for attaching this disk,
      which is either SCSI or NVME. The default is SCSI. For performance
      characteristics of SCSI over NVMe, see Local SSD performance.
  """

  class InterfaceValueValuesEnum(_messages.Enum):
    r"""Specifies the disk interface to use for attaching this disk, which is
    either SCSI or NVME. The default is SCSI. For performance characteristics
    of SCSI over NVMe, see Local SSD performance.

    Values:
      NVDIMM: <no description>
      NVME: <no description>
      SCSI: <no description>
    """
    NVDIMM = 0
    NVME = 1
    SCSI = 2

  diskSizeGb = _messages.IntegerField(1)
  interface = _messages.EnumField('InterfaceValueValuesEnum', 2)


class AllocationSpecificSKUAllocationReservedInstanceProperties(_messages.Message):
  r"""Properties of the SKU instances being reserved.

  Fields:
    guestAccelerators: Specifies accelerator type and count.
    localSsds: Specifies amount of local ssd to reserve with each instance.
      The type of disk is local-ssd.
    locationHint: An opaque location hint used to place the allocation close
      to other resources. This field is for use by internal tools that use the
      public API.
    longTermRelease: Compute Engine Long Term Release. When specified, VMs
      that have this policy become long term release (internal: stable fleet)
      VMs.  For all VM shapes, this should result in fewer disruptions due to
      software updates and greater predictability via 1 week extended
      notifications.  For GPU VMs, this should also result in an 2 week uptime
      guarantee. See go/stable-fleet-gpus-design for more details.
    machineType: Specifies type of machine (name only) which has fixed number
      of vCPUs and fixed amount of memory. This also includes specifying
      custom machine type following custom-NUMBER_OF_CPUS-AMOUNT_OF_MEMORY
      pattern.
    minCpuPlatform: Minimum cpu platform the reservation.
  """

  guestAccelerators = _messages.MessageField('AcceleratorConfig', 1, repeated=True)
  localSsds = _messages.MessageField('AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk', 2, repeated=True)
  locationHint = _messages.StringField(3)
  longTermRelease = _messages.BooleanField(4)
  machineType = _messages.StringField(5)
  minCpuPlatform = _messages.StringField(6)


class AllocationSpecificSKUReservation(_messages.Message):
  r"""This reservation type allows to pre allocate specific instance
  configuration.

  Fields:
    count: Specifies the number of resources that are allocated.
    inUseCount: [Output Only] Indicates how many instances are in use.
    instanceProperties: The instance properties for the reservation.
  """

  count = _messages.IntegerField(1)
  inUseCount = _messages.IntegerField(2)
  instanceProperties = _messages.MessageField('AllocationSpecificSKUAllocationReservedInstanceProperties', 3)


class AttachedDisk(_messages.Message):
  r"""An instance-attached disk resource.

  Enums:
    InterfaceValueValuesEnum: Specifies the disk interface to use for
      attaching this disk, which is either SCSI or NVME. The default is SCSI.
      Persistent disks must always use SCSI and the request will fail if you
      attempt to attach a persistent disk in any other format than SCSI. Local
      SSDs can use either NVME or SCSI. For performance characteristics of
      SCSI over NVMe, see Local SSD performance.
    ModeValueValuesEnum: The mode in which to attach this disk, either
      READ_WRITE or READ_ONLY. If not specified, the default is to attach the
      disk in READ_WRITE mode.
    SavedStateValueValuesEnum: For LocalSSD disks on VM Instances in STOPPED
      or SUSPENDED state, this field is set to PRESERVED if the LocalSSD data
      has been saved to a persistent location by customer request. (see the
      discard_local_ssd option on Stop/Suspend). Read-only in the api.
    TypeValueValuesEnum: Specifies the type of the disk, either SCRATCH or
      PERSISTENT. If not specified, the default is PERSISTENT.

  Fields:
    autoDelete: Specifies whether the disk will be auto-deleted when the
      instance is deleted (but not when the disk is detached from the
      instance).
    boot: Indicates that this is a boot disk. The virtual machine will use the
      first partition of the disk for its root filesystem.
    deviceName: Specifies a unique device name of your choice that is
      reflected into the /dev/disk/by-id/google-* tree of a Linux operating
      system running within the instance. This name can be used to reference
      the device for mounting, resizing, and so on, from within the instance.
      If not specified, the server chooses a default device name to apply to
      this disk, in the form persistent-disk-x, where x is a number assigned
      by Google Compute Engine. This field is only applicable for persistent
      disks.
    diskEncryptionKey: Encrypts or decrypts a disk using a customer-supplied
      encryption key.  If you are creating a new disk, this field encrypts the
      new disk using an encryption key that you provide. If you are attaching
      an existing disk that is already encrypted, this field decrypts the disk
      using the customer-supplied encryption key.  If you encrypt a disk using
      a customer-supplied key, you must provide the same key again when you
      attempt to use this resource at a later time. For example, you must
      provide the key when you create a snapshot or an image from the disk or
      when you attach the disk to a virtual machine instance.  If you do not
      provide an encryption key, then the disk will be encrypted using an
      automatically generated key and you do not need to provide a key to use
      the disk later.  Instance templates do not store customer-supplied
      encryption keys, so you cannot use your own keys to encrypt disks in a
      managed instance group.
    diskSizeGb: The size of the disk in GB.
    guestOsFeatures: A list of features to enable on the guest operating
      system. Applicable only for bootable images. Read  Enabling guest
      operating system features to see a list of available options.
    index: [Output Only] A zero-based index to this disk, where 0 is reserved
      for the boot disk. If you have many disks attached to an instance, each
      disk would have a unique index number.
    initializeParams: [Input Only] Specifies the parameters for a new disk
      that will be created alongside the new instance. Use initialization
      parameters to create boot disks or local SSDs attached to the new
      instance.  This property is mutually exclusive with the source property;
      you can only define one or the other, but not both.
    interface: Specifies the disk interface to use for attaching this disk,
      which is either SCSI or NVME. The default is SCSI. Persistent disks must
      always use SCSI and the request will fail if you attempt to attach a
      persistent disk in any other format than SCSI. Local SSDs can use either
      NVME or SCSI. For performance characteristics of SCSI over NVMe, see
      Local SSD performance.
    kind: [Output Only] Type of the resource. Always compute#attachedDisk for
      attached disks.
    licenses: [Output Only] Any valid publicly visible licenses.
    mode: The mode in which to attach this disk, either READ_WRITE or
      READ_ONLY. If not specified, the default is to attach the disk in
      READ_WRITE mode.
    savedState: For LocalSSD disks on VM Instances in STOPPED or SUSPENDED
      state, this field is set to PRESERVED if the LocalSSD data has been
      saved to a persistent location by customer request. (see the
      discard_local_ssd option on Stop/Suspend). Read-only in the api.
    shieldedInstanceInitialState: [Output Only] shielded vm initial state
      stored on disk
    source: Specifies a valid partial or full URL to an existing Persistent
      Disk resource. When creating a new instance, one of
      initializeParams.sourceImage or initializeParams.sourceSnapshot or
      disks.source is required except for local SSD.  If desired, you can also
      attach existing non-root persistent disks using this property. This
      field is only applicable for persistent disks.  Note that for
      InstanceTemplate, specify the disk name, not the URL for the disk.
    type: Specifies the type of the disk, either SCRATCH or PERSISTENT. If not
      specified, the default is PERSISTENT.
  """

  class InterfaceValueValuesEnum(_messages.Enum):
    r"""Specifies the disk interface to use for attaching this disk, which is
    either SCSI or NVME. The default is SCSI. Persistent disks must always use
    SCSI and the request will fail if you attempt to attach a persistent disk
    in any other format than SCSI. Local SSDs can use either NVME or SCSI. For
    performance characteristics of SCSI over NVMe, see Local SSD performance.

    Values:
      NVDIMM: <no description>
      NVME: <no description>
      SCSI: <no description>
    """
    NVDIMM = 0
    NVME = 1
    SCSI = 2

  class ModeValueValuesEnum(_messages.Enum):
    r"""The mode in which to attach this disk, either READ_WRITE or READ_ONLY.
    If not specified, the default is to attach the disk in READ_WRITE mode.

    Values:
      READ_ONLY: <no description>
      READ_WRITE: <no description>
    """
    READ_ONLY = 0
    READ_WRITE = 1

  class SavedStateValueValuesEnum(_messages.Enum):
    r"""For LocalSSD disks on VM Instances in STOPPED or SUSPENDED state, this
    field is set to PRESERVED if the LocalSSD data has been saved to a
    persistent location by customer request. (see the discard_local_ssd option
    on Stop/Suspend). Read-only in the api.

    Values:
      DISK_SAVED_STATE_UNSPECIFIED: <no description>
      PRESERVED: <no description>
    """
    DISK_SAVED_STATE_UNSPECIFIED = 0
    PRESERVED = 1

  class TypeValueValuesEnum(_messages.Enum):
    r"""Specifies the type of the disk, either SCRATCH or PERSISTENT. If not
    specified, the default is PERSISTENT.

    Values:
      PERSISTENT: <no description>
      SCRATCH: <no description>
    """
    PERSISTENT = 0
    SCRATCH = 1

  autoDelete = _messages.BooleanField(1)
  boot = _messages.BooleanField(2)
  deviceName = _messages.StringField(3)
  diskEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 4)
  diskSizeGb = _messages.IntegerField(5)
  guestOsFeatures = _messages.MessageField('GuestOsFeature', 6, repeated=True)
  index = _messages.IntegerField(7, variant=_messages.Variant.INT32)
  initializeParams = _messages.MessageField('AttachedDiskInitializeParams', 8)
  interface = _messages.EnumField('InterfaceValueValuesEnum', 9)
  kind = _messages.StringField(10, default=u'compute#attachedDisk')
  licenses = _messages.StringField(11, repeated=True)
  mode = _messages.EnumField('ModeValueValuesEnum', 12)
  savedState = _messages.EnumField('SavedStateValueValuesEnum', 13)
  shieldedInstanceInitialState = _messages.MessageField('InitialStateConfig', 14)
  source = _messages.StringField(15)
  type = _messages.EnumField('TypeValueValuesEnum', 16)


class AttachedDiskInitializeParams(_messages.Message):
  r"""[Input Only] Specifies the parameters for a new disk that will be
  created alongside the new instance. Use initialization parameters to create
  boot disks or local SSDs attached to the new instance.  This property is
  mutually exclusive with the source property; you can only define one or the
  other, but not both.

  Enums:
    OnUpdateActionValueValuesEnum: Specifies which action to take on instance
      update with this disk. Default is to use the existing disk.

  Messages:
    LabelsValue: Labels to apply to this disk. These can be later modified by
      the disks.setLabels method. This field is only applicable for persistent
      disks.

  Fields:
    description: An optional description. Provide this property when creating
      the disk.
    diskName: Specifies the disk name. If not specified, the default is to use
      the name of the instance. If a disk with the same name already exists in
      the given region, the existing disk is attached to the new instance and
      the new disk is not created.
    diskSizeGb: Specifies the size of the disk in base-2 GB. The size must be
      at least 10 GB. If you specify a sourceImage, which is required for boot
      disks, the default size is the size of the sourceImage. If you do not
      specify a sourceImage, the default disk size is 500 GB.
    diskType: Specifies the disk type to use to create the instance. If not
      specified, the default is pd-standard, specified using the full URL. For
      example: https://www.googleapis.com/compute/v1/projects/project/zones/zo
      ne/diskTypes/pd-standard   Other values include pd-ssd and local-ssd. If
      you define this field, you can provide either the full or partial URL.
      For example, the following are valid values:   - https://www.googleapis.
      com/compute/v1/projects/project/zones/zone/diskTypes/diskType  -
      projects/project/zones/zone/diskTypes/diskType  -
      zones/zone/diskTypes/diskType  Note that for InstanceTemplate, this is
      the name of the disk type, not URL.
    guestOsFeatures: A list of features to enable on the guest operating
      system. Applicable only for bootable images. Read  Enabling guest
      operating system features to see a list of available options.  Guest OS
      features are applied by merging initializeParams.guestOsFeatures and
      disks.guestOsFeatures
    labels: Labels to apply to this disk. These can be later modified by the
      disks.setLabels method. This field is only applicable for persistent
      disks.
    onUpdateAction: Specifies which action to take on instance update with
      this disk. Default is to use the existing disk.
    replicaZones: URLs of the zones where the disk should be replicated to.
      Only applicable for regional resources.
    resourcePolicies: Resource policies applied to this disk for automatic
      snapshot creations. Specified using the full or partial URL. For
      instance template, specify only the resource policy name.
    sourceImage: The source image to create this disk. When creating a new
      instance, one of initializeParams.sourceImage or
      initializeParams.sourceSnapshot or disks.source is required except for
      local SSD.  To create a disk with one of the public operating system
      images, specify the image by its family name. For example, specify
      family/debian-9 to use the latest Debian 9 image: projects/debian-
      cloud/global/images/family/debian-9   Alternatively, use a specific
      version of a public operating system image: projects/debian-
      cloud/global/images/debian-9-stretch-vYYYYMMDD   To create a disk with a
      custom image that you created, specify the image name in the following
      format: global/images/my-custom-image   You can also specify a custom
      image by its image family, which returns the latest version of the image
      in that family. Replace the image name with family/family-name:
      global/images/family/my-image-family   If the source image is deleted
      later, this field will not be set.
    sourceImageEncryptionKey: The customer-supplied encryption key of the
      source image. Required if the source image is protected by a customer-
      supplied encryption key.  Instance templates do not store customer-
      supplied encryption keys, so you cannot create disks for instances in a
      managed instance group if the source images are encrypted with your own
      keys.
    sourceSnapshot: The source snapshot to create this disk. When creating a
      new instance, one of initializeParams.sourceSnapshot or
      initializeParams.sourceImage or disks.source is required except for
      local SSD.  To create a disk with a snapshot that you created, specify
      the snapshot name in the following format: global/snapshots/my-backup
      If the source snapshot is deleted later, this field will not be set.
    sourceSnapshotEncryptionKey: The customer-supplied encryption key of the
      source snapshot.
  """

  class OnUpdateActionValueValuesEnum(_messages.Enum):
    r"""Specifies which action to take on instance update with this disk.
    Default is to use the existing disk.

    Values:
      RECREATE_DISK: <no description>
      RECREATE_DISK_IF_SOURCE_CHANGED: <no description>
      USE_EXISTING_DISK: <no description>
    """
    RECREATE_DISK = 0
    RECREATE_DISK_IF_SOURCE_CHANGED = 1
    USE_EXISTING_DISK = 2

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels to apply to this disk. These can be later modified by the
    disks.setLabels method. This field is only applicable for persistent
    disks.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  description = _messages.StringField(1)
  diskName = _messages.StringField(2)
  diskSizeGb = _messages.IntegerField(3)
  diskType = _messages.StringField(4)
  guestOsFeatures = _messages.MessageField('GuestOsFeature', 5, repeated=True)
  labels = _messages.MessageField('LabelsValue', 6)
  onUpdateAction = _messages.EnumField('OnUpdateActionValueValuesEnum', 7)
  replicaZones = _messages.StringField(8, repeated=True)
  resourcePolicies = _messages.StringField(9, repeated=True)
  sourceImage = _messages.StringField(10)
  sourceImageEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 11)
  sourceSnapshot = _messages.StringField(12)
  sourceSnapshotEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 13)


class AuditConfig(_messages.Message):
  r"""Specifies the audit configuration for a service. The configuration
  determines which permission types are logged, and what identities, if any,
  are exempted from logging. An AuditConfig must have one or more
  AuditLogConfigs.  If there are AuditConfigs for both `allServices` and a
  specific service, the union of the two AuditConfigs is used for that
  service: the log_types specified in each AuditConfig are enabled, and the
  exempted_members in each AuditLogConfig are exempted.  Example Policy with
  multiple AuditConfigs:  { "audit_configs": [ { "service": "allServices"
  "audit_log_configs": [ { "log_type": "DATA_READ", "exempted_members": [
  "user:jose@example.com" ] }, { "log_type": "DATA_WRITE", }, { "log_type":
  "ADMIN_READ", } ] }, { "service": "sampleservice.googleapis.com"
  "audit_log_configs": [ { "log_type": "DATA_READ", }, { "log_type":
  "DATA_WRITE", "exempted_members": [ "user:aliya@example.com" ] } ] } ] }
  For sampleservice, this policy enables DATA_READ, DATA_WRITE and ADMIN_READ
  logging. It also exempts jose@example.com from DATA_READ logging, and
  aliya@example.com from DATA_WRITE logging.

  Fields:
    auditLogConfigs: The configuration for logging of each type of permission.
    exemptedMembers:
    service: Specifies a service that will be enabled for audit logging. For
      example, `storage.googleapis.com`, `cloudsql.googleapis.com`.
      `allServices` is a special value that covers all services.
  """

  auditLogConfigs = _messages.MessageField('AuditLogConfig', 1, repeated=True)
  exemptedMembers = _messages.StringField(2, repeated=True)
  service = _messages.StringField(3)


class AuditLogConfig(_messages.Message):
  r"""Provides the configuration for logging a type of permissions. Example:
  { "audit_log_configs": [ { "log_type": "DATA_READ", "exempted_members": [
  "user:jose@example.com" ] }, { "log_type": "DATA_WRITE", } ] }  This enables
  'DATA_READ' and 'DATA_WRITE' logging, while exempting jose@example.com from
  DATA_READ logging.

  Enums:
    LogTypeValueValuesEnum: The log type that this config enables.

  Fields:
    exemptedMembers: Specifies the identities that do not cause logging for
      this type of permission. Follows the same format of [Binding.members][].
    ignoreChildExemptions:
    logType: The log type that this config enables.
  """

  class LogTypeValueValuesEnum(_messages.Enum):
    r"""The log type that this config enables.

    Values:
      ADMIN_READ: <no description>
      DATA_READ: <no description>
      DATA_WRITE: <no description>
      LOG_TYPE_UNSPECIFIED: <no description>
    """
    ADMIN_READ = 0
    DATA_READ = 1
    DATA_WRITE = 2
    LOG_TYPE_UNSPECIFIED = 3

  exemptedMembers = _messages.StringField(1, repeated=True)
  ignoreChildExemptions = _messages.BooleanField(2)
  logType = _messages.EnumField('LogTypeValueValuesEnum', 3)


class AuthenticationPolicy(_messages.Message):
  r"""[Deprecated] The authentication settings for the backend service. The
  authentication settings for the backend service.

  Enums:
    PrincipalBindingValueValuesEnum: Define whether peer or origin identity
      should be used for principal. Default value is USE_PEER. If peer (or
      origin) identity is not available, either because peer/origin
      authentication is not defined, or failed, principal will be left unset.
      In other words, binding rule does not affect the decision to accept or
      reject request. This field can be set to one of the following: USE_PEER:
      Principal will be set to the identity from peer authentication.
      USE_ORIGIN: Principal will be set to the identity from origin
      authentication.

  Fields:
    origins: List of authentication methods that can be used for origin
      authentication. Similar to peers, these will be evaluated in order the
      first valid one will be used to set origin identity. If none of these
      methods pass, the request will be rejected with authentication failed
      error (401). Leave the list empty if origin authentication is not
      required.
    peers: List of authentication methods that can be used for peer
      authentication. They will be evaluated in order the first valid one will
      be used to set peer identity. If none of these methods pass, the request
      will be rejected with authentication failed error (401). Leave the list
      empty if peer authentication is not required.
    principalBinding: Define whether peer or origin identity should be used
      for principal. Default value is USE_PEER. If peer (or origin) identity
      is not available, either because peer/origin authentication is not
      defined, or failed, principal will be left unset. In other words,
      binding rule does not affect the decision to accept or reject request.
      This field can be set to one of the following: USE_PEER: Principal will
      be set to the identity from peer authentication. USE_ORIGIN: Principal
      will be set to the identity from origin authentication.
    serverTlsContext: Configures the mechanism to obtain server-side security
      certificates and identity information.
  """

  class PrincipalBindingValueValuesEnum(_messages.Enum):
    r"""Define whether peer or origin identity should be used for principal.
    Default value is USE_PEER. If peer (or origin) identity is not available,
    either because peer/origin authentication is not defined, or failed,
    principal will be left unset. In other words, binding rule does not affect
    the decision to accept or reject request. This field can be set to one of
    the following: USE_PEER: Principal will be set to the identity from peer
    authentication. USE_ORIGIN: Principal will be set to the identity from
    origin authentication.

    Values:
      INVALID: <no description>
      USE_ORIGIN: <no description>
      USE_PEER: <no description>
    """
    INVALID = 0
    USE_ORIGIN = 1
    USE_PEER = 2

  origins = _messages.MessageField('OriginAuthenticationMethod', 1, repeated=True)
  peers = _messages.MessageField('PeerAuthenticationMethod', 2, repeated=True)
  principalBinding = _messages.EnumField('PrincipalBindingValueValuesEnum', 3)
  serverTlsContext = _messages.MessageField('TlsContext', 4)


class AuthorizationConfig(_messages.Message):
  r"""[Deprecated] Authorization configuration provides service-level and
  method-level access control for a service. control for a service.

  Fields:
    policies: List of RbacPolicies.
  """

  policies = _messages.MessageField('RbacPolicy', 1, repeated=True)


class AuthorizationLoggingOptions(_messages.Message):
  r"""Authorization-related information used by Cloud Audit Logging.

  Enums:
    PermissionTypeValueValuesEnum: The type of the permission that was
      checked.

  Fields:
    permissionType: The type of the permission that was checked.
  """

  class PermissionTypeValueValuesEnum(_messages.Enum):
    r"""The type of the permission that was checked.

    Values:
      ADMIN_READ: <no description>
      ADMIN_WRITE: <no description>
      DATA_READ: <no description>
      DATA_WRITE: <no description>
      PERMISSION_TYPE_UNSPECIFIED: <no description>
    """
    ADMIN_READ = 0
    ADMIN_WRITE = 1
    DATA_READ = 2
    DATA_WRITE = 3
    PERMISSION_TYPE_UNSPECIFIED = 4

  permissionType = _messages.EnumField('PermissionTypeValueValuesEnum', 1)


class Autoscaler(_messages.Message):
  r"""Represents an Autoscaler resource.  Google Compute Engine has two
  Autoscaler resources:  *
  [Global](/compute/docs/reference/rest/{$api_version}/autoscalers) *
  [Regional](/compute/docs/reference/rest/{$api_version}/regionAutoscalers)
  Use autoscalers to automatically add or delete instances from a managed
  instance group according to your defined autoscaling policy. For more
  information, read Autoscaling Groups of Instances.  For zonal managed
  instance groups resource, use the autoscaler resource.  For regional managed
  instance groups, use the regionAutoscalers resource. (== resource_for
  {$api_version}.autoscalers ==) (== resource_for
  {$api_version}.regionAutoscalers ==)

  Enums:
    StatusValueValuesEnum: [Output Only] The status of the autoscaler
      configuration. Current set of possible values:   - PENDING: Autoscaler
      backend hasn't read new/updated configuration.  - DELETING:
      Configuration is being deleted.  - ACTIVE: Configuration is acknowledged
      to be effective. Some warnings might be present in the statusDetails
      field.  - ERROR: Configuration has errors. Actionable for users. Details
      are present in the statusDetails field.  New values might be added in
      the future.

  Fields:
    autoscalingPolicy: The configuration parameters for the autoscaling
      algorithm. You can define one or more of the policies for an autoscaler:
      cpuUtilization, customMetricUtilizations, and loadBalancingUtilization.
      If none of these are specified, the default will be to autoscale based
      on cpuUtilization to 0.6 or 60%.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#autoscaler for
      autoscalers.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    recommendedSize: [Output Only] Target recommended MIG size (number of
      instances) computed by autoscaler. Autoscaler calculates recommended MIG
      size even when autoscaling policy mode is different from ON. This field
      is empty when autoscaler is not connected to the existing managed
      instance group or autoscaler did not generate its prediction.
    region: [Output Only] URL of the region where the instance group resides
      (for autoscalers living in regional scope).
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    status: [Output Only] The status of the autoscaler configuration. Current
      set of possible values:   - PENDING: Autoscaler backend hasn't read
      new/updated configuration.  - DELETING: Configuration is being deleted.
      - ACTIVE: Configuration is acknowledged to be effective. Some warnings
      might be present in the statusDetails field.  - ERROR: Configuration has
      errors. Actionable for users. Details are present in the statusDetails
      field.  New values might be added in the future.
    statusDetails: [Output Only] Human-readable details about the current
      state of the autoscaler. Read the documentation for Commonly returned
      status messages for examples of status messages you might encounter.
    target: URL of the managed instance group that this autoscaler will scale.
    zone: [Output Only] URL of the zone where the instance group resides (for
      autoscalers living in zonal scope).
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the autoscaler configuration. Current set
    of possible values:   - PENDING: Autoscaler backend hasn't read
    new/updated configuration.  - DELETING: Configuration is being deleted.  -
    ACTIVE: Configuration is acknowledged to be effective. Some warnings might
    be present in the statusDetails field.  - ERROR: Configuration has errors.
    Actionable for users. Details are present in the statusDetails field.  New
    values might be added in the future.

    Values:
      ACTIVE: <no description>
      DELETING: <no description>
      ERROR: <no description>
      PENDING: <no description>
    """
    ACTIVE = 0
    DELETING = 1
    ERROR = 2
    PENDING = 3

  autoscalingPolicy = _messages.MessageField('AutoscalingPolicy', 1)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default=u'compute#autoscaler')
  name = _messages.StringField(6)
  recommendedSize = _messages.IntegerField(7, variant=_messages.Variant.INT32)
  region = _messages.StringField(8)
  selfLink = _messages.StringField(9)
  selfLinkWithId = _messages.StringField(10)
  status = _messages.EnumField('StatusValueValuesEnum', 11)
  statusDetails = _messages.MessageField('AutoscalerStatusDetails', 12, repeated=True)
  target = _messages.StringField(13)
  zone = _messages.StringField(14)


class AutoscalerAggregatedList(_messages.Message):
  r"""A AutoscalerAggregatedList object.

  Messages:
    ItemsValue: A list of AutoscalersScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of AutoscalersScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#autoscalerAggregatedList for aggregated lists of autoscalers.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of AutoscalersScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of autoscalers.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A AutoscalersScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('AutoscalersScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#autoscalerAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class AutoscalerList(_messages.Message):
  r"""Contains a list of Autoscaler resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Autoscaler resources.
    kind: [Output Only] Type of resource. Always compute#autoscalerList for
      lists of autoscalers.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Autoscaler', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#autoscalerList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class AutoscalerStatusDetails(_messages.Message):
  r"""A AutoscalerStatusDetails object.

  Enums:
    TypeValueValuesEnum: The type of error, warning, or notice returned.
      Current set of possible values:   - ALL_INSTANCES_UNHEALTHY (WARNING):
      All instances in the instance group are unhealthy (not in RUNNING
      state).  - BACKEND_SERVICE_DOES_NOT_EXIST (ERROR): There is no backend
      service attached to the instance group.  - CAPPED_AT_MAX_NUM_REPLICAS
      (WARNING): Autoscaler recommends a size greater than maxNumReplicas.  -
      CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE (WARNING): The custom metric
      samples are not exported often enough to be a credible base for
      autoscaling.  - CUSTOM_METRIC_INVALID (ERROR): The custom metric that
      was specified does not exist or does not have the necessary labels.  -
      MIN_EQUALS_MAX (WARNING): The minNumReplicas is equal to maxNumReplicas.
      This means the autoscaler cannot add or remove instances from the
      instance group.  - MISSING_CUSTOM_METRIC_DATA_POINTS (WARNING): The
      autoscaler did not receive any data from the custom metric configured
      for autoscaling.  - MISSING_LOAD_BALANCING_DATA_POINTS (WARNING): The
      autoscaler is configured to scale based on a load balancing signal but
      the instance group has not received any requests from the load balancer.
      - MODE_OFF (WARNING): Autoscaling is turned off. The number of instances
      in the group won't change automatically. The autoscaling configuration
      is preserved.  - MODE_ONLY_UP (WARNING): Autoscaling is in the
      "Autoscale only up" mode. The autoscaler can add instances but not
      remove any.  - MORE_THAN_ONE_BACKEND_SERVICE (ERROR): The instance group
      cannot be autoscaled because it has more than one backend service
      attached to it.  - NOT_ENOUGH_QUOTA_AVAILABLE (ERROR): There is
      insufficient quota for the necessary resources, such as CPU or number of
      instances.  - REGION_RESOURCE_STOCKOUT (ERROR): Shown only for regional
      autoscalers: there is a resource stockout in the chosen region.  -
      SCALING_TARGET_DOES_NOT_EXIST (ERROR): The target to be scaled does not
      exist.  - UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION (ERROR):
      Autoscaling does not work with an HTTP/S load balancer that has been
      configured for maxRate.  - ZONE_RESOURCE_STOCKOUT (ERROR): For zonal
      autoscalers: there is a resource stockout in the chosen zone. For
      regional autoscalers: in at least one of the zones you're using there is
      a resource stockout.  New values might be added in the future. Some of
      the values might not be available in all API versions.

  Fields:
    message: The status message.
    type: The type of error, warning, or notice returned. Current set of
      possible values:   - ALL_INSTANCES_UNHEALTHY (WARNING): All instances in
      the instance group are unhealthy (not in RUNNING state).  -
      BACKEND_SERVICE_DOES_NOT_EXIST (ERROR): There is no backend service
      attached to the instance group.  - CAPPED_AT_MAX_NUM_REPLICAS (WARNING):
      Autoscaler recommends a size greater than maxNumReplicas.  -
      CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE (WARNING): The custom metric
      samples are not exported often enough to be a credible base for
      autoscaling.  - CUSTOM_METRIC_INVALID (ERROR): The custom metric that
      was specified does not exist or does not have the necessary labels.  -
      MIN_EQUALS_MAX (WARNING): The minNumReplicas is equal to maxNumReplicas.
      This means the autoscaler cannot add or remove instances from the
      instance group.  - MISSING_CUSTOM_METRIC_DATA_POINTS (WARNING): The
      autoscaler did not receive any data from the custom metric configured
      for autoscaling.  - MISSING_LOAD_BALANCING_DATA_POINTS (WARNING): The
      autoscaler is configured to scale based on a load balancing signal but
      the instance group has not received any requests from the load balancer.
      - MODE_OFF (WARNING): Autoscaling is turned off. The number of instances
      in the group won't change automatically. The autoscaling configuration
      is preserved.  - MODE_ONLY_UP (WARNING): Autoscaling is in the
      "Autoscale only up" mode. The autoscaler can add instances but not
      remove any.  - MORE_THAN_ONE_BACKEND_SERVICE (ERROR): The instance group
      cannot be autoscaled because it has more than one backend service
      attached to it.  - NOT_ENOUGH_QUOTA_AVAILABLE (ERROR): There is
      insufficient quota for the necessary resources, such as CPU or number of
      instances.  - REGION_RESOURCE_STOCKOUT (ERROR): Shown only for regional
      autoscalers: there is a resource stockout in the chosen region.  -
      SCALING_TARGET_DOES_NOT_EXIST (ERROR): The target to be scaled does not
      exist.  - UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION (ERROR):
      Autoscaling does not work with an HTTP/S load balancer that has been
      configured for maxRate.  - ZONE_RESOURCE_STOCKOUT (ERROR): For zonal
      autoscalers: there is a resource stockout in the chosen zone. For
      regional autoscalers: in at least one of the zones you're using there is
      a resource stockout.  New values might be added in the future. Some of
      the values might not be available in all API versions.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""The type of error, warning, or notice returned. Current set of
    possible values:   - ALL_INSTANCES_UNHEALTHY (WARNING): All instances in
    the instance group are unhealthy (not in RUNNING state).  -
    BACKEND_SERVICE_DOES_NOT_EXIST (ERROR): There is no backend service
    attached to the instance group.  - CAPPED_AT_MAX_NUM_REPLICAS (WARNING):
    Autoscaler recommends a size greater than maxNumReplicas.  -
    CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE (WARNING): The custom metric samples
    are not exported often enough to be a credible base for autoscaling.  -
    CUSTOM_METRIC_INVALID (ERROR): The custom metric that was specified does
    not exist or does not have the necessary labels.  - MIN_EQUALS_MAX
    (WARNING): The minNumReplicas is equal to maxNumReplicas. This means the
    autoscaler cannot add or remove instances from the instance group.  -
    MISSING_CUSTOM_METRIC_DATA_POINTS (WARNING): The autoscaler did not
    receive any data from the custom metric configured for autoscaling.  -
    MISSING_LOAD_BALANCING_DATA_POINTS (WARNING): The autoscaler is configured
    to scale based on a load balancing signal but the instance group has not
    received any requests from the load balancer.  - MODE_OFF (WARNING):
    Autoscaling is turned off. The number of instances in the group won't
    change automatically. The autoscaling configuration is preserved.  -
    MODE_ONLY_UP (WARNING): Autoscaling is in the "Autoscale only up" mode.
    The autoscaler can add instances but not remove any.  -
    MORE_THAN_ONE_BACKEND_SERVICE (ERROR): The instance group cannot be
    autoscaled because it has more than one backend service attached to it.  -
    NOT_ENOUGH_QUOTA_AVAILABLE (ERROR): There is insufficient quota for the
    necessary resources, such as CPU or number of instances.  -
    REGION_RESOURCE_STOCKOUT (ERROR): Shown only for regional autoscalers:
    there is a resource stockout in the chosen region.  -
    SCALING_TARGET_DOES_NOT_EXIST (ERROR): The target to be scaled does not
    exist.  - UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION (ERROR):
    Autoscaling does not work with an HTTP/S load balancer that has been
    configured for maxRate.  - ZONE_RESOURCE_STOCKOUT (ERROR): For zonal
    autoscalers: there is a resource stockout in the chosen zone. For regional
    autoscalers: in at least one of the zones you're using there is a resource
    stockout.  New values might be added in the future. Some of the values
    might not be available in all API versions.

    Values:
      ALL_INSTANCES_UNHEALTHY: <no description>
      BACKEND_SERVICE_DOES_NOT_EXIST: <no description>
      CAPPED_AT_MAX_NUM_REPLICAS: <no description>
      CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE: <no description>
      CUSTOM_METRIC_INVALID: <no description>
      MIN_EQUALS_MAX: <no description>
      MISSING_CUSTOM_METRIC_DATA_POINTS: <no description>
      MISSING_LOAD_BALANCING_DATA_POINTS: <no description>
      MODE_OFF: <no description>
      MODE_ONLY_UP: <no description>
      MORE_THAN_ONE_BACKEND_SERVICE: <no description>
      NOT_ENOUGH_QUOTA_AVAILABLE: <no description>
      REGION_RESOURCE_STOCKOUT: <no description>
      SCALING_TARGET_DOES_NOT_EXIST: <no description>
      UNKNOWN: <no description>
      UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION: <no description>
      ZONE_RESOURCE_STOCKOUT: <no description>
    """
    ALL_INSTANCES_UNHEALTHY = 0
    BACKEND_SERVICE_DOES_NOT_EXIST = 1
    CAPPED_AT_MAX_NUM_REPLICAS = 2
    CUSTOM_METRIC_DATA_POINTS_TOO_SPARSE = 3
    CUSTOM_METRIC_INVALID = 4
    MIN_EQUALS_MAX = 5
    MISSING_CUSTOM_METRIC_DATA_POINTS = 6
    MISSING_LOAD_BALANCING_DATA_POINTS = 7
    MODE_OFF = 8
    MODE_ONLY_UP = 9
    MORE_THAN_ONE_BACKEND_SERVICE = 10
    NOT_ENOUGH_QUOTA_AVAILABLE = 11
    REGION_RESOURCE_STOCKOUT = 12
    SCALING_TARGET_DOES_NOT_EXIST = 13
    UNKNOWN = 14
    UNSUPPORTED_MAX_RATE_LOAD_BALANCING_CONFIGURATION = 15
    ZONE_RESOURCE_STOCKOUT = 16

  message = _messages.StringField(1)
  type = _messages.EnumField('TypeValueValuesEnum', 2)


class AutoscalersScopedList(_messages.Message):
  r"""A AutoscalersScopedList object.

  Messages:
    WarningValue: [Output Only] Informational warning which replaces the list
      of autoscalers when the list is empty.

  Fields:
    autoscalers: [Output Only] A list of autoscalers contained in this scope.
    warning: [Output Only] Informational warning which replaces the list of
      autoscalers when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning which replaces the list of
    autoscalers when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  autoscalers = _messages.MessageField('Autoscaler', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class AutoscalingPolicy(_messages.Message):
  r"""Cloud Autoscaler policy.

  Enums:
    ModeValueValuesEnum: Defines operating mode for this policy.

  Fields:
    coolDownPeriodSec: The number of seconds that the autoscaler should wait
      before it starts collecting information from a new instance. This
      prevents the autoscaler from collecting information when the instance is
      initializing, during which the collected usage would not be reliable.
      The default time autoscaler waits is 60 seconds.  Virtual machine
      initialization times might vary because of numerous factors. We
      recommend that you test how long an instance may take to initialize. To
      do this, create an instance and time the startup process.
    cpuUtilization: Defines the CPU utilization policy that allows the
      autoscaler to scale based on the average CPU utilization of a managed
      instance group.
    customMetricUtilizations: Configuration parameters of autoscaling based on
      a custom metric.
    loadBalancingUtilization: Configuration parameters of autoscaling based on
      load balancer.
    maxNumReplicas: The maximum number of instances that the autoscaler can
      scale up to. This is required when creating or updating an autoscaler.
      The maximum number of replicas should not be lower than minimal number
      of replicas.
    minNumReplicas: The minimum number of replicas that the autoscaler can
      scale down to. This cannot be less than 0. If not provided, autoscaler
      will choose a default value depending on maximum number of instances
      allowed.
    mode: Defines operating mode for this policy.
    queueBasedScaling: Configuration parameters of autoscaling based on
      queuing system.
    scaleDownControl: A AutoscalingPolicyScaleDownControl attribute.
    scaleInControl: A AutoscalingPolicyScaleInControl attribute.
  """

  class ModeValueValuesEnum(_messages.Enum):
    r"""Defines operating mode for this policy.

    Values:
      OFF: <no description>
      ON: <no description>
      ONLY_SCALE_OUT: <no description>
      ONLY_UP: <no description>
    """
    OFF = 0
    ON = 1
    ONLY_SCALE_OUT = 2
    ONLY_UP = 3

  coolDownPeriodSec = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  cpuUtilization = _messages.MessageField('AutoscalingPolicyCpuUtilization', 2)
  customMetricUtilizations = _messages.MessageField('AutoscalingPolicyCustomMetricUtilization', 3, repeated=True)
  loadBalancingUtilization = _messages.MessageField('AutoscalingPolicyLoadBalancingUtilization', 4)
  maxNumReplicas = _messages.IntegerField(5, variant=_messages.Variant.INT32)
  minNumReplicas = _messages.IntegerField(6, variant=_messages.Variant.INT32)
  mode = _messages.EnumField('ModeValueValuesEnum', 7)
  queueBasedScaling = _messages.MessageField('AutoscalingPolicyQueueBasedScaling', 8)
  scaleDownControl = _messages.MessageField('AutoscalingPolicyScaleDownControl', 9)
  scaleInControl = _messages.MessageField('AutoscalingPolicyScaleInControl', 10)


class AutoscalingPolicyCpuUtilization(_messages.Message):
  r"""CPU utilization policy.

  Enums:
    PredictiveMethodValueValuesEnum: Indicates which method of prediction is
      used for CPU utilization metric, if any. Current set of possible values:
      * NONE: No predictions are made based on the scaling metric when
      calculating the number of VM instances. * STANDARD: Standard predictive
      autoscaling predicts the future values of the scaling metric and then
      scales a MIG to ensure that new VM instances are ready in time to cover
      the predicted peak. New values might be added in the future. Some of the
      values might not be available in all API versions.

  Fields:
    predictiveMethod: Indicates which method of prediction is used for CPU
      utilization metric, if any. Current set of possible values: * NONE: No
      predictions are made based on the scaling metric when calculating the
      number of VM instances. * STANDARD: Standard predictive autoscaling
      predicts the future values of the scaling metric and then scales a MIG
      to ensure that new VM instances are ready in time to cover the predicted
      peak. New values might be added in the future. Some of the values might
      not be available in all API versions.
    utilizationTarget: The target CPU utilization that the autoscaler should
      maintain. Must be a float value in the range (0, 1]. If not specified,
      the default is 0.6.  If the CPU level is below the target utilization,
      the autoscaler scales down the number of instances until it reaches the
      minimum number of instances you specified or until the average CPU of
      your instances reaches the target utilization.  If the average CPU is
      above the target utilization, the autoscaler scales up until it reaches
      the maximum number of instances you specified or until the average
      utilization reaches the target utilization.
  """

  class PredictiveMethodValueValuesEnum(_messages.Enum):
    r"""Indicates which method of prediction is used for CPU utilization
    metric, if any. Current set of possible values: * NONE: No predictions are
    made based on the scaling metric when calculating the number of VM
    instances. * STANDARD: Standard predictive autoscaling predicts the future
    values of the scaling metric and then scales a MIG to ensure that new VM
    instances are ready in time to cover the predicted peak. New values might
    be added in the future. Some of the values might not be available in all
    API versions.

    Values:
      NONE: <no description>
      PREDICTIVE_METHOD_UNSPECIFIED: <no description>
      STANDARD: <no description>
    """
    NONE = 0
    PREDICTIVE_METHOD_UNSPECIFIED = 1
    STANDARD = 2

  predictiveMethod = _messages.EnumField('PredictiveMethodValueValuesEnum', 1)
  utilizationTarget = _messages.FloatField(2)


class AutoscalingPolicyCustomMetricUtilization(_messages.Message):
  r"""Custom utilization metric policy.

  Enums:
    UtilizationTargetTypeValueValuesEnum: Defines how target utilization value
      is expressed for a Stackdriver Monitoring metric. Either GAUGE,
      DELTA_PER_SECOND, or DELTA_PER_MINUTE.

  Fields:
    filter: A filter string, compatible with a Stackdriver Monitoring filter
      string for TimeSeries.list API call. This filter is used to select a
      specific TimeSeries for the purpose of autoscaling and to determine
      whether the metric is exporting per-instance or per-group data.  For the
      filter to be valid for autoscaling purposes, the following rules apply:
      - You can only use the AND operator for joining selectors.  - You can
      only use direct equality comparison operator (=) without any functions
      for each selector.  - You can specify the metric in both the filter
      string and in the metric field. However, if specified in both places,
      the metric must be identical.  - The monitored resource type determines
      what kind of values are expected for the metric. If it is a
      gce_instance, the autoscaler expects the metric to include a separate
      TimeSeries for each instance in a group. In such a case, you cannot
      filter on resource labels. If the resource type is any other value, the
      autoscaler expects this metric to contain values that apply to the
      entire autoscaled instance group and resource label filtering can be
      performed to point autoscaler at the correct TimeSeries to scale upon.
      This is called a per-group metric for the purpose of autoscaling.  If
      not specified, the type defaults to gce_instance.    You should provide
      a filter that is selective enough to pick just one TimeSeries for the
      autoscaled group or for each of the instances (if you are using
      gce_instance resource type). If multiple TimeSeries are returned upon
      the query execution, the autoscaler will sum their respective values to
      obtain its scaling value.
    metric: The identifier (type) of the Stackdriver Monitoring metric. The
      metric cannot have negative values.  The metric must have a value type
      of INT64 or DOUBLE.
    singleInstanceAssignment: If scaling is based on a per-group metric value
      that represents the total amount of work to be done or resource usage,
      set this value to an amount assigned for a single instance of the scaled
      group. Autoscaler will keep the number of instances proportional to the
      value of this metric, the metric itself should not change value due to
      group resizing.  A good metric to use with the target is for example
      pubsub.googleapis.com/subscription/num_undelivered_messages or a custom
      metric exporting the total number of requests coming to your instances.
      A bad example would be a metric exporting an average or median latency,
      since this value can't include a chunk assignable to a single instance,
      it could be better used with utilization_target instead.
    utilizationTarget: The target value of the metric that autoscaler should
      maintain. This must be a positive value. A utilization metric scales
      number of virtual machines handling requests to increase or decrease
      proportionally to the metric.  For example, a good metric to use as a
      utilization_target is
      compute.googleapis.com/instance/network/received_bytes_count. The
      autoscaler will work to keep this value constant for each of the
      instances.
    utilizationTargetType: Defines how target utilization value is expressed
      for a Stackdriver Monitoring metric. Either GAUGE, DELTA_PER_SECOND, or
      DELTA_PER_MINUTE.
  """

  class UtilizationTargetTypeValueValuesEnum(_messages.Enum):
    r"""Defines how target utilization value is expressed for a Stackdriver
    Monitoring metric. Either GAUGE, DELTA_PER_SECOND, or DELTA_PER_MINUTE.

    Values:
      DELTA_PER_MINUTE: <no description>
      DELTA_PER_SECOND: <no description>
      GAUGE: <no description>
    """
    DELTA_PER_MINUTE = 0
    DELTA_PER_SECOND = 1
    GAUGE = 2

  filter = _messages.StringField(1)
  metric = _messages.StringField(2)
  singleInstanceAssignment = _messages.FloatField(3)
  utilizationTarget = _messages.FloatField(4)
  utilizationTargetType = _messages.EnumField('UtilizationTargetTypeValueValuesEnum', 5)


class AutoscalingPolicyLoadBalancingUtilization(_messages.Message):
  r"""Configuration parameters of autoscaling based on load balancing.

  Fields:
    utilizationTarget: Fraction of backend capacity utilization (set in
      HTTP(S) load balancing configuration) that autoscaler should maintain.
      Must be a positive float value. If not defined, the default is 0.8.
  """

  utilizationTarget = _messages.FloatField(1)


class AutoscalingPolicyQueueBasedScaling(_messages.Message):
  r"""Configuration parameters of autoscaling based on queuing system.

  Fields:
    acceptableBacklogPerInstance: Scaling based on the average number of tasks
      in the queue per each active instance. The autoscaler keeps the average
      number of tasks per instance below this number, based on data collected
      in the last couple of minutes. The autoscaler will also take into
      account incoming tasks when calculating when to scale.
    cloudPubSub: Configuration for Cloud Pub/Sub subscription queue.
    singleWorkerThroughputPerSec: The scaling algorithm will also calculate
      throughput estimates on its own; if you explicitly provide this value,
      the autoscaler will take into account your value as well as automatic
      estimates when deciding how to scale.
  """

  acceptableBacklogPerInstance = _messages.FloatField(1)
  cloudPubSub = _messages.MessageField('AutoscalingPolicyQueueBasedScalingCloudPubSub', 2)
  singleWorkerThroughputPerSec = _messages.FloatField(3)


class AutoscalingPolicyQueueBasedScalingCloudPubSub(_messages.Message):
  r"""Configuration parameters for scaling based on Cloud Pub/Sub subscription
  queue.

  Fields:
    subscription: Cloud Pub/Sub subscription used for scaling. Provide the
      partial URL (starting with projects/) or just the subscription name. The
      subscription must be assigned to the topic specified in topicName and
      must be in a pull configuration. The subscription must belong to the
      same project as the Autoscaler.
    topic: Cloud Pub/Sub topic used for scaling. Provide the partial URL or
      partial URL (starting with projects/) or just the topic name. The topic
      must belong to the same project as the Autoscaler resource.
  """

  subscription = _messages.StringField(1)
  topic = _messages.StringField(2)


class AutoscalingPolicyScaleDownControl(_messages.Message):
  r"""Configuration that allows for slower scale down so that even if
  Autoscaler recommends an abrupt scale down of a MIG, it will be throttled as
  specified by the parameters below.

  Fields:
    maxScaledDownReplicas: Maximum allowed number (or %) of VMs that can be
      deducted from the peak recommendation during the window autoscaler looks
      at when computing recommendations. Possibly all these VMs can be deleted
      at once so user service needs to be prepared to lose that many VMs in
      one step.
    timeWindowSec: How long back autoscaling should look when computing
      recommendations to include directives regarding slower scale down, as
      described above.
  """

  maxScaledDownReplicas = _messages.MessageField('FixedOrPercent', 1)
  timeWindowSec = _messages.IntegerField(2, variant=_messages.Variant.INT32)


class AutoscalingPolicyScaleInControl(_messages.Message):
  r"""Configuration that allows for slower scale in so that even if Autoscaler
  recommends an abrupt scale in of a MIG, it will be throttled as specified by
  the parameters below.

  Fields:
    maxScaledInReplicas: Maximum allowed number (or %) of VMs that can be
      deducted from the peak recommendation during the window autoscaler looks
      at when computing recommendations. Possibly all these VMs can be deleted
      at once so user service needs to be prepared to lose that many VMs in
      one step.
    timeWindowSec: How long back autoscaling should look when computing
      recommendations to include directives regarding slower scale in, as
      described above.
  """

  maxScaledInReplicas = _messages.MessageField('FixedOrPercent', 1)
  timeWindowSec = _messages.IntegerField(2, variant=_messages.Variant.INT32)


class Backend(_messages.Message):
  r"""Message containing information of one individual backend.

  Enums:
    BalancingModeValueValuesEnum: Specifies the balancing mode for the
      backend.  When choosing a balancing mode, you need to consider the
      loadBalancingScheme, and protocol for the backend service, as well as
      the type of backend (instance group or NEG).    - If the load balancing
      mode is CONNECTION, then the load is spread based on how many concurrent
      connections the backend can handle. You can use the CONNECTION balancing
      mode if the protocol for the backend service is SSL, TCP, or UDP.  If
      the loadBalancingScheme for the backend service is EXTERNAL (SSL Proxy
      and TCP Proxy load balancers), you must also specify exactly one of the
      following parameters: maxConnections (except for regional managed
      instance groups), maxConnectionsPerInstance, or
      maxConnectionsPerEndpoint.  If the loadBalancingScheme for the backend
      service is INTERNAL (internal TCP/UDP load balancers), you cannot
      specify any additional parameters.   - If the load balancing mode is
      RATE, the load is spread based on the rate of HTTP requests per second
      (RPS). You can use the RATE balancing mode if the protocol for the
      backend service is HTTP or HTTPS. You must specify exactly one of the
      following parameters: maxRate (except for regional managed instance
      groups), maxRatePerInstance, or maxRatePerEndpoint.   - If the load
      balancing mode is UTILIZATION, the load is spread based on the backend
      utilization of instances in an instance group. You can use the
      UTILIZATION balancing mode if the loadBalancingScheme of the backend
      service is EXTERNAL, INTERNAL_SELF_MANAGED, or INTERNAL_MANAGED and the
      backends are instance groups. There are no restrictions on the backend
      service protocol.

  Fields:
    balancingMode: Specifies the balancing mode for the backend.  When
      choosing a balancing mode, you need to consider the loadBalancingScheme,
      and protocol for the backend service, as well as the type of backend
      (instance group or NEG).    - If the load balancing mode is CONNECTION,
      then the load is spread based on how many concurrent connections the
      backend can handle. You can use the CONNECTION balancing mode if the
      protocol for the backend service is SSL, TCP, or UDP.  If the
      loadBalancingScheme for the backend service is EXTERNAL (SSL Proxy and
      TCP Proxy load balancers), you must also specify exactly one of the
      following parameters: maxConnections (except for regional managed
      instance groups), maxConnectionsPerInstance, or
      maxConnectionsPerEndpoint.  If the loadBalancingScheme for the backend
      service is INTERNAL (internal TCP/UDP load balancers), you cannot
      specify any additional parameters.   - If the load balancing mode is
      RATE, the load is spread based on the rate of HTTP requests per second
      (RPS). You can use the RATE balancing mode if the protocol for the
      backend service is HTTP or HTTPS. You must specify exactly one of the
      following parameters: maxRate (except for regional managed instance
      groups), maxRatePerInstance, or maxRatePerEndpoint.   - If the load
      balancing mode is UTILIZATION, the load is spread based on the backend
      utilization of instances in an instance group. You can use the
      UTILIZATION balancing mode if the loadBalancingScheme of the backend
      service is EXTERNAL, INTERNAL_SELF_MANAGED, or INTERNAL_MANAGED and the
      backends are instance groups. There are no restrictions on the backend
      service protocol.
    capacityScaler: A multiplier applied to the group's maximum servicing
      capacity (based on UTILIZATION, RATE or CONNECTION). Default value is 1,
      which means the group will serve up to 100% of its configured capacity
      (depending on balancingMode). A setting of 0 means the group is
      completely drained, offering 0% of its available Capacity. Valid range
      is [0.0,1.0].  This cannot be used for internal load balancing.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    failover: This field designates whether this is a failover backend. More
      than one failover backend can be configured for a given BackendService.
    group: The fully-qualified URL of an instance group or network endpoint
      group (NEG) resource. The type of backend that a backend service
      supports depends on the backend service's loadBalancingScheme.    - When
      the loadBalancingScheme for the backend service is EXTERNAL,
      INTERNAL_SELF_MANAGED, or INTERNAL_MANAGED, the backend can be either an
      instance group or a NEG. The backends on the backend service must be
      either all instance groups or all NEGs. You cannot mix instance group
      and NEG backends on the same backend service.    - When the
      loadBalancingScheme for the backend service is INTERNAL, the backend
      must be an instance group in the same region as the backend service.
      NEGs are not supported.    You must use the fully-qualified URL
      (starting with https://www.googleapis.com/) to specify the instance
      group or NEG. Partial URLs are not supported.
    maxConnections: Defines a target maximum number of simultaneous
      connections that the backend can handle. Valid for network endpoint
      group and instance group backends (except for regional managed instance
      groups). If the backend's balancingMode is UTILIZATION, this is an
      optional parameter. If the backend's balancingMode is CONNECTION, and
      backend is attached to a backend service whose loadBalancingScheme is
      EXTERNAL, you must specify either this parameter,
      maxConnectionsPerInstance, or maxConnectionsPerEndpoint.  Not available
      if the backend's balancingMode is RATE. If the loadBalancingScheme is
      INTERNAL, then maxConnections is not supported, even though the backend
      requires a balancing mode of CONNECTION.
    maxConnectionsPerEndpoint: Defines a target maximum number of simultaneous
      connections for an endpoint of a NEG. This is multiplied by the number
      of endpoints in the NEG to implicitly calculate a maximum number of
      target maximum simultaneous connections for the NEG. If the backend's
      balancingMode is CONNECTION, and the backend is attached to a backend
      service whose loadBalancingScheme is EXTERNAL, you must specify either
      this parameter, maxConnections, or maxConnectionsPerInstance.  Not
      available if the backend's balancingMode is RATE. Internal TCP/UDP load
      balancing does not support setting maxConnectionsPerEndpoint even though
      its backends require a balancing mode of CONNECTION.
    maxConnectionsPerInstance: Defines a target maximum number of simultaneous
      connections for a single VM in a backend instance group. This is
      multiplied by the number of instances in the instance group to
      implicitly calculate a target maximum number of simultaneous connections
      for the whole instance group. If the backend's balancingMode is
      UTILIZATION, this is an optional parameter. If the backend's
      balancingMode is CONNECTION, and backend is attached to a backend
      service whose loadBalancingScheme is EXTERNAL, you must specify either
      this parameter, maxConnections, or maxConnectionsPerEndpoint.  Not
      available if the backend's balancingMode is RATE. Internal TCP/UDP load
      balancing does not support setting maxConnectionsPerInstance even though
      its backends require a balancing mode of CONNECTION.
    maxRate: Defines a maximum number of HTTP requests per second (RPS) that
      the backend can handle. Valid for network endpoint group and instance
      group backends (except for regional managed instance groups). Must not
      be defined if the backend is a managed instance group that uses
      autoscaling based on load balancing.  If the backend's balancingMode is
      UTILIZATION, this is an optional parameter. If the backend's
      balancingMode is RATE, you must specify maxRate, maxRatePerInstance, or
      maxRatePerEndpoint.  Not available if the backend's balancingMode is
      CONNECTION.
    maxRatePerEndpoint: Defines a maximum target for requests per second (RPS)
      for an endpoint of a NEG. This is multiplied by the number of endpoints
      in the NEG to implicitly calculate a target maximum rate for the NEG.
      If the backend's balancingMode is RATE, you must specify either this
      parameter, maxRate (except for regional managed instance groups), or
      maxRatePerInstance.  Not available if the backend's balancingMode is
      CONNECTION.
    maxRatePerInstance: Defines a maximum target for requests per second (RPS)
      for a single VM in a backend instance group. This is multiplied by the
      number of instances in the instance group to implicitly calculate a
      target maximum rate for the whole instance group.  If the backend's
      balancingMode is UTILIZATION, this is an optional parameter. If the
      backend's balancingMode is RATE, you must specify either this parameter,
      maxRate (except for regional managed instance groups), or
      maxRatePerEndpoint.  Not available if the backend's balancingMode is
      CONNECTION.
    maxUtilization: Defines the maximum average backend utilization of a
      backend VM in an instance group. The valid range is [0.0, 1.0]. This is
      an optional parameter if the backend's balancingMode is UTILIZATION.
      This parameter can be used in conjunction with maxRate,
      maxRatePerInstance, maxConnections (except for regional managed instance
      groups), or maxConnectionsPerInstance.
  """

  class BalancingModeValueValuesEnum(_messages.Enum):
    r"""Specifies the balancing mode for the backend.  When choosing a
    balancing mode, you need to consider the loadBalancingScheme, and protocol
    for the backend service, as well as the type of backend (instance group or
    NEG).    - If the load balancing mode is CONNECTION, then the load is
    spread based on how many concurrent connections the backend can handle.
    You can use the CONNECTION balancing mode if the protocol for the backend
    service is SSL, TCP, or UDP.  If the loadBalancingScheme for the backend
    service is EXTERNAL (SSL Proxy and TCP Proxy load balancers), you must
    also specify exactly one of the following parameters: maxConnections
    (except for regional managed instance groups), maxConnectionsPerInstance,
    or maxConnectionsPerEndpoint.  If the loadBalancingScheme for the backend
    service is INTERNAL (internal TCP/UDP load balancers), you cannot specify
    any additional parameters.   - If the load balancing mode is RATE, the
    load is spread based on the rate of HTTP requests per second (RPS). You
    can use the RATE balancing mode if the protocol for the backend service is
    HTTP or HTTPS. You must specify exactly one of the following parameters:
    maxRate (except for regional managed instance groups), maxRatePerInstance,
    or maxRatePerEndpoint.   - If the load balancing mode is UTILIZATION, the
    load is spread based on the backend utilization of instances in an
    instance group. You can use the UTILIZATION balancing mode if the
    loadBalancingScheme of the backend service is EXTERNAL,
    INTERNAL_SELF_MANAGED, or INTERNAL_MANAGED and the backends are instance
    groups. There are no restrictions on the backend service protocol.

    Values:
      CONNECTION: <no description>
      RATE: <no description>
      UTILIZATION: <no description>
    """
    CONNECTION = 0
    RATE = 1
    UTILIZATION = 2

  balancingMode = _messages.EnumField('BalancingModeValueValuesEnum', 1)
  capacityScaler = _messages.FloatField(2, variant=_messages.Variant.FLOAT)
  description = _messages.StringField(3)
  failover = _messages.BooleanField(4)
  group = _messages.StringField(5)
  maxConnections = _messages.IntegerField(6, variant=_messages.Variant.INT32)
  maxConnectionsPerEndpoint = _messages.IntegerField(7, variant=_messages.Variant.INT32)
  maxConnectionsPerInstance = _messages.IntegerField(8, variant=_messages.Variant.INT32)
  maxRate = _messages.IntegerField(9, variant=_messages.Variant.INT32)
  maxRatePerEndpoint = _messages.FloatField(10, variant=_messages.Variant.FLOAT)
  maxRatePerInstance = _messages.FloatField(11, variant=_messages.Variant.FLOAT)
  maxUtilization = _messages.FloatField(12, variant=_messages.Variant.FLOAT)


class BackendBucket(_messages.Message):
  r"""Represents a Cloud Storage Bucket resource.  This Cloud Storage bucket
  resource is referenced by a URL map of a load balancer. For more
  information, read Backend Buckets.

  Fields:
    bucketName: Cloud Storage bucket name.
    cdnPolicy: Cloud CDN configuration for this BackendBucket.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional textual description of the resource; provided by
      the client when the resource is created.
    enableCdn: If true, enable Cloud CDN for this BackendBucket.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    kind: Type of the resource.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
  """

  bucketName = _messages.StringField(1)
  cdnPolicy = _messages.MessageField('BackendBucketCdnPolicy', 2)
  creationTimestamp = _messages.StringField(3)
  description = _messages.StringField(4)
  enableCdn = _messages.BooleanField(5)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(7, default=u'compute#backendBucket')
  name = _messages.StringField(8)
  selfLink = _messages.StringField(9)
  selfLinkWithId = _messages.StringField(10)


class BackendBucketCdnPolicy(_messages.Message):
  r"""Message containing Cloud CDN configuration for a backend bucket.

  Fields:
    signedUrlCacheMaxAgeSec: Maximum number of seconds the response to a
      signed URL request will be considered fresh. After this time period, the
      response will be revalidated before being served. Defaults to 1hr
      (3600s). When serving responses to signed URL requests, Cloud CDN will
      internally behave as though all responses from this backend had a
      "Cache-Control: public, max-age=[TTL]" header, regardless of any
      existing Cache-Control header. The actual headers served in responses
      will not be altered.
    signedUrlKeyNames: [Output Only] Names of the keys for signing request
      URLs.
  """

  signedUrlCacheMaxAgeSec = _messages.IntegerField(1)
  signedUrlKeyNames = _messages.StringField(2, repeated=True)


class BackendBucketList(_messages.Message):
  r"""Contains a list of BackendBucket resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of BackendBucket resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('BackendBucket', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#backendBucketList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class BackendService(_messages.Message):
  r"""Represents a Backend Service resource.  A backend service contains
  configuration values for Google Cloud Platform load balancing services.
  Backend services in Google Compute Engine can be either regionally or
  globally scoped.  *
  [Global](/compute/docs/reference/rest/{$api_version}/backendServices) * [Reg
  ional](/compute/docs/reference/rest/{$api_version}/regionBackendServices)
  For more information, read Backend Services.  (== resource_for
  {$api_version}.backendService ==)

  Enums:
    LoadBalancingSchemeValueValuesEnum: Specifies the load balancer type.
      Choose EXTERNAL for load balancers that receive traffic from external
      clients. Choose INTERNAL for Internal TCP/UDP Load Balancing. Choose
      INTERNAL_MANAGED for Internal HTTP(S) Load Balancing. Choose
      INTERNAL_SELF_MANAGED for Traffic Director. A backend service created
      for one type of load balancing cannot be used with another. For more
      information, refer to Choosing a load balancer.
    LocalityLbPolicyValueValuesEnum: The load balancing algorithm used within
      the scope of the locality. The possible values are:   - ROUND_ROBIN:
      This is a simple policy in which each healthy backend is selected in
      round robin order. This is the default.  - LEAST_REQUEST: An O(1)
      algorithm which selects two random healthy hosts and picks the host
      which has fewer active requests.  - RING_HASH: The ring/modulo hash load
      balancer implements consistent hashing to backends. The algorithm has
      the property that the addition/removal of a host from a set of N hosts
      only affects 1/N of the requests.  - RANDOM: The load balancer selects a
      random healthy host.  - ORIGINAL_DESTINATION: Backend host is selected
      based on the client connection metadata, i.e., connections are opened to
      the same address as the destination address of the incoming connection
      before the connection was redirected to the load balancer.  - MAGLEV:
      used as a drop in replacement for the ring hash load balancer. Maglev is
      not as stable as ring hash but has faster table lookup build times and
      host selection times. For more information about Maglev, refer to
      https://ai.google/research/pubs/pub44824   This field is applicable to
      either:   - A regional backend service with the service_protocol set to
      HTTP, HTTPS, or HTTP2, and load_balancing_scheme set to
      INTERNAL_MANAGED.  - A global backend service with the
      load_balancing_scheme set to INTERNAL_SELF_MANAGED.    If
      sessionAffinity is not NONE, and this field is not set to >MAGLEV or
      RING_HASH, session affinity settings will not take effect.
    ProtocolValueValuesEnum: The protocol this BackendService uses to
      communicate with backends.  Possible values are HTTP, HTTPS, HTTP2, TCP,
      SSL, or UDP. depending on the chosen load balancer or Traffic Director
      configuration. Refer to the documentation for the load balancer or for
      Traffic Director for more information.
    SessionAffinityValueValuesEnum: Type of session affinity to use. The
      default is NONE. Session affinity is not applicable if the --protocol is
      UDP.  When the loadBalancingScheme is EXTERNAL, possible values are
      NONE, CLIENT_IP, or GENERATED_COOKIE. You can use GENERATED_COOKIE if
      the protocol is HTTP or HTTPS.  When the loadBalancingScheme is
      INTERNAL, possible values are NONE, CLIENT_IP, CLIENT_IP_PROTO, or
      CLIENT_IP_PORT_PROTO.  When the loadBalancingScheme is
      INTERNAL_SELF_MANAGED, or INTERNAL_MANAGED, possible values are NONE,
      CLIENT_IP, GENERATED_COOKIE, HEADER_FIELD, or HTTP_COOKIE.

  Fields:
    affinityCookieTtlSec: If set to 0, the cookie is non-persistent and lasts
      only until the end of the browser session (or equivalent). The maximum
      allowed value is one day (86,400).
    backends: The list of backends that serve this BackendService.
    cdnPolicy: Cloud CDN configuration for this BackendService.
    circuitBreakers: Settings controlling the volume of connections to a
      backend service. If not set, this feature is considered disabled.  This
      field is applicable to either:   - A regional backend service with the
      service_protocol set to HTTP, HTTPS, or HTTP2, and load_balancing_scheme
      set to INTERNAL_MANAGED.  - A global backend service with the
      load_balancing_scheme set to INTERNAL_SELF_MANAGED.
    connectionDraining: A ConnectionDraining attribute.
    consistentHash: Consistent Hash-based load balancing can be used to
      provide soft session affinity based on HTTP headers, cookies or other
      properties. This load balancing policy is applicable only for HTTP
      connections. The affinity to a particular destination host will be lost
      when one or more hosts are added/removed from the destination service.
      This field specifies parameters that control consistent hashing. This
      field is only applicable when localityLbPolicy is set to MAGLEV or
      RING_HASH.  This field is applicable to either:   - A regional backend
      service with the service_protocol set to HTTP, HTTPS, or HTTP2, and
      load_balancing_scheme set to INTERNAL_MANAGED.  - A global backend
      service with the load_balancing_scheme set to INTERNAL_SELF_MANAGED.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    customRequestHeaders: Headers that the HTTP/S load balancer should add to
      proxied requests.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    enableCDN: If true, enables Cloud CDN for the backend service. Only
      applicable if the loadBalancingScheme is EXTERNAL and the protocol is
      HTTP or HTTPS.
    failoverPolicy: Applicable only to Failover for Internal TCP/UDP Load
      Balancing. Requires at least one backend instance group to be defined as
      a backup (failover) backend.
    fingerprint: Fingerprint of this resource. A hash of the contents stored
      in this object. This field is used in optimistic locking. This field
      will be ignored when inserting a BackendService. An up-to-date
      fingerprint must be provided in order to update the BackendService,
      otherwise the request will fail with error 412 conditionNotMet.  To see
      the latest fingerprint, make a get() request to retrieve a
      BackendService.
    healthChecks: The list of URLs to the healthChecks, httpHealthChecks
      (legacy), or httpsHealthChecks (legacy) resource for health checking
      this backend service. Not all backend services support legacy health
      checks. See  Load balancer guide. Currently at most one health check can
      be specified. Backend services with instance group or zonal NEG backends
      must have a health check. Backend services with internet NEG backends
      must not have a health check. A health check must
    iap: A BackendServiceIAP attribute.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of resource. Always compute#backendService for
      backend services.
    loadBalancingScheme: Specifies the load balancer type. Choose EXTERNAL for
      load balancers that receive traffic from external clients. Choose
      INTERNAL for Internal TCP/UDP Load Balancing. Choose INTERNAL_MANAGED
      for Internal HTTP(S) Load Balancing. Choose INTERNAL_SELF_MANAGED for
      Traffic Director. A backend service created for one type of load
      balancing cannot be used with another. For more information, refer to
      Choosing a load balancer.
    localityLbPolicy: The load balancing algorithm used within the scope of
      the locality. The possible values are:   - ROUND_ROBIN: This is a simple
      policy in which each healthy backend is selected in round robin order.
      This is the default.  - LEAST_REQUEST: An O(1) algorithm which selects
      two random healthy hosts and picks the host which has fewer active
      requests.  - RING_HASH: The ring/modulo hash load balancer implements
      consistent hashing to backends. The algorithm has the property that the
      addition/removal of a host from a set of N hosts only affects 1/N of the
      requests.  - RANDOM: The load balancer selects a random healthy host.  -
      ORIGINAL_DESTINATION: Backend host is selected based on the client
      connection metadata, i.e., connections are opened to the same address as
      the destination address of the incoming connection before the connection
      was redirected to the load balancer.  - MAGLEV: used as a drop in
      replacement for the ring hash load balancer. Maglev is not as stable as
      ring hash but has faster table lookup build times and host selection
      times. For more information about Maglev, refer to
      https://ai.google/research/pubs/pub44824   This field is applicable to
      either:   - A regional backend service with the service_protocol set to
      HTTP, HTTPS, or HTTP2, and load_balancing_scheme set to
      INTERNAL_MANAGED.  - A global backend service with the
      load_balancing_scheme set to INTERNAL_SELF_MANAGED.    If
      sessionAffinity is not NONE, and this field is not set to >MAGLEV or
      RING_HASH, session affinity settings will not take effect.
    logConfig: This field denotes the logging options for the load balancer
      traffic served by this backend service. If logging is enabled, logs will
      be exported to Stackdriver.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    network: The URL of the network to which this backend service belongs.
      This field can only be spcified when the load balancing scheme is set to
      INTERNAL.
    outlierDetection: Settings controlling the eviction of unhealthy hosts
      from the load balancing pool for the backend service. If not set, this
      feature is considered disabled.  This field is applicable to either:   -
      A regional backend service with the service_protocol set to HTTP, HTTPS,
      or HTTP2, and load_balancing_scheme set to INTERNAL_MANAGED.  - A global
      backend service with the load_balancing_scheme set to
      INTERNAL_SELF_MANAGED.
    port: Deprecated in favor of portName. The TCP port to connect on the
      backend. The default value is 80.  This cannot be used if the
      loadBalancingScheme is INTERNAL (Internal TCP/UDP Load Balancing).
    portName: A named port on a backend instance group representing the port
      for communication to the backend VMs in that group. Required when the
      loadBalancingScheme is EXTERNAL, INTERNAL_MANAGED, or
      INTERNAL_SELF_MANAGED and the backends are instance groups. The named
      port must be defined on each backend instance group. This parameter has
      no meaning if the backends are NEGs.    Must be omitted when the
      loadBalancingScheme is INTERNAL (Internal TCP/UDP Load Blaancing).
    protocol: The protocol this BackendService uses to communicate with
      backends.  Possible values are HTTP, HTTPS, HTTP2, TCP, SSL, or UDP.
      depending on the chosen load balancer or Traffic Director configuration.
      Refer to the documentation for the load balancer or for Traffic Director
      for more information.
    region: [Output Only] URL of the region where the regional backend service
      resides. This field is not applicable to global backend services. You
      must specify this field as part of the HTTP request URL. It is not
      settable as a field in the request body.
    securityPolicy: [Output Only] The resource URL for the security policy
      associated with this backend service.
    securitySettings: This field specifies the security policy that applies to
      this backend service. This field is applicable to either:   - A regional
      backend service with the service_protocol set to HTTP, HTTPS, or HTTP2,
      and load_balancing_scheme set to INTERNAL_MANAGED.  - A global backend
      service with the load_balancing_scheme set to INTERNAL_SELF_MANAGED.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    sessionAffinity: Type of session affinity to use. The default is NONE.
      Session affinity is not applicable if the --protocol is UDP.  When the
      loadBalancingScheme is EXTERNAL, possible values are NONE, CLIENT_IP, or
      GENERATED_COOKIE. You can use GENERATED_COOKIE if the protocol is HTTP
      or HTTPS.  When the loadBalancingScheme is INTERNAL, possible values are
      NONE, CLIENT_IP, CLIENT_IP_PROTO, or CLIENT_IP_PORT_PROTO.  When the
      loadBalancingScheme is INTERNAL_SELF_MANAGED, or INTERNAL_MANAGED,
      possible values are NONE, CLIENT_IP, GENERATED_COOKIE, HEADER_FIELD, or
      HTTP_COOKIE.
    timeoutSec: The backend service timeout has a different meaning depending
      on the type of load balancer. For more information read,  Backend
      service settings The default is 30 seconds.
  """

  class LoadBalancingSchemeValueValuesEnum(_messages.Enum):
    r"""Specifies the load balancer type. Choose EXTERNAL for load balancers
    that receive traffic from external clients. Choose INTERNAL for Internal
    TCP/UDP Load Balancing. Choose INTERNAL_MANAGED for Internal HTTP(S) Load
    Balancing. Choose INTERNAL_SELF_MANAGED for Traffic Director. A backend
    service created for one type of load balancing cannot be used with
    another. For more information, refer to Choosing a load balancer.

    Values:
      EXTERNAL: <no description>
      INTERNAL: <no description>
      INTERNAL_MANAGED: <no description>
      INTERNAL_SELF_MANAGED: <no description>
      INVALID_LOAD_BALANCING_SCHEME: <no description>
    """
    EXTERNAL = 0
    INTERNAL = 1
    INTERNAL_MANAGED = 2
    INTERNAL_SELF_MANAGED = 3
    INVALID_LOAD_BALANCING_SCHEME = 4

  class LocalityLbPolicyValueValuesEnum(_messages.Enum):
    r"""The load balancing algorithm used within the scope of the locality.
    The possible values are:   - ROUND_ROBIN: This is a simple policy in which
    each healthy backend is selected in round robin order. This is the
    default.  - LEAST_REQUEST: An O(1) algorithm which selects two random
    healthy hosts and picks the host which has fewer active requests.  -
    RING_HASH: The ring/modulo hash load balancer implements consistent
    hashing to backends. The algorithm has the property that the
    addition/removal of a host from a set of N hosts only affects 1/N of the
    requests.  - RANDOM: The load balancer selects a random healthy host.  -
    ORIGINAL_DESTINATION: Backend host is selected based on the client
    connection metadata, i.e., connections are opened to the same address as
    the destination address of the incoming connection before the connection
    was redirected to the load balancer.  - MAGLEV: used as a drop in
    replacement for the ring hash load balancer. Maglev is not as stable as
    ring hash but has faster table lookup build times and host selection
    times. For more information about Maglev, refer to
    https://ai.google/research/pubs/pub44824   This field is applicable to
    either:   - A regional backend service with the service_protocol set to
    HTTP, HTTPS, or HTTP2, and load_balancing_scheme set to INTERNAL_MANAGED.
    - A global backend service with the load_balancing_scheme set to
    INTERNAL_SELF_MANAGED.    If sessionAffinity is not NONE, and this field
    is not set to >MAGLEV or RING_HASH, session affinity settings will not
    take effect.

    Values:
      INVALID_LB_POLICY: <no description>
      LEAST_REQUEST: <no description>
      MAGLEV: <no description>
      ORIGINAL_DESTINATION: <no description>
      RANDOM: <no description>
      RING_HASH: <no description>
      ROUND_ROBIN: <no description>
    """
    INVALID_LB_POLICY = 0
    LEAST_REQUEST = 1
    MAGLEV = 2
    ORIGINAL_DESTINATION = 3
    RANDOM = 4
    RING_HASH = 5
    ROUND_ROBIN = 6

  class ProtocolValueValuesEnum(_messages.Enum):
    r"""The protocol this BackendService uses to communicate with backends.
    Possible values are HTTP, HTTPS, HTTP2, TCP, SSL, or UDP. depending on the
    chosen load balancer or Traffic Director configuration. Refer to the
    documentation for the load balancer or for Traffic Director for more
    information.

    Values:
      GRPC: <no description>
      HTTP: <no description>
      HTTP2: <no description>
      HTTPS: <no description>
      SSL: <no description>
      TCP: <no description>
      UDP: <no description>
    """
    GRPC = 0
    HTTP = 1
    HTTP2 = 2
    HTTPS = 3
    SSL = 4
    TCP = 5
    UDP = 6

  class SessionAffinityValueValuesEnum(_messages.Enum):
    r"""Type of session affinity to use. The default is NONE. Session affinity
    is not applicable if the --protocol is UDP.  When the loadBalancingScheme
    is EXTERNAL, possible values are NONE, CLIENT_IP, or GENERATED_COOKIE. You
    can use GENERATED_COOKIE if the protocol is HTTP or HTTPS.  When the
    loadBalancingScheme is INTERNAL, possible values are NONE, CLIENT_IP,
    CLIENT_IP_PROTO, or CLIENT_IP_PORT_PROTO.  When the loadBalancingScheme is
    INTERNAL_SELF_MANAGED, or INTERNAL_MANAGED, possible values are NONE,
    CLIENT_IP, GENERATED_COOKIE, HEADER_FIELD, or HTTP_COOKIE.

    Values:
      CLIENT_IP: <no description>
      CLIENT_IP_NO_DESTINATION: <no description>
      CLIENT_IP_PORT_PROTO: <no description>
      CLIENT_IP_PROTO: <no description>
      GENERATED_COOKIE: <no description>
      HEADER_FIELD: <no description>
      HTTP_COOKIE: <no description>
      NONE: <no description>
    """
    CLIENT_IP = 0
    CLIENT_IP_NO_DESTINATION = 1
    CLIENT_IP_PORT_PROTO = 2
    CLIENT_IP_PROTO = 3
    GENERATED_COOKIE = 4
    HEADER_FIELD = 5
    HTTP_COOKIE = 6
    NONE = 7

  affinityCookieTtlSec = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  backends = _messages.MessageField('Backend', 2, repeated=True)
  cdnPolicy = _messages.MessageField('BackendServiceCdnPolicy', 3)
  circuitBreakers = _messages.MessageField('CircuitBreakers', 4)
  connectionDraining = _messages.MessageField('ConnectionDraining', 5)
  consistentHash = _messages.MessageField('ConsistentHashLoadBalancerSettings', 6)
  creationTimestamp = _messages.StringField(7)
  customRequestHeaders = _messages.StringField(8, repeated=True)
  description = _messages.StringField(9)
  enableCDN = _messages.BooleanField(10)
  failoverPolicy = _messages.MessageField('BackendServiceFailoverPolicy', 11)
  fingerprint = _messages.BytesField(12)
  healthChecks = _messages.StringField(13, repeated=True)
  iap = _messages.MessageField('BackendServiceIAP', 14)
  id = _messages.IntegerField(15, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(16, default=u'compute#backendService')
  loadBalancingScheme = _messages.EnumField('LoadBalancingSchemeValueValuesEnum', 17)
  localityLbPolicy = _messages.EnumField('LocalityLbPolicyValueValuesEnum', 18)
  logConfig = _messages.MessageField('BackendServiceLogConfig', 19)
  name = _messages.StringField(20)
  network = _messages.StringField(21)
  outlierDetection = _messages.MessageField('OutlierDetection', 22)
  port = _messages.IntegerField(23, variant=_messages.Variant.INT32)
  portName = _messages.StringField(24)
  protocol = _messages.EnumField('ProtocolValueValuesEnum', 25)
  region = _messages.StringField(26)
  securityPolicy = _messages.StringField(27)
  securitySettings = _messages.MessageField('SecuritySettings', 28)
  selfLink = _messages.StringField(29)
  selfLinkWithId = _messages.StringField(30)
  sessionAffinity = _messages.EnumField('SessionAffinityValueValuesEnum', 31)
  timeoutSec = _messages.IntegerField(32, variant=_messages.Variant.INT32)


class BackendServiceAggregatedList(_messages.Message):
  r"""Contains a list of BackendServicesScopedList.

  Messages:
    ItemsValue: A list of BackendServicesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of BackendServicesScopedList resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of BackendServicesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        BackendServices.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A BackendServicesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('BackendServicesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#backendServiceAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class BackendServiceCdnPolicy(_messages.Message):
  r"""Message containing Cloud CDN configuration for a backend service.

  Fields:
    cacheKeyPolicy: The CacheKeyPolicy for this CdnPolicy.
    signedUrlCacheMaxAgeSec: Maximum number of seconds the response to a
      signed URL request will be considered fresh. After this time period, the
      response will be revalidated before being served. Defaults to 1hr
      (3600s). When serving responses to signed URL requests, Cloud CDN will
      internally behave as though all responses from this backend had a
      "Cache-Control: public, max-age=[TTL]" header, regardless of any
      existing Cache-Control header. The actual headers served in responses
      will not be altered.
    signedUrlKeyNames: [Output Only] Names of the keys for signing request
      URLs.
  """

  cacheKeyPolicy = _messages.MessageField('CacheKeyPolicy', 1)
  signedUrlCacheMaxAgeSec = _messages.IntegerField(2)
  signedUrlKeyNames = _messages.StringField(3, repeated=True)


class BackendServiceFailoverPolicy(_messages.Message):
  r"""Applicable only to Failover for Internal TCP/UDP Load Balancing. On
  failover or failback, this field indicates whether connection draining will
  be honored. GCP has a fixed connection draining timeout of 10 minutes. A
  setting of true terminates existing TCP connections to the active pool
  during failover and failback, immediately draining traffic. A setting of
  false allows existing TCP connections to persist, even on VMs no longer in
  the active pool, for up to the duration of the connection draining timeout
  (10 minutes).

  Fields:
    disableConnectionDrainOnFailover: This can be set to true only if the
      protocol is TCP.  The default is false.
    dropTrafficIfUnhealthy: Applicable only to Failover for Internal TCP/UDP
      Load Balancing. If set to true, connections to the load balancer are
      dropped when all primary and all backup backend VMs are unhealthy. If
      set to false, connections are distributed among all primary VMs when all
      primary and all backup backend VMs are unhealthy.  The default is false.
    failoverRatio: Applicable only to Failover for Internal TCP/UDP Load
      Balancing. The value of the field must be in the range [0, 1]. If the
      value is 0, the load balancer performs a failover when the number of
      healthy primary VMs equals zero. For all other values, the load balancer
      performs a failover when the total number of healthy primary VMs is less
      than this ratio.
  """

  disableConnectionDrainOnFailover = _messages.BooleanField(1)
  dropTrafficIfUnhealthy = _messages.BooleanField(2)
  failoverRatio = _messages.FloatField(3, variant=_messages.Variant.FLOAT)


class BackendServiceGroupHealth(_messages.Message):
  r"""A BackendServiceGroupHealth object.

  Messages:
    AnnotationsValue: Metadata defined as annotations on the network endpoint
      group.

  Fields:
    annotations: Metadata defined as annotations on the network endpoint
      group.
    healthStatus: Health state of the backend instances or endpoints in
      requested instance or network endpoint group, determined based on
      configured health checks.
    kind: [Output Only] Type of resource. Always
      compute#backendServiceGroupHealth for the health of backend services.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class AnnotationsValue(_messages.Message):
    r"""Metadata defined as annotations on the network endpoint group.

    Messages:
      AdditionalProperty: An additional property for a AnnotationsValue
        object.

    Fields:
      additionalProperties: Additional properties of type AnnotationsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a AnnotationsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  annotations = _messages.MessageField('AnnotationsValue', 1)
  healthStatus = _messages.MessageField('HealthStatus', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#backendServiceGroupHealth')


class BackendServiceIAP(_messages.Message):
  r"""Identity-Aware Proxy

  Fields:
    enabled: A boolean attribute.
    oauth2ClientId: A string attribute.
    oauth2ClientInfo: [Input Only] OAuth client info required to generate
      client id to be used for IAP.
    oauth2ClientSecret: A string attribute.
    oauth2ClientSecretSha256: [Output Only] SHA256 hash value for the field
      oauth2_client_secret above.
  """

  enabled = _messages.BooleanField(1)
  oauth2ClientId = _messages.StringField(2)
  oauth2ClientInfo = _messages.MessageField('BackendServiceIAPOAuth2ClientInfo', 3)
  oauth2ClientSecret = _messages.StringField(4)
  oauth2ClientSecretSha256 = _messages.StringField(5)


class BackendServiceIAPOAuth2ClientInfo(_messages.Message):
  r"""A BackendServiceIAPOAuth2ClientInfo object.

  Fields:
    applicationName: Application name to be used in OAuth consent screen.
    clientName: Name of the client to be generated. Optional - If not
      provided, the name will be autogenerated by the backend.
    developerEmailAddress: Developer's information to be used in OAuth consent
      screen.
  """

  applicationName = _messages.StringField(1)
  clientName = _messages.StringField(2)
  developerEmailAddress = _messages.StringField(3)


class BackendServiceList(_messages.Message):
  r"""Contains a list of BackendService resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of BackendService resources.
    kind: [Output Only] Type of resource. Always compute#backendServiceList
      for lists of backend services.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('BackendService', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#backendServiceList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class BackendServiceLogConfig(_messages.Message):
  r"""The available logging options for the load balancer traffic served by
  this backend service.

  Fields:
    enable: This field denotes whether to enable logging for the load balancer
      traffic served by this backend service.
    sampleRate: This field can only be specified if logging is enabled for
      this backend service. The value of the field must be in [0, 1]. This
      configures the sampling rate of requests to the load balancer where 1.0
      means all logged requests are reported and 0.0 means no logged requests
      are reported. The default value is 1.0.
  """

  enable = _messages.BooleanField(1)
  sampleRate = _messages.FloatField(2, variant=_messages.Variant.FLOAT)


class BackendServiceReference(_messages.Message):
  r"""A BackendServiceReference object.

  Fields:
    backendService: A string attribute.
  """

  backendService = _messages.StringField(1)


class BackendServicesScopedList(_messages.Message):
  r"""A BackendServicesScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of backend
      services when the list is empty.

  Fields:
    backendServices: A list of BackendServices contained in this scope.
    warning: Informational warning which replaces the list of backend services
      when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of backend services when
    the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  backendServices = _messages.MessageField('BackendService', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class BfdPacket(_messages.Message):
  r"""BfdPacket message type.

  Enums:
    DiagnosticValueValuesEnum: The diagnostic code specifies the local
      system's reason for the last change in session state. This allows remote
      systems to determine the reason that the previous session failed, for
      example. These diagnostic codes are specified in section 4.1 of RFC5880
    StateValueValuesEnum: The current BFD session state as seen by the
      transmitting system. These states are specified in section 4.1 of
      RFC5880

  Fields:
    authenticationPresent: The Authentication Present bit of the BFD packet.
      This is specified in section 4.1 of RFC5880
    controlPlaneIndependent: The Control Plane Independent bit of the BFD
      packet. This is specified in section 4.1 of RFC5880
    demand: The demand bit of the BFD packet. This is specified in section 4.1
      of RFC5880
    diagnostic: The diagnostic code specifies the local system's reason for
      the last change in session state. This allows remote systems to
      determine the reason that the previous session failed, for example.
      These diagnostic codes are specified in section 4.1 of RFC5880
    final: The Final bit of the BFD packet. This is specified in section 4.1
      of RFC5880
    length: The length of the BFD Control packet in bytes. This is specified
      in section 4.1 of RFC5880
    minEchoRxIntervalMs: The Required Min Echo RX Interval value in the BFD
      packet. This is specified in section 4.1 of RFC5880
    minRxIntervalMs: The Required Min RX Interval value in the BFD packet.
      This is specified in section 4.1 of RFC5880
    minTxIntervalMs: The Desired Min TX Interval value in the BFD packet. This
      is specified in section 4.1 of RFC5880
    multiplier: The detection time multiplier of the BFD packet. This is
      specified in section 4.1 of RFC5880
    multipoint: The multipoint bit of the BFD packet. This is specified in
      section 4.1 of RFC5880
    myDiscriminator: The My Discriminator value in the BFD packet. This is
      specified in section 4.1 of RFC5880
    poll: The Poll bit of the BFD packet. This is specified in section 4.1 of
      RFC5880
    state: The current BFD session state as seen by the transmitting system.
      These states are specified in section 4.1 of RFC5880
    version: The version number of the BFD protocol, as specified in section
      4.1 of RFC5880.
    yourDiscriminator: The Your Discriminator value in the BFD packet. This is
      specified in section 4.1 of RFC5880
  """

  class DiagnosticValueValuesEnum(_messages.Enum):
    r"""The diagnostic code specifies the local system's reason for the last
    change in session state. This allows remote systems to determine the
    reason that the previous session failed, for example. These diagnostic
    codes are specified in section 4.1 of RFC5880

    Values:
      ADMINISTRATIVELY_DOWN: <no description>
      CONCATENATED_PATH_DOWN: <no description>
      CONTROL_DETECTION_TIME_EXPIRED: <no description>
      DIAGNOSTIC_UNSPECIFIED: <no description>
      ECHO_FUNCTION_FAILED: <no description>
      FORWARDING_PLANE_RESET: <no description>
      NEIGHBOR_SIGNALED_SESSION_DOWN: <no description>
      NO_DIAGNOSTIC: <no description>
      PATH_DOWN: <no description>
      REVERSE_CONCATENATED_PATH_DOWN: <no description>
    """
    ADMINISTRATIVELY_DOWN = 0
    CONCATENATED_PATH_DOWN = 1
    CONTROL_DETECTION_TIME_EXPIRED = 2
    DIAGNOSTIC_UNSPECIFIED = 3
    ECHO_FUNCTION_FAILED = 4
    FORWARDING_PLANE_RESET = 5
    NEIGHBOR_SIGNALED_SESSION_DOWN = 6
    NO_DIAGNOSTIC = 7
    PATH_DOWN = 8
    REVERSE_CONCATENATED_PATH_DOWN = 9

  class StateValueValuesEnum(_messages.Enum):
    r"""The current BFD session state as seen by the transmitting system.
    These states are specified in section 4.1 of RFC5880

    Values:
      ADMIN_DOWN: <no description>
      DOWN: <no description>
      INIT: <no description>
      STATE_UNSPECIFIED: <no description>
      UP: <no description>
    """
    ADMIN_DOWN = 0
    DOWN = 1
    INIT = 2
    STATE_UNSPECIFIED = 3
    UP = 4

  authenticationPresent = _messages.BooleanField(1)
  controlPlaneIndependent = _messages.BooleanField(2)
  demand = _messages.BooleanField(3)
  diagnostic = _messages.EnumField('DiagnosticValueValuesEnum', 4)
  final = _messages.BooleanField(5)
  length = _messages.IntegerField(6, variant=_messages.Variant.UINT32)
  minEchoRxIntervalMs = _messages.IntegerField(7, variant=_messages.Variant.UINT32)
  minRxIntervalMs = _messages.IntegerField(8, variant=_messages.Variant.UINT32)
  minTxIntervalMs = _messages.IntegerField(9, variant=_messages.Variant.UINT32)
  multiplier = _messages.IntegerField(10, variant=_messages.Variant.UINT32)
  multipoint = _messages.BooleanField(11)
  myDiscriminator = _messages.IntegerField(12, variant=_messages.Variant.UINT32)
  poll = _messages.BooleanField(13)
  state = _messages.EnumField('StateValueValuesEnum', 14)
  version = _messages.IntegerField(15, variant=_messages.Variant.UINT32)
  yourDiscriminator = _messages.IntegerField(16, variant=_messages.Variant.UINT32)


class BfdStatus(_messages.Message):
  r"""Next free: 15

  Enums:
    BfdSessionInitializationModeValueValuesEnum: The BFD session
      initialization mode for this BGP peer. If set to ACTIVE, the Cloud
      Router will initiate the BFD session for this BGP peer. If set to
      PASSIVE, the Cloud Router will wait for the peer router to initiate the
      BFD session for this BGP peer. If set to DISABLED, BFD is disabled for
      this BGP peer.
    LocalDiagnosticValueValuesEnum: The diagnostic code specifies the local
      system's reason for the last change in session state. This allows remote
      systems to determine the reason that the previous session failed, for
      example. These diagnostic codes are specified in section 4.1 of RFC5880
    LocalStateValueValuesEnum: The current BFD session state as seen by the
      transmitting system. These states are specified in section 4.1 of
      RFC5880

  Fields:
    bfdSessionInitializationMode: The BFD session initialization mode for this
      BGP peer. If set to ACTIVE, the Cloud Router will initiate the BFD
      session for this BGP peer. If set to PASSIVE, the Cloud Router will wait
      for the peer router to initiate the BFD session for this BGP peer. If
      set to DISABLED, BFD is disabled for this BGP peer.
    configUpdateTimestampMicros: Unix timestamp of the most recent config
      update.
    controlPacketCounts: Control packet counts for the current BFD session.
    controlPacketIntervals: Inter-packet time interval statistics for control
      packets.
    echoPacketCounts: Echo packet counts for the current BFD session.
    echoPacketIntervals: Inter-packet time interval statistics for echo
      packets.
    localDiagnostic: The diagnostic code specifies the local system's reason
      for the last change in session state. This allows remote systems to
      determine the reason that the previous session failed, for example.
      These diagnostic codes are specified in section 4.1 of RFC5880
    localState: The current BFD session state as seen by the transmitting
      system. These states are specified in section 4.1 of RFC5880
    negotiatedLocalControlTxIntervalMs: Negotiated transmit interval for
      control packets.
    negotiatedLocalEchoTxIntervalMs: Negotiated transmit interval for echo
      packets.
    rxPacket: The most recent Rx control packet for this BFD session.
    txPacket: The most recent Tx control packet for this BFD session.
    uptimeMs: Session uptime in milliseconds. Value will be 0 if session is
      not up.
    usingEchoMode: Indicates if echo mode is currently being used.
  """

  class BfdSessionInitializationModeValueValuesEnum(_messages.Enum):
    r"""The BFD session initialization mode for this BGP peer. If set to
    ACTIVE, the Cloud Router will initiate the BFD session for this BGP peer.
    If set to PASSIVE, the Cloud Router will wait for the peer router to
    initiate the BFD session for this BGP peer. If set to DISABLED, BFD is
    disabled for this BGP peer.

    Values:
      ACTIVE: <no description>
      DISABLED: <no description>
      PASSIVE: <no description>
    """
    ACTIVE = 0
    DISABLED = 1
    PASSIVE = 2

  class LocalDiagnosticValueValuesEnum(_messages.Enum):
    r"""The diagnostic code specifies the local system's reason for the last
    change in session state. This allows remote systems to determine the
    reason that the previous session failed, for example. These diagnostic
    codes are specified in section 4.1 of RFC5880

    Values:
      ADMINISTRATIVELY_DOWN: <no description>
      CONCATENATED_PATH_DOWN: <no description>
      CONTROL_DETECTION_TIME_EXPIRED: <no description>
      DIAGNOSTIC_UNSPECIFIED: <no description>
      ECHO_FUNCTION_FAILED: <no description>
      FORWARDING_PLANE_RESET: <no description>
      NEIGHBOR_SIGNALED_SESSION_DOWN: <no description>
      NO_DIAGNOSTIC: <no description>
      PATH_DOWN: <no description>
      REVERSE_CONCATENATED_PATH_DOWN: <no description>
    """
    ADMINISTRATIVELY_DOWN = 0
    CONCATENATED_PATH_DOWN = 1
    CONTROL_DETECTION_TIME_EXPIRED = 2
    DIAGNOSTIC_UNSPECIFIED = 3
    ECHO_FUNCTION_FAILED = 4
    FORWARDING_PLANE_RESET = 5
    NEIGHBOR_SIGNALED_SESSION_DOWN = 6
    NO_DIAGNOSTIC = 7
    PATH_DOWN = 8
    REVERSE_CONCATENATED_PATH_DOWN = 9

  class LocalStateValueValuesEnum(_messages.Enum):
    r"""The current BFD session state as seen by the transmitting system.
    These states are specified in section 4.1 of RFC5880

    Values:
      ADMIN_DOWN: <no description>
      DOWN: <no description>
      INIT: <no description>
      STATE_UNSPECIFIED: <no description>
      UP: <no description>
    """
    ADMIN_DOWN = 0
    DOWN = 1
    INIT = 2
    STATE_UNSPECIFIED = 3
    UP = 4

  bfdSessionInitializationMode = _messages.EnumField('BfdSessionInitializationModeValueValuesEnum', 1)
  configUpdateTimestampMicros = _messages.IntegerField(2)
  controlPacketCounts = _messages.MessageField('BfdStatusPacketCounts', 3)
  controlPacketIntervals = _messages.MessageField('PacketIntervals', 4, repeated=True)
  echoPacketCounts = _messages.MessageField('BfdStatusPacketCounts', 5)
  echoPacketIntervals = _messages.MessageField('PacketIntervals', 6, repeated=True)
  localDiagnostic = _messages.EnumField('LocalDiagnosticValueValuesEnum', 7)
  localState = _messages.EnumField('LocalStateValueValuesEnum', 8)
  negotiatedLocalControlTxIntervalMs = _messages.IntegerField(9, variant=_messages.Variant.UINT32)
  negotiatedLocalEchoTxIntervalMs = _messages.IntegerField(10, variant=_messages.Variant.UINT32)
  rxPacket = _messages.MessageField('BfdPacket', 11)
  txPacket = _messages.MessageField('BfdPacket', 12)
  uptimeMs = _messages.IntegerField(13)
  usingEchoMode = _messages.BooleanField(14)


class BfdStatusPacketCounts(_messages.Message):
  r"""A BfdStatusPacketCounts object.

  Fields:
    numRx: Number of packets received since the beginning of the current BFD
      session.
    numRxRejected: Number of packets received that were rejected because of
      errors since the beginning of the current BFD session.
    numRxSuccessful: Number of packets received that were successfully
      processed since the beginning of the current BFD session.
    numTx: Number of packets transmitted since the beginning of the current
      BFD session.
  """

  numRx = _messages.IntegerField(1, variant=_messages.Variant.UINT32)
  numRxRejected = _messages.IntegerField(2, variant=_messages.Variant.UINT32)
  numRxSuccessful = _messages.IntegerField(3, variant=_messages.Variant.UINT32)
  numTx = _messages.IntegerField(4, variant=_messages.Variant.UINT32)


class Binding(_messages.Message):
  r"""Associates `members` with a `role`.

  Fields:
    condition: The condition that is associated with this binding. NOTE: An
      unsatisfied condition will not allow user access via current binding.
      Different bindings, including their conditions, are examined
      independently.
    members: Specifies the identities requesting access for a Cloud Platform
      resource. `members` can have the following values:  * `allUsers`: A
      special identifier that represents anyone who is on the internet; with
      or without a Google account.  * `allAuthenticatedUsers`: A special
      identifier that represents anyone who is authenticated with a Google
      account or a service account.  * `user:{emailid}`: An email address that
      represents a specific Google account. For example, `alice@example.com` .
      * `serviceAccount:{emailid}`: An email address that represents a service
      account. For example, `my-other-app@appspot.gserviceaccount.com`.  *
      `group:{emailid}`: An email address that represents a Google group. For
      example, `admins@example.com`.  *
      `deleted:user:{emailid}?uid={uniqueid}`: An email address (plus unique
      identifier) representing a user that has been recently deleted. For
      example, `alice@example.com?uid=123456789012345678901`. If the user is
      recovered, this value reverts to `user:{emailid}` and the recovered user
      retains the role in the binding.  *
      `deleted:serviceAccount:{emailid}?uid={uniqueid}`: An email address
      (plus unique identifier) representing a service account that has been
      recently deleted. For example, `my-other-
      app@appspot.gserviceaccount.com?uid=123456789012345678901`. If the
      service account is undeleted, this value reverts to
      `serviceAccount:{emailid}` and the undeleted service account retains the
      role in the binding.  * `deleted:group:{emailid}?uid={uniqueid}`: An
      email address (plus unique identifier) representing a Google group that
      has been recently deleted. For example,
      `admins@example.com?uid=123456789012345678901`. If the group is
      recovered, this value reverts to `group:{emailid}` and the recovered
      group retains the role in the binding.    * `domain:{domain}`: The G
      Suite domain (primary) that represents all the users of that domain. For
      example, `google.com` or `example.com`.
    role: Role that is assigned to `members`. For example, `roles/viewer`,
      `roles/editor`, or `roles/owner`.
  """

  condition = _messages.MessageField('Expr', 1)
  members = _messages.StringField(2, repeated=True)
  role = _messages.StringField(3)


class BulkInsertInstanceResource(_messages.Message):
  r"""A BulkInsertInstanceResource object.

  Fields:
    count: The maximum number of instances to create.
    excludedZones: List of zones to exclude for regional requests.
    instance: A Instance attribute.
    minCount: The minimum number of instances to create. If no min_count is
      specified then count is used as the default value. If min_count
      instances cannot be created, then no instances will be created.
    predefinedNames: List of predefined names. The number of names provided
      must be equal to count.
    sourceInstanceTemplate: Specifies the instance template from which to
      create the instance. This field is optional. This field is optional. It
      can be a full or partial URL. For example, the following are all valid
      URLs to an instance template:   - https://www.googleapis.com/compute/v1/
      projects/project/global/instanceTemplates/instanceTemplate  -
      projects/project/global/instanceTemplates/instanceTemplate  -
      global/instanceTemplates/instanceTemplate
  """

  count = _messages.IntegerField(1)
  excludedZones = _messages.StringField(2, repeated=True)
  instance = _messages.MessageField('Instance', 3)
  minCount = _messages.IntegerField(4)
  predefinedNames = _messages.StringField(5, repeated=True)
  sourceInstanceTemplate = _messages.StringField(6)


class CacheInvalidationRule(_messages.Message):
  r"""A CacheInvalidationRule object.

  Fields:
    host: If set, this invalidation rule will only apply to requests with a
      Host header matching host.
    path: A string attribute.
  """

  host = _messages.StringField(1)
  path = _messages.StringField(2)


class CacheKeyPolicy(_messages.Message):
  r"""Message containing what to include in the cache key for a request for
  Cloud CDN.

  Fields:
    includeHost: If true, requests to different hosts will be cached
      separately.
    includeProtocol: If true, http and https requests will be cached
      separately.
    includeQueryString: If true, include query string parameters in the cache
      key according to query_string_whitelist and query_string_blacklist. If
      neither is set, the entire query string will be included. If false, the
      query string will be excluded from the cache key entirely.
    queryStringBlacklist: Names of query string parameters to exclude in cache
      keys. All other parameters will be included. Either specify
      query_string_whitelist or query_string_blacklist, not both. '&' and '='
      will be percent encoded and not treated as delimiters.
    queryStringWhitelist: Names of query string parameters to include in cache
      keys. All other parameters will be excluded. Either specify
      query_string_whitelist or query_string_blacklist, not both. '&' and '='
      will be percent encoded and not treated as delimiters.
  """

  includeHost = _messages.BooleanField(1)
  includeProtocol = _messages.BooleanField(2)
  includeQueryString = _messages.BooleanField(3)
  queryStringBlacklist = _messages.StringField(4, repeated=True)
  queryStringWhitelist = _messages.StringField(5, repeated=True)


class CallCredentials(_messages.Message):
  r"""[Deprecated] gRPC call credentials to access the SDS server. gRPC call
  credentials to access the SDS server.

  Enums:
    CallCredentialTypeValueValuesEnum: The type of call credentials to use for
      GRPC requests to the SDS server. This field can be set to one of the
      following:   - GCE_VM: The local GCE VM service account credentials are
      used to access the SDS server. - FROM_PLUGIN: Custom authenticator
      credentials are used to access the SDS server.

  Fields:
    callCredentialType: The type of call credentials to use for GRPC requests
      to the SDS server. This field can be set to one of the following:   -
      GCE_VM: The local GCE VM service account credentials are used to access
      the SDS server. - FROM_PLUGIN: Custom authenticator credentials are used
      to access the SDS server.
    fromPlugin: Custom authenticator credentials. Valid if callCredentialType
      is FROM_PLUGIN.
  """

  class CallCredentialTypeValueValuesEnum(_messages.Enum):
    r"""The type of call credentials to use for GRPC requests to the SDS
    server. This field can be set to one of the following:   - GCE_VM: The
    local GCE VM service account credentials are used to access the SDS
    server. - FROM_PLUGIN: Custom authenticator credentials are used to access
    the SDS server.

    Values:
      FROM_PLUGIN: <no description>
      GCE_VM: <no description>
      INVALID: <no description>
    """
    FROM_PLUGIN = 0
    GCE_VM = 1
    INVALID = 2

  callCredentialType = _messages.EnumField('CallCredentialTypeValueValuesEnum', 1)
  fromPlugin = _messages.MessageField('MetadataCredentialsFromPlugin', 2)


class ChannelCredentials(_messages.Message):
  r"""[Deprecated] gRPC channel credentials to access the SDS server. gRPC
  channel credentials to access the SDS server.

  Enums:
    ChannelCredentialTypeValueValuesEnum: The channel credentials to access
      the SDS server. This field can be set to one of the following:
      CERTIFICATES: Use TLS certificates to access the SDS server. GCE_VM: Use
      local GCE VM credentials to access the SDS server.

  Fields:
    certificates: The call credentials to access the SDS server.
    channelCredentialType: The channel credentials to access the SDS server.
      This field can be set to one of the following: CERTIFICATES: Use TLS
      certificates to access the SDS server. GCE_VM: Use local GCE VM
      credentials to access the SDS server.
  """

  class ChannelCredentialTypeValueValuesEnum(_messages.Enum):
    r"""The channel credentials to access the SDS server. This field can be
    set to one of the following: CERTIFICATES: Use TLS certificates to access
    the SDS server. GCE_VM: Use local GCE VM credentials to access the SDS
    server.

    Values:
      CERTIFICATES: <no description>
      GCE_VM: <no description>
      INVALID: <no description>
    """
    CERTIFICATES = 0
    GCE_VM = 1
    INVALID = 2

  certificates = _messages.MessageField('TlsCertificatePaths', 1)
  channelCredentialType = _messages.EnumField('ChannelCredentialTypeValueValuesEnum', 2)


class CircuitBreakers(_messages.Message):
  r"""Settings controlling the volume of connections to a backend service.

  Fields:
    connectTimeout: The timeout for new network connections to hosts.
    maxConnections: The maximum number of connections to the backend service.
      If not specified, there is no limit.
    maxPendingRequests: The maximum number of pending requests allowed to the
      backend service. If not specified, there is no limit.
    maxRequests: The maximum number of parallel requests that allowed to the
      backend service. If not specified, there is no limit.
    maxRequestsPerConnection: Maximum requests for a single connection to the
      backend service. This parameter is respected by both the HTTP/1.1 and
      HTTP/2 implementations. If not specified, there is no limit. Setting
      this parameter to 1 will effectively disable keep alive.
    maxRetries: The maximum number of parallel retries allowed to the backend
      cluster. If not specified, the default is 1.
  """

  connectTimeout = _messages.MessageField('Duration', 1)
  maxConnections = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  maxPendingRequests = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  maxRequests = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  maxRequestsPerConnection = _messages.IntegerField(5, variant=_messages.Variant.INT32)
  maxRetries = _messages.IntegerField(6, variant=_messages.Variant.INT32)


class ClientTlsSettings(_messages.Message):
  r"""[Deprecated] The client side authentication settings for connection
  originating from the backend service. the backend service.

  Enums:
    ModeValueValuesEnum: Indicates whether connections to this port should be
      secured using TLS. The value of this field determines how TLS is
      enforced. This can be set to one of the following values: DISABLE: Do
      not setup a TLS connection to the backends. SIMPLE: Originate a TLS
      connection to the backends. MUTUAL: Secure connections to the backends
      using mutual TLS by presenting client certificates for authentication.

  Fields:
    clientTlsContext: Configures the mechanism to obtain client-side security
      certificates and identity information. This field is only applicable
      when mode is set to MUTUAL.
    mode: Indicates whether connections to this port should be secured using
      TLS. The value of this field determines how TLS is enforced. This can be
      set to one of the following values: DISABLE: Do not setup a TLS
      connection to the backends. SIMPLE: Originate a TLS connection to the
      backends. MUTUAL: Secure connections to the backends using mutual TLS by
      presenting client certificates for authentication.
    sni: SNI string to present to the server during TLS handshake. This field
      is applicable only when mode is SIMPLE or MUTUAL.
    subjectAltNames: A list of alternate names to verify the subject identity
      in the certificate.If specified, the proxy will verify that the server
      certificate's subject alt name matches one of the specified values. This
      field is applicable only when mode is SIMPLE or MUTUAL.
  """

  class ModeValueValuesEnum(_messages.Enum):
    r"""Indicates whether connections to this port should be secured using
    TLS. The value of this field determines how TLS is enforced. This can be
    set to one of the following values: DISABLE: Do not setup a TLS connection
    to the backends. SIMPLE: Originate a TLS connection to the backends.
    MUTUAL: Secure connections to the backends using mutual TLS by presenting
    client certificates for authentication.

    Values:
      DISABLE: <no description>
      INVALID: <no description>
      MUTUAL: <no description>
      SIMPLE: <no description>
    """
    DISABLE = 0
    INVALID = 1
    MUTUAL = 2
    SIMPLE = 3

  clientTlsContext = _messages.MessageField('TlsContext', 1)
  mode = _messages.EnumField('ModeValueValuesEnum', 2)
  sni = _messages.StringField(3)
  subjectAltNames = _messages.StringField(4, repeated=True)


class Commitment(_messages.Message):
  r"""Represents a regional Commitment resource.  Creating a commitment
  resource means that you are purchasing a committed use contract with an
  explicit start and end time. You can create commitments based on vCPUs and
  memory usage and receive discounted rates. For full details, read Signing Up
  for Committed Use Discounts. (== resource_for
  {$api_version}.regionCommitments ==)

  Enums:
    CategoryValueValuesEnum: The category of the commitment. Category MACHINE
      specifies commitments composed of machine resources such as VCPU or
      MEMORY, listed in resources. Category LICENSE specifies commitments
      composed of software licenses, listed in licenseResources. Note that
      only MACHINE commitments should have a Type specified.
    PlanValueValuesEnum: The plan for this commitment, which determines
      duration and discount rate. The currently supported plans are
      TWELVE_MONTH (1 year), and THIRTY_SIX_MONTH (3 years).
    StatusValueValuesEnum: [Output Only] Status of the commitment with regards
      to eventual expiration (each commitment has an end date defined). One of
      the following values: NOT_YET_ACTIVE, ACTIVE, EXPIRED.
    TypeValueValuesEnum: The type of commitment, which affects the discount
      rate and the eligible resources. Type MEMORY_OPTIMIZED specifies a
      commitment that will only apply to memory optimized machines.

  Fields:
    category: The category of the commitment. Category MACHINE specifies
      commitments composed of machine resources such as VCPU or MEMORY, listed
      in resources. Category LICENSE specifies commitments composed of
      software licenses, listed in licenseResources. Note that only MACHINE
      commitments should have a Type specified.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    endTimestamp: [Output Only] Commitment end time in RFC3339 text format.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#commitment for
      commitments.
    licenseResource: The license specification required as part of a license
      commitment.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    plan: The plan for this commitment, which determines duration and discount
      rate. The currently supported plans are TWELVE_MONTH (1 year), and
      THIRTY_SIX_MONTH (3 years).
    region: [Output Only] URL of the region where this commitment may be used.
    reservations: List of reservations in this commitment.
    resources: A list of commitment amounts for particular resources. Note
      that VCPU and MEMORY resource commitments must occur together.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    startTimestamp: [Output Only] Commitment start time in RFC3339 text
      format.
    status: [Output Only] Status of the commitment with regards to eventual
      expiration (each commitment has an end date defined). One of the
      following values: NOT_YET_ACTIVE, ACTIVE, EXPIRED.
    statusMessage: [Output Only] An optional, human-readable explanation of
      the status.
    type: The type of commitment, which affects the discount rate and the
      eligible resources. Type MEMORY_OPTIMIZED specifies a commitment that
      will only apply to memory optimized machines.
  """

  class CategoryValueValuesEnum(_messages.Enum):
    r"""The category of the commitment. Category MACHINE specifies commitments
    composed of machine resources such as VCPU or MEMORY, listed in resources.
    Category LICENSE specifies commitments composed of software licenses,
    listed in licenseResources. Note that only MACHINE commitments should have
    a Type specified.

    Values:
      CATEGORY_UNSPECIFIED: <no description>
      LICENSE: <no description>
      MACHINE: <no description>
    """
    CATEGORY_UNSPECIFIED = 0
    LICENSE = 1
    MACHINE = 2

  class PlanValueValuesEnum(_messages.Enum):
    r"""The plan for this commitment, which determines duration and discount
    rate. The currently supported plans are TWELVE_MONTH (1 year), and
    THIRTY_SIX_MONTH (3 years).

    Values:
      INVALID: <no description>
      THIRTY_SIX_MONTH: <no description>
      TWELVE_MONTH: <no description>
    """
    INVALID = 0
    THIRTY_SIX_MONTH = 1
    TWELVE_MONTH = 2

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] Status of the commitment with regards to eventual
    expiration (each commitment has an end date defined). One of the following
    values: NOT_YET_ACTIVE, ACTIVE, EXPIRED.

    Values:
      ACTIVE: <no description>
      CREATING: <no description>
      EXPIRED: <no description>
      NOT_YET_ACTIVE: <no description>
    """
    ACTIVE = 0
    CREATING = 1
    EXPIRED = 2
    NOT_YET_ACTIVE = 3

  class TypeValueValuesEnum(_messages.Enum):
    r"""The type of commitment, which affects the discount rate and the
    eligible resources. Type MEMORY_OPTIMIZED specifies a commitment that will
    only apply to memory optimized machines.

    Values:
      COMPUTE_OPTIMIZED: <no description>
      GENERAL_PURPOSE: <no description>
      GENERAL_PURPOSE_E2: <no description>
      GENERAL_PURPOSE_N2: <no description>
      GENERAL_PURPOSE_N2D: <no description>
      MEMORY_OPTIMIZED: <no description>
      TYPE_UNSPECIFIED: <no description>
    """
    COMPUTE_OPTIMIZED = 0
    GENERAL_PURPOSE = 1
    GENERAL_PURPOSE_E2 = 2
    GENERAL_PURPOSE_N2 = 3
    GENERAL_PURPOSE_N2D = 4
    MEMORY_OPTIMIZED = 5
    TYPE_UNSPECIFIED = 6

  category = _messages.EnumField('CategoryValueValuesEnum', 1)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  endTimestamp = _messages.StringField(4)
  id = _messages.IntegerField(5, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(6, default=u'compute#commitment')
  licenseResource = _messages.MessageField('LicenseResourceCommitment', 7)
  name = _messages.StringField(8)
  plan = _messages.EnumField('PlanValueValuesEnum', 9)
  region = _messages.StringField(10)
  reservations = _messages.MessageField('Reservation', 11, repeated=True)
  resources = _messages.MessageField('ResourceCommitment', 12, repeated=True)
  selfLink = _messages.StringField(13)
  selfLinkWithId = _messages.StringField(14)
  startTimestamp = _messages.StringField(15)
  status = _messages.EnumField('StatusValueValuesEnum', 16)
  statusMessage = _messages.StringField(17)
  type = _messages.EnumField('TypeValueValuesEnum', 18)


class CommitmentAggregatedList(_messages.Message):
  r"""A CommitmentAggregatedList object.

  Messages:
    ItemsValue: A list of CommitmentsScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of CommitmentsScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#commitmentAggregatedList for aggregated lists of commitments.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of CommitmentsScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of commitments.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A CommitmentsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('CommitmentsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#commitmentAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class CommitmentList(_messages.Message):
  r"""Contains a list of Commitment resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Commitment resources.
    kind: [Output Only] Type of resource. Always compute#commitmentList for
      lists of commitments.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Commitment', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#commitmentList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class CommitmentsScopedList(_messages.Message):
  r"""A CommitmentsScopedList object.

  Messages:
    WarningValue: [Output Only] Informational warning which replaces the list
      of commitments when the list is empty.

  Fields:
    commitments: [Output Only] A list of commitments contained in this scope.
    warning: [Output Only] Informational warning which replaces the list of
      commitments when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning which replaces the list of
    commitments when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  commitments = _messages.MessageField('Commitment', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class ComputeAcceleratorTypesAggregatedListRequest(_messages.Message):
  r"""A ComputeAcceleratorTypesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeAcceleratorTypesGetRequest(_messages.Message):
  r"""A ComputeAcceleratorTypesGetRequest object.

  Fields:
    acceleratorType: Name of the accelerator type to return.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  acceleratorType = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeAcceleratorTypesListRequest(_messages.Message):
  r"""A ComputeAcceleratorTypesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
    zone: The name of the zone for this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeAddressesAggregatedListRequest(_messages.Message):
  r"""A ComputeAddressesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeAddressesDeleteRequest(_messages.Message):
  r"""A ComputeAddressesDeleteRequest object.

  Fields:
    address: Name of the address resource to delete.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  address = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeAddressesGetRequest(_messages.Message):
  r"""A ComputeAddressesGetRequest object.

  Fields:
    address: Name of the address resource to return.
    project: Project ID for this request.
    region: Name of the region for this request.
  """

  address = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeAddressesInsertRequest(_messages.Message):
  r"""A ComputeAddressesInsertRequest object.

  Fields:
    address: A Address resource to be passed as the request body.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  address = _messages.MessageField('Address', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeAddressesListRequest(_messages.Message):
  r"""A ComputeAddressesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeAddressesSetLabelsRequest(_messages.Message):
  r"""A ComputeAddressesSetLabelsRequest object.

  Fields:
    project: Project ID for this request.
    region: The region for this request.
    regionSetLabelsRequest: A RegionSetLabelsRequest resource to be passed as
      the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetLabelsRequest = _messages.MessageField('RegionSetLabelsRequest', 3)
  requestId = _messages.StringField(4)
  resource = _messages.StringField(5, required=True)


class ComputeAddressesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeAddressesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeAutoscalersAggregatedListRequest(_messages.Message):
  r"""A ComputeAutoscalersAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeAutoscalersDeleteRequest(_messages.Message):
  r"""A ComputeAutoscalersDeleteRequest object.

  Fields:
    autoscaler: Name of the autoscaler to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: Name of the zone for this request.
  """

  autoscaler = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeAutoscalersGetRequest(_messages.Message):
  r"""A ComputeAutoscalersGetRequest object.

  Fields:
    autoscaler: Name of the autoscaler to return.
    project: Project ID for this request.
    zone: Name of the zone for this request.
  """

  autoscaler = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeAutoscalersInsertRequest(_messages.Message):
  r"""A ComputeAutoscalersInsertRequest object.

  Fields:
    autoscaler: A Autoscaler resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: Name of the zone for this request.
  """

  autoscaler = _messages.MessageField('Autoscaler', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeAutoscalersListRequest(_messages.Message):
  r"""A ComputeAutoscalersListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
    zone: Name of the zone for this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeAutoscalersPatchRequest(_messages.Message):
  r"""A ComputeAutoscalersPatchRequest object.

  Fields:
    autoscaler: Name of the autoscaler to patch.
    autoscalerResource: A Autoscaler resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: Name of the zone for this request.
  """

  autoscaler = _messages.StringField(1)
  autoscalerResource = _messages.MessageField('Autoscaler', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeAutoscalersTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeAutoscalersTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
    zone: The name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)
  zone = _messages.StringField(4, required=True)


class ComputeAutoscalersUpdateRequest(_messages.Message):
  r"""A ComputeAutoscalersUpdateRequest object.

  Fields:
    autoscaler: Name of the autoscaler to update.
    autoscalerResource: A Autoscaler resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: Name of the zone for this request.
  """

  autoscaler = _messages.StringField(1)
  autoscalerResource = _messages.MessageField('Autoscaler', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeBackendBucketsAddSignedUrlKeyRequest(_messages.Message):
  r"""A ComputeBackendBucketsAddSignedUrlKeyRequest object.

  Fields:
    backendBucket: Name of the BackendBucket resource to which the Signed URL
      Key should be added. The name should conform to RFC1035.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    signedUrlKey: A SignedUrlKey resource to be passed as the request body.
  """

  backendBucket = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  signedUrlKey = _messages.MessageField('SignedUrlKey', 4)


class ComputeBackendBucketsDeleteRequest(_messages.Message):
  r"""A ComputeBackendBucketsDeleteRequest object.

  Fields:
    backendBucket: Name of the BackendBucket resource to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  backendBucket = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeBackendBucketsDeleteSignedUrlKeyRequest(_messages.Message):
  r"""A ComputeBackendBucketsDeleteSignedUrlKeyRequest object.

  Fields:
    backendBucket: Name of the BackendBucket resource to which the Signed URL
      Key should be added. The name should conform to RFC1035.
    keyName: The name of the Signed URL Key to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  backendBucket = _messages.StringField(1, required=True)
  keyName = _messages.StringField(2, required=True)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeBackendBucketsGetIamPolicyRequest(_messages.Message):
  r"""A ComputeBackendBucketsGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeBackendBucketsGetRequest(_messages.Message):
  r"""A ComputeBackendBucketsGetRequest object.

  Fields:
    backendBucket: Name of the BackendBucket resource to return.
    project: Project ID for this request.
  """

  backendBucket = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeBackendBucketsInsertRequest(_messages.Message):
  r"""A ComputeBackendBucketsInsertRequest object.

  Fields:
    backendBucket: A BackendBucket resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  backendBucket = _messages.MessageField('BackendBucket', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeBackendBucketsListRequest(_messages.Message):
  r"""A ComputeBackendBucketsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeBackendBucketsPatchRequest(_messages.Message):
  r"""A ComputeBackendBucketsPatchRequest object.

  Fields:
    backendBucket: Name of the BackendBucket resource to patch.
    backendBucketResource: A BackendBucket resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  backendBucket = _messages.StringField(1, required=True)
  backendBucketResource = _messages.MessageField('BackendBucket', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeBackendBucketsSetIamPolicyRequest(_messages.Message):
  r"""A ComputeBackendBucketsSetIamPolicyRequest object.

  Fields:
    globalSetPolicyRequest: A GlobalSetPolicyRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetPolicyRequest = _messages.MessageField('GlobalSetPolicyRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeBackendBucketsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeBackendBucketsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeBackendBucketsUpdateRequest(_messages.Message):
  r"""A ComputeBackendBucketsUpdateRequest object.

  Fields:
    backendBucket: Name of the BackendBucket resource to update.
    backendBucketResource: A BackendBucket resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  backendBucket = _messages.StringField(1, required=True)
  backendBucketResource = _messages.MessageField('BackendBucket', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeBackendServicesAddSignedUrlKeyRequest(_messages.Message):
  r"""A ComputeBackendServicesAddSignedUrlKeyRequest object.

  Fields:
    backendService: Name of the BackendService resource to which the Signed
      URL Key should be added. The name should conform to RFC1035.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    signedUrlKey: A SignedUrlKey resource to be passed as the request body.
  """

  backendService = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  signedUrlKey = _messages.MessageField('SignedUrlKey', 4)


class ComputeBackendServicesAggregatedListRequest(_messages.Message):
  r"""A ComputeBackendServicesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Name of the project scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeBackendServicesDeleteRequest(_messages.Message):
  r"""A ComputeBackendServicesDeleteRequest object.

  Fields:
    backendService: Name of the BackendService resource to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  backendService = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeBackendServicesDeleteSignedUrlKeyRequest(_messages.Message):
  r"""A ComputeBackendServicesDeleteSignedUrlKeyRequest object.

  Fields:
    backendService: Name of the BackendService resource to which the Signed
      URL Key should be added. The name should conform to RFC1035.
    keyName: The name of the Signed URL Key to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  backendService = _messages.StringField(1, required=True)
  keyName = _messages.StringField(2, required=True)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeBackendServicesGetHealthRequest(_messages.Message):
  r"""A ComputeBackendServicesGetHealthRequest object.

  Fields:
    backendService: Name of the BackendService resource to which the queried
      instance belongs.
    project: A string attribute.
    resourceGroupReference: A ResourceGroupReference resource to be passed as
      the request body.
  """

  backendService = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  resourceGroupReference = _messages.MessageField('ResourceGroupReference', 3)


class ComputeBackendServicesGetRequest(_messages.Message):
  r"""A ComputeBackendServicesGetRequest object.

  Fields:
    backendService: Name of the BackendService resource to return.
    project: Project ID for this request.
  """

  backendService = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeBackendServicesInsertRequest(_messages.Message):
  r"""A ComputeBackendServicesInsertRequest object.

  Fields:
    backendService: A BackendService resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  backendService = _messages.MessageField('BackendService', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeBackendServicesListRequest(_messages.Message):
  r"""A ComputeBackendServicesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeBackendServicesPatchRequest(_messages.Message):
  r"""A ComputeBackendServicesPatchRequest object.

  Fields:
    backendService: Name of the BackendService resource to patch.
    backendServiceResource: A BackendService resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  backendService = _messages.StringField(1, required=True)
  backendServiceResource = _messages.MessageField('BackendService', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeBackendServicesSetSecurityPolicyRequest(_messages.Message):
  r"""A ComputeBackendServicesSetSecurityPolicyRequest object.

  Fields:
    backendService: Name of the BackendService resource to which the security
      policy should be set. The name should conform to RFC1035.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    securityPolicyReference: A SecurityPolicyReference resource to be passed
      as the request body.
  """

  backendService = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  securityPolicyReference = _messages.MessageField('SecurityPolicyReference', 4)


class ComputeBackendServicesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeBackendServicesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeBackendServicesUpdateRequest(_messages.Message):
  r"""A ComputeBackendServicesUpdateRequest object.

  Fields:
    backendService: Name of the BackendService resource to update.
    backendServiceResource: A BackendService resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  backendService = _messages.StringField(1, required=True)
  backendServiceResource = _messages.MessageField('BackendService', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeDiskTypesAggregatedListRequest(_messages.Message):
  r"""A ComputeDiskTypesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeDiskTypesGetRequest(_messages.Message):
  r"""A ComputeDiskTypesGetRequest object.

  Fields:
    diskType: Name of the disk type to return.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  diskType = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeDiskTypesListRequest(_messages.Message):
  r"""A ComputeDiskTypesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
    zone: The name of the zone for this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeDisksAddResourcePoliciesRequest(_messages.Message):
  r"""A ComputeDisksAddResourcePoliciesRequest object.

  Fields:
    disk: The disk name for this request.
    disksAddResourcePoliciesRequest: A DisksAddResourcePoliciesRequest
      resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  disk = _messages.StringField(1, required=True)
  disksAddResourcePoliciesRequest = _messages.MessageField('DisksAddResourcePoliciesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeDisksAggregatedListRequest(_messages.Message):
  r"""A ComputeDisksAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeDisksCreateSnapshotRequest(_messages.Message):
  r"""A ComputeDisksCreateSnapshotRequest object.

  Fields:
    disk: Name of the persistent disk to snapshot.
    guestFlush: [Input Only] Specifies to create an application consistent
      snapshot by informing the OS to prepare for the snapshot process.
      Currently only supported on Windows instances using the Volume Shadow
      Copy Service (VSS).
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    snapshot: A Snapshot resource to be passed as the request body.
    zone: The name of the zone for this request.
  """

  disk = _messages.StringField(1, required=True)
  guestFlush = _messages.BooleanField(2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  snapshot = _messages.MessageField('Snapshot', 5)
  zone = _messages.StringField(6, required=True)


class ComputeDisksDeleteRequest(_messages.Message):
  r"""A ComputeDisksDeleteRequest object.

  Fields:
    disk: Name of the persistent disk to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  disk = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeDisksGetIamPolicyRequest(_messages.Message):
  r"""A ComputeDisksGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)


class ComputeDisksGetRequest(_messages.Message):
  r"""A ComputeDisksGetRequest object.

  Fields:
    disk: Name of the persistent disk to return.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  disk = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeDisksInsertRequest(_messages.Message):
  r"""A ComputeDisksInsertRequest object.

  Fields:
    disk: A Disk resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    sourceImage: Optional. Source image to restore onto a disk.
    zone: The name of the zone for this request.
  """

  disk = _messages.MessageField('Disk', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  sourceImage = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeDisksListRequest(_messages.Message):
  r"""A ComputeDisksListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
    zone: The name of the zone for this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeDisksRemoveResourcePoliciesRequest(_messages.Message):
  r"""A ComputeDisksRemoveResourcePoliciesRequest object.

  Fields:
    disk: The disk name for this request.
    disksRemoveResourcePoliciesRequest: A DisksRemoveResourcePoliciesRequest
      resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  disk = _messages.StringField(1, required=True)
  disksRemoveResourcePoliciesRequest = _messages.MessageField('DisksRemoveResourcePoliciesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeDisksResizeRequest(_messages.Message):
  r"""A ComputeDisksResizeRequest object.

  Fields:
    disk: The name of the persistent disk.
    disksResizeRequest: A DisksResizeRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  disk = _messages.StringField(1, required=True)
  disksResizeRequest = _messages.MessageField('DisksResizeRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeDisksSetIamPolicyRequest(_messages.Message):
  r"""A ComputeDisksSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
    zoneSetPolicyRequest: A ZoneSetPolicyRequest resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)
  zoneSetPolicyRequest = _messages.MessageField('ZoneSetPolicyRequest', 4)


class ComputeDisksSetLabelsRequest(_messages.Message):
  r"""A ComputeDisksSetLabelsRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
    zoneSetLabelsRequest: A ZoneSetLabelsRequest resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  resource = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)
  zoneSetLabelsRequest = _messages.MessageField('ZoneSetLabelsRequest', 5)


class ComputeDisksTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeDisksTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
    zone: The name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)
  zone = _messages.StringField(4, required=True)


class ComputeExternalVpnGatewaysDeleteRequest(_messages.Message):
  r"""A ComputeExternalVpnGatewaysDeleteRequest object.

  Fields:
    externalVpnGateway: Name of the externalVpnGateways to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  externalVpnGateway = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeExternalVpnGatewaysGetRequest(_messages.Message):
  r"""A ComputeExternalVpnGatewaysGetRequest object.

  Fields:
    externalVpnGateway: Name of the externalVpnGateway to return.
    project: Project ID for this request.
  """

  externalVpnGateway = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeExternalVpnGatewaysInsertRequest(_messages.Message):
  r"""A ComputeExternalVpnGatewaysInsertRequest object.

  Fields:
    externalVpnGateway: A ExternalVpnGateway resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  externalVpnGateway = _messages.MessageField('ExternalVpnGateway', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeExternalVpnGatewaysListRequest(_messages.Message):
  r"""A ComputeExternalVpnGatewaysListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeExternalVpnGatewaysSetLabelsRequest(_messages.Message):
  r"""A ComputeExternalVpnGatewaysSetLabelsRequest object.

  Fields:
    globalSetLabelsRequest: A GlobalSetLabelsRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetLabelsRequest = _messages.MessageField('GlobalSetLabelsRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeExternalVpnGatewaysTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeExternalVpnGatewaysTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeFirewallsDeleteRequest(_messages.Message):
  r"""A ComputeFirewallsDeleteRequest object.

  Fields:
    firewall: Name of the firewall rule to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  firewall = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeFirewallsGetRequest(_messages.Message):
  r"""A ComputeFirewallsGetRequest object.

  Fields:
    firewall: Name of the firewall rule to return.
    project: Project ID for this request.
  """

  firewall = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeFirewallsInsertRequest(_messages.Message):
  r"""A ComputeFirewallsInsertRequest object.

  Fields:
    firewall: A Firewall resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  firewall = _messages.MessageField('Firewall', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeFirewallsListRequest(_messages.Message):
  r"""A ComputeFirewallsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeFirewallsPatchRequest(_messages.Message):
  r"""A ComputeFirewallsPatchRequest object.

  Fields:
    firewall: Name of the firewall rule to patch.
    firewallResource: A Firewall resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  firewall = _messages.StringField(1, required=True)
  firewallResource = _messages.MessageField('Firewall', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeFirewallsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeFirewallsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeFirewallsUpdateRequest(_messages.Message):
  r"""A ComputeFirewallsUpdateRequest object.

  Fields:
    firewall: Name of the firewall rule to update.
    firewallResource: A Firewall resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  firewall = _messages.StringField(1, required=True)
  firewallResource = _messages.MessageField('Firewall', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeForwardingRulesAggregatedListRequest(_messages.Message):
  r"""A ComputeForwardingRulesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeForwardingRulesDeleteRequest(_messages.Message):
  r"""A ComputeForwardingRulesDeleteRequest object.

  Fields:
    forwardingRule: Name of the ForwardingRule resource to delete.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  forwardingRule = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeForwardingRulesGetRequest(_messages.Message):
  r"""A ComputeForwardingRulesGetRequest object.

  Fields:
    forwardingRule: Name of the ForwardingRule resource to return.
    project: Project ID for this request.
    region: Name of the region scoping this request.
  """

  forwardingRule = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeForwardingRulesInsertRequest(_messages.Message):
  r"""A ComputeForwardingRulesInsertRequest object.

  Fields:
    forwardingRule: A ForwardingRule resource to be passed as the request
      body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  forwardingRule = _messages.MessageField('ForwardingRule', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeForwardingRulesListRequest(_messages.Message):
  r"""A ComputeForwardingRulesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeForwardingRulesPatchRequest(_messages.Message):
  r"""A ComputeForwardingRulesPatchRequest object.

  Fields:
    forwardingRule: Name of the ForwardingRule resource to patch.
    forwardingRuleResource: A ForwardingRule resource to be passed as the
      request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  forwardingRule = _messages.StringField(1, required=True)
  forwardingRuleResource = _messages.MessageField('ForwardingRule', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeForwardingRulesSetLabelsRequest(_messages.Message):
  r"""A ComputeForwardingRulesSetLabelsRequest object.

  Fields:
    project: Project ID for this request.
    region: The region for this request.
    regionSetLabelsRequest: A RegionSetLabelsRequest resource to be passed as
      the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetLabelsRequest = _messages.MessageField('RegionSetLabelsRequest', 3)
  requestId = _messages.StringField(4)
  resource = _messages.StringField(5, required=True)


class ComputeForwardingRulesSetTargetRequest(_messages.Message):
  r"""A ComputeForwardingRulesSetTargetRequest object.

  Fields:
    forwardingRule: Name of the ForwardingRule resource in which target is to
      be set.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetReference: A TargetReference resource to be passed as the request
      body.
  """

  forwardingRule = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  targetReference = _messages.MessageField('TargetReference', 5)


class ComputeForwardingRulesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeForwardingRulesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeGlobalAddressesDeleteRequest(_messages.Message):
  r"""A ComputeGlobalAddressesDeleteRequest object.

  Fields:
    address: Name of the address resource to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  address = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeGlobalAddressesGetRequest(_messages.Message):
  r"""A ComputeGlobalAddressesGetRequest object.

  Fields:
    address: Name of the address resource to return.
    project: Project ID for this request.
  """

  address = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeGlobalAddressesInsertRequest(_messages.Message):
  r"""A ComputeGlobalAddressesInsertRequest object.

  Fields:
    address: A Address resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  address = _messages.MessageField('Address', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeGlobalAddressesListRequest(_messages.Message):
  r"""A ComputeGlobalAddressesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeGlobalAddressesSetLabelsRequest(_messages.Message):
  r"""A ComputeGlobalAddressesSetLabelsRequest object.

  Fields:
    globalSetLabelsRequest: A GlobalSetLabelsRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetLabelsRequest = _messages.MessageField('GlobalSetLabelsRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeGlobalAddressesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeGlobalAddressesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeGlobalForwardingRulesDeleteRequest(_messages.Message):
  r"""A ComputeGlobalForwardingRulesDeleteRequest object.

  Fields:
    forwardingRule: Name of the ForwardingRule resource to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  forwardingRule = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeGlobalForwardingRulesGetRequest(_messages.Message):
  r"""A ComputeGlobalForwardingRulesGetRequest object.

  Fields:
    forwardingRule: Name of the ForwardingRule resource to return.
    project: Project ID for this request.
  """

  forwardingRule = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeGlobalForwardingRulesInsertRequest(_messages.Message):
  r"""A ComputeGlobalForwardingRulesInsertRequest object.

  Fields:
    forwardingRule: A ForwardingRule resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  forwardingRule = _messages.MessageField('ForwardingRule', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeGlobalForwardingRulesListRequest(_messages.Message):
  r"""A ComputeGlobalForwardingRulesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeGlobalForwardingRulesPatchRequest(_messages.Message):
  r"""A ComputeGlobalForwardingRulesPatchRequest object.

  Fields:
    forwardingRule: Name of the ForwardingRule resource to patch.
    forwardingRuleResource: A ForwardingRule resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  forwardingRule = _messages.StringField(1, required=True)
  forwardingRuleResource = _messages.MessageField('ForwardingRule', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeGlobalForwardingRulesSetLabelsRequest(_messages.Message):
  r"""A ComputeGlobalForwardingRulesSetLabelsRequest object.

  Fields:
    globalSetLabelsRequest: A GlobalSetLabelsRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetLabelsRequest = _messages.MessageField('GlobalSetLabelsRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeGlobalForwardingRulesSetTargetRequest(_messages.Message):
  r"""A ComputeGlobalForwardingRulesSetTargetRequest object.

  Fields:
    forwardingRule: Name of the ForwardingRule resource in which target is to
      be set.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetReference: A TargetReference resource to be passed as the request
      body.
  """

  forwardingRule = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetReference = _messages.MessageField('TargetReference', 4)


class ComputeGlobalForwardingRulesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeGlobalForwardingRulesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeGlobalNetworkEndpointGroupsAttachNetworkEndpointsRequest(_messages.Message):
  r"""A ComputeGlobalNetworkEndpointGroupsAttachNetworkEndpointsRequest
  object.

  Fields:
    globalNetworkEndpointGroupsAttachEndpointsRequest: A
      GlobalNetworkEndpointGroupsAttachEndpointsRequest resource to be passed
      as the request body.
    networkEndpointGroup: The name of the network endpoint group where you are
      attaching network endpoints to. It should comply with RFC1035.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  globalNetworkEndpointGroupsAttachEndpointsRequest = _messages.MessageField('GlobalNetworkEndpointGroupsAttachEndpointsRequest', 1)
  networkEndpointGroup = _messages.StringField(2, required=True)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeGlobalNetworkEndpointGroupsDeleteRequest(_messages.Message):
  r"""A ComputeGlobalNetworkEndpointGroupsDeleteRequest object.

  Fields:
    networkEndpointGroup: The name of the network endpoint group to delete. It
      should comply with RFC1035.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  networkEndpointGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeGlobalNetworkEndpointGroupsDetachNetworkEndpointsRequest(_messages.Message):
  r"""A ComputeGlobalNetworkEndpointGroupsDetachNetworkEndpointsRequest
  object.

  Fields:
    globalNetworkEndpointGroupsDetachEndpointsRequest: A
      GlobalNetworkEndpointGroupsDetachEndpointsRequest resource to be passed
      as the request body.
    networkEndpointGroup: The name of the network endpoint group where you are
      removing network endpoints. It should comply with RFC1035.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  globalNetworkEndpointGroupsDetachEndpointsRequest = _messages.MessageField('GlobalNetworkEndpointGroupsDetachEndpointsRequest', 1)
  networkEndpointGroup = _messages.StringField(2, required=True)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeGlobalNetworkEndpointGroupsGetRequest(_messages.Message):
  r"""A ComputeGlobalNetworkEndpointGroupsGetRequest object.

  Fields:
    networkEndpointGroup: The name of the network endpoint group. It should
      comply with RFC1035.
    project: Project ID for this request.
  """

  networkEndpointGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeGlobalNetworkEndpointGroupsInsertRequest(_messages.Message):
  r"""A ComputeGlobalNetworkEndpointGroupsInsertRequest object.

  Fields:
    networkEndpointGroup: A NetworkEndpointGroup resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  networkEndpointGroup = _messages.MessageField('NetworkEndpointGroup', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeGlobalNetworkEndpointGroupsListNetworkEndpointsRequest(_messages.Message):
  r"""A ComputeGlobalNetworkEndpointGroupsListNetworkEndpointsRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    networkEndpointGroup: The name of the network endpoint group from which
      you want to generate a list of included network endpoints. It should
      comply with RFC1035.
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  networkEndpointGroup = _messages.StringField(3, required=True)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeGlobalNetworkEndpointGroupsListRequest(_messages.Message):
  r"""A ComputeGlobalNetworkEndpointGroupsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeGlobalOperationsAggregatedListRequest(_messages.Message):
  r"""A ComputeGlobalOperationsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeGlobalOperationsDeleteRequest(_messages.Message):
  r"""A ComputeGlobalOperationsDeleteRequest object.

  Fields:
    operation: Name of the Operations resource to delete.
    project: Project ID for this request.
  """

  operation = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeGlobalOperationsDeleteResponse(_messages.Message):
  r"""An empty ComputeGlobalOperationsDelete response."""


class ComputeGlobalOperationsGetRequest(_messages.Message):
  r"""A ComputeGlobalOperationsGetRequest object.

  Fields:
    operation: Name of the Operations resource to return.
    project: Project ID for this request.
  """

  operation = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeGlobalOperationsListRequest(_messages.Message):
  r"""A ComputeGlobalOperationsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeGlobalOperationsWaitRequest(_messages.Message):
  r"""A ComputeGlobalOperationsWaitRequest object.

  Fields:
    operation: Name of the Operations resource to return.
    project: Project ID for this request.
  """

  operation = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeGlobalOrganizationOperationsDeleteRequest(_messages.Message):
  r"""A ComputeGlobalOrganizationOperationsDeleteRequest object.

  Fields:
    operation: Name of the Operations resource to delete.
    parentId: Parent ID for this request.
  """

  operation = _messages.StringField(1, required=True)
  parentId = _messages.StringField(2)


class ComputeGlobalOrganizationOperationsDeleteResponse(_messages.Message):
  r"""An empty ComputeGlobalOrganizationOperationsDelete response."""


class ComputeGlobalOrganizationOperationsGetRequest(_messages.Message):
  r"""A ComputeGlobalOrganizationOperationsGetRequest object.

  Fields:
    operation: Name of the Operations resource to return.
    parentId: Parent ID for this request.
  """

  operation = _messages.StringField(1, required=True)
  parentId = _messages.StringField(2)


class ComputeGlobalOrganizationOperationsListRequest(_messages.Message):
  r"""A ComputeGlobalOrganizationOperationsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    parentId: Parent ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  parentId = _messages.StringField(5)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeGlobalPublicDelegatedPrefixesDeleteRequest(_messages.Message):
  r"""A ComputeGlobalPublicDelegatedPrefixesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    publicDelegatedPrefix: Name of the PublicDelegatedPrefix resource to
      delete.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  publicDelegatedPrefix = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeGlobalPublicDelegatedPrefixesGetRequest(_messages.Message):
  r"""A ComputeGlobalPublicDelegatedPrefixesGetRequest object.

  Fields:
    project: Project ID for this request.
    publicDelegatedPrefix: Name of the PublicDelegatedPrefix resource to
      return.
  """

  project = _messages.StringField(1, required=True)
  publicDelegatedPrefix = _messages.StringField(2, required=True)


class ComputeGlobalPublicDelegatedPrefixesInsertRequest(_messages.Message):
  r"""A ComputeGlobalPublicDelegatedPrefixesInsertRequest object.

  Fields:
    project: Project ID for this request.
    publicDelegatedPrefix: A PublicDelegatedPrefix resource to be passed as
      the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  publicDelegatedPrefix = _messages.MessageField('PublicDelegatedPrefix', 2)
  requestId = _messages.StringField(3)


class ComputeGlobalPublicDelegatedPrefixesListRequest(_messages.Message):
  r"""A ComputeGlobalPublicDelegatedPrefixesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeGlobalPublicDelegatedPrefixesPatchRequest(_messages.Message):
  r"""A ComputeGlobalPublicDelegatedPrefixesPatchRequest object.

  Fields:
    project: Project ID for this request.
    publicDelegatedPrefix: Name of the PublicDelegatedPrefix resource to
      patch.
    publicDelegatedPrefixResource: A PublicDelegatedPrefix resource to be
      passed as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  publicDelegatedPrefix = _messages.StringField(2, required=True)
  publicDelegatedPrefixResource = _messages.MessageField('PublicDelegatedPrefix', 3)
  requestId = _messages.StringField(4)


class ComputeHealthChecksAggregatedListRequest(_messages.Message):
  r"""A ComputeHealthChecksAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Name of the project scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeHealthChecksDeleteRequest(_messages.Message):
  r"""A ComputeHealthChecksDeleteRequest object.

  Fields:
    healthCheck: Name of the HealthCheck resource to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  healthCheck = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeHealthChecksGetRequest(_messages.Message):
  r"""A ComputeHealthChecksGetRequest object.

  Fields:
    healthCheck: Name of the HealthCheck resource to return.
    project: Project ID for this request.
  """

  healthCheck = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeHealthChecksInsertRequest(_messages.Message):
  r"""A ComputeHealthChecksInsertRequest object.

  Fields:
    healthCheck: A HealthCheck resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  healthCheck = _messages.MessageField('HealthCheck', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeHealthChecksListRequest(_messages.Message):
  r"""A ComputeHealthChecksListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeHealthChecksPatchRequest(_messages.Message):
  r"""A ComputeHealthChecksPatchRequest object.

  Fields:
    healthCheck: Name of the HealthCheck resource to patch.
    healthCheckResource: A HealthCheck resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  healthCheck = _messages.StringField(1, required=True)
  healthCheckResource = _messages.MessageField('HealthCheck', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeHealthChecksTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeHealthChecksTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeHealthChecksUpdateRequest(_messages.Message):
  r"""A ComputeHealthChecksUpdateRequest object.

  Fields:
    healthCheck: Name of the HealthCheck resource to update.
    healthCheckResource: A HealthCheck resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  healthCheck = _messages.StringField(1, required=True)
  healthCheckResource = _messages.MessageField('HealthCheck', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeHttpHealthChecksDeleteRequest(_messages.Message):
  r"""A ComputeHttpHealthChecksDeleteRequest object.

  Fields:
    httpHealthCheck: Name of the HttpHealthCheck resource to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  httpHealthCheck = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeHttpHealthChecksGetRequest(_messages.Message):
  r"""A ComputeHttpHealthChecksGetRequest object.

  Fields:
    httpHealthCheck: Name of the HttpHealthCheck resource to return.
    project: Project ID for this request.
  """

  httpHealthCheck = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeHttpHealthChecksInsertRequest(_messages.Message):
  r"""A ComputeHttpHealthChecksInsertRequest object.

  Fields:
    httpHealthCheck: A HttpHealthCheck resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  httpHealthCheck = _messages.MessageField('HttpHealthCheck', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeHttpHealthChecksListRequest(_messages.Message):
  r"""A ComputeHttpHealthChecksListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeHttpHealthChecksPatchRequest(_messages.Message):
  r"""A ComputeHttpHealthChecksPatchRequest object.

  Fields:
    httpHealthCheck: Name of the HttpHealthCheck resource to patch.
    httpHealthCheckResource: A HttpHealthCheck resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  httpHealthCheck = _messages.StringField(1, required=True)
  httpHealthCheckResource = _messages.MessageField('HttpHealthCheck', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeHttpHealthChecksTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeHttpHealthChecksTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeHttpHealthChecksUpdateRequest(_messages.Message):
  r"""A ComputeHttpHealthChecksUpdateRequest object.

  Fields:
    httpHealthCheck: Name of the HttpHealthCheck resource to update.
    httpHealthCheckResource: A HttpHealthCheck resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  httpHealthCheck = _messages.StringField(1, required=True)
  httpHealthCheckResource = _messages.MessageField('HttpHealthCheck', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeHttpsHealthChecksDeleteRequest(_messages.Message):
  r"""A ComputeHttpsHealthChecksDeleteRequest object.

  Fields:
    httpsHealthCheck: Name of the HttpsHealthCheck resource to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  httpsHealthCheck = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeHttpsHealthChecksGetRequest(_messages.Message):
  r"""A ComputeHttpsHealthChecksGetRequest object.

  Fields:
    httpsHealthCheck: Name of the HttpsHealthCheck resource to return.
    project: Project ID for this request.
  """

  httpsHealthCheck = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeHttpsHealthChecksInsertRequest(_messages.Message):
  r"""A ComputeHttpsHealthChecksInsertRequest object.

  Fields:
    httpsHealthCheck: A HttpsHealthCheck resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  httpsHealthCheck = _messages.MessageField('HttpsHealthCheck', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeHttpsHealthChecksListRequest(_messages.Message):
  r"""A ComputeHttpsHealthChecksListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeHttpsHealthChecksPatchRequest(_messages.Message):
  r"""A ComputeHttpsHealthChecksPatchRequest object.

  Fields:
    httpsHealthCheck: Name of the HttpsHealthCheck resource to patch.
    httpsHealthCheckResource: A HttpsHealthCheck resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  httpsHealthCheck = _messages.StringField(1, required=True)
  httpsHealthCheckResource = _messages.MessageField('HttpsHealthCheck', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeHttpsHealthChecksTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeHttpsHealthChecksTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeHttpsHealthChecksUpdateRequest(_messages.Message):
  r"""A ComputeHttpsHealthChecksUpdateRequest object.

  Fields:
    httpsHealthCheck: Name of the HttpsHealthCheck resource to update.
    httpsHealthCheckResource: A HttpsHealthCheck resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  httpsHealthCheck = _messages.StringField(1, required=True)
  httpsHealthCheckResource = _messages.MessageField('HttpsHealthCheck', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeImagesDeleteRequest(_messages.Message):
  r"""A ComputeImagesDeleteRequest object.

  Fields:
    image: Name of the image resource to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  image = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeImagesDeprecateRequest(_messages.Message):
  r"""A ComputeImagesDeprecateRequest object.

  Fields:
    deprecationStatus: A DeprecationStatus resource to be passed as the
      request body.
    image: Image name.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  deprecationStatus = _messages.MessageField('DeprecationStatus', 1)
  image = _messages.StringField(2, required=True)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeImagesGetFromFamilyRequest(_messages.Message):
  r"""A ComputeImagesGetFromFamilyRequest object.

  Fields:
    family: Name of the image family to search for.
    project: Project ID for this request.
  """

  family = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeImagesGetIamPolicyRequest(_messages.Message):
  r"""A ComputeImagesGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeImagesGetRequest(_messages.Message):
  r"""A ComputeImagesGetRequest object.

  Fields:
    image: Name of the image resource to return.
    project: Project ID for this request.
  """

  image = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeImagesInsertRequest(_messages.Message):
  r"""A ComputeImagesInsertRequest object.

  Fields:
    forceCreate: Force image creation if true.
    image: A Image resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  forceCreate = _messages.BooleanField(1)
  image = _messages.MessageField('Image', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeImagesListRequest(_messages.Message):
  r"""A ComputeImagesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeImagesPatchRequest(_messages.Message):
  r"""A ComputeImagesPatchRequest object.

  Fields:
    image: Name of the image resource to patch.
    imageResource: A Image resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  image = _messages.StringField(1, required=True)
  imageResource = _messages.MessageField('Image', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeImagesSetIamPolicyRequest(_messages.Message):
  r"""A ComputeImagesSetIamPolicyRequest object.

  Fields:
    globalSetPolicyRequest: A GlobalSetPolicyRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetPolicyRequest = _messages.MessageField('GlobalSetPolicyRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeImagesSetLabelsRequest(_messages.Message):
  r"""A ComputeImagesSetLabelsRequest object.

  Fields:
    globalSetLabelsRequest: A GlobalSetLabelsRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetLabelsRequest = _messages.MessageField('GlobalSetLabelsRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeImagesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeImagesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeInstanceGroupManagersAbandonInstancesRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersAbandonInstancesRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group.
    instanceGroupManagersAbandonInstancesRequest: A
      InstanceGroupManagersAbandonInstancesRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the managed instance group is located.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersAbandonInstancesRequest = _messages.MessageField('InstanceGroupManagersAbandonInstancesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersAggregatedListRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeInstanceGroupManagersApplyUpdatesToInstancesRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersApplyUpdatesToInstancesRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group, should
      conform to RFC1035.
    instanceGroupManagersApplyUpdatesRequest: A
      InstanceGroupManagersApplyUpdatesRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    zone: The name of the zone where the managed instance group is located.
      Should conform to RFC1035.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersApplyUpdatesRequest = _messages.MessageField('InstanceGroupManagersApplyUpdatesRequest', 2)
  project = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)


class ComputeInstanceGroupManagersCreateInstancesRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersCreateInstancesRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group. It should
      conform to RFC1035.
    instanceGroupManagersCreateInstancesRequest: A
      InstanceGroupManagersCreateInstancesRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request.  The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the managed instance group is located. It
      should conform to RFC1035.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersCreateInstancesRequest = _messages.MessageField('InstanceGroupManagersCreateInstancesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersDeleteInstancesRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersDeleteInstancesRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group.
    instanceGroupManagersDeleteInstancesRequest: A
      InstanceGroupManagersDeleteInstancesRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the managed instance group is located.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersDeleteInstancesRequest = _messages.MessageField('InstanceGroupManagersDeleteInstancesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersDeletePerInstanceConfigsRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersDeletePerInstanceConfigsRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group. It should
      conform to RFC1035.
    instanceGroupManagersDeletePerInstanceConfigsReq: A
      InstanceGroupManagersDeletePerInstanceConfigsReq resource to be passed
      as the request body.
    project: Project ID for this request.
    zone: The name of the zone where the managed instance group is located. It
      should conform to RFC1035.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersDeletePerInstanceConfigsReq = _messages.MessageField('InstanceGroupManagersDeletePerInstanceConfigsReq', 2)
  project = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)


class ComputeInstanceGroupManagersDeleteRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersDeleteRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the managed instance group is located.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeInstanceGroupManagersGetRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersGetRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group.
    project: Project ID for this request.
    zone: The name of the zone where the managed instance group is located.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeInstanceGroupManagersInsertRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersInsertRequest object.

  Fields:
    instanceGroupManager: A InstanceGroupManager resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where you want to create the managed instance
      group.
  """

  instanceGroupManager = _messages.MessageField('InstanceGroupManager', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeInstanceGroupManagersListErrorsRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersListErrorsRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    instanceGroupManager: The name of the managed instance group. It must be a
      string that meets the requirements in RFC1035, or an unsigned long
      integer: must match regexp pattern:
      (?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?)|[1-9][0-9]{0,19}.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
    zone: The name of the zone where the managed instance group is located. It
      should conform to RFC1035.
  """

  filter = _messages.StringField(1)
  instanceGroupManager = _messages.StringField(2, required=True)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  zone = _messages.StringField(8, required=True)


class ComputeInstanceGroupManagersListManagedInstancesRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersListManagedInstancesRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    instanceGroupManager: The name of the managed instance group.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    zone: The name of the zone where the managed instance group is located.
  """

  filter = _messages.StringField(1)
  instanceGroupManager = _messages.StringField(2, required=True)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  zone = _messages.StringField(7, required=True)


class ComputeInstanceGroupManagersListPerInstanceConfigsRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersListPerInstanceConfigsRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    instanceGroupManager: The name of the managed instance group. It should
      conform to RFC1035.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
    zone: The name of the zone where the managed instance group is located. It
      should conform to RFC1035.
  """

  filter = _messages.StringField(1)
  instanceGroupManager = _messages.StringField(2, required=True)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  zone = _messages.StringField(8, required=True)


class ComputeInstanceGroupManagersListRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
    zone: The name of the zone where the managed instance group is located.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeInstanceGroupManagersPatchPerInstanceConfigsRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersPatchPerInstanceConfigsRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group. It should
      conform to RFC1035.
    instanceGroupManagersPatchPerInstanceConfigsReq: A
      InstanceGroupManagersPatchPerInstanceConfigsReq resource to be passed as
      the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the managed instance group is located. It
      should conform to RFC1035.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersPatchPerInstanceConfigsReq = _messages.MessageField('InstanceGroupManagersPatchPerInstanceConfigsReq', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersPatchRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersPatchRequest object.

  Fields:
    instanceGroupManager: The name of the instance group manager.
    instanceGroupManagerResource: A InstanceGroupManager resource to be passed
      as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where you want to create the managed instance
      group.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagerResource = _messages.MessageField('InstanceGroupManager', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersRecreateInstancesRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersRecreateInstancesRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group.
    instanceGroupManagersRecreateInstancesRequest: A
      InstanceGroupManagersRecreateInstancesRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the managed instance group is located.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersRecreateInstancesRequest = _messages.MessageField('InstanceGroupManagersRecreateInstancesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersResizeAdvancedRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersResizeAdvancedRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group.
    instanceGroupManagersResizeAdvancedRequest: A
      InstanceGroupManagersResizeAdvancedRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the managed instance group is located.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersResizeAdvancedRequest = _messages.MessageField('InstanceGroupManagersResizeAdvancedRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersResizeRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersResizeRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    size: The number of running instances that the managed instance group
      should maintain at any given time. The group automatically adds or
      removes instances to maintain the number of instances specified by this
      parameter.
    zone: The name of the zone where the managed instance group is located.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  size = _messages.IntegerField(4, required=True, variant=_messages.Variant.INT32)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersSetAutoHealingPoliciesRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersSetAutoHealingPoliciesRequest object.

  Fields:
    instanceGroupManager: The name of the instance group manager.
    instanceGroupManagersSetAutoHealingRequest: A
      InstanceGroupManagersSetAutoHealingRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the managed instance group is located.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersSetAutoHealingRequest = _messages.MessageField('InstanceGroupManagersSetAutoHealingRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersSetInstanceTemplateRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersSetInstanceTemplateRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group.
    instanceGroupManagersSetInstanceTemplateRequest: A
      InstanceGroupManagersSetInstanceTemplateRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the managed instance group is located.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersSetInstanceTemplateRequest = _messages.MessageField('InstanceGroupManagersSetInstanceTemplateRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersSetTargetPoolsRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersSetTargetPoolsRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group.
    instanceGroupManagersSetTargetPoolsRequest: A
      InstanceGroupManagersSetTargetPoolsRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the managed instance group is located.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersSetTargetPoolsRequest = _messages.MessageField('InstanceGroupManagersSetTargetPoolsRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
    zone: The name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)
  zone = _messages.StringField(4, required=True)


class ComputeInstanceGroupManagersUpdatePerInstanceConfigsRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersUpdatePerInstanceConfigsRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group. It should
      conform to RFC1035.
    instanceGroupManagersUpdatePerInstanceConfigsReq: A
      InstanceGroupManagersUpdatePerInstanceConfigsReq resource to be passed
      as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the managed instance group is located. It
      should conform to RFC1035.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagersUpdatePerInstanceConfigsReq = _messages.MessageField('InstanceGroupManagersUpdatePerInstanceConfigsReq', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupManagersUpdateRequest(_messages.Message):
  r"""A ComputeInstanceGroupManagersUpdateRequest object.

  Fields:
    instanceGroupManager: The name of the instance group manager.
    instanceGroupManagerResource: A InstanceGroupManager resource to be passed
      as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where you want to create the managed instance
      group.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagerResource = _messages.MessageField('InstanceGroupManager', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupsAddInstancesRequest(_messages.Message):
  r"""A ComputeInstanceGroupsAddInstancesRequest object.

  Fields:
    instanceGroup: The name of the instance group where you are adding
      instances.
    instanceGroupsAddInstancesRequest: A InstanceGroupsAddInstancesRequest
      resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the instance group is located.
  """

  instanceGroup = _messages.StringField(1, required=True)
  instanceGroupsAddInstancesRequest = _messages.MessageField('InstanceGroupsAddInstancesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupsAggregatedListRequest(_messages.Message):
  r"""A ComputeInstanceGroupsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeInstanceGroupsDeleteRequest(_messages.Message):
  r"""A ComputeInstanceGroupsDeleteRequest object.

  Fields:
    instanceGroup: The name of the instance group to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the instance group is located.
  """

  instanceGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeInstanceGroupsGetRequest(_messages.Message):
  r"""A ComputeInstanceGroupsGetRequest object.

  Fields:
    instanceGroup: The name of the instance group.
    project: Project ID for this request.
    zone: The name of the zone where the instance group is located.
  """

  instanceGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeInstanceGroupsInsertRequest(_messages.Message):
  r"""A ComputeInstanceGroupsInsertRequest object.

  Fields:
    instanceGroup: A InstanceGroup resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where you want to create the instance group.
  """

  instanceGroup = _messages.MessageField('InstanceGroup', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeInstanceGroupsListInstancesRequest(_messages.Message):
  r"""A ComputeInstanceGroupsListInstancesRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    instanceGroup: The name of the instance group from which you want to
      generate a list of included instances.
    instanceGroupsListInstancesRequest: A InstanceGroupsListInstancesRequest
      resource to be passed as the request body.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
    zone: The name of the zone where the instance group is located.
  """

  filter = _messages.StringField(1)
  instanceGroup = _messages.StringField(2, required=True)
  instanceGroupsListInstancesRequest = _messages.MessageField('InstanceGroupsListInstancesRequest', 3)
  maxResults = _messages.IntegerField(4, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(5)
  pageToken = _messages.StringField(6)
  project = _messages.StringField(7, required=True)
  returnPartialSuccess = _messages.BooleanField(8)
  zone = _messages.StringField(9, required=True)


class ComputeInstanceGroupsListRequest(_messages.Message):
  r"""A ComputeInstanceGroupsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
    zone: The name of the zone where the instance group is located.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeInstanceGroupsRemoveInstancesRequest(_messages.Message):
  r"""A ComputeInstanceGroupsRemoveInstancesRequest object.

  Fields:
    instanceGroup: The name of the instance group where the specified
      instances will be removed.
    instanceGroupsRemoveInstancesRequest: A
      InstanceGroupsRemoveInstancesRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the instance group is located.
  """

  instanceGroup = _messages.StringField(1, required=True)
  instanceGroupsRemoveInstancesRequest = _messages.MessageField('InstanceGroupsRemoveInstancesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupsSetNamedPortsRequest(_messages.Message):
  r"""A ComputeInstanceGroupsSetNamedPortsRequest object.

  Fields:
    instanceGroup: The name of the instance group where the named ports are
      updated.
    instanceGroupsSetNamedPortsRequest: A InstanceGroupsSetNamedPortsRequest
      resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the instance group is located.
  """

  instanceGroup = _messages.StringField(1, required=True)
  instanceGroupsSetNamedPortsRequest = _messages.MessageField('InstanceGroupsSetNamedPortsRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstanceGroupsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeInstanceGroupsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
    zone: The name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)
  zone = _messages.StringField(4, required=True)


class ComputeInstanceTemplatesDeleteRequest(_messages.Message):
  r"""A ComputeInstanceTemplatesDeleteRequest object.

  Fields:
    instanceTemplate: The name of the instance template to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  instanceTemplate = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeInstanceTemplatesGetIamPolicyRequest(_messages.Message):
  r"""A ComputeInstanceTemplatesGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeInstanceTemplatesGetRequest(_messages.Message):
  r"""A ComputeInstanceTemplatesGetRequest object.

  Fields:
    instanceTemplate: The name of the instance template.
    project: Project ID for this request.
  """

  instanceTemplate = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeInstanceTemplatesInsertRequest(_messages.Message):
  r"""A ComputeInstanceTemplatesInsertRequest object.

  Fields:
    instanceTemplate: A InstanceTemplate resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  instanceTemplate = _messages.MessageField('InstanceTemplate', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeInstanceTemplatesListRequest(_messages.Message):
  r"""A ComputeInstanceTemplatesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeInstanceTemplatesSetIamPolicyRequest(_messages.Message):
  r"""A ComputeInstanceTemplatesSetIamPolicyRequest object.

  Fields:
    globalSetPolicyRequest: A GlobalSetPolicyRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetPolicyRequest = _messages.MessageField('GlobalSetPolicyRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeInstanceTemplatesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeInstanceTemplatesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeInstancesAddAccessConfigRequest(_messages.Message):
  r"""A ComputeInstancesAddAccessConfigRequest object.

  Fields:
    accessConfig: A AccessConfig resource to be passed as the request body.
    instance: The instance name for this request.
    networkInterface: The name of the network interface to add to this
      instance.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  accessConfig = _messages.MessageField('AccessConfig', 1)
  instance = _messages.StringField(2, required=True)
  networkInterface = _messages.StringField(3, required=True)
  project = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)
  zone = _messages.StringField(6, required=True)


class ComputeInstancesAddResourcePoliciesRequest(_messages.Message):
  r"""A ComputeInstancesAddResourcePoliciesRequest object.

  Fields:
    instance: The instance name for this request.
    instancesAddResourcePoliciesRequest: A InstancesAddResourcePoliciesRequest
      resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  instancesAddResourcePoliciesRequest = _messages.MessageField('InstancesAddResourcePoliciesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesAggregatedListRequest(_messages.Message):
  r"""A ComputeInstancesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeInstancesAttachDiskRequest(_messages.Message):
  r"""A ComputeInstancesAttachDiskRequest object.

  Fields:
    attachedDisk: A AttachedDisk resource to be passed as the request body.
    forceAttach: Whether to force attach the disk even if it's currently
      attached to another instance.
    instance: The instance name for this request.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  attachedDisk = _messages.MessageField('AttachedDisk', 1)
  forceAttach = _messages.BooleanField(2)
  instance = _messages.StringField(3, required=True)
  project = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)
  zone = _messages.StringField(6, required=True)


class ComputeInstancesBulkInsertRequest(_messages.Message):
  r"""A ComputeInstancesBulkInsertRequest object.

  Fields:
    bulkInsertInstanceResource: A BulkInsertInstanceResource resource to be
      passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  bulkInsertInstanceResource = _messages.MessageField('BulkInsertInstanceResource', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeInstancesDeleteAccessConfigRequest(_messages.Message):
  r"""A ComputeInstancesDeleteAccessConfigRequest object.

  Fields:
    accessConfig: The name of the access config to delete.
    instance: The instance name for this request.
    networkInterface: The name of the network interface.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  accessConfig = _messages.StringField(1, required=True)
  instance = _messages.StringField(2, required=True)
  networkInterface = _messages.StringField(3, required=True)
  project = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)
  zone = _messages.StringField(6, required=True)


class ComputeInstancesDeleteRequest(_messages.Message):
  r"""A ComputeInstancesDeleteRequest object.

  Fields:
    instance: Name of the instance resource to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeInstancesDetachDiskRequest(_messages.Message):
  r"""A ComputeInstancesDetachDiskRequest object.

  Fields:
    deviceName: The device name of the disk to detach. Make a get() request on
      the instance to view currently attached disks and device names.
    instance: Instance name for this request.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  deviceName = _messages.StringField(1, required=True)
  instance = _messages.StringField(2, required=True)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesGetEffectiveFirewallsRequest(_messages.Message):
  r"""A ComputeInstancesGetEffectiveFirewallsRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    networkInterface: The name of the network interface to get the effective
      firewalls.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  networkInterface = _messages.StringField(2, required=True)
  project = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)


class ComputeInstancesGetGuestAttributesRequest(_messages.Message):
  r"""A ComputeInstancesGetGuestAttributesRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    project: Project ID for this request.
    queryPath: Specifies the guest attributes path to be queried.
    variableKey: Specifies the key for the guest attributes entry.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  queryPath = _messages.StringField(3)
  variableKey = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesGetIamPolicyRequest(_messages.Message):
  r"""A ComputeInstancesGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)


class ComputeInstancesGetRequest(_messages.Message):
  r"""A ComputeInstancesGetRequest object.

  Fields:
    instance: Name of the instance resource to return.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeInstancesGetScreenshotRequest(_messages.Message):
  r"""A ComputeInstancesGetScreenshotRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeInstancesGetSerialPortOutputRequest(_messages.Message):
  r"""A ComputeInstancesGetSerialPortOutputRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    port: Specifies which COM or serial port to retrieve data from.
    project: Project ID for this request.
    start: Returns output starting from a specific byte position. Use this to
      page through output when the output is too large to return in a single
      request. For the initial request, leave this field unspecified. For
      subsequent calls, this field should be set to the next value returned in
      the previous call.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  port = _messages.IntegerField(2, variant=_messages.Variant.INT32, default=1)
  project = _messages.StringField(3, required=True)
  start = _messages.IntegerField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesGetShieldedInstanceIdentityRequest(_messages.Message):
  r"""A ComputeInstancesGetShieldedInstanceIdentityRequest object.

  Fields:
    instance: Name or id of the instance scoping this request.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeInstancesGetShieldedVmIdentityRequest(_messages.Message):
  r"""A ComputeInstancesGetShieldedVmIdentityRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeInstancesInsertRequest(_messages.Message):
  r"""A ComputeInstancesInsertRequest object.

  Fields:
    instance: A Instance resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    sourceInstanceTemplate: Specifies instance template to create the
      instance.  This field is optional. It can be a full or partial URL. For
      example, the following are all valid URLs to an instance template:   - h
      ttps://www.googleapis.com/compute/v1/projects/project/global/instanceTem
      plates/instanceTemplate  -
      projects/project/global/instanceTemplates/instanceTemplate  -
      global/instanceTemplates/instanceTemplate
    sourceMachineImage: Specifies instance machine to create the instance.
      This field is optional. It can be a full or partial URL. For example,
      the following are all valid URLs to an instance template:   - https://ww
      w.googleapis.com/compute/v1/projects/project/global/global/machineImages
      /machineImage  -
      projects/project/global/global/machineImages/machineImage  -
      global/machineImages/machineImage
    zone: The name of the zone for this request.
  """

  instance = _messages.MessageField('Instance', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  sourceInstanceTemplate = _messages.StringField(4)
  sourceMachineImage = _messages.StringField(5)
  zone = _messages.StringField(6, required=True)


class ComputeInstancesListReferrersRequest(_messages.Message):
  r"""A ComputeInstancesListReferrersRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    instance: Name of the target instance scoping this request, or '-' if the
      request should span over all instances in the container.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
    zone: The name of the zone for this request.
  """

  filter = _messages.StringField(1)
  instance = _messages.StringField(2, required=True)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  zone = _messages.StringField(8, required=True)


class ComputeInstancesListRequest(_messages.Message):
  r"""A ComputeInstancesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
    zone: The name of the zone for this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeInstancesRemoveResourcePoliciesRequest(_messages.Message):
  r"""A ComputeInstancesRemoveResourcePoliciesRequest object.

  Fields:
    instance: The instance name for this request.
    instancesRemoveResourcePoliciesRequest: A
      InstancesRemoveResourcePoliciesRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  instancesRemoveResourcePoliciesRequest = _messages.MessageField('InstancesRemoveResourcePoliciesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesResetRequest(_messages.Message):
  r"""A ComputeInstancesResetRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeInstancesResumeRequest(_messages.Message):
  r"""A ComputeInstancesResumeRequest object.

  Fields:
    instance: Name of the instance resource to resume.
    instancesResumeRequest: A InstancesResumeRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  instancesResumeRequest = _messages.MessageField('InstancesResumeRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSetDeletionProtectionRequest(_messages.Message):
  r"""A ComputeInstancesSetDeletionProtectionRequest object.

  Fields:
    deletionProtection: Whether the resource should be protected against
      deletion.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
  """

  deletionProtection = _messages.BooleanField(1, default=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  resource = _messages.StringField(4, required=True)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSetDiskAutoDeleteRequest(_messages.Message):
  r"""A ComputeInstancesSetDiskAutoDeleteRequest object.

  Fields:
    autoDelete: Whether to auto-delete the disk when the instance is deleted.
    deviceName: The device name of the disk to modify. Make a get() request on
      the instance to view currently attached disks and device names.
    instance: The instance name for this request.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  autoDelete = _messages.BooleanField(1, required=True)
  deviceName = _messages.StringField(2, required=True)
  instance = _messages.StringField(3, required=True)
  project = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)
  zone = _messages.StringField(6, required=True)


class ComputeInstancesSetIamPolicyRequest(_messages.Message):
  r"""A ComputeInstancesSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
    zoneSetPolicyRequest: A ZoneSetPolicyRequest resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)
  zoneSetPolicyRequest = _messages.MessageField('ZoneSetPolicyRequest', 4)


class ComputeInstancesSetLabelsRequest(_messages.Message):
  r"""A ComputeInstancesSetLabelsRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    instancesSetLabelsRequest: A InstancesSetLabelsRequest resource to be
      passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  instancesSetLabelsRequest = _messages.MessageField('InstancesSetLabelsRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSetMachineResourcesRequest(_messages.Message):
  r"""A ComputeInstancesSetMachineResourcesRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    instancesSetMachineResourcesRequest: A InstancesSetMachineResourcesRequest
      resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  instancesSetMachineResourcesRequest = _messages.MessageField('InstancesSetMachineResourcesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSetMachineTypeRequest(_messages.Message):
  r"""A ComputeInstancesSetMachineTypeRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    instancesSetMachineTypeRequest: A InstancesSetMachineTypeRequest resource
      to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  instancesSetMachineTypeRequest = _messages.MessageField('InstancesSetMachineTypeRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSetMetadataRequest(_messages.Message):
  r"""A ComputeInstancesSetMetadataRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    metadata: A Metadata resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  metadata = _messages.MessageField('Metadata', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSetMinCpuPlatformRequest(_messages.Message):
  r"""A ComputeInstancesSetMinCpuPlatformRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    instancesSetMinCpuPlatformRequest: A InstancesSetMinCpuPlatformRequest
      resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  instancesSetMinCpuPlatformRequest = _messages.MessageField('InstancesSetMinCpuPlatformRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSetNameRequest(_messages.Message):
  r"""A ComputeInstancesSetNameRequest object.

  Fields:
    instance: The instance name for this request.
    instancesSetNameRequest: A InstancesSetNameRequest resource to be passed
      as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  instancesSetNameRequest = _messages.MessageField('InstancesSetNameRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSetSchedulingRequest(_messages.Message):
  r"""A ComputeInstancesSetSchedulingRequest object.

  Fields:
    instance: Instance name for this request.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    scheduling: A Scheduling resource to be passed as the request body.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  scheduling = _messages.MessageField('Scheduling', 4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSetServiceAccountRequest(_messages.Message):
  r"""A ComputeInstancesSetServiceAccountRequest object.

  Fields:
    instance: Name of the instance resource to start.
    instancesSetServiceAccountRequest: A InstancesSetServiceAccountRequest
      resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  instancesSetServiceAccountRequest = _messages.MessageField('InstancesSetServiceAccountRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSetShieldedInstanceIntegrityPolicyRequest(_messages.Message):
  r"""A ComputeInstancesSetShieldedInstanceIntegrityPolicyRequest object.

  Fields:
    instance: Name or id of the instance scoping this request.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    shieldedInstanceIntegrityPolicy: A ShieldedInstanceIntegrityPolicy
      resource to be passed as the request body.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  shieldedInstanceIntegrityPolicy = _messages.MessageField('ShieldedInstanceIntegrityPolicy', 4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSetShieldedVmIntegrityPolicyRequest(_messages.Message):
  r"""A ComputeInstancesSetShieldedVmIntegrityPolicyRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    shieldedVmIntegrityPolicy: A ShieldedVmIntegrityPolicy resource to be
      passed as the request body.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  shieldedVmIntegrityPolicy = _messages.MessageField('ShieldedVmIntegrityPolicy', 4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSetTagsRequest(_messages.Message):
  r"""A ComputeInstancesSetTagsRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    tags: A Tags resource to be passed as the request body.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  tags = _messages.MessageField('Tags', 4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSimulateMaintenanceEventRequest(_messages.Message):
  r"""A ComputeInstancesSimulateMaintenanceEventRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeInstancesStartRequest(_messages.Message):
  r"""A ComputeInstancesStartRequest object.

  Fields:
    instance: Name of the instance resource to start.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeInstancesStartWithEncryptionKeyRequest(_messages.Message):
  r"""A ComputeInstancesStartWithEncryptionKeyRequest object.

  Fields:
    instance: Name of the instance resource to start.
    instancesStartWithEncryptionKeyRequest: A
      InstancesStartWithEncryptionKeyRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  instancesStartWithEncryptionKeyRequest = _messages.MessageField('InstancesStartWithEncryptionKeyRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesStopRequest(_messages.Message):
  r"""A ComputeInstancesStopRequest object.

  Fields:
    discardLocalSsd: If true, discard the contents of any attached localSSD
      partitions. Default value is false (== preserve localSSD data).
    instance: Name of the instance resource to stop.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  discardLocalSsd = _messages.BooleanField(1)
  instance = _messages.StringField(2, required=True)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesSuspendRequest(_messages.Message):
  r"""A ComputeInstancesSuspendRequest object.

  Fields:
    discardLocalSsd: If true, discard the contents of any attached localSSD
      partitions. Default value is false (== preserve localSSD data).
    instance: Name of the instance resource to suspend.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  discardLocalSsd = _messages.BooleanField(1)
  instance = _messages.StringField(2, required=True)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeInstancesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
    zone: The name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)
  zone = _messages.StringField(4, required=True)


class ComputeInstancesUpdateAccessConfigRequest(_messages.Message):
  r"""A ComputeInstancesUpdateAccessConfigRequest object.

  Fields:
    accessConfig: A AccessConfig resource to be passed as the request body.
    instance: The instance name for this request.
    networkInterface: The name of the network interface where the access
      config is attached.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  accessConfig = _messages.MessageField('AccessConfig', 1)
  instance = _messages.StringField(2, required=True)
  networkInterface = _messages.StringField(3, required=True)
  project = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)
  zone = _messages.StringField(6, required=True)


class ComputeInstancesUpdateDisplayDeviceRequest(_messages.Message):
  r"""A ComputeInstancesUpdateDisplayDeviceRequest object.

  Fields:
    displayDevice: A DisplayDevice resource to be passed as the request body.
    instance: Name of the instance scoping this request.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  displayDevice = _messages.MessageField('DisplayDevice', 1)
  instance = _messages.StringField(2, required=True)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesUpdateNetworkInterfaceRequest(_messages.Message):
  r"""A ComputeInstancesUpdateNetworkInterfaceRequest object.

  Fields:
    instance: The instance name for this request.
    networkInterface: The name of the network interface to update.
    networkInterfaceResource: A NetworkInterface resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  networkInterface = _messages.StringField(2, required=True)
  networkInterfaceResource = _messages.MessageField('NetworkInterface', 3)
  project = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)
  zone = _messages.StringField(6, required=True)


class ComputeInstancesUpdateRequest(_messages.Message):
  r"""A ComputeInstancesUpdateRequest object.

  Enums:
    MinimalActionValueValuesEnum: Specifies the action to take when updating
      an instance even if the updated properties do not require it. If not
      specified, then Compute Engine acts based on the minimum action that the
      updated properties require.
    MostDisruptiveAllowedActionValueValuesEnum: Specifies the most disruptive
      action that can be taken on the instance as part of the update. Compute
      Engine returns an error if the instance properties require a more
      disruptive action as part of the instance update. Valid options from
      lowest to highest are NO_EFFECT, REFRESH, and RESTART.

  Fields:
    instance: Name of the instance resource to update.
    instanceResource: A Instance resource to be passed as the request body.
    minimalAction: Specifies the action to take when updating an instance even
      if the updated properties do not require it. If not specified, then
      Compute Engine acts based on the minimum action that the updated
      properties require.
    mostDisruptiveAllowedAction: Specifies the most disruptive action that can
      be taken on the instance as part of the update. Compute Engine returns
      an error if the instance properties require a more disruptive action as
      part of the instance update. Valid options from lowest to highest are
      NO_EFFECT, REFRESH, and RESTART.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  class MinimalActionValueValuesEnum(_messages.Enum):
    r"""Specifies the action to take when updating an instance even if the
    updated properties do not require it. If not specified, then Compute
    Engine acts based on the minimum action that the updated properties
    require.

    Values:
      INVALID: <no description>
      NO_EFFECT: <no description>
      REFRESH: <no description>
      RESTART: <no description>
    """
    INVALID = 0
    NO_EFFECT = 1
    REFRESH = 2
    RESTART = 3

  class MostDisruptiveAllowedActionValueValuesEnum(_messages.Enum):
    r"""Specifies the most disruptive action that can be taken on the instance
    as part of the update. Compute Engine returns an error if the instance
    properties require a more disruptive action as part of the instance
    update. Valid options from lowest to highest are NO_EFFECT, REFRESH, and
    RESTART.

    Values:
      INVALID: <no description>
      NO_EFFECT: <no description>
      REFRESH: <no description>
      RESTART: <no description>
    """
    INVALID = 0
    NO_EFFECT = 1
    REFRESH = 2
    RESTART = 3

  instance = _messages.StringField(1, required=True)
  instanceResource = _messages.MessageField('Instance', 2)
  minimalAction = _messages.EnumField('MinimalActionValueValuesEnum', 3)
  mostDisruptiveAllowedAction = _messages.EnumField('MostDisruptiveAllowedActionValueValuesEnum', 4)
  project = _messages.StringField(5, required=True)
  requestId = _messages.StringField(6)
  zone = _messages.StringField(7, required=True)


class ComputeInstancesUpdateShieldedInstanceConfigRequest(_messages.Message):
  r"""A ComputeInstancesUpdateShieldedInstanceConfigRequest object.

  Fields:
    instance: Name or id of the instance scoping this request.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    shieldedInstanceConfig: A ShieldedInstanceConfig resource to be passed as
      the request body.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  shieldedInstanceConfig = _messages.MessageField('ShieldedInstanceConfig', 4)
  zone = _messages.StringField(5, required=True)


class ComputeInstancesUpdateShieldedVmConfigRequest(_messages.Message):
  r"""A ComputeInstancesUpdateShieldedVmConfigRequest object.

  Fields:
    instance: Name of the instance scoping this request.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    shieldedVmConfig: A ShieldedVmConfig resource to be passed as the request
      body.
    zone: The name of the zone for this request.
  """

  instance = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  shieldedVmConfig = _messages.MessageField('ShieldedVmConfig', 4)
  zone = _messages.StringField(5, required=True)


class ComputeInterconnectAttachmentsAggregatedListRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeInterconnectAttachmentsDeleteRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentsDeleteRequest object.

  Fields:
    interconnectAttachment: Name of the interconnect attachment to delete.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  interconnectAttachment = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeInterconnectAttachmentsGetIamPolicyRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentsGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  resource = _messages.StringField(4, required=True)


class ComputeInterconnectAttachmentsGetRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentsGetRequest object.

  Fields:
    interconnectAttachment: Name of the interconnect attachment to return.
    project: Project ID for this request.
    region: Name of the region for this request.
  """

  interconnectAttachment = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeInterconnectAttachmentsInsertRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentsInsertRequest object.

  Fields:
    interconnectAttachment: A InterconnectAttachment resource to be passed as
      the request body.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    validateOnly: If true, the request will not be committed.
  """

  interconnectAttachment = _messages.MessageField('InterconnectAttachment', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  validateOnly = _messages.BooleanField(5)


class ComputeInterconnectAttachmentsListRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeInterconnectAttachmentsPatchRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentsPatchRequest object.

  Fields:
    interconnectAttachment: Name of the interconnect attachment to patch.
    interconnectAttachmentResource: A InterconnectAttachment resource to be
      passed as the request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  interconnectAttachment = _messages.StringField(1, required=True)
  interconnectAttachmentResource = _messages.MessageField('InterconnectAttachment', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeInterconnectAttachmentsSetIamPolicyRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentsSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    regionSetPolicyRequest: A RegionSetPolicyRequest resource to be passed as
      the request body.
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetPolicyRequest = _messages.MessageField('RegionSetPolicyRequest', 3)
  resource = _messages.StringField(4, required=True)


class ComputeInterconnectAttachmentsSetLabelsRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentsSetLabelsRequest object.

  Fields:
    project: Project ID for this request.
    region: The region for this request.
    regionSetLabelsRequest: A RegionSetLabelsRequest resource to be passed as
      the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetLabelsRequest = _messages.MessageField('RegionSetLabelsRequest', 3)
  requestId = _messages.StringField(4)
  resource = _messages.StringField(5, required=True)


class ComputeInterconnectAttachmentsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeInterconnectAttachmentsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeInterconnectLocationsGetRequest(_messages.Message):
  r"""A ComputeInterconnectLocationsGetRequest object.

  Fields:
    interconnectLocation: Name of the interconnect location to return.
    project: Project ID for this request.
  """

  interconnectLocation = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeInterconnectLocationsListRequest(_messages.Message):
  r"""A ComputeInterconnectLocationsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeInterconnectLocationsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeInterconnectLocationsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeInterconnectsDeleteRequest(_messages.Message):
  r"""A ComputeInterconnectsDeleteRequest object.

  Fields:
    interconnect: Name of the interconnect to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  interconnect = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeInterconnectsGetDiagnosticsRequest(_messages.Message):
  r"""A ComputeInterconnectsGetDiagnosticsRequest object.

  Fields:
    interconnect: Name of the interconnect resource to query.
    project: Project ID for this request.
  """

  interconnect = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeInterconnectsGetIamPolicyRequest(_messages.Message):
  r"""A ComputeInterconnectsGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeInterconnectsGetRequest(_messages.Message):
  r"""A ComputeInterconnectsGetRequest object.

  Fields:
    interconnect: Name of the interconnect to return.
    project: Project ID for this request.
  """

  interconnect = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeInterconnectsInsertRequest(_messages.Message):
  r"""A ComputeInterconnectsInsertRequest object.

  Fields:
    interconnect: A Interconnect resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  interconnect = _messages.MessageField('Interconnect', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeInterconnectsListRequest(_messages.Message):
  r"""A ComputeInterconnectsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeInterconnectsPatchRequest(_messages.Message):
  r"""A ComputeInterconnectsPatchRequest object.

  Fields:
    interconnect: Name of the interconnect to update.
    interconnectResource: A Interconnect resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  interconnect = _messages.StringField(1, required=True)
  interconnectResource = _messages.MessageField('Interconnect', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeInterconnectsSetIamPolicyRequest(_messages.Message):
  r"""A ComputeInterconnectsSetIamPolicyRequest object.

  Fields:
    globalSetPolicyRequest: A GlobalSetPolicyRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetPolicyRequest = _messages.MessageField('GlobalSetPolicyRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeInterconnectsSetLabelsRequest(_messages.Message):
  r"""A ComputeInterconnectsSetLabelsRequest object.

  Fields:
    globalSetLabelsRequest: A GlobalSetLabelsRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetLabelsRequest = _messages.MessageField('GlobalSetLabelsRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeInterconnectsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeInterconnectsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeLicenseCodesGetIamPolicyRequest(_messages.Message):
  r"""A ComputeLicenseCodesGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeLicenseCodesGetRequest(_messages.Message):
  r"""A ComputeLicenseCodesGetRequest object.

  Fields:
    licenseCode: Number corresponding to the License code resource to return.
    project: Project ID for this request.
  """

  licenseCode = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeLicenseCodesSetIamPolicyRequest(_messages.Message):
  r"""A ComputeLicenseCodesSetIamPolicyRequest object.

  Fields:
    globalSetPolicyRequest: A GlobalSetPolicyRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetPolicyRequest = _messages.MessageField('GlobalSetPolicyRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeLicenseCodesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeLicenseCodesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeLicensesDeleteRequest(_messages.Message):
  r"""A ComputeLicensesDeleteRequest object.

  Fields:
    license: Name of the license resource to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  license = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeLicensesGetIamPolicyRequest(_messages.Message):
  r"""A ComputeLicensesGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeLicensesGetRequest(_messages.Message):
  r"""A ComputeLicensesGetRequest object.

  Fields:
    license: Name of the License resource to return.
    project: Project ID for this request.
  """

  license = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeLicensesInsertRequest(_messages.Message):
  r"""A ComputeLicensesInsertRequest object.

  Fields:
    license: A License resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  license = _messages.MessageField('License', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeLicensesListRequest(_messages.Message):
  r"""A ComputeLicensesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeLicensesSetIamPolicyRequest(_messages.Message):
  r"""A ComputeLicensesSetIamPolicyRequest object.

  Fields:
    globalSetPolicyRequest: A GlobalSetPolicyRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetPolicyRequest = _messages.MessageField('GlobalSetPolicyRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeLicensesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeLicensesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeMachineImagesDeleteRequest(_messages.Message):
  r"""A ComputeMachineImagesDeleteRequest object.

  Fields:
    machineImage: The name of the machine image to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  machineImage = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeMachineImagesGetIamPolicyRequest(_messages.Message):
  r"""A ComputeMachineImagesGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeMachineImagesGetRequest(_messages.Message):
  r"""A ComputeMachineImagesGetRequest object.

  Fields:
    machineImage: The name of the machine image.
    project: Project ID for this request.
  """

  machineImage = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeMachineImagesInsertRequest(_messages.Message):
  r"""A ComputeMachineImagesInsertRequest object.

  Fields:
    machineImage: A MachineImage resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    sourceInstance: Required. Source instance that is used to create the
      machine image from.
  """

  machineImage = _messages.MessageField('MachineImage', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  sourceInstance = _messages.StringField(4)


class ComputeMachineImagesListRequest(_messages.Message):
  r"""A ComputeMachineImagesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeMachineImagesSetIamPolicyRequest(_messages.Message):
  r"""A ComputeMachineImagesSetIamPolicyRequest object.

  Fields:
    globalSetPolicyRequest: A GlobalSetPolicyRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetPolicyRequest = _messages.MessageField('GlobalSetPolicyRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeMachineImagesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeMachineImagesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeMachineTypesAggregatedListRequest(_messages.Message):
  r"""A ComputeMachineTypesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeMachineTypesGetRequest(_messages.Message):
  r"""A ComputeMachineTypesGetRequest object.

  Fields:
    machineType: Name of the machine type to return.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  machineType = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeMachineTypesListRequest(_messages.Message):
  r"""A ComputeMachineTypesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
    zone: The name of the zone for this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeNetworkEndpointGroupsAggregatedListRequest(_messages.Message):
  r"""A ComputeNetworkEndpointGroupsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeNetworkEndpointGroupsAttachNetworkEndpointsRequest(_messages.Message):
  r"""A ComputeNetworkEndpointGroupsAttachNetworkEndpointsRequest object.

  Fields:
    networkEndpointGroup: The name of the network endpoint group where you are
      attaching network endpoints to. It should comply with RFC1035.
    networkEndpointGroupsAttachEndpointsRequest: A
      NetworkEndpointGroupsAttachEndpointsRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the network endpoint group is located. It
      should comply with RFC1035.
  """

  networkEndpointGroup = _messages.StringField(1, required=True)
  networkEndpointGroupsAttachEndpointsRequest = _messages.MessageField('NetworkEndpointGroupsAttachEndpointsRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeNetworkEndpointGroupsDeleteRequest(_messages.Message):
  r"""A ComputeNetworkEndpointGroupsDeleteRequest object.

  Fields:
    networkEndpointGroup: The name of the network endpoint group to delete. It
      should comply with RFC1035.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the network endpoint group is located. It
      should comply with RFC1035.
  """

  networkEndpointGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeNetworkEndpointGroupsDetachNetworkEndpointsRequest(_messages.Message):
  r"""A ComputeNetworkEndpointGroupsDetachNetworkEndpointsRequest object.

  Fields:
    networkEndpointGroup: The name of the network endpoint group where you are
      removing network endpoints. It should comply with RFC1035.
    networkEndpointGroupsDetachEndpointsRequest: A
      NetworkEndpointGroupsDetachEndpointsRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where the network endpoint group is located. It
      should comply with RFC1035.
  """

  networkEndpointGroup = _messages.StringField(1, required=True)
  networkEndpointGroupsDetachEndpointsRequest = _messages.MessageField('NetworkEndpointGroupsDetachEndpointsRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeNetworkEndpointGroupsGetRequest(_messages.Message):
  r"""A ComputeNetworkEndpointGroupsGetRequest object.

  Fields:
    networkEndpointGroup: The name of the network endpoint group. It should
      comply with RFC1035.
    project: Project ID for this request.
    zone: The name of the zone where the network endpoint group is located. It
      should comply with RFC1035.
  """

  networkEndpointGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeNetworkEndpointGroupsInsertRequest(_messages.Message):
  r"""A ComputeNetworkEndpointGroupsInsertRequest object.

  Fields:
    networkEndpointGroup: A NetworkEndpointGroup resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone where you want to create the network endpoint
      group. It should comply with RFC1035.
  """

  networkEndpointGroup = _messages.MessageField('NetworkEndpointGroup', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeNetworkEndpointGroupsListNetworkEndpointsRequest(_messages.Message):
  r"""A ComputeNetworkEndpointGroupsListNetworkEndpointsRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    networkEndpointGroup: The name of the network endpoint group from which
      you want to generate a list of included network endpoints. It should
      comply with RFC1035.
    networkEndpointGroupsListEndpointsRequest: A
      NetworkEndpointGroupsListEndpointsRequest resource to be passed as the
      request body.
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
    zone: The name of the zone where the network endpoint group is located. It
      should comply with RFC1035.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  networkEndpointGroup = _messages.StringField(3, required=True)
  networkEndpointGroupsListEndpointsRequest = _messages.MessageField('NetworkEndpointGroupsListEndpointsRequest', 4)
  orderBy = _messages.StringField(5)
  pageToken = _messages.StringField(6)
  project = _messages.StringField(7, required=True)
  returnPartialSuccess = _messages.BooleanField(8)
  zone = _messages.StringField(9, required=True)


class ComputeNetworkEndpointGroupsListRequest(_messages.Message):
  r"""A ComputeNetworkEndpointGroupsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
    zone: The name of the zone where the network endpoint group is located. It
      should comply with RFC1035.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeNetworkEndpointGroupsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeNetworkEndpointGroupsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
    zone: The name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)
  zone = _messages.StringField(4, required=True)


class ComputeNetworksAddPeeringRequest(_messages.Message):
  r"""A ComputeNetworksAddPeeringRequest object.

  Fields:
    network: Name of the network resource to add peering to.
    networksAddPeeringRequest: A NetworksAddPeeringRequest resource to be
      passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  network = _messages.StringField(1, required=True)
  networksAddPeeringRequest = _messages.MessageField('NetworksAddPeeringRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeNetworksDeleteRequest(_messages.Message):
  r"""A ComputeNetworksDeleteRequest object.

  Fields:
    network: Name of the network to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  network = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeNetworksGetEffectiveFirewallsRequest(_messages.Message):
  r"""A ComputeNetworksGetEffectiveFirewallsRequest object.

  Fields:
    network: Name of the network for this request.
    project: Project ID for this request.
  """

  network = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeNetworksGetRequest(_messages.Message):
  r"""A ComputeNetworksGetRequest object.

  Fields:
    network: Name of the network to return.
    project: Project ID for this request.
  """

  network = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)


class ComputeNetworksInsertRequest(_messages.Message):
  r"""A ComputeNetworksInsertRequest object.

  Fields:
    network: A Network resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  network = _messages.MessageField('Network', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeNetworksListIpAddressesRequest(_messages.Message):
  r"""A ComputeNetworksListIpAddressesRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    network: Name of the network for this request.
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
    types: (Optional) types filter separate by comma, valid values are:
      SUBNETWORK, RESERVED, PEER_USED, PEER_RESERVED, REMOTE_USED,
      REMOTE_RESERVED.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  network = _messages.StringField(3, required=True)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  types = _messages.StringField(8)


class ComputeNetworksListIpOwnersRequest(_messages.Message):
  r"""A ComputeNetworksListIpOwnersRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    ipCidrRange: (Optional) IP CIDR range filter, example: "10.128.10.0/30".
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    network: Name of the network to return.
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    ownerProjects: (Optional) Project IDs filter, example:
      "project-1,project-2".
    ownerTypes: (Optional) Owner types filter, example:
      "instance,forwardingRule".
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
    subnetName: (Optional) Subnetwork name filter.
    subnetRegion: (Optional) Subnetwork region filter.
  """

  filter = _messages.StringField(1)
  ipCidrRange = _messages.StringField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  network = _messages.StringField(4, required=True)
  orderBy = _messages.StringField(5)
  ownerProjects = _messages.StringField(6)
  ownerTypes = _messages.StringField(7)
  pageToken = _messages.StringField(8)
  project = _messages.StringField(9, required=True)
  returnPartialSuccess = _messages.BooleanField(10)
  subnetName = _messages.StringField(11)
  subnetRegion = _messages.StringField(12)


class ComputeNetworksListPeeringRoutesRequest(_messages.Message):
  r"""A ComputeNetworksListPeeringRoutesRequest object.

  Enums:
    DirectionValueValuesEnum: The direction of the exchanged routes.

  Fields:
    direction: The direction of the exchanged routes.
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    network: Name of the network for this request.
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    peeringName: The response will show routes exchanged over the given
      peering connection.
    project: Project ID for this request.
    region: The region of the request. The response will include all subnet
      routes, static routes and dynamic routes in the region.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  class DirectionValueValuesEnum(_messages.Enum):
    r"""The direction of the exchanged routes.

    Values:
      INCOMING: <no description>
      OUTGOING: <no description>
    """
    INCOMING = 0
    OUTGOING = 1

  direction = _messages.EnumField('DirectionValueValuesEnum', 1)
  filter = _messages.StringField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  network = _messages.StringField(4, required=True)
  orderBy = _messages.StringField(5)
  pageToken = _messages.StringField(6)
  peeringName = _messages.StringField(7)
  project = _messages.StringField(8, required=True)
  region = _messages.StringField(9)
  returnPartialSuccess = _messages.BooleanField(10)


class ComputeNetworksListRequest(_messages.Message):
  r"""A ComputeNetworksListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeNetworksPatchRequest(_messages.Message):
  r"""A ComputeNetworksPatchRequest object.

  Fields:
    network: Name of the network to update.
    networkResource: A Network resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  network = _messages.StringField(1, required=True)
  networkResource = _messages.MessageField('Network', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeNetworksRemovePeeringRequest(_messages.Message):
  r"""A ComputeNetworksRemovePeeringRequest object.

  Fields:
    network: Name of the network resource to remove peering from.
    networksRemovePeeringRequest: A NetworksRemovePeeringRequest resource to
      be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  network = _messages.StringField(1, required=True)
  networksRemovePeeringRequest = _messages.MessageField('NetworksRemovePeeringRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeNetworksSwitchToCustomModeRequest(_messages.Message):
  r"""A ComputeNetworksSwitchToCustomModeRequest object.

  Fields:
    network: Name of the network to be updated.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  network = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeNetworksTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeNetworksTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeNetworksUpdatePeeringRequest(_messages.Message):
  r"""A ComputeNetworksUpdatePeeringRequest object.

  Fields:
    network: Name of the network resource which the updated peering is
      belonging to.
    networksUpdatePeeringRequest: A NetworksUpdatePeeringRequest resource to
      be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  network = _messages.StringField(1, required=True)
  networksUpdatePeeringRequest = _messages.MessageField('NetworksUpdatePeeringRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeNodeGroupsAddNodesRequest(_messages.Message):
  r"""A ComputeNodeGroupsAddNodesRequest object.

  Fields:
    nodeGroup: Name of the NodeGroup resource.
    nodeGroupsAddNodesRequest: A NodeGroupsAddNodesRequest resource to be
      passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  nodeGroup = _messages.StringField(1, required=True)
  nodeGroupsAddNodesRequest = _messages.MessageField('NodeGroupsAddNodesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeNodeGroupsAggregatedListRequest(_messages.Message):
  r"""A ComputeNodeGroupsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeNodeGroupsDeleteNodesRequest(_messages.Message):
  r"""A ComputeNodeGroupsDeleteNodesRequest object.

  Fields:
    nodeGroup: Name of the NodeGroup resource whose nodes will be deleted.
    nodeGroupsDeleteNodesRequest: A NodeGroupsDeleteNodesRequest resource to
      be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  nodeGroup = _messages.StringField(1, required=True)
  nodeGroupsDeleteNodesRequest = _messages.MessageField('NodeGroupsDeleteNodesRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeNodeGroupsDeleteRequest(_messages.Message):
  r"""A ComputeNodeGroupsDeleteRequest object.

  Fields:
    nodeGroup: Name of the NodeGroup resource to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  nodeGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeNodeGroupsGetIamPolicyRequest(_messages.Message):
  r"""A ComputeNodeGroupsGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)


class ComputeNodeGroupsGetRequest(_messages.Message):
  r"""A ComputeNodeGroupsGetRequest object.

  Fields:
    nodeGroup: Name of the node group to return.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  nodeGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeNodeGroupsInsertRequest(_messages.Message):
  r"""A ComputeNodeGroupsInsertRequest object.

  Fields:
    initialNodeCount: Initial count of nodes in the node group.
    nodeGroup: A NodeGroup resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  initialNodeCount = _messages.IntegerField(1, required=True, variant=_messages.Variant.INT32)
  nodeGroup = _messages.MessageField('NodeGroup', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeNodeGroupsListNodesRequest(_messages.Message):
  r"""A ComputeNodeGroupsListNodesRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    nodeGroup: Name of the NodeGroup resource whose nodes you want to list.
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
    zone: The name of the zone for this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  nodeGroup = _messages.StringField(3, required=True)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)
  zone = _messages.StringField(8, required=True)


class ComputeNodeGroupsListRequest(_messages.Message):
  r"""A ComputeNodeGroupsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
    zone: The name of the zone for this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeNodeGroupsPatchRequest(_messages.Message):
  r"""A ComputeNodeGroupsPatchRequest object.

  Fields:
    nodeGroup: Name of the NodeGroup resource to update.
    nodeGroupResource: A NodeGroup resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  nodeGroup = _messages.StringField(1, required=True)
  nodeGroupResource = _messages.MessageField('NodeGroup', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeNodeGroupsSetIamPolicyRequest(_messages.Message):
  r"""A ComputeNodeGroupsSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
    zoneSetPolicyRequest: A ZoneSetPolicyRequest resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)
  zoneSetPolicyRequest = _messages.MessageField('ZoneSetPolicyRequest', 4)


class ComputeNodeGroupsSetNodeTemplateRequest(_messages.Message):
  r"""A ComputeNodeGroupsSetNodeTemplateRequest object.

  Fields:
    nodeGroup: Name of the NodeGroup resource to update.
    nodeGroupsSetNodeTemplateRequest: A NodeGroupsSetNodeTemplateRequest
      resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  nodeGroup = _messages.StringField(1, required=True)
  nodeGroupsSetNodeTemplateRequest = _messages.MessageField('NodeGroupsSetNodeTemplateRequest', 2)
  project = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  zone = _messages.StringField(5, required=True)


class ComputeNodeGroupsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeNodeGroupsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
    zone: The name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)
  zone = _messages.StringField(4, required=True)


class ComputeNodeTemplatesAggregatedListRequest(_messages.Message):
  r"""A ComputeNodeTemplatesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeNodeTemplatesDeleteRequest(_messages.Message):
  r"""A ComputeNodeTemplatesDeleteRequest object.

  Fields:
    nodeTemplate: Name of the NodeTemplate resource to delete.
    project: Project ID for this request.
    region: The name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  nodeTemplate = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeNodeTemplatesGetIamPolicyRequest(_messages.Message):
  r"""A ComputeNodeTemplatesGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  resource = _messages.StringField(4, required=True)


class ComputeNodeTemplatesGetRequest(_messages.Message):
  r"""A ComputeNodeTemplatesGetRequest object.

  Fields:
    nodeTemplate: Name of the node template to return.
    project: Project ID for this request.
    region: The name of the region for this request.
  """

  nodeTemplate = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeNodeTemplatesInsertRequest(_messages.Message):
  r"""A ComputeNodeTemplatesInsertRequest object.

  Fields:
    nodeTemplate: A NodeTemplate resource to be passed as the request body.
    project: Project ID for this request.
    region: The name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  nodeTemplate = _messages.MessageField('NodeTemplate', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeNodeTemplatesListRequest(_messages.Message):
  r"""A ComputeNodeTemplatesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: The name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeNodeTemplatesSetIamPolicyRequest(_messages.Message):
  r"""A ComputeNodeTemplatesSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    regionSetPolicyRequest: A RegionSetPolicyRequest resource to be passed as
      the request body.
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetPolicyRequest = _messages.MessageField('RegionSetPolicyRequest', 3)
  resource = _messages.StringField(4, required=True)


class ComputeNodeTemplatesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeNodeTemplatesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeNodeTypesAggregatedListRequest(_messages.Message):
  r"""A ComputeNodeTypesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeNodeTypesGetRequest(_messages.Message):
  r"""A ComputeNodeTypesGetRequest object.

  Fields:
    nodeType: Name of the node type to return.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  nodeType = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeNodeTypesListRequest(_messages.Message):
  r"""A ComputeNodeTypesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
    zone: The name of the zone for this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeOrganizationSecurityPoliciesAddAssociationRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesAddAssociationRequest object.

  Fields:
    replaceExistingAssociation: Indicates whether or not to replace it if an
      association of the attachment already exists. This is false by default,
      in which case an error will be returned if an assocation already exists.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    securityPolicy: Name of the security policy to update.
    securityPolicyAssociation: A SecurityPolicyAssociation resource to be
      passed as the request body.
  """

  replaceExistingAssociation = _messages.BooleanField(1)
  requestId = _messages.StringField(2)
  securityPolicy = _messages.StringField(3, required=True)
  securityPolicyAssociation = _messages.MessageField('SecurityPolicyAssociation', 4)


class ComputeOrganizationSecurityPoliciesAddRuleRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesAddRuleRequest object.

  Fields:
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    securityPolicy: Name of the security policy to update.
    securityPolicyRule: A SecurityPolicyRule resource to be passed as the
      request body.
  """

  requestId = _messages.StringField(1)
  securityPolicy = _messages.StringField(2, required=True)
  securityPolicyRule = _messages.MessageField('SecurityPolicyRule', 3)


class ComputeOrganizationSecurityPoliciesCopyRulesRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesCopyRulesRequest object.

  Fields:
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    securityPolicy: Name of the security policy to update.
    sourceSecurityPolicy: The security policy from which to copy rules.
  """

  requestId = _messages.StringField(1)
  securityPolicy = _messages.StringField(2, required=True)
  sourceSecurityPolicy = _messages.StringField(3)


class ComputeOrganizationSecurityPoliciesDeleteRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesDeleteRequest object.

  Fields:
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    securityPolicy: Name of the security policy to delete.
  """

  requestId = _messages.StringField(1)
  securityPolicy = _messages.StringField(2, required=True)


class ComputeOrganizationSecurityPoliciesGetAssociationRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesGetAssociationRequest object.

  Fields:
    name: The name of the association to get from the security policy.
    securityPolicy: Name of the security policy to which the queried rule
      belongs.
  """

  name = _messages.StringField(1)
  securityPolicy = _messages.StringField(2, required=True)


class ComputeOrganizationSecurityPoliciesGetRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesGetRequest object.

  Fields:
    securityPolicy: Name of the security policy to get.
  """

  securityPolicy = _messages.StringField(1, required=True)


class ComputeOrganizationSecurityPoliciesGetRuleRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesGetRuleRequest object.

  Fields:
    priority: The priority of the rule to get from the security policy.
    securityPolicy: Name of the security policy to which the queried rule
      belongs.
  """

  priority = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  securityPolicy = _messages.StringField(2, required=True)


class ComputeOrganizationSecurityPoliciesInsertRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesInsertRequest object.

  Fields:
    parentId: Parent ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    securityPolicy: A SecurityPolicy resource to be passed as the request
      body.
  """

  parentId = _messages.StringField(1)
  requestId = _messages.StringField(2)
  securityPolicy = _messages.MessageField('SecurityPolicy', 3)


class ComputeOrganizationSecurityPoliciesListAssociationsRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesListAssociationsRequest object.

  Fields:
    targetResource: The target resource to list associations. It is an
      organization, or a folder.
  """

  targetResource = _messages.StringField(1)


class ComputeOrganizationSecurityPoliciesListRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    parentId: Parent ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  parentId = _messages.StringField(5)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeOrganizationSecurityPoliciesMoveRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesMoveRequest object.

  Fields:
    parentId: The new parent of the security policy.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    securityPolicy: Name of the security policy to update.
  """

  parentId = _messages.StringField(1)
  requestId = _messages.StringField(2)
  securityPolicy = _messages.StringField(3, required=True)


class ComputeOrganizationSecurityPoliciesPatchRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesPatchRequest object.

  Fields:
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    securityPolicy: Name of the security policy to update.
    securityPolicyResource: A SecurityPolicy resource to be passed as the
      request body.
  """

  requestId = _messages.StringField(1)
  securityPolicy = _messages.StringField(2, required=True)
  securityPolicyResource = _messages.MessageField('SecurityPolicy', 3)


class ComputeOrganizationSecurityPoliciesPatchRuleRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesPatchRuleRequest object.

  Fields:
    priority: The priority of the rule to patch.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    securityPolicy: Name of the security policy to update.
    securityPolicyRule: A SecurityPolicyRule resource to be passed as the
      request body.
  """

  priority = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  requestId = _messages.StringField(2)
  securityPolicy = _messages.StringField(3, required=True)
  securityPolicyRule = _messages.MessageField('SecurityPolicyRule', 4)


class ComputeOrganizationSecurityPoliciesRemoveAssociationRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesRemoveAssociationRequest object.

  Fields:
    name: Name for the attachment that will be removed.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    securityPolicy: Name of the security policy to update.
  """

  name = _messages.StringField(1)
  requestId = _messages.StringField(2)
  securityPolicy = _messages.StringField(3, required=True)


class ComputeOrganizationSecurityPoliciesRemoveRuleRequest(_messages.Message):
  r"""A ComputeOrganizationSecurityPoliciesRemoveRuleRequest object.

  Fields:
    priority: The priority of the rule to remove from the security policy.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    securityPolicy: Name of the security policy to update.
  """

  priority = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  requestId = _messages.StringField(2)
  securityPolicy = _messages.StringField(3, required=True)


class ComputePacketMirroringsAggregatedListRequest(_messages.Message):
  r"""A ComputePacketMirroringsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputePacketMirroringsDeleteRequest(_messages.Message):
  r"""A ComputePacketMirroringsDeleteRequest object.

  Fields:
    packetMirroring: Name of the PacketMirroring resource to delete.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  packetMirroring = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputePacketMirroringsGetRequest(_messages.Message):
  r"""A ComputePacketMirroringsGetRequest object.

  Fields:
    packetMirroring: Name of the PacketMirroring resource to return.
    project: Project ID for this request.
    region: Name of the region for this request.
  """

  packetMirroring = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputePacketMirroringsInsertRequest(_messages.Message):
  r"""A ComputePacketMirroringsInsertRequest object.

  Fields:
    packetMirroring: A PacketMirroring resource to be passed as the request
      body.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  packetMirroring = _messages.MessageField('PacketMirroring', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputePacketMirroringsListRequest(_messages.Message):
  r"""A ComputePacketMirroringsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputePacketMirroringsPatchRequest(_messages.Message):
  r"""A ComputePacketMirroringsPatchRequest object.

  Fields:
    packetMirroring: Name of the PacketMirroring resource to patch.
    packetMirroringResource: A PacketMirroring resource to be passed as the
      request body.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  packetMirroring = _messages.StringField(1, required=True)
  packetMirroringResource = _messages.MessageField('PacketMirroring', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputePacketMirroringsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputePacketMirroringsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeProjectsDisableXpnHostRequest(_messages.Message):
  r"""A ComputeProjectsDisableXpnHostRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)


class ComputeProjectsDisableXpnResourceRequest(_messages.Message):
  r"""A ComputeProjectsDisableXpnResourceRequest object.

  Fields:
    project: Project ID for this request.
    projectsDisableXpnResourceRequest: A ProjectsDisableXpnResourceRequest
      resource to be passed as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  projectsDisableXpnResourceRequest = _messages.MessageField('ProjectsDisableXpnResourceRequest', 2)
  requestId = _messages.StringField(3)


class ComputeProjectsEnableXpnHostRequest(_messages.Message):
  r"""A ComputeProjectsEnableXpnHostRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)


class ComputeProjectsEnableXpnResourceRequest(_messages.Message):
  r"""A ComputeProjectsEnableXpnResourceRequest object.

  Fields:
    project: Project ID for this request.
    projectsEnableXpnResourceRequest: A ProjectsEnableXpnResourceRequest
      resource to be passed as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  projectsEnableXpnResourceRequest = _messages.MessageField('ProjectsEnableXpnResourceRequest', 2)
  requestId = _messages.StringField(3)


class ComputeProjectsGetRequest(_messages.Message):
  r"""A ComputeProjectsGetRequest object.

  Fields:
    project: Project ID for this request.
  """

  project = _messages.StringField(1, required=True)


class ComputeProjectsGetXpnHostRequest(_messages.Message):
  r"""A ComputeProjectsGetXpnHostRequest object.

  Fields:
    project: Project ID for this request.
  """

  project = _messages.StringField(1, required=True)


class ComputeProjectsGetXpnResourcesRequest(_messages.Message):
  r"""A ComputeProjectsGetXpnResourcesRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)


class ComputeProjectsListXpnHostsRequest(_messages.Message):
  r"""A ComputeProjectsListXpnHostsRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    projectsListXpnHostsRequest: A ProjectsListXpnHostsRequest resource to be
      passed as the request body.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  projectsListXpnHostsRequest = _messages.MessageField('ProjectsListXpnHostsRequest', 6)


class ComputeProjectsMoveDiskRequest(_messages.Message):
  r"""A ComputeProjectsMoveDiskRequest object.

  Fields:
    diskMoveRequest: A DiskMoveRequest resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  diskMoveRequest = _messages.MessageField('DiskMoveRequest', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeProjectsMoveInstanceRequest(_messages.Message):
  r"""A ComputeProjectsMoveInstanceRequest object.

  Fields:
    instanceMoveRequest: A InstanceMoveRequest resource to be passed as the
      request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  instanceMoveRequest = _messages.MessageField('InstanceMoveRequest', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeProjectsSetCommonInstanceMetadataRequest(_messages.Message):
  r"""A ComputeProjectsSetCommonInstanceMetadataRequest object.

  Fields:
    metadata: A Metadata resource to be passed as the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  metadata = _messages.MessageField('Metadata', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputeProjectsSetDefaultNetworkTierRequest(_messages.Message):
  r"""A ComputeProjectsSetDefaultNetworkTierRequest object.

  Fields:
    project: Project ID for this request.
    projectsSetDefaultNetworkTierRequest: A
      ProjectsSetDefaultNetworkTierRequest resource to be passed as the
      request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  projectsSetDefaultNetworkTierRequest = _messages.MessageField('ProjectsSetDefaultNetworkTierRequest', 2)
  requestId = _messages.StringField(3)


class ComputeProjectsSetDefaultServiceAccountRequest(_messages.Message):
  r"""A ComputeProjectsSetDefaultServiceAccountRequest object.

  Fields:
    project: Project ID for this request.
    projectsSetDefaultServiceAccountRequest: A
      ProjectsSetDefaultServiceAccountRequest resource to be passed as the
      request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  projectsSetDefaultServiceAccountRequest = _messages.MessageField('ProjectsSetDefaultServiceAccountRequest', 2)
  requestId = _messages.StringField(3)


class ComputeProjectsSetUsageExportBucketRequest(_messages.Message):
  r"""A ComputeProjectsSetUsageExportBucketRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    usageExportLocation: A UsageExportLocation resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  usageExportLocation = _messages.MessageField('UsageExportLocation', 3)


class ComputePublicAdvertisedPrefixesDeleteRequest(_messages.Message):
  r"""A ComputePublicAdvertisedPrefixesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    publicAdvertisedPrefix: Name of the PublicAdvertisedPrefix resource to
      delete.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  publicAdvertisedPrefix = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)


class ComputePublicAdvertisedPrefixesGetRequest(_messages.Message):
  r"""A ComputePublicAdvertisedPrefixesGetRequest object.

  Fields:
    project: Project ID for this request.
    publicAdvertisedPrefix: Name of the PublicAdvertisedPrefix resource to
      return.
  """

  project = _messages.StringField(1, required=True)
  publicAdvertisedPrefix = _messages.StringField(2, required=True)


class ComputePublicAdvertisedPrefixesInsertRequest(_messages.Message):
  r"""A ComputePublicAdvertisedPrefixesInsertRequest object.

  Fields:
    project: Project ID for this request.
    publicAdvertisedPrefix: A PublicAdvertisedPrefix resource to be passed as
      the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  publicAdvertisedPrefix = _messages.MessageField('PublicAdvertisedPrefix', 2)
  requestId = _messages.StringField(3)


class ComputePublicAdvertisedPrefixesListRequest(_messages.Message):
  r"""A ComputePublicAdvertisedPrefixesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputePublicAdvertisedPrefixesPatchRequest(_messages.Message):
  r"""A ComputePublicAdvertisedPrefixesPatchRequest object.

  Fields:
    project: Project ID for this request.
    publicAdvertisedPrefix: Name of the PublicAdvertisedPrefix resource to
      patch.
    publicAdvertisedPrefixResource: A PublicAdvertisedPrefix resource to be
      passed as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  publicAdvertisedPrefix = _messages.StringField(2, required=True)
  publicAdvertisedPrefixResource = _messages.MessageField('PublicAdvertisedPrefix', 3)
  requestId = _messages.StringField(4)


class ComputePublicDelegatedPrefixesAggregatedListRequest(_messages.Message):
  r"""A ComputePublicDelegatedPrefixesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Name of the project scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputePublicDelegatedPrefixesDeleteRequest(_messages.Message):
  r"""A ComputePublicDelegatedPrefixesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    publicDelegatedPrefix: Name of the PublicDelegatedPrefix resource to
      delete.
    region: Name of the region of this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  publicDelegatedPrefix = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputePublicDelegatedPrefixesGetRequest(_messages.Message):
  r"""A ComputePublicDelegatedPrefixesGetRequest object.

  Fields:
    project: Project ID for this request.
    publicDelegatedPrefix: Name of the PublicDelegatedPrefix resource to
      return.
    region: Name of the region of this request.
  """

  project = _messages.StringField(1, required=True)
  publicDelegatedPrefix = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputePublicDelegatedPrefixesInsertRequest(_messages.Message):
  r"""A ComputePublicDelegatedPrefixesInsertRequest object.

  Fields:
    project: Project ID for this request.
    publicDelegatedPrefix: A PublicDelegatedPrefix resource to be passed as
      the request body.
    region: Name of the region of this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  publicDelegatedPrefix = _messages.MessageField('PublicDelegatedPrefix', 2)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputePublicDelegatedPrefixesListRequest(_messages.Message):
  r"""A ComputePublicDelegatedPrefixesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region of this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputePublicDelegatedPrefixesPatchRequest(_messages.Message):
  r"""A ComputePublicDelegatedPrefixesPatchRequest object.

  Fields:
    project: Project ID for this request.
    publicDelegatedPrefix: Name of the PublicDelegatedPrefix resource to
      patch.
    publicDelegatedPrefixResource: A PublicDelegatedPrefix resource to be
      passed as the request body.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  project = _messages.StringField(1, required=True)
  publicDelegatedPrefix = _messages.StringField(2, required=True)
  publicDelegatedPrefixResource = _messages.MessageField('PublicDelegatedPrefix', 3)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeRegionAutoscalersDeleteRequest(_messages.Message):
  r"""A ComputeRegionAutoscalersDeleteRequest object.

  Fields:
    autoscaler: Name of the autoscaler to delete.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  autoscaler = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionAutoscalersGetRequest(_messages.Message):
  r"""A ComputeRegionAutoscalersGetRequest object.

  Fields:
    autoscaler: Name of the autoscaler to return.
    project: Project ID for this request.
    region: Name of the region scoping this request.
  """

  autoscaler = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionAutoscalersInsertRequest(_messages.Message):
  r"""A ComputeRegionAutoscalersInsertRequest object.

  Fields:
    autoscaler: A Autoscaler resource to be passed as the request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  autoscaler = _messages.MessageField('Autoscaler', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionAutoscalersListRequest(_messages.Message):
  r"""A ComputeRegionAutoscalersListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionAutoscalersPatchRequest(_messages.Message):
  r"""A ComputeRegionAutoscalersPatchRequest object.

  Fields:
    autoscaler: Name of the autoscaler to patch.
    autoscalerResource: A Autoscaler resource to be passed as the request
      body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  autoscaler = _messages.StringField(1)
  autoscalerResource = _messages.MessageField('Autoscaler', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeRegionAutoscalersTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionAutoscalersTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionAutoscalersUpdateRequest(_messages.Message):
  r"""A ComputeRegionAutoscalersUpdateRequest object.

  Fields:
    autoscaler: Name of the autoscaler to update.
    autoscalerResource: A Autoscaler resource to be passed as the request
      body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  autoscaler = _messages.StringField(1)
  autoscalerResource = _messages.MessageField('Autoscaler', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeRegionBackendServicesDeleteRequest(_messages.Message):
  r"""A ComputeRegionBackendServicesDeleteRequest object.

  Fields:
    backendService: Name of the BackendService resource to delete.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  backendService = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionBackendServicesGetHealthRequest(_messages.Message):
  r"""A ComputeRegionBackendServicesGetHealthRequest object.

  Fields:
    backendService: Name of the BackendService resource for which to get
      health.
    project: A string attribute.
    region: Name of the region scoping this request.
    resourceGroupReference: A ResourceGroupReference resource to be passed as
      the request body.
  """

  backendService = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  resourceGroupReference = _messages.MessageField('ResourceGroupReference', 4)


class ComputeRegionBackendServicesGetRequest(_messages.Message):
  r"""A ComputeRegionBackendServicesGetRequest object.

  Fields:
    backendService: Name of the BackendService resource to return.
    project: Project ID for this request.
    region: Name of the region scoping this request.
  """

  backendService = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionBackendServicesInsertRequest(_messages.Message):
  r"""A ComputeRegionBackendServicesInsertRequest object.

  Fields:
    backendService: A BackendService resource to be passed as the request
      body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  backendService = _messages.MessageField('BackendService', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionBackendServicesListRequest(_messages.Message):
  r"""A ComputeRegionBackendServicesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionBackendServicesPatchRequest(_messages.Message):
  r"""A ComputeRegionBackendServicesPatchRequest object.

  Fields:
    backendService: Name of the BackendService resource to patch.
    backendServiceResource: A BackendService resource to be passed as the
      request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  backendService = _messages.StringField(1, required=True)
  backendServiceResource = _messages.MessageField('BackendService', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeRegionBackendServicesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionBackendServicesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionBackendServicesUpdateRequest(_messages.Message):
  r"""A ComputeRegionBackendServicesUpdateRequest object.

  Fields:
    backendService: Name of the BackendService resource to update.
    backendServiceResource: A BackendService resource to be passed as the
      request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  backendService = _messages.StringField(1, required=True)
  backendServiceResource = _messages.MessageField('BackendService', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeRegionCommitmentsAggregatedListRequest(_messages.Message):
  r"""A ComputeRegionCommitmentsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionCommitmentsGetRequest(_messages.Message):
  r"""A ComputeRegionCommitmentsGetRequest object.

  Fields:
    commitment: Name of the commitment to return.
    project: Project ID for this request.
    region: Name of the region for this request.
  """

  commitment = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionCommitmentsInsertRequest(_messages.Message):
  r"""A ComputeRegionCommitmentsInsertRequest object.

  Fields:
    commitment: A Commitment resource to be passed as the request body.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  commitment = _messages.MessageField('Commitment', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionCommitmentsListRequest(_messages.Message):
  r"""A ComputeRegionCommitmentsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionCommitmentsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionCommitmentsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionCommitmentsUpdateReservationsRequest(_messages.Message):
  r"""A ComputeRegionCommitmentsUpdateReservationsRequest object.

  Fields:
    commitment: Name of the commitment for which the reservation is being
      updated.
    project: Project ID for this request.
    region: Name of the region for this request.
    regionCommitmentsUpdateReservationsRequest: A
      RegionCommitmentsUpdateReservationsRequest resource to be passed as the
      request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  commitment = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionCommitmentsUpdateReservationsRequest = _messages.MessageField('RegionCommitmentsUpdateReservationsRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionDiskTypesGetRequest(_messages.Message):
  r"""A ComputeRegionDiskTypesGetRequest object.

  Fields:
    diskType: Name of the disk type to return.
    project: Project ID for this request.
    region: The name of the region for this request.
  """

  diskType = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionDiskTypesListRequest(_messages.Message):
  r"""A ComputeRegionDiskTypesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: The name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionDisksAddResourcePoliciesRequest(_messages.Message):
  r"""A ComputeRegionDisksAddResourcePoliciesRequest object.

  Fields:
    disk: The disk name for this request.
    project: Project ID for this request.
    region: The name of the region for this request.
    regionDisksAddResourcePoliciesRequest: A
      RegionDisksAddResourcePoliciesRequest resource to be passed as the
      request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  disk = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionDisksAddResourcePoliciesRequest = _messages.MessageField('RegionDisksAddResourcePoliciesRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionDisksCreateSnapshotRequest(_messages.Message):
  r"""A ComputeRegionDisksCreateSnapshotRequest object.

  Fields:
    disk: Name of the regional persistent disk to snapshot.
    guestFlush: [Input Only] Specifies to create an application consistent
      snapshot by informing the OS to prepare for the snapshot process.
      Currently only supported on Windows instances using the Volume Shadow
      Copy Service (VSS).
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    snapshot: A Snapshot resource to be passed as the request body.
  """

  disk = _messages.StringField(1, required=True)
  guestFlush = _messages.BooleanField(2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)
  snapshot = _messages.MessageField('Snapshot', 6)


class ComputeRegionDisksDeleteRequest(_messages.Message):
  r"""A ComputeRegionDisksDeleteRequest object.

  Fields:
    disk: Name of the regional persistent disk to delete.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  disk = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionDisksGetIamPolicyRequest(_messages.Message):
  r"""A ComputeRegionDisksGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  resource = _messages.StringField(4, required=True)


class ComputeRegionDisksGetRequest(_messages.Message):
  r"""A ComputeRegionDisksGetRequest object.

  Fields:
    disk: Name of the regional persistent disk to return.
    project: Project ID for this request.
    region: Name of the region for this request.
  """

  disk = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionDisksInsertRequest(_messages.Message):
  r"""A ComputeRegionDisksInsertRequest object.

  Fields:
    disk: A Disk resource to be passed as the request body.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    sourceImage: Optional. Source image to restore onto a disk.
  """

  disk = _messages.MessageField('Disk', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  sourceImage = _messages.StringField(5)


class ComputeRegionDisksListRequest(_messages.Message):
  r"""A ComputeRegionDisksListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionDisksRemoveResourcePoliciesRequest(_messages.Message):
  r"""A ComputeRegionDisksRemoveResourcePoliciesRequest object.

  Fields:
    disk: The disk name for this request.
    project: Project ID for this request.
    region: The name of the region for this request.
    regionDisksRemoveResourcePoliciesRequest: A
      RegionDisksRemoveResourcePoliciesRequest resource to be passed as the
      request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  disk = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionDisksRemoveResourcePoliciesRequest = _messages.MessageField('RegionDisksRemoveResourcePoliciesRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionDisksResizeRequest(_messages.Message):
  r"""A ComputeRegionDisksResizeRequest object.

  Fields:
    disk: Name of the regional persistent disk.
    project: The project ID for this request.
    region: Name of the region for this request.
    regionDisksResizeRequest: A RegionDisksResizeRequest resource to be passed
      as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  disk = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionDisksResizeRequest = _messages.MessageField('RegionDisksResizeRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionDisksSetIamPolicyRequest(_messages.Message):
  r"""A ComputeRegionDisksSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    regionSetPolicyRequest: A RegionSetPolicyRequest resource to be passed as
      the request body.
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetPolicyRequest = _messages.MessageField('RegionSetPolicyRequest', 3)
  resource = _messages.StringField(4, required=True)


class ComputeRegionDisksSetLabelsRequest(_messages.Message):
  r"""A ComputeRegionDisksSetLabelsRequest object.

  Fields:
    project: Project ID for this request.
    region: The region for this request.
    regionSetLabelsRequest: A RegionSetLabelsRequest resource to be passed as
      the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetLabelsRequest = _messages.MessageField('RegionSetLabelsRequest', 3)
  requestId = _messages.StringField(4)
  resource = _messages.StringField(5, required=True)


class ComputeRegionDisksTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionDisksTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionHealthCheckServicesDeleteRequest(_messages.Message):
  r"""A ComputeRegionHealthCheckServicesDeleteRequest object.

  Fields:
    healthCheckService: Name of the HealthCheckService to delete. The name
      must be 1-63 characters long, and comply with RFC1035.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  healthCheckService = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionHealthCheckServicesGetRequest(_messages.Message):
  r"""A ComputeRegionHealthCheckServicesGetRequest object.

  Fields:
    healthCheckService: Name of the HealthCheckService to update. The name
      must be 1-63 characters long, and comply with RFC1035.
    project: Project ID for this request.
    region: Name of the region scoping this request.
  """

  healthCheckService = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionHealthCheckServicesInsertRequest(_messages.Message):
  r"""A ComputeRegionHealthCheckServicesInsertRequest object.

  Fields:
    healthCheckService: A HealthCheckService resource to be passed as the
      request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  healthCheckService = _messages.MessageField('HealthCheckService', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionHealthCheckServicesListRequest(_messages.Message):
  r"""A ComputeRegionHealthCheckServicesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionHealthCheckServicesPatchRequest(_messages.Message):
  r"""A ComputeRegionHealthCheckServicesPatchRequest object.

  Fields:
    healthCheckService: Name of the HealthCheckService to update. The name
      must be 1-63 characters long, and comply with RFC1035.
    healthCheckServiceResource: A HealthCheckService resource to be passed as
      the request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  healthCheckService = _messages.StringField(1, required=True)
  healthCheckServiceResource = _messages.MessageField('HealthCheckService', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeRegionHealthCheckServicesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionHealthCheckServicesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionHealthChecksDeleteRequest(_messages.Message):
  r"""A ComputeRegionHealthChecksDeleteRequest object.

  Fields:
    healthCheck: Name of the HealthCheck resource to delete.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  healthCheck = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionHealthChecksGetRequest(_messages.Message):
  r"""A ComputeRegionHealthChecksGetRequest object.

  Fields:
    healthCheck: Name of the HealthCheck resource to return.
    project: Project ID for this request.
    region: Name of the region scoping this request.
  """

  healthCheck = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionHealthChecksInsertRequest(_messages.Message):
  r"""A ComputeRegionHealthChecksInsertRequest object.

  Fields:
    healthCheck: A HealthCheck resource to be passed as the request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  healthCheck = _messages.MessageField('HealthCheck', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionHealthChecksListRequest(_messages.Message):
  r"""A ComputeRegionHealthChecksListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionHealthChecksPatchRequest(_messages.Message):
  r"""A ComputeRegionHealthChecksPatchRequest object.

  Fields:
    healthCheck: Name of the HealthCheck resource to patch.
    healthCheckResource: A HealthCheck resource to be passed as the request
      body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  healthCheck = _messages.StringField(1, required=True)
  healthCheckResource = _messages.MessageField('HealthCheck', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeRegionHealthChecksTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionHealthChecksTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionHealthChecksUpdateRequest(_messages.Message):
  r"""A ComputeRegionHealthChecksUpdateRequest object.

  Fields:
    healthCheck: Name of the HealthCheck resource to update.
    healthCheckResource: A HealthCheck resource to be passed as the request
      body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  healthCheck = _messages.StringField(1, required=True)
  healthCheckResource = _messages.MessageField('HealthCheck', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeRegionInPlaceSnapshotsDeleteRequest(_messages.Message):
  r"""A ComputeRegionInPlaceSnapshotsDeleteRequest object.

  Fields:
    inPlaceSnapshot: Name of the InPlaceSnapshot resource to delete.
    project: Project ID for this request.
    region: The name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  inPlaceSnapshot = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionInPlaceSnapshotsGetIamPolicyRequest(_messages.Message):
  r"""A ComputeRegionInPlaceSnapshotsGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  resource = _messages.StringField(4, required=True)


class ComputeRegionInPlaceSnapshotsGetRequest(_messages.Message):
  r"""A ComputeRegionInPlaceSnapshotsGetRequest object.

  Fields:
    inPlaceSnapshot: Name of the InPlaceSnapshot resource to return.
    project: Project ID for this request.
    region: The name of the region for this request.
  """

  inPlaceSnapshot = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionInPlaceSnapshotsInsertRequest(_messages.Message):
  r"""A ComputeRegionInPlaceSnapshotsInsertRequest object.

  Fields:
    inPlaceSnapshot: A InPlaceSnapshot resource to be passed as the request
      body.
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  inPlaceSnapshot = _messages.MessageField('InPlaceSnapshot', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionInPlaceSnapshotsListRequest(_messages.Message):
  r"""A ComputeRegionInPlaceSnapshotsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: The name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionInPlaceSnapshotsSetIamPolicyRequest(_messages.Message):
  r"""A ComputeRegionInPlaceSnapshotsSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    regionSetPolicyRequest: A RegionSetPolicyRequest resource to be passed as
      the request body.
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetPolicyRequest = _messages.MessageField('RegionSetPolicyRequest', 3)
  resource = _messages.StringField(4, required=True)


class ComputeRegionInPlaceSnapshotsSetLabelsRequest(_messages.Message):
  r"""A ComputeRegionInPlaceSnapshotsSetLabelsRequest object.

  Fields:
    project: Project ID for this request.
    region: The region for this request.
    regionSetLabelsRequest: A RegionSetLabelsRequest resource to be passed as
      the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetLabelsRequest = _messages.MessageField('RegionSetLabelsRequest', 3)
  requestId = _messages.StringField(4)
  resource = _messages.StringField(5, required=True)


class ComputeRegionInPlaceSnapshotsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionInPlaceSnapshotsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionInstanceGroupManagersAbandonInstancesRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersAbandonInstancesRequest object.

  Fields:
    instanceGroupManager: Name of the managed instance group.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    regionInstanceGroupManagersAbandonInstancesRequest: A
      RegionInstanceGroupManagersAbandonInstancesRequest resource to be passed
      as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupManagersAbandonInstancesRequest = _messages.MessageField('RegionInstanceGroupManagersAbandonInstancesRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupManagersApplyUpdatesToInstancesRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersApplyUpdatesToInstancesRequest
  object.

  Fields:
    instanceGroupManager: The name of the managed instance group, should
      conform to RFC1035.
    project: Project ID for this request.
    region: Name of the region scoping this request, should conform to
      RFC1035.
    regionInstanceGroupManagersApplyUpdatesRequest: A
      RegionInstanceGroupManagersApplyUpdatesRequest resource to be passed as
      the request body.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupManagersApplyUpdatesRequest = _messages.MessageField('RegionInstanceGroupManagersApplyUpdatesRequest', 4)


class ComputeRegionInstanceGroupManagersCreateInstancesRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersCreateInstancesRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group. It should
      conform to RFC1035.
    project: Project ID for this request.
    region: The name of the region where the managed instance group is
      located. It should conform to RFC1035.
    regionInstanceGroupManagersCreateInstancesRequest: A
      RegionInstanceGroupManagersCreateInstancesRequest resource to be passed
      as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request.  The request ID
      must be a valid UUID with the exception that zero UUID is not supported
      (00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupManagersCreateInstancesRequest = _messages.MessageField('RegionInstanceGroupManagersCreateInstancesRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupManagersDeleteInstancesRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersDeleteInstancesRequest object.

  Fields:
    instanceGroupManager: Name of the managed instance group.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    regionInstanceGroupManagersDeleteInstancesRequest: A
      RegionInstanceGroupManagersDeleteInstancesRequest resource to be passed
      as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupManagersDeleteInstancesRequest = _messages.MessageField('RegionInstanceGroupManagersDeleteInstancesRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupManagersDeletePerInstanceConfigsRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersDeletePerInstanceConfigsRequest
  object.

  Fields:
    instanceGroupManager: The name of the managed instance group. It should
      conform to RFC1035.
    project: Project ID for this request.
    region: Name of the region scoping this request, should conform to
      RFC1035.
    regionInstanceGroupManagerDeleteInstanceConfigReq: A
      RegionInstanceGroupManagerDeleteInstanceConfigReq resource to be passed
      as the request body.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupManagerDeleteInstanceConfigReq = _messages.MessageField('RegionInstanceGroupManagerDeleteInstanceConfigReq', 4)


class ComputeRegionInstanceGroupManagersDeleteRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersDeleteRequest object.

  Fields:
    instanceGroupManager: Name of the managed instance group to delete.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionInstanceGroupManagersGetRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersGetRequest object.

  Fields:
    instanceGroupManager: Name of the managed instance group to return.
    project: Project ID for this request.
    region: Name of the region scoping this request.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionInstanceGroupManagersInsertRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersInsertRequest object.

  Fields:
    instanceGroupManager: A InstanceGroupManager resource to be passed as the
      request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.MessageField('InstanceGroupManager', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionInstanceGroupManagersListErrorsRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersListErrorsRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    instanceGroupManager: The name of the managed instance group. It must be a
      string that meets the requirements in RFC1035, or an unsigned long
      integer: must match regexp pattern:
      (?:[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?)|[1-9][0-9]{0,19}.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request. This should conform to
      RFC1035.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  instanceGroupManager = _messages.StringField(2, required=True)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  region = _messages.StringField(7, required=True)
  returnPartialSuccess = _messages.BooleanField(8)


class ComputeRegionInstanceGroupManagersListManagedInstancesRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersListManagedInstancesRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    instanceGroupManager: The name of the managed instance group.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
  """

  filter = _messages.StringField(1)
  instanceGroupManager = _messages.StringField(2, required=True)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  region = _messages.StringField(7, required=True)


class ComputeRegionInstanceGroupManagersListPerInstanceConfigsRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersListPerInstanceConfigsRequest
  object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    instanceGroupManager: The name of the managed instance group. It should
      conform to RFC1035.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request, should conform to
      RFC1035.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  instanceGroupManager = _messages.StringField(2, required=True)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  region = _messages.StringField(7, required=True)
  returnPartialSuccess = _messages.BooleanField(8)


class ComputeRegionInstanceGroupManagersListRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionInstanceGroupManagersPatchPerInstanceConfigsRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersPatchPerInstanceConfigsRequest
  object.

  Fields:
    instanceGroupManager: The name of the managed instance group. It should
      conform to RFC1035.
    project: Project ID for this request.
    region: Name of the region scoping this request, should conform to
      RFC1035.
    regionInstanceGroupManagerPatchInstanceConfigReq: A
      RegionInstanceGroupManagerPatchInstanceConfigReq resource to be passed
      as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupManagerPatchInstanceConfigReq = _messages.MessageField('RegionInstanceGroupManagerPatchInstanceConfigReq', 4)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupManagersPatchRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersPatchRequest object.

  Fields:
    instanceGroupManager: The name of the instance group manager.
    instanceGroupManagerResource: A InstanceGroupManager resource to be passed
      as the request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagerResource = _messages.MessageField('InstanceGroupManager', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupManagersRecreateInstancesRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersRecreateInstancesRequest object.

  Fields:
    instanceGroupManager: Name of the managed instance group.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    regionInstanceGroupManagersRecreateRequest: A
      RegionInstanceGroupManagersRecreateRequest resource to be passed as the
      request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupManagersRecreateRequest = _messages.MessageField('RegionInstanceGroupManagersRecreateRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupManagersResizeRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersResizeRequest object.

  Fields:
    instanceGroupManager: Name of the managed instance group.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    size: Number of instances that should exist in this instance group
      manager.
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  size = _messages.IntegerField(5, required=True, variant=_messages.Variant.INT32)


class ComputeRegionInstanceGroupManagersSetAutoHealingPoliciesRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersSetAutoHealingPoliciesRequest
  object.

  Fields:
    instanceGroupManager: Name of the managed instance group.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    regionInstanceGroupManagersSetAutoHealingRequest: A
      RegionInstanceGroupManagersSetAutoHealingRequest resource to be passed
      as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupManagersSetAutoHealingRequest = _messages.MessageField('RegionInstanceGroupManagersSetAutoHealingRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupManagersSetInstanceTemplateRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersSetInstanceTemplateRequest object.

  Fields:
    instanceGroupManager: The name of the managed instance group.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    regionInstanceGroupManagersSetTemplateRequest: A
      RegionInstanceGroupManagersSetTemplateRequest resource to be passed as
      the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupManagersSetTemplateRequest = _messages.MessageField('RegionInstanceGroupManagersSetTemplateRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupManagersSetTargetPoolsRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersSetTargetPoolsRequest object.

  Fields:
    instanceGroupManager: Name of the managed instance group.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    regionInstanceGroupManagersSetTargetPoolsRequest: A
      RegionInstanceGroupManagersSetTargetPoolsRequest resource to be passed
      as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupManagersSetTargetPoolsRequest = _messages.MessageField('RegionInstanceGroupManagersSetTargetPoolsRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupManagersTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionInstanceGroupManagersUpdatePerInstanceConfigsRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersUpdatePerInstanceConfigsRequest
  object.

  Fields:
    instanceGroupManager: The name of the managed instance group. It should
      conform to RFC1035.
    project: Project ID for this request.
    region: Name of the region scoping this request, should conform to
      RFC1035.
    regionInstanceGroupManagerUpdateInstanceConfigReq: A
      RegionInstanceGroupManagerUpdateInstanceConfigReq resource to be passed
      as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupManagerUpdateInstanceConfigReq = _messages.MessageField('RegionInstanceGroupManagerUpdateInstanceConfigReq', 4)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupManagersUpdateRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupManagersUpdateRequest object.

  Fields:
    instanceGroupManager: The name of the instance group manager.
    instanceGroupManagerResource: A InstanceGroupManager resource to be passed
      as the request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  instanceGroupManager = _messages.StringField(1, required=True)
  instanceGroupManagerResource = _messages.MessageField('InstanceGroupManager', 2)
  project = _messages.StringField(3, required=True)
  region = _messages.StringField(4, required=True)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupsGetRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupsGetRequest object.

  Fields:
    instanceGroup: Name of the instance group resource to return.
    project: Project ID for this request.
    region: Name of the region scoping this request.
  """

  instanceGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionInstanceGroupsListInstancesRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupsListInstancesRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    instanceGroup: Name of the regional instance group for which we want to
      list the instances.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    regionInstanceGroupsListInstancesRequest: A
      RegionInstanceGroupsListInstancesRequest resource to be passed as the
      request body.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  instanceGroup = _messages.StringField(2, required=True)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  region = _messages.StringField(7, required=True)
  regionInstanceGroupsListInstancesRequest = _messages.MessageField('RegionInstanceGroupsListInstancesRequest', 8)
  returnPartialSuccess = _messages.BooleanField(9)


class ComputeRegionInstanceGroupsListRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionInstanceGroupsSetNamedPortsRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupsSetNamedPortsRequest object.

  Fields:
    instanceGroup: The name of the regional instance group where the named
      ports are updated.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    regionInstanceGroupsSetNamedPortsRequest: A
      RegionInstanceGroupsSetNamedPortsRequest resource to be passed as the
      request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  instanceGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  regionInstanceGroupsSetNamedPortsRequest = _messages.MessageField('RegionInstanceGroupsSetNamedPortsRequest', 4)
  requestId = _messages.StringField(5)


class ComputeRegionInstanceGroupsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionInstanceGroupsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionInstancesBulkInsertRequest(_messages.Message):
  r"""A ComputeRegionInstancesBulkInsertRequest object.

  Fields:
    bulkInsertInstanceResource: A BulkInsertInstanceResource resource to be
      passed as the request body.
    project: Project ID for this request.
    region: The name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  bulkInsertInstanceResource = _messages.MessageField('BulkInsertInstanceResource', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionNetworkEndpointGroupsDeleteRequest(_messages.Message):
  r"""A ComputeRegionNetworkEndpointGroupsDeleteRequest object.

  Fields:
    networkEndpointGroup: The name of the network endpoint group to delete. It
      should comply with RFC1035.
    project: Project ID for this request.
    region: The name of the region where the network endpoint group is
      located. It should comply with RFC1035.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  networkEndpointGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionNetworkEndpointGroupsGetRequest(_messages.Message):
  r"""A ComputeRegionNetworkEndpointGroupsGetRequest object.

  Fields:
    networkEndpointGroup: The name of the network endpoint group. It should
      comply with RFC1035.
    project: Project ID for this request.
    region: The name of the region where the network endpoint group is
      located. It should comply with RFC1035.
  """

  networkEndpointGroup = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionNetworkEndpointGroupsInsertRequest(_messages.Message):
  r"""A ComputeRegionNetworkEndpointGroupsInsertRequest object.

  Fields:
    networkEndpointGroup: A NetworkEndpointGroup resource to be passed as the
      request body.
    project: Project ID for this request.
    region: The name of the region where you want to create the network
      endpoint group. It should comply with RFC1035.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  networkEndpointGroup = _messages.MessageField('NetworkEndpointGroup', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionNetworkEndpointGroupsListRequest(_messages.Message):
  r"""A ComputeRegionNetworkEndpointGroupsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: The name of the region where the network endpoint group is
      located. It should comply with RFC1035.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionNotificationEndpointsDeleteRequest(_messages.Message):
  r"""A ComputeRegionNotificationEndpointsDeleteRequest object.

  Fields:
    notificationEndpoint: Name of the NotificationEndpoint resource to delete.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  notificationEndpoint = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionNotificationEndpointsGetRequest(_messages.Message):
  r"""A ComputeRegionNotificationEndpointsGetRequest object.

  Fields:
    notificationEndpoint: Name of the NotificationEndpoint resource to return.
    project: Project ID for this request.
    region: Name of the region scoping this request.
  """

  notificationEndpoint = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionNotificationEndpointsInsertRequest(_messages.Message):
  r"""A ComputeRegionNotificationEndpointsInsertRequest object.

  Fields:
    notificationEndpoint: A NotificationEndpoint resource to be passed as the
      request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
  """

  notificationEndpoint = _messages.MessageField('NotificationEndpoint', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)


class ComputeRegionNotificationEndpointsListRequest(_messages.Message):
  r"""A ComputeRegionNotificationEndpointsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionNotificationEndpointsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionNotificationEndpointsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionOperationsDeleteRequest(_messages.Message):
  r"""A ComputeRegionOperationsDeleteRequest object.

  Fields:
    operation: Name of the Operations resource to delete.
    project: Project ID for this request.
    region: Name of the region for this request.
  """

  operation = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionOperationsDeleteResponse(_messages.Message):
  r"""An empty ComputeRegionOperationsDelete response."""


class ComputeRegionOperationsGetRequest(_messages.Message):
  r"""A ComputeRegionOperationsGetRequest object.

  Fields:
    operation: Name of the Operations resource to return.
    project: Project ID for this request.
    region: Name of the region for this request.
  """

  operation = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionOperationsListRequest(_messages.Message):
  r"""A ComputeRegionOperationsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionOperationsWaitRequest(_messages.Message):
  r"""A ComputeRegionOperationsWaitRequest object.

  Fields:
    operation: Name of the Operations resource to return.
    project: Project ID for this request.
    region: Name of the region for this request.
  """

  operation = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)


class ComputeRegionSslCertificatesDeleteRequest(_messages.Message):
  r"""A ComputeRegionSslCertificatesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    sslCertificate: Name of the SslCertificate resource to delete.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  sslCertificate = _messages.StringField(4, required=True)


class ComputeRegionSslCertificatesGetRequest(_messages.Message):
  r"""A ComputeRegionSslCertificatesGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    sslCertificate: Name of the SslCertificate resource to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  sslCertificate = _messages.StringField(3, required=True)


class ComputeRegionSslCertificatesInsertRequest(_messages.Message):
  r"""A ComputeRegionSslCertificatesInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    sslCertificate: A SslCertificate resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  sslCertificate = _messages.MessageField('SslCertificate', 4)


class ComputeRegionSslCertificatesListRequest(_messages.Message):
  r"""A ComputeRegionSslCertificatesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionSslCertificatesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionSslCertificatesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionTargetHttpProxiesDeleteRequest(_messages.Message):
  r"""A ComputeRegionTargetHttpProxiesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetHttpProxy: Name of the TargetHttpProxy resource to delete.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetHttpProxy = _messages.StringField(4, required=True)


class ComputeRegionTargetHttpProxiesGetRequest(_messages.Message):
  r"""A ComputeRegionTargetHttpProxiesGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    targetHttpProxy: Name of the TargetHttpProxy resource to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  targetHttpProxy = _messages.StringField(3, required=True)


class ComputeRegionTargetHttpProxiesInsertRequest(_messages.Message):
  r"""A ComputeRegionTargetHttpProxiesInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetHttpProxy: A TargetHttpProxy resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetHttpProxy = _messages.MessageField('TargetHttpProxy', 4)


class ComputeRegionTargetHttpProxiesListRequest(_messages.Message):
  r"""A ComputeRegionTargetHttpProxiesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionTargetHttpProxiesSetUrlMapRequest(_messages.Message):
  r"""A ComputeRegionTargetHttpProxiesSetUrlMapRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetHttpProxy: Name of the TargetHttpProxy to set a URL map for.
    urlMapReference: A UrlMapReference resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetHttpProxy = _messages.StringField(4, required=True)
  urlMapReference = _messages.MessageField('UrlMapReference', 5)


class ComputeRegionTargetHttpProxiesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionTargetHttpProxiesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionTargetHttpsProxiesDeleteRequest(_messages.Message):
  r"""A ComputeRegionTargetHttpsProxiesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetHttpsProxy: Name of the TargetHttpsProxy resource to delete.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetHttpsProxy = _messages.StringField(4, required=True)


class ComputeRegionTargetHttpsProxiesGetRequest(_messages.Message):
  r"""A ComputeRegionTargetHttpsProxiesGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    targetHttpsProxy: Name of the TargetHttpsProxy resource to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  targetHttpsProxy = _messages.StringField(3, required=True)


class ComputeRegionTargetHttpsProxiesInsertRequest(_messages.Message):
  r"""A ComputeRegionTargetHttpsProxiesInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetHttpsProxy: A TargetHttpsProxy resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetHttpsProxy = _messages.MessageField('TargetHttpsProxy', 4)


class ComputeRegionTargetHttpsProxiesListRequest(_messages.Message):
  r"""A ComputeRegionTargetHttpsProxiesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionTargetHttpsProxiesSetSslCertificatesRequest(_messages.Message):
  r"""A ComputeRegionTargetHttpsProxiesSetSslCertificatesRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    regionTargetHttpsProxiesSetSslCertificatesRequest: A
      RegionTargetHttpsProxiesSetSslCertificatesRequest resource to be passed
      as the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetHttpsProxy: Name of the TargetHttpsProxy resource to set an
      SslCertificates resource for.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionTargetHttpsProxiesSetSslCertificatesRequest = _messages.MessageField('RegionTargetHttpsProxiesSetSslCertificatesRequest', 3)
  requestId = _messages.StringField(4)
  targetHttpsProxy = _messages.StringField(5, required=True)


class ComputeRegionTargetHttpsProxiesSetUrlMapRequest(_messages.Message):
  r"""A ComputeRegionTargetHttpsProxiesSetUrlMapRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetHttpsProxy: Name of the TargetHttpsProxy to set a URL map for.
    urlMapReference: A UrlMapReference resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetHttpsProxy = _messages.StringField(4, required=True)
  urlMapReference = _messages.MessageField('UrlMapReference', 5)


class ComputeRegionTargetHttpsProxiesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionTargetHttpsProxiesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionUrlMapsDeleteRequest(_messages.Message):
  r"""A ComputeRegionUrlMapsDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: begin_interface: MixerMutationRequestBuilder Request ID to
      support idempotency.
    urlMap: Name of the UrlMap resource to delete.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  urlMap = _messages.StringField(4, required=True)


class ComputeRegionUrlMapsGetRequest(_messages.Message):
  r"""A ComputeRegionUrlMapsGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    urlMap: Name of the UrlMap resource to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  urlMap = _messages.StringField(3, required=True)


class ComputeRegionUrlMapsInsertRequest(_messages.Message):
  r"""A ComputeRegionUrlMapsInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: begin_interface: MixerMutationRequestBuilder Request ID to
      support idempotency.
    urlMap: A UrlMap resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  urlMap = _messages.MessageField('UrlMap', 4)


class ComputeRegionUrlMapsInvalidateCacheRequest(_messages.Message):
  r"""A ComputeRegionUrlMapsInvalidateCacheRequest object.

  Fields:
    cacheInvalidationRule: A CacheInvalidationRule resource to be passed as
      the request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: begin_interface: MixerMutationRequestBuilder Request ID to
      support idempotency.
    urlMap: Name of the UrlMap scoping this request.
  """

  cacheInvalidationRule = _messages.MessageField('CacheInvalidationRule', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  urlMap = _messages.StringField(5, required=True)


class ComputeRegionUrlMapsListRequest(_messages.Message):
  r"""A ComputeRegionUrlMapsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRegionUrlMapsPatchRequest(_messages.Message):
  r"""A ComputeRegionUrlMapsPatchRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: begin_interface: MixerMutationRequestBuilder Request ID to
      support idempotency.
    urlMap: Name of the UrlMap resource to patch.
    urlMapResource: A UrlMap resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  urlMap = _messages.StringField(4, required=True)
  urlMapResource = _messages.MessageField('UrlMap', 5)


class ComputeRegionUrlMapsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRegionUrlMapsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRegionUrlMapsUpdateRequest(_messages.Message):
  r"""A ComputeRegionUrlMapsUpdateRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: begin_interface: MixerMutationRequestBuilder Request ID to
      support idempotency.
    urlMap: Name of the UrlMap resource to update.
    urlMapResource: A UrlMap resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  urlMap = _messages.StringField(4, required=True)
  urlMapResource = _messages.MessageField('UrlMap', 5)


class ComputeRegionUrlMapsValidateRequest(_messages.Message):
  r"""A ComputeRegionUrlMapsValidateRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    regionUrlMapsValidateRequest: A RegionUrlMapsValidateRequest resource to
      be passed as the request body.
    urlMap: Name of the UrlMap resource to be validated as.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionUrlMapsValidateRequest = _messages.MessageField('RegionUrlMapsValidateRequest', 3)
  urlMap = _messages.StringField(4, required=True)


class ComputeRegionsGetRequest(_messages.Message):
  r"""A ComputeRegionsGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region resource to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)


class ComputeRegionsListRequest(_messages.Message):
  r"""A ComputeRegionsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeReservationsAggregatedListRequest(_messages.Message):
  r"""A ComputeReservationsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeReservationsDeleteRequest(_messages.Message):
  r"""A ComputeReservationsDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    reservation: Name of the reservation to delete.
    zone: Name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  reservation = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)


class ComputeReservationsGetIamPolicyRequest(_messages.Message):
  r"""A ComputeReservationsGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)


class ComputeReservationsGetRequest(_messages.Message):
  r"""A ComputeReservationsGetRequest object.

  Fields:
    project: Project ID for this request.
    reservation: Name of the reservation to retrieve.
    zone: Name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  reservation = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeReservationsInsertRequest(_messages.Message):
  r"""A ComputeReservationsInsertRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    reservation: A Reservation resource to be passed as the request body.
    zone: Name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  reservation = _messages.MessageField('Reservation', 3)
  zone = _messages.StringField(4, required=True)


class ComputeReservationsListRequest(_messages.Message):
  r"""A ComputeReservationsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
    zone: Name of the zone for this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeReservationsResizeRequest(_messages.Message):
  r"""A ComputeReservationsResizeRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    reservation: Name of the reservation to update.
    reservationsResizeRequest: A ReservationsResizeRequest resource to be
      passed as the request body.
    zone: Name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  reservation = _messages.StringField(3, required=True)
  reservationsResizeRequest = _messages.MessageField('ReservationsResizeRequest', 4)
  zone = _messages.StringField(5, required=True)


class ComputeReservationsSetIamPolicyRequest(_messages.Message):
  r"""A ComputeReservationsSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
    zoneSetPolicyRequest: A ZoneSetPolicyRequest resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)
  zoneSetPolicyRequest = _messages.MessageField('ZoneSetPolicyRequest', 4)


class ComputeReservationsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeReservationsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
    zone: The name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)
  zone = _messages.StringField(4, required=True)


class ComputeResourcePoliciesAggregatedListRequest(_messages.Message):
  r"""A ComputeResourcePoliciesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeResourcePoliciesDeleteRequest(_messages.Message):
  r"""A ComputeResourcePoliciesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    resourcePolicy: Name of the resource policy to delete.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  resourcePolicy = _messages.StringField(4, required=True)


class ComputeResourcePoliciesGetIamPolicyRequest(_messages.Message):
  r"""A ComputeResourcePoliciesGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  resource = _messages.StringField(4, required=True)


class ComputeResourcePoliciesGetRequest(_messages.Message):
  r"""A ComputeResourcePoliciesGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    resourcePolicy: Name of the resource policy to retrieve.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resourcePolicy = _messages.StringField(3, required=True)


class ComputeResourcePoliciesInsertRequest(_messages.Message):
  r"""A ComputeResourcePoliciesInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    resourcePolicy: A ResourcePolicy resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  resourcePolicy = _messages.MessageField('ResourcePolicy', 4)


class ComputeResourcePoliciesListRequest(_messages.Message):
  r"""A ComputeResourcePoliciesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeResourcePoliciesSetIamPolicyRequest(_messages.Message):
  r"""A ComputeResourcePoliciesSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    regionSetPolicyRequest: A RegionSetPolicyRequest resource to be passed as
      the request body.
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetPolicyRequest = _messages.MessageField('RegionSetPolicyRequest', 3)
  resource = _messages.StringField(4, required=True)


class ComputeResourcePoliciesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeResourcePoliciesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRoutersAggregatedListRequest(_messages.Message):
  r"""A ComputeRoutersAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRoutersDeleteRequest(_messages.Message):
  r"""A ComputeRoutersDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    router: Name of the Router resource to delete.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  router = _messages.StringField(4, required=True)


class ComputeRoutersGetNatMappingInfoRequest(_messages.Message):
  r"""A ComputeRoutersGetNatMappingInfoRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    natName: Name of the nat service to filter the Nat Mapping information. If
      it is omitted, all nats for this router will be returned. Name should
      conform to RFC1035.
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
    router: Name of the Router resource to query for Nat Mapping information
      of VM endpoints.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  natName = _messages.StringField(3)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  region = _messages.StringField(7, required=True)
  returnPartialSuccess = _messages.BooleanField(8)
  router = _messages.StringField(9, required=True)


class ComputeRoutersGetRequest(_messages.Message):
  r"""A ComputeRoutersGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    router: Name of the Router resource to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  router = _messages.StringField(3, required=True)


class ComputeRoutersGetRouterStatusRequest(_messages.Message):
  r"""A ComputeRoutersGetRouterStatusRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    router: Name of the Router resource to query.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  router = _messages.StringField(3, required=True)


class ComputeRoutersInsertRequest(_messages.Message):
  r"""A ComputeRoutersInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    router: A Router resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  router = _messages.MessageField('Router', 4)


class ComputeRoutersListRequest(_messages.Message):
  r"""A ComputeRoutersListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeRoutersPatchRequest(_messages.Message):
  r"""A ComputeRoutersPatchRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    router: Name of the Router resource to patch.
    routerResource: A Router resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  router = _messages.StringField(4, required=True)
  routerResource = _messages.MessageField('Router', 5)


class ComputeRoutersPreviewRequest(_messages.Message):
  r"""A ComputeRoutersPreviewRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    router: Name of the Router resource to query.
    routerResource: A Router resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  router = _messages.StringField(3, required=True)
  routerResource = _messages.MessageField('Router', 4)


class ComputeRoutersTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRoutersTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeRoutersUpdateRequest(_messages.Message):
  r"""A ComputeRoutersUpdateRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    router: Name of the Router resource to update.
    routerResource: A Router resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  router = _messages.StringField(4, required=True)
  routerResource = _messages.MessageField('Router', 5)


class ComputeRoutesDeleteRequest(_messages.Message):
  r"""A ComputeRoutesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    route: Name of the Route resource to delete.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  route = _messages.StringField(3, required=True)


class ComputeRoutesGetRequest(_messages.Message):
  r"""A ComputeRoutesGetRequest object.

  Fields:
    project: Project ID for this request.
    route: Name of the Route resource to return.
  """

  project = _messages.StringField(1, required=True)
  route = _messages.StringField(2, required=True)


class ComputeRoutesInsertRequest(_messages.Message):
  r"""A ComputeRoutesInsertRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    route: A Route resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  route = _messages.MessageField('Route', 3)


class ComputeRoutesListRequest(_messages.Message):
  r"""A ComputeRoutesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeRoutesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeRoutesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeSecurityPoliciesAddRuleRequest(_messages.Message):
  r"""A ComputeSecurityPoliciesAddRuleRequest object.

  Fields:
    project: Project ID for this request.
    securityPolicy: Name of the security policy to update.
    securityPolicyRule: A SecurityPolicyRule resource to be passed as the
      request body.
    validateOnly: If true, the request will not be committed.
  """

  project = _messages.StringField(1, required=True)
  securityPolicy = _messages.StringField(2, required=True)
  securityPolicyRule = _messages.MessageField('SecurityPolicyRule', 3)
  validateOnly = _messages.BooleanField(4)


class ComputeSecurityPoliciesDeleteRequest(_messages.Message):
  r"""A ComputeSecurityPoliciesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    securityPolicy: Name of the security policy to delete.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  securityPolicy = _messages.StringField(3, required=True)


class ComputeSecurityPoliciesGetRequest(_messages.Message):
  r"""A ComputeSecurityPoliciesGetRequest object.

  Fields:
    project: Project ID for this request.
    securityPolicy: Name of the security policy to get.
  """

  project = _messages.StringField(1, required=True)
  securityPolicy = _messages.StringField(2, required=True)


class ComputeSecurityPoliciesGetRuleRequest(_messages.Message):
  r"""A ComputeSecurityPoliciesGetRuleRequest object.

  Fields:
    priority: The priority of the rule to get from the security policy.
    project: Project ID for this request.
    securityPolicy: Name of the security policy to which the queried rule
      belongs.
  """

  priority = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  securityPolicy = _messages.StringField(3, required=True)


class ComputeSecurityPoliciesInsertRequest(_messages.Message):
  r"""A ComputeSecurityPoliciesInsertRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    securityPolicy: A SecurityPolicy resource to be passed as the request
      body.
    validateOnly: If true, the request will not be committed.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  securityPolicy = _messages.MessageField('SecurityPolicy', 3)
  validateOnly = _messages.BooleanField(4)


class ComputeSecurityPoliciesListPreconfiguredExpressionSetsRequest(_messages.Message):
  r"""A ComputeSecurityPoliciesListPreconfiguredExpressionSetsRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeSecurityPoliciesListRequest(_messages.Message):
  r"""A ComputeSecurityPoliciesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeSecurityPoliciesPatchRequest(_messages.Message):
  r"""A ComputeSecurityPoliciesPatchRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    securityPolicy: Name of the security policy to update.
    securityPolicyResource: A SecurityPolicy resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  securityPolicy = _messages.StringField(3, required=True)
  securityPolicyResource = _messages.MessageField('SecurityPolicy', 4)


class ComputeSecurityPoliciesPatchRuleRequest(_messages.Message):
  r"""A ComputeSecurityPoliciesPatchRuleRequest object.

  Fields:
    priority: The priority of the rule to patch.
    project: Project ID for this request.
    securityPolicy: Name of the security policy to update.
    securityPolicyRule: A SecurityPolicyRule resource to be passed as the
      request body.
    validateOnly: If true, the request will not be committed.
  """

  priority = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  securityPolicy = _messages.StringField(3, required=True)
  securityPolicyRule = _messages.MessageField('SecurityPolicyRule', 4)
  validateOnly = _messages.BooleanField(5)


class ComputeSecurityPoliciesRemoveRuleRequest(_messages.Message):
  r"""A ComputeSecurityPoliciesRemoveRuleRequest object.

  Fields:
    priority: The priority of the rule to remove from the security policy.
    project: Project ID for this request.
    securityPolicy: Name of the security policy to update.
  """

  priority = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  securityPolicy = _messages.StringField(3, required=True)


class ComputeSecurityPoliciesSetLabelsRequest(_messages.Message):
  r"""A ComputeSecurityPoliciesSetLabelsRequest object.

  Fields:
    globalSetLabelsRequest: A GlobalSetLabelsRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetLabelsRequest = _messages.MessageField('GlobalSetLabelsRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeSecurityPoliciesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeSecurityPoliciesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeServiceAttachmentsDeleteRequest(_messages.Message):
  r"""A ComputeServiceAttachmentsDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region of this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    serviceAttachment: Name of the ServiceAttachment resource to delete.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  serviceAttachment = _messages.StringField(4, required=True)


class ComputeServiceAttachmentsGetIamPolicyRequest(_messages.Message):
  r"""A ComputeServiceAttachmentsGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  resource = _messages.StringField(4, required=True)


class ComputeServiceAttachmentsGetRequest(_messages.Message):
  r"""A ComputeServiceAttachmentsGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region of this request.
    serviceAttachment: Name of the ServiceAttachment resource to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  serviceAttachment = _messages.StringField(3, required=True)


class ComputeServiceAttachmentsInsertRequest(_messages.Message):
  r"""A ComputeServiceAttachmentsInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region of this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    serviceAttachment: A ServiceAttachment resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  serviceAttachment = _messages.MessageField('ServiceAttachment', 4)


class ComputeServiceAttachmentsListRequest(_messages.Message):
  r"""A ComputeServiceAttachmentsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region of this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeServiceAttachmentsSetIamPolicyRequest(_messages.Message):
  r"""A ComputeServiceAttachmentsSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    regionSetPolicyRequest: A RegionSetPolicyRequest resource to be passed as
      the request body.
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetPolicyRequest = _messages.MessageField('RegionSetPolicyRequest', 3)
  resource = _messages.StringField(4, required=True)


class ComputeServiceAttachmentsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeServiceAttachmentsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeSnapshotsDeleteRequest(_messages.Message):
  r"""A ComputeSnapshotsDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    snapshot: Name of the Snapshot resource to delete.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  snapshot = _messages.StringField(3, required=True)


class ComputeSnapshotsGetIamPolicyRequest(_messages.Message):
  r"""A ComputeSnapshotsGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeSnapshotsGetRequest(_messages.Message):
  r"""A ComputeSnapshotsGetRequest object.

  Fields:
    project: Project ID for this request.
    snapshot: Name of the Snapshot resource to return.
  """

  project = _messages.StringField(1, required=True)
  snapshot = _messages.StringField(2, required=True)


class ComputeSnapshotsListRequest(_messages.Message):
  r"""A ComputeSnapshotsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeSnapshotsSetIamPolicyRequest(_messages.Message):
  r"""A ComputeSnapshotsSetIamPolicyRequest object.

  Fields:
    globalSetPolicyRequest: A GlobalSetPolicyRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetPolicyRequest = _messages.MessageField('GlobalSetPolicyRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeSnapshotsSetLabelsRequest(_messages.Message):
  r"""A ComputeSnapshotsSetLabelsRequest object.

  Fields:
    globalSetLabelsRequest: A GlobalSetLabelsRequest resource to be passed as
      the request body.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
  """

  globalSetLabelsRequest = _messages.MessageField('GlobalSetLabelsRequest', 1)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)


class ComputeSnapshotsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeSnapshotsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeSslCertificatesAggregatedListRequest(_messages.Message):
  r"""A ComputeSslCertificatesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Name of the project scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeSslCertificatesDeleteRequest(_messages.Message):
  r"""A ComputeSslCertificatesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    sslCertificate: Name of the SslCertificate resource to delete.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  sslCertificate = _messages.StringField(3, required=True)


class ComputeSslCertificatesGetRequest(_messages.Message):
  r"""A ComputeSslCertificatesGetRequest object.

  Fields:
    project: Project ID for this request.
    sslCertificate: Name of the SslCertificate resource to return.
  """

  project = _messages.StringField(1, required=True)
  sslCertificate = _messages.StringField(2, required=True)


class ComputeSslCertificatesInsertRequest(_messages.Message):
  r"""A ComputeSslCertificatesInsertRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    sslCertificate: A SslCertificate resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  sslCertificate = _messages.MessageField('SslCertificate', 3)


class ComputeSslCertificatesListRequest(_messages.Message):
  r"""A ComputeSslCertificatesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeSslCertificatesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeSslCertificatesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeSslPoliciesDeleteRequest(_messages.Message):
  r"""A ComputeSslPoliciesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    sslPolicy: Name of the SSL policy to delete. The name must be 1-63
      characters long, and comply with RFC1035.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  sslPolicy = _messages.StringField(3, required=True)


class ComputeSslPoliciesGetRequest(_messages.Message):
  r"""A ComputeSslPoliciesGetRequest object.

  Fields:
    project: Project ID for this request.
    sslPolicy: Name of the SSL policy to update. The name must be 1-63
      characters long, and comply with RFC1035.
  """

  project = _messages.StringField(1, required=True)
  sslPolicy = _messages.StringField(2, required=True)


class ComputeSslPoliciesInsertRequest(_messages.Message):
  r"""A ComputeSslPoliciesInsertRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    sslPolicy: A SslPolicy resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  sslPolicy = _messages.MessageField('SslPolicy', 3)


class ComputeSslPoliciesListAvailableFeaturesRequest(_messages.Message):
  r"""A ComputeSslPoliciesListAvailableFeaturesRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeSslPoliciesListRequest(_messages.Message):
  r"""A ComputeSslPoliciesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeSslPoliciesPatchRequest(_messages.Message):
  r"""A ComputeSslPoliciesPatchRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    sslPolicy: Name of the SSL policy to update. The name must be 1-63
      characters long, and comply with RFC1035.
    sslPolicyResource: A SslPolicy resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  sslPolicy = _messages.StringField(3, required=True)
  sslPolicyResource = _messages.MessageField('SslPolicy', 4)


class ComputeSslPoliciesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeSslPoliciesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeSubnetworksAggregatedListRequest(_messages.Message):
  r"""A ComputeSubnetworksAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeSubnetworksDeleteRequest(_messages.Message):
  r"""A ComputeSubnetworksDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    subnetwork: Name of the Subnetwork resource to delete.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  subnetwork = _messages.StringField(4, required=True)


class ComputeSubnetworksExpandIpCidrRangeRequest(_messages.Message):
  r"""A ComputeSubnetworksExpandIpCidrRangeRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    subnetwork: Name of the Subnetwork resource to update.
    subnetworksExpandIpCidrRangeRequest: A SubnetworksExpandIpCidrRangeRequest
      resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  subnetwork = _messages.StringField(4, required=True)
  subnetworksExpandIpCidrRangeRequest = _messages.MessageField('SubnetworksExpandIpCidrRangeRequest', 5)


class ComputeSubnetworksGetIamPolicyRequest(_messages.Message):
  r"""A ComputeSubnetworksGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  resource = _messages.StringField(4, required=True)


class ComputeSubnetworksGetRequest(_messages.Message):
  r"""A ComputeSubnetworksGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    subnetwork: Name of the Subnetwork resource to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  subnetwork = _messages.StringField(3, required=True)


class ComputeSubnetworksInsertRequest(_messages.Message):
  r"""A ComputeSubnetworksInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    subnetwork: A Subnetwork resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  subnetwork = _messages.MessageField('Subnetwork', 4)


class ComputeSubnetworksListRequest(_messages.Message):
  r"""A ComputeSubnetworksListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeSubnetworksListUsableRequest(_messages.Message):
  r"""A ComputeSubnetworksListUsableRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeSubnetworksPatchRequest(_messages.Message):
  r"""A ComputeSubnetworksPatchRequest object.

  Fields:
    drainTimeoutSeconds: The drain timeout specifies the upper bound in
      seconds on the amount of time allowed to drain connections from the
      current ACTIVE subnetwork to the current BACKUP subnetwork. The drain
      timeout is only applicable when the following conditions are true: - the
      subnetwork being patched has purpose = INTERNAL_HTTPS_LOAD_BALANCER -
      the subnetwork being patched has role = BACKUP - the patch request is
      setting the role to ACTIVE. Note that after this patch operation the
      roles of the ACTIVE and BACKUP subnetworks will be swapped.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    subnetwork: Name of the Subnetwork resource to patch.
    subnetworkResource: A Subnetwork resource to be passed as the request
      body.
  """

  drainTimeoutSeconds = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  subnetwork = _messages.StringField(5, required=True)
  subnetworkResource = _messages.MessageField('Subnetwork', 6)


class ComputeSubnetworksSetIamPolicyRequest(_messages.Message):
  r"""A ComputeSubnetworksSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    regionSetPolicyRequest: A RegionSetPolicyRequest resource to be passed as
      the request body.
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetPolicyRequest = _messages.MessageField('RegionSetPolicyRequest', 3)
  resource = _messages.StringField(4, required=True)


class ComputeSubnetworksSetPrivateIpGoogleAccessRequest(_messages.Message):
  r"""A ComputeSubnetworksSetPrivateIpGoogleAccessRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    subnetwork: Name of the Subnetwork resource.
    subnetworksSetPrivateIpGoogleAccessRequest: A
      SubnetworksSetPrivateIpGoogleAccessRequest resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  subnetwork = _messages.StringField(4, required=True)
  subnetworksSetPrivateIpGoogleAccessRequest = _messages.MessageField('SubnetworksSetPrivateIpGoogleAccessRequest', 5)


class ComputeSubnetworksTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeSubnetworksTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeTargetGrpcProxiesDeleteRequest(_messages.Message):
  r"""A ComputeTargetGrpcProxiesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetGrpcProxy: Name of the TargetGrpcProxy resource to delete.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetGrpcProxy = _messages.StringField(3, required=True)


class ComputeTargetGrpcProxiesGetRequest(_messages.Message):
  r"""A ComputeTargetGrpcProxiesGetRequest object.

  Fields:
    project: Project ID for this request.
    targetGrpcProxy: Name of the TargetGrpcProxy resource to return.
  """

  project = _messages.StringField(1, required=True)
  targetGrpcProxy = _messages.StringField(2, required=True)


class ComputeTargetGrpcProxiesInsertRequest(_messages.Message):
  r"""A ComputeTargetGrpcProxiesInsertRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetGrpcProxy: A TargetGrpcProxy resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetGrpcProxy = _messages.MessageField('TargetGrpcProxy', 3)


class ComputeTargetGrpcProxiesListRequest(_messages.Message):
  r"""A ComputeTargetGrpcProxiesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeTargetGrpcProxiesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeTargetGrpcProxiesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeTargetHttpProxiesAggregatedListRequest(_messages.Message):
  r"""A ComputeTargetHttpProxiesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Name of the project scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeTargetHttpProxiesDeleteRequest(_messages.Message):
  r"""A ComputeTargetHttpProxiesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetHttpProxy: Name of the TargetHttpProxy resource to delete.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetHttpProxy = _messages.StringField(3, required=True)


class ComputeTargetHttpProxiesGetRequest(_messages.Message):
  r"""A ComputeTargetHttpProxiesGetRequest object.

  Fields:
    project: Project ID for this request.
    targetHttpProxy: Name of the TargetHttpProxy resource to return.
  """

  project = _messages.StringField(1, required=True)
  targetHttpProxy = _messages.StringField(2, required=True)


class ComputeTargetHttpProxiesInsertRequest(_messages.Message):
  r"""A ComputeTargetHttpProxiesInsertRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetHttpProxy: A TargetHttpProxy resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetHttpProxy = _messages.MessageField('TargetHttpProxy', 3)


class ComputeTargetHttpProxiesListRequest(_messages.Message):
  r"""A ComputeTargetHttpProxiesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeTargetHttpProxiesSetUrlMapRequest(_messages.Message):
  r"""A ComputeTargetHttpProxiesSetUrlMapRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetHttpProxy: Name of the TargetHttpProxy to set a URL map for.
    urlMapReference: A UrlMapReference resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetHttpProxy = _messages.StringField(3, required=True)
  urlMapReference = _messages.MessageField('UrlMapReference', 4)


class ComputeTargetHttpProxiesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeTargetHttpProxiesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeTargetHttpsProxiesAggregatedListRequest(_messages.Message):
  r"""A ComputeTargetHttpsProxiesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Name of the project scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeTargetHttpsProxiesDeleteRequest(_messages.Message):
  r"""A ComputeTargetHttpsProxiesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetHttpsProxy: Name of the TargetHttpsProxy resource to delete.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetHttpsProxy = _messages.StringField(3, required=True)


class ComputeTargetHttpsProxiesGetRequest(_messages.Message):
  r"""A ComputeTargetHttpsProxiesGetRequest object.

  Fields:
    project: Project ID for this request.
    targetHttpsProxy: Name of the TargetHttpsProxy resource to return.
  """

  project = _messages.StringField(1, required=True)
  targetHttpsProxy = _messages.StringField(2, required=True)


class ComputeTargetHttpsProxiesInsertRequest(_messages.Message):
  r"""A ComputeTargetHttpsProxiesInsertRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetHttpsProxy: A TargetHttpsProxy resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetHttpsProxy = _messages.MessageField('TargetHttpsProxy', 3)


class ComputeTargetHttpsProxiesListRequest(_messages.Message):
  r"""A ComputeTargetHttpsProxiesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeTargetHttpsProxiesSetCertificateMapRequest(_messages.Message):
  r"""A ComputeTargetHttpsProxiesSetCertificateMapRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetHttpsProxiesSetCertificateMapRequest: A
      TargetHttpsProxiesSetCertificateMapRequest resource to be passed as the
      request body.
    targetHttpsProxy: Name of the TargetHttpsProxy resource whose
      CertificateMap is to be set. The name must be 1-63 characters long, and
      comply with RFC1035.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetHttpsProxiesSetCertificateMapRequest = _messages.MessageField('TargetHttpsProxiesSetCertificateMapRequest', 3)
  targetHttpsProxy = _messages.StringField(4, required=True)


class ComputeTargetHttpsProxiesSetQuicOverrideRequest(_messages.Message):
  r"""A ComputeTargetHttpsProxiesSetQuicOverrideRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetHttpsProxiesSetQuicOverrideRequest: A
      TargetHttpsProxiesSetQuicOverrideRequest resource to be passed as the
      request body.
    targetHttpsProxy: Name of the TargetHttpsProxy resource to set the QUIC
      override policy for. The name should conform to RFC1035.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetHttpsProxiesSetQuicOverrideRequest = _messages.MessageField('TargetHttpsProxiesSetQuicOverrideRequest', 3)
  targetHttpsProxy = _messages.StringField(4, required=True)


class ComputeTargetHttpsProxiesSetSslCertificatesRequest(_messages.Message):
  r"""A ComputeTargetHttpsProxiesSetSslCertificatesRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetHttpsProxiesSetSslCertificatesRequest: A
      TargetHttpsProxiesSetSslCertificatesRequest resource to be passed as the
      request body.
    targetHttpsProxy: Name of the TargetHttpsProxy resource to set an
      SslCertificates resource for.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetHttpsProxiesSetSslCertificatesRequest = _messages.MessageField('TargetHttpsProxiesSetSslCertificatesRequest', 3)
  targetHttpsProxy = _messages.StringField(4, required=True)


class ComputeTargetHttpsProxiesSetSslPolicyRequest(_messages.Message):
  r"""A ComputeTargetHttpsProxiesSetSslPolicyRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    sslPolicyReference: A SslPolicyReference resource to be passed as the
      request body.
    targetHttpsProxy: Name of the TargetHttpsProxy resource whose SSL policy
      is to be set. The name must be 1-63 characters long, and comply with
      RFC1035.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  sslPolicyReference = _messages.MessageField('SslPolicyReference', 3)
  targetHttpsProxy = _messages.StringField(4, required=True)


class ComputeTargetHttpsProxiesSetUrlMapRequest(_messages.Message):
  r"""A ComputeTargetHttpsProxiesSetUrlMapRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetHttpsProxy: Name of the TargetHttpsProxy resource whose URL map is
      to be set.
    urlMapReference: A UrlMapReference resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetHttpsProxy = _messages.StringField(3, required=True)
  urlMapReference = _messages.MessageField('UrlMapReference', 4)


class ComputeTargetHttpsProxiesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeTargetHttpsProxiesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeTargetInstancesAggregatedListRequest(_messages.Message):
  r"""A ComputeTargetInstancesAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeTargetInstancesDeleteRequest(_messages.Message):
  r"""A ComputeTargetInstancesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetInstance: Name of the TargetInstance resource to delete.
    zone: Name of the zone scoping this request.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetInstance = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)


class ComputeTargetInstancesGetRequest(_messages.Message):
  r"""A ComputeTargetInstancesGetRequest object.

  Fields:
    project: Project ID for this request.
    targetInstance: Name of the TargetInstance resource to return.
    zone: Name of the zone scoping this request.
  """

  project = _messages.StringField(1, required=True)
  targetInstance = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeTargetInstancesInsertRequest(_messages.Message):
  r"""A ComputeTargetInstancesInsertRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetInstance: A TargetInstance resource to be passed as the request
      body.
    zone: Name of the zone scoping this request.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetInstance = _messages.MessageField('TargetInstance', 3)
  zone = _messages.StringField(4, required=True)


class ComputeTargetInstancesListRequest(_messages.Message):
  r"""A ComputeTargetInstancesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
    zone: Name of the zone scoping this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeTargetInstancesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeTargetInstancesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
    zone: The name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)
  zone = _messages.StringField(4, required=True)


class ComputeTargetPoolsAddHealthCheckRequest(_messages.Message):
  r"""A ComputeTargetPoolsAddHealthCheckRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetPool: Name of the target pool to add a health check to.
    targetPoolsAddHealthCheckRequest: A TargetPoolsAddHealthCheckRequest
      resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetPool = _messages.StringField(4, required=True)
  targetPoolsAddHealthCheckRequest = _messages.MessageField('TargetPoolsAddHealthCheckRequest', 5)


class ComputeTargetPoolsAddInstanceRequest(_messages.Message):
  r"""A ComputeTargetPoolsAddInstanceRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetPool: Name of the TargetPool resource to add instances to.
    targetPoolsAddInstanceRequest: A TargetPoolsAddInstanceRequest resource to
      be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetPool = _messages.StringField(4, required=True)
  targetPoolsAddInstanceRequest = _messages.MessageField('TargetPoolsAddInstanceRequest', 5)


class ComputeTargetPoolsAggregatedListRequest(_messages.Message):
  r"""A ComputeTargetPoolsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeTargetPoolsDeleteRequest(_messages.Message):
  r"""A ComputeTargetPoolsDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetPool: Name of the TargetPool resource to delete.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetPool = _messages.StringField(4, required=True)


class ComputeTargetPoolsGetHealthRequest(_messages.Message):
  r"""A ComputeTargetPoolsGetHealthRequest object.

  Fields:
    instanceReference: A InstanceReference resource to be passed as the
      request body.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    targetPool: Name of the TargetPool resource to which the queried instance
      belongs.
  """

  instanceReference = _messages.MessageField('InstanceReference', 1)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  targetPool = _messages.StringField(4, required=True)


class ComputeTargetPoolsGetRequest(_messages.Message):
  r"""A ComputeTargetPoolsGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    targetPool: Name of the TargetPool resource to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  targetPool = _messages.StringField(3, required=True)


class ComputeTargetPoolsInsertRequest(_messages.Message):
  r"""A ComputeTargetPoolsInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetPool: A TargetPool resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetPool = _messages.MessageField('TargetPool', 4)


class ComputeTargetPoolsListRequest(_messages.Message):
  r"""A ComputeTargetPoolsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeTargetPoolsRemoveHealthCheckRequest(_messages.Message):
  r"""A ComputeTargetPoolsRemoveHealthCheckRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetPool: Name of the target pool to remove health checks from.
    targetPoolsRemoveHealthCheckRequest: A TargetPoolsRemoveHealthCheckRequest
      resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetPool = _messages.StringField(4, required=True)
  targetPoolsRemoveHealthCheckRequest = _messages.MessageField('TargetPoolsRemoveHealthCheckRequest', 5)


class ComputeTargetPoolsRemoveInstanceRequest(_messages.Message):
  r"""A ComputeTargetPoolsRemoveInstanceRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetPool: Name of the TargetPool resource to remove instances from.
    targetPoolsRemoveInstanceRequest: A TargetPoolsRemoveInstanceRequest
      resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetPool = _messages.StringField(4, required=True)
  targetPoolsRemoveInstanceRequest = _messages.MessageField('TargetPoolsRemoveInstanceRequest', 5)


class ComputeTargetPoolsSetBackupRequest(_messages.Message):
  r"""A ComputeTargetPoolsSetBackupRequest object.

  Fields:
    failoverRatio: New failoverRatio value for the target pool.
    project: Project ID for this request.
    region: Name of the region scoping this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetPool: Name of the TargetPool resource to set a backup pool for.
    targetReference: A TargetReference resource to be passed as the request
      body.
  """

  failoverRatio = _messages.FloatField(1, variant=_messages.Variant.FLOAT)
  project = _messages.StringField(2, required=True)
  region = _messages.StringField(3, required=True)
  requestId = _messages.StringField(4)
  targetPool = _messages.StringField(5, required=True)
  targetReference = _messages.MessageField('TargetReference', 6)


class ComputeTargetPoolsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeTargetPoolsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeTargetSslProxiesDeleteRequest(_messages.Message):
  r"""A ComputeTargetSslProxiesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetSslProxy: Name of the TargetSslProxy resource to delete.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetSslProxy = _messages.StringField(3, required=True)


class ComputeTargetSslProxiesGetRequest(_messages.Message):
  r"""A ComputeTargetSslProxiesGetRequest object.

  Fields:
    project: Project ID for this request.
    targetSslProxy: Name of the TargetSslProxy resource to return.
  """

  project = _messages.StringField(1, required=True)
  targetSslProxy = _messages.StringField(2, required=True)


class ComputeTargetSslProxiesInsertRequest(_messages.Message):
  r"""A ComputeTargetSslProxiesInsertRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetSslProxy: A TargetSslProxy resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetSslProxy = _messages.MessageField('TargetSslProxy', 3)


class ComputeTargetSslProxiesListRequest(_messages.Message):
  r"""A ComputeTargetSslProxiesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeTargetSslProxiesSetBackendServiceRequest(_messages.Message):
  r"""A ComputeTargetSslProxiesSetBackendServiceRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetSslProxiesSetBackendServiceRequest: A
      TargetSslProxiesSetBackendServiceRequest resource to be passed as the
      request body.
    targetSslProxy: Name of the TargetSslProxy resource whose BackendService
      resource is to be set.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetSslProxiesSetBackendServiceRequest = _messages.MessageField('TargetSslProxiesSetBackendServiceRequest', 3)
  targetSslProxy = _messages.StringField(4, required=True)


class ComputeTargetSslProxiesSetCertificateMapRequest(_messages.Message):
  r"""A ComputeTargetSslProxiesSetCertificateMapRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetSslProxiesSetCertificateMapRequest: A
      TargetSslProxiesSetCertificateMapRequest resource to be passed as the
      request body.
    targetSslProxy: Name of the TargetSslProxy resource whose CertificateMap
      is to be set. The name must be 1-63 characters long, and comply with
      RFC1035.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetSslProxiesSetCertificateMapRequest = _messages.MessageField('TargetSslProxiesSetCertificateMapRequest', 3)
  targetSslProxy = _messages.StringField(4, required=True)


class ComputeTargetSslProxiesSetProxyHeaderRequest(_messages.Message):
  r"""A ComputeTargetSslProxiesSetProxyHeaderRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetSslProxiesSetProxyHeaderRequest: A
      TargetSslProxiesSetProxyHeaderRequest resource to be passed as the
      request body.
    targetSslProxy: Name of the TargetSslProxy resource whose ProxyHeader is
      to be set.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetSslProxiesSetProxyHeaderRequest = _messages.MessageField('TargetSslProxiesSetProxyHeaderRequest', 3)
  targetSslProxy = _messages.StringField(4, required=True)


class ComputeTargetSslProxiesSetSslCertificatesRequest(_messages.Message):
  r"""A ComputeTargetSslProxiesSetSslCertificatesRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetSslProxiesSetSslCertificatesRequest: A
      TargetSslProxiesSetSslCertificatesRequest resource to be passed as the
      request body.
    targetSslProxy: Name of the TargetSslProxy resource whose SslCertificate
      resource is to be set.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetSslProxiesSetSslCertificatesRequest = _messages.MessageField('TargetSslProxiesSetSslCertificatesRequest', 3)
  targetSslProxy = _messages.StringField(4, required=True)


class ComputeTargetSslProxiesSetSslPolicyRequest(_messages.Message):
  r"""A ComputeTargetSslProxiesSetSslPolicyRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    sslPolicyReference: A SslPolicyReference resource to be passed as the
      request body.
    targetSslProxy: Name of the TargetSslProxy resource whose SSL policy is to
      be set. The name must be 1-63 characters long, and comply with RFC1035.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  sslPolicyReference = _messages.MessageField('SslPolicyReference', 3)
  targetSslProxy = _messages.StringField(4, required=True)


class ComputeTargetSslProxiesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeTargetSslProxiesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeTargetTcpProxiesDeleteRequest(_messages.Message):
  r"""A ComputeTargetTcpProxiesDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetTcpProxy: Name of the TargetTcpProxy resource to delete.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetTcpProxy = _messages.StringField(3, required=True)


class ComputeTargetTcpProxiesGetRequest(_messages.Message):
  r"""A ComputeTargetTcpProxiesGetRequest object.

  Fields:
    project: Project ID for this request.
    targetTcpProxy: Name of the TargetTcpProxy resource to return.
  """

  project = _messages.StringField(1, required=True)
  targetTcpProxy = _messages.StringField(2, required=True)


class ComputeTargetTcpProxiesInsertRequest(_messages.Message):
  r"""A ComputeTargetTcpProxiesInsertRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetTcpProxy: A TargetTcpProxy resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetTcpProxy = _messages.MessageField('TargetTcpProxy', 3)


class ComputeTargetTcpProxiesListRequest(_messages.Message):
  r"""A ComputeTargetTcpProxiesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeTargetTcpProxiesSetBackendServiceRequest(_messages.Message):
  r"""A ComputeTargetTcpProxiesSetBackendServiceRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetTcpProxiesSetBackendServiceRequest: A
      TargetTcpProxiesSetBackendServiceRequest resource to be passed as the
      request body.
    targetTcpProxy: Name of the TargetTcpProxy resource whose BackendService
      resource is to be set.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetTcpProxiesSetBackendServiceRequest = _messages.MessageField('TargetTcpProxiesSetBackendServiceRequest', 3)
  targetTcpProxy = _messages.StringField(4, required=True)


class ComputeTargetTcpProxiesSetProxyHeaderRequest(_messages.Message):
  r"""A ComputeTargetTcpProxiesSetProxyHeaderRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetTcpProxiesSetProxyHeaderRequest: A
      TargetTcpProxiesSetProxyHeaderRequest resource to be passed as the
      request body.
    targetTcpProxy: Name of the TargetTcpProxy resource whose ProxyHeader is
      to be set.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  targetTcpProxiesSetProxyHeaderRequest = _messages.MessageField('TargetTcpProxiesSetProxyHeaderRequest', 3)
  targetTcpProxy = _messages.StringField(4, required=True)


class ComputeTargetTcpProxiesTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeTargetTcpProxiesTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeTargetVpnGatewaysAggregatedListRequest(_messages.Message):
  r"""A ComputeTargetVpnGatewaysAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeTargetVpnGatewaysDeleteRequest(_messages.Message):
  r"""A ComputeTargetVpnGatewaysDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetVpnGateway: Name of the target VPN gateway to delete.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetVpnGateway = _messages.StringField(4, required=True)


class ComputeTargetVpnGatewaysGetRequest(_messages.Message):
  r"""A ComputeTargetVpnGatewaysGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    targetVpnGateway: Name of the target VPN gateway to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  targetVpnGateway = _messages.StringField(3, required=True)


class ComputeTargetVpnGatewaysInsertRequest(_messages.Message):
  r"""A ComputeTargetVpnGatewaysInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    targetVpnGateway: A TargetVpnGateway resource to be passed as the request
      body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  targetVpnGateway = _messages.MessageField('TargetVpnGateway', 4)


class ComputeTargetVpnGatewaysListRequest(_messages.Message):
  r"""A ComputeTargetVpnGatewaysListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeTargetVpnGatewaysSetLabelsRequest(_messages.Message):
  r"""A ComputeTargetVpnGatewaysSetLabelsRequest object.

  Fields:
    project: Project ID for this request.
    region: The region for this request.
    regionSetLabelsRequest: A RegionSetLabelsRequest resource to be passed as
      the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetLabelsRequest = _messages.MessageField('RegionSetLabelsRequest', 3)
  requestId = _messages.StringField(4)
  resource = _messages.StringField(5, required=True)


class ComputeTargetVpnGatewaysTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeTargetVpnGatewaysTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeUrlMapsAggregatedListRequest(_messages.Message):
  r"""A ComputeUrlMapsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Name of the project scoping this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeUrlMapsDeleteRequest(_messages.Message):
  r"""A ComputeUrlMapsDeleteRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    urlMap: Name of the UrlMap resource to delete.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  urlMap = _messages.StringField(3, required=True)


class ComputeUrlMapsGetRequest(_messages.Message):
  r"""A ComputeUrlMapsGetRequest object.

  Fields:
    project: Project ID for this request.
    urlMap: Name of the UrlMap resource to return.
  """

  project = _messages.StringField(1, required=True)
  urlMap = _messages.StringField(2, required=True)


class ComputeUrlMapsInsertRequest(_messages.Message):
  r"""A ComputeUrlMapsInsertRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    urlMap: A UrlMap resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  urlMap = _messages.MessageField('UrlMap', 3)


class ComputeUrlMapsInvalidateCacheRequest(_messages.Message):
  r"""A ComputeUrlMapsInvalidateCacheRequest object.

  Fields:
    cacheInvalidationRule: A CacheInvalidationRule resource to be passed as
      the request body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    urlMap: Name of the UrlMap scoping this request.
  """

  cacheInvalidationRule = _messages.MessageField('CacheInvalidationRule', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  urlMap = _messages.StringField(4, required=True)


class ComputeUrlMapsListRequest(_messages.Message):
  r"""A ComputeUrlMapsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class ComputeUrlMapsPatchRequest(_messages.Message):
  r"""A ComputeUrlMapsPatchRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    urlMap: Name of the UrlMap resource to patch.
    urlMapResource: A UrlMap resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  urlMap = _messages.StringField(3, required=True)
  urlMapResource = _messages.MessageField('UrlMap', 4)


class ComputeUrlMapsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeUrlMapsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)


class ComputeUrlMapsUpdateRequest(_messages.Message):
  r"""A ComputeUrlMapsUpdateRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    urlMap: Name of the UrlMap resource to update.
    urlMapResource: A UrlMap resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  urlMap = _messages.StringField(3, required=True)
  urlMapResource = _messages.MessageField('UrlMap', 4)


class ComputeUrlMapsValidateRequest(_messages.Message):
  r"""A ComputeUrlMapsValidateRequest object.

  Fields:
    project: Project ID for this request.
    urlMap: Name of the UrlMap resource to be validated as.
    urlMapsValidateRequest: A UrlMapsValidateRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  urlMap = _messages.StringField(2, required=True)
  urlMapsValidateRequest = _messages.MessageField('UrlMapsValidateRequest', 3)


class ComputeVpnGatewaysAggregatedListRequest(_messages.Message):
  r"""A ComputeVpnGatewaysAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeVpnGatewaysDeleteRequest(_messages.Message):
  r"""A ComputeVpnGatewaysDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    vpnGateway: Name of the VPN gateway to delete.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  vpnGateway = _messages.StringField(4, required=True)


class ComputeVpnGatewaysGetRequest(_messages.Message):
  r"""A ComputeVpnGatewaysGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    vpnGateway: Name of the VPN gateway to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  vpnGateway = _messages.StringField(3, required=True)


class ComputeVpnGatewaysGetStatusRequest(_messages.Message):
  r"""A ComputeVpnGatewaysGetStatusRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    vpnGateway: Name of the VPN gateway to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  vpnGateway = _messages.StringField(3, required=True)


class ComputeVpnGatewaysInsertRequest(_messages.Message):
  r"""A ComputeVpnGatewaysInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    vpnGateway: A VpnGateway resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  vpnGateway = _messages.MessageField('VpnGateway', 4)


class ComputeVpnGatewaysListRequest(_messages.Message):
  r"""A ComputeVpnGatewaysListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeVpnGatewaysSetLabelsRequest(_messages.Message):
  r"""A ComputeVpnGatewaysSetLabelsRequest object.

  Fields:
    project: Project ID for this request.
    region: The region for this request.
    regionSetLabelsRequest: A RegionSetLabelsRequest resource to be passed as
      the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetLabelsRequest = _messages.MessageField('RegionSetLabelsRequest', 3)
  requestId = _messages.StringField(4)
  resource = _messages.StringField(5, required=True)


class ComputeVpnGatewaysTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeVpnGatewaysTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeVpnTunnelsAggregatedListRequest(_messages.Message):
  r"""A ComputeVpnTunnelsAggregatedListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    includeAllScopes: Indicates whether every visible scope for each scope
      type (zone, region, global) should be included in the response. For new
      resource types added after this field, the flag has no effect as new
      resource types will always include every visible scope for each scope
      type in response. For resource types which predate this field, if this
      flag is omitted or false, only scopes of the scope types where the
      resource type is expected to be found will be included.
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  includeAllScopes = _messages.BooleanField(2)
  maxResults = _messages.IntegerField(3, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(4)
  pageToken = _messages.StringField(5)
  project = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeVpnTunnelsDeleteRequest(_messages.Message):
  r"""A ComputeVpnTunnelsDeleteRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    vpnTunnel: Name of the VpnTunnel resource to delete.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  vpnTunnel = _messages.StringField(4, required=True)


class ComputeVpnTunnelsGetRequest(_messages.Message):
  r"""A ComputeVpnTunnelsGetRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    vpnTunnel: Name of the VpnTunnel resource to return.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  vpnTunnel = _messages.StringField(3, required=True)


class ComputeVpnTunnelsInsertRequest(_messages.Message):
  r"""A ComputeVpnTunnelsInsertRequest object.

  Fields:
    project: Project ID for this request.
    region: Name of the region for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    vpnTunnel: A VpnTunnel resource to be passed as the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  vpnTunnel = _messages.MessageField('VpnTunnel', 4)


class ComputeVpnTunnelsListRequest(_messages.Message):
  r"""A ComputeVpnTunnelsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    region: Name of the region for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  region = _messages.StringField(6, required=True)
  returnPartialSuccess = _messages.BooleanField(7)


class ComputeVpnTunnelsSetLabelsRequest(_messages.Message):
  r"""A ComputeVpnTunnelsSetLabelsRequest object.

  Fields:
    project: Project ID for this request.
    region: The region for this request.
    regionSetLabelsRequest: A RegionSetLabelsRequest resource to be passed as
      the request body.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    resource: Name or id of the resource for this request.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  regionSetLabelsRequest = _messages.MessageField('RegionSetLabelsRequest', 3)
  requestId = _messages.StringField(4)
  resource = _messages.StringField(5, required=True)


class ComputeVpnTunnelsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeVpnTunnelsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    region: The name of the region for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
  """

  project = _messages.StringField(1, required=True)
  region = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 4)


class ComputeZoneInPlaceSnapshotsDeleteRequest(_messages.Message):
  r"""A ComputeZoneInPlaceSnapshotsDeleteRequest object.

  Fields:
    inPlaceSnapshot: Name of the InPlaceSnapshot resource to delete.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: The name of the zone for this request.
  """

  inPlaceSnapshot = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeZoneInPlaceSnapshotsGetIamPolicyRequest(_messages.Message):
  r"""A ComputeZoneInPlaceSnapshotsGetIamPolicyRequest object.

  Fields:
    optionsRequestedPolicyVersion: Requested IAM Policy version.
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
  """

  optionsRequestedPolicyVersion = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  project = _messages.StringField(2, required=True)
  resource = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)


class ComputeZoneInPlaceSnapshotsGetRequest(_messages.Message):
  r"""A ComputeZoneInPlaceSnapshotsGetRequest object.

  Fields:
    inPlaceSnapshot: Name of the InPlaceSnapshot resource to return.
    project: Project ID for this request.
    zone: The name of the zone for this request.
  """

  inPlaceSnapshot = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeZoneInPlaceSnapshotsInsertRequest(_messages.Message):
  r"""A ComputeZoneInPlaceSnapshotsInsertRequest object.

  Fields:
    inPlaceSnapshot: A InPlaceSnapshot resource to be passed as the request
      body.
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    zone: Name of the zone for this request.
  """

  inPlaceSnapshot = _messages.MessageField('InPlaceSnapshot', 1)
  project = _messages.StringField(2, required=True)
  requestId = _messages.StringField(3)
  zone = _messages.StringField(4, required=True)


class ComputeZoneInPlaceSnapshotsListRequest(_messages.Message):
  r"""A ComputeZoneInPlaceSnapshotsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
    zone: The name of the zone for this request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeZoneInPlaceSnapshotsSetIamPolicyRequest(_messages.Message):
  r"""A ComputeZoneInPlaceSnapshotsSetIamPolicyRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
    zoneSetPolicyRequest: A ZoneSetPolicyRequest resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)
  zoneSetPolicyRequest = _messages.MessageField('ZoneSetPolicyRequest', 4)


class ComputeZoneInPlaceSnapshotsSetLabelsRequest(_messages.Message):
  r"""A ComputeZoneInPlaceSnapshotsSetLabelsRequest object.

  Fields:
    project: Project ID for this request.
    requestId: An optional request ID to identify requests. Specify a unique
      request ID so that if you must retry your request, the server will know
      to ignore the request if it has already been completed.  For example,
      consider a situation where you make an initial request and the request
      times out. If you make the request again with the same request ID, the
      server can check if original operation with the same request ID was
      received, and if so, will ignore the second request. This prevents
      clients from accidentally creating duplicate commitments.  The request
      ID must be a valid UUID with the exception that zero UUID is not
      supported (00000000-0000-0000-0000-000000000000).
    resource: Name or id of the resource for this request.
    zone: The name of the zone for this request.
    zoneSetLabelsRequest: A ZoneSetLabelsRequest resource to be passed as the
      request body.
  """

  project = _messages.StringField(1, required=True)
  requestId = _messages.StringField(2)
  resource = _messages.StringField(3, required=True)
  zone = _messages.StringField(4, required=True)
  zoneSetLabelsRequest = _messages.MessageField('ZoneSetLabelsRequest', 5)


class ComputeZoneInPlaceSnapshotsTestIamPermissionsRequest(_messages.Message):
  r"""A ComputeZoneInPlaceSnapshotsTestIamPermissionsRequest object.

  Fields:
    project: Project ID for this request.
    resource: Name or id of the resource for this request.
    testPermissionsRequest: A TestPermissionsRequest resource to be passed as
      the request body.
    zone: The name of the zone for this request.
  """

  project = _messages.StringField(1, required=True)
  resource = _messages.StringField(2, required=True)
  testPermissionsRequest = _messages.MessageField('TestPermissionsRequest', 3)
  zone = _messages.StringField(4, required=True)


class ComputeZoneOperationsDeleteRequest(_messages.Message):
  r"""A ComputeZoneOperationsDeleteRequest object.

  Fields:
    operation: Name of the Operations resource to delete.
    project: Project ID for this request.
    zone: Name of the zone for this request.
  """

  operation = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeZoneOperationsDeleteResponse(_messages.Message):
  r"""An empty ComputeZoneOperationsDelete response."""


class ComputeZoneOperationsGetRequest(_messages.Message):
  r"""A ComputeZoneOperationsGetRequest object.

  Fields:
    operation: Name of the Operations resource to return.
    project: Project ID for this request.
    zone: Name of the zone for this request.
  """

  operation = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeZoneOperationsListRequest(_messages.Message):
  r"""A ComputeZoneOperationsListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
    zone: Name of the zone for request.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)
  zone = _messages.StringField(7, required=True)


class ComputeZoneOperationsWaitRequest(_messages.Message):
  r"""A ComputeZoneOperationsWaitRequest object.

  Fields:
    operation: Name of the Operations resource to return.
    project: Project ID for this request.
    zone: Name of the zone for this request.
  """

  operation = _messages.StringField(1, required=True)
  project = _messages.StringField(2, required=True)
  zone = _messages.StringField(3, required=True)


class ComputeZonesGetRequest(_messages.Message):
  r"""A ComputeZonesGetRequest object.

  Fields:
    project: Project ID for this request.
    zone: Name of the zone resource to return.
  """

  project = _messages.StringField(1, required=True)
  zone = _messages.StringField(2, required=True)


class ComputeZonesListRequest(_messages.Message):
  r"""A ComputeZonesListRequest object.

  Fields:
    filter: A filter expression that filters resources listed in the response.
      The expression must specify the field name, a comparison operator, and
      the value that you want to use for filtering. The value must be a
      string, a number, or a boolean. The comparison operator must be either
      `=`, `!=`, `>`, or `<`.  For example, if you are filtering Compute
      Engine instances, you can exclude instances named `example-instance` by
      specifying `name != example-instance`.  You can also filter nested
      fields. For example, you could specify `scheduling.automaticRestart =
      false` to include instances only if they are not scheduled for automatic
      restarts. You can use filtering on nested fields to filter based on
      resource labels.  To filter on multiple expressions, provide each
      separate expression within parentheses. For example: ```
      (scheduling.automaticRestart = true) (cpuPlatform = "Intel Skylake") ```
      By default, each expression is an `AND` expression. However, you can
      include `AND` and `OR` expressions explicitly. For example: ```
      (cpuPlatform = "Intel Skylake") OR (cpuPlatform = "Intel Broadwell") AND
      (scheduling.automaticRestart = true) ```
    maxResults: The maximum number of results per page that should be
      returned. If the number of available results is larger than
      `maxResults`, Compute Engine returns a `nextPageToken` that can be used
      to get the next page of results in subsequent list requests. Acceptable
      values are `0` to `500`, inclusive. (Default: `500`)
    orderBy: Sorts list results by a certain order. By default, results are
      returned in alphanumerical order based on the resource name.  You can
      also sort results in descending order based on the creation timestamp
      using `orderBy="creationTimestamp desc"`. This sorts results based on
      the `creationTimestamp` field in reverse chronological order (newest
      result first). Use this to sort resources like operations so that the
      newest operation is returned first.  Currently, only sorting by `name`
      or `creationTimestamp desc` is supported.
    pageToken: Specifies a page token to use. Set `pageToken` to the
      `nextPageToken` returned by a previous list request to get the next page
      of results.
    project: Project ID for this request.
    returnPartialSuccess: Opt-in for partial success behavior which provides
      partial results in case of failure. The default value is false and the
      logic is the same as today.
  """

  filter = _messages.StringField(1)
  maxResults = _messages.IntegerField(2, variant=_messages.Variant.UINT32, default=500)
  orderBy = _messages.StringField(3)
  pageToken = _messages.StringField(4)
  project = _messages.StringField(5, required=True)
  returnPartialSuccess = _messages.BooleanField(6)


class Condition(_messages.Message):
  r"""A condition to be met.

  Enums:
    IamValueValuesEnum: Trusted attributes supplied by the IAM system.
    OpValueValuesEnum: An operator to apply the subject with.
    SysValueValuesEnum: Trusted attributes supplied by any service that owns
      resources and uses the IAM system for access control.

  Fields:
    iam: Trusted attributes supplied by the IAM system.
    op: An operator to apply the subject with.
    svc: Trusted attributes discharged by the service.
    sys: Trusted attributes supplied by any service that owns resources and
      uses the IAM system for access control.
    values: The objects of the condition.
  """

  class IamValueValuesEnum(_messages.Enum):
    r"""Trusted attributes supplied by the IAM system.

    Values:
      APPROVER: <no description>
      ATTRIBUTION: <no description>
      AUTHORITY: <no description>
      CREDENTIALS_TYPE: <no description>
      JUSTIFICATION_TYPE: <no description>
      NO_ATTR: <no description>
      SECURITY_REALM: <no description>
    """
    APPROVER = 0
    ATTRIBUTION = 1
    AUTHORITY = 2
    CREDENTIALS_TYPE = 3
    JUSTIFICATION_TYPE = 4
    NO_ATTR = 5
    SECURITY_REALM = 6

  class OpValueValuesEnum(_messages.Enum):
    r"""An operator to apply the subject with.

    Values:
      DISCHARGED: <no description>
      EQUALS: <no description>
      IN: <no description>
      NOT_EQUALS: <no description>
      NOT_IN: <no description>
      NO_OP: <no description>
    """
    DISCHARGED = 0
    EQUALS = 1
    IN = 2
    NOT_EQUALS = 3
    NOT_IN = 4
    NO_OP = 5

  class SysValueValuesEnum(_messages.Enum):
    r"""Trusted attributes supplied by any service that owns resources and
    uses the IAM system for access control.

    Values:
      IP: <no description>
      NAME: <no description>
      NO_ATTR: <no description>
      REGION: <no description>
      SERVICE: <no description>
    """
    IP = 0
    NAME = 1
    NO_ATTR = 2
    REGION = 3
    SERVICE = 4

  iam = _messages.EnumField('IamValueValuesEnum', 1)
  op = _messages.EnumField('OpValueValuesEnum', 2)
  svc = _messages.StringField(3)
  sys = _messages.EnumField('SysValueValuesEnum', 4)
  values = _messages.StringField(5, repeated=True)


class ConfidentialInstanceConfig(_messages.Message):
  r"""A set of Confidential Instance options.

  Fields:
    enableConfidentialCompute: Defines whether the instance should have
      confidential compute enabled.
  """

  enableConfidentialCompute = _messages.BooleanField(1)


class ConnectionDraining(_messages.Message):
  r"""Message containing connection draining configuration.

  Fields:
    drainingTimeoutSec: The amount of time in seconds to allow existing
      connections to persist while on unhealthy backend VMs. Only applicable
      if the protocol is not UDP. The valid range is [0, 3600].
  """

  drainingTimeoutSec = _messages.IntegerField(1, variant=_messages.Variant.INT32)


class ConsistentHashLoadBalancerSettings(_messages.Message):
  r"""This message defines settings for a consistent hash style load balancer.

  Fields:
    httpCookie: Hash is based on HTTP Cookie. This field describes a HTTP
      cookie that will be used as the hash key for the consistent hash load
      balancer. If the cookie is not present, it will be generated. This field
      is applicable if the sessionAffinity is set to HTTP_COOKIE.
    httpHeaderName: The hash based on the value of the specified header field.
      This field is applicable if the sessionAffinity is set to HEADER_FIELD.
    minimumRingSize: The minimum number of virtual nodes to use for the hash
      ring. Defaults to 1024. Larger ring sizes result in more granular load
      distributions. If the number of hosts in the load balancing pool is
      larger than the ring size, each host will be assigned a single virtual
      node.
  """

  httpCookie = _messages.MessageField('ConsistentHashLoadBalancerSettingsHttpCookie', 1)
  httpHeaderName = _messages.StringField(2)
  minimumRingSize = _messages.IntegerField(3)


class ConsistentHashLoadBalancerSettingsHttpCookie(_messages.Message):
  r"""The information about the HTTP Cookie on which the hash function is
  based for load balancing policies that use a consistent hash.

  Fields:
    name: Name of the cookie.
    path: Path to set for the cookie.
    ttl: Lifetime of the cookie.
  """

  name = _messages.StringField(1)
  path = _messages.StringField(2)
  ttl = _messages.MessageField('Duration', 3)


class CorsPolicy(_messages.Message):
  r"""The specification for allowing client side cross-origin requests. Please
  see W3C Recommendation for Cross Origin Resource Sharing

  Fields:
    allowCredentials: In response to a preflight request, setting this to true
      indicates that the actual request can include user credentials. This
      translates to the Access-Control-Allow-Credentials header. Default is
      false.
    allowHeaders: Specifies the content for the Access-Control-Allow-Headers
      header.
    allowMethods: Specifies the content for the Access-Control-Allow-Methods
      header.
    allowOriginRegexes: Specifies the regualar expression patterns that match
      allowed origins. For regular expression grammar please see
      en.cppreference.com/w/cpp/regex/ecmascript  An origin is allowed if it
      matches either an item in allowOrigins or an item in allowOriginRegexes.
    allowOrigins: Specifies the list of origins that will be allowed to do
      CORS requests. An origin is allowed if it matches either an item in
      allowOrigins or an item in allowOriginRegexes.
    disabled: If true, specifies the CORS policy is disabled. The default
      value of false, which indicates that the CORS policy is in effect.
    exposeHeaders: Specifies the content for the Access-Control-Expose-Headers
      header.
    maxAge: Specifies how long results of a preflight request can be cached in
      seconds. This translates to the Access-Control-Max-Age header.
  """

  allowCredentials = _messages.BooleanField(1)
  allowHeaders = _messages.StringField(2, repeated=True)
  allowMethods = _messages.StringField(3, repeated=True)
  allowOriginRegexes = _messages.StringField(4, repeated=True)
  allowOrigins = _messages.StringField(5, repeated=True)
  disabled = _messages.BooleanField(6)
  exposeHeaders = _messages.StringField(7, repeated=True)
  maxAge = _messages.IntegerField(8, variant=_messages.Variant.INT32)


class CustomerEncryptionKey(_messages.Message):
  r"""Represents a customer-supplied encryption key

  Fields:
    kmsKeyName: The name of the encryption key that is stored in Google Cloud
      KMS.
    kmsKeyServiceAccount: The service account being used for the encryption
      request for the given KMS key. If absent, the Compute Engine default
      service account is used.
    rawKey: Specifies a 256-bit customer-supplied encryption key, encoded in
      RFC 4648 base64 to either encrypt or decrypt this resource.
    rsaEncryptedKey: Specifies an RFC 4648 base64 encoded, RSA-wrapped
      2048-bit customer-supplied encryption key to either encrypt or decrypt
      this resource.  The key must meet the following requirements before you
      can provide it to Compute Engine:   - The key is wrapped using a RSA
      public key certificate provided by Google.  - After being wrapped, the
      key must be encoded in RFC 4648 base64 encoding.  Gets the RSA public
      key certificate provided by Google at: https://cloud-
      certs.storage.googleapis.com/google-cloud-csek-ingress.pem
    sha256: [Output only] The RFC 4648 base64 encoded SHA-256 hash of the
      customer-supplied encryption key that protects this resource.
  """

  kmsKeyName = _messages.StringField(1)
  kmsKeyServiceAccount = _messages.StringField(2)
  rawKey = _messages.StringField(3)
  rsaEncryptedKey = _messages.StringField(4)
  sha256 = _messages.StringField(5)


class CustomerEncryptionKeyProtectedDisk(_messages.Message):
  r"""A CustomerEncryptionKeyProtectedDisk object.

  Fields:
    diskEncryptionKey: Decrypts data associated with the disk with a customer-
      supplied encryption key.
    source: Specifies a valid partial or full URL to an existing Persistent
      Disk resource. This field is only applicable for persistent disks.
  """

  diskEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 1)
  source = _messages.StringField(2)


class DeprecationStatus(_messages.Message):
  r"""Deprecation status for a public resource.

  Enums:
    StateValueValuesEnum: The deprecation state of this resource. This can be
      ACTIVE, DEPRECATED, OBSOLETE, or DELETED. Operations which communicate
      the end of life date for an image, can use ACTIVE. Operations which
      create a new resource using a DEPRECATED resource will return
      successfully, but with a warning indicating the deprecated resource and
      recommending its replacement. Operations which use OBSOLETE or DELETED
      resources will be rejected and result in an error.

  Fields:
    deleted: An optional RFC3339 timestamp on or after which the state of this
      resource is intended to change to DELETED. This is only informational
      and the status will not change unless the client explicitly changes it.
    deprecated: An optional RFC3339 timestamp on or after which the state of
      this resource is intended to change to DEPRECATED. This is only
      informational and the status will not change unless the client
      explicitly changes it.
    obsolete: An optional RFC3339 timestamp on or after which the state of
      this resource is intended to change to OBSOLETE. This is only
      informational and the status will not change unless the client
      explicitly changes it.
    replacement: The URL of the suggested replacement for a deprecated
      resource. The suggested replacement resource must be the same kind of
      resource as the deprecated resource.
    state: The deprecation state of this resource. This can be ACTIVE,
      DEPRECATED, OBSOLETE, or DELETED. Operations which communicate the end
      of life date for an image, can use ACTIVE. Operations which create a new
      resource using a DEPRECATED resource will return successfully, but with
      a warning indicating the deprecated resource and recommending its
      replacement. Operations which use OBSOLETE or DELETED resources will be
      rejected and result in an error.
  """

  class StateValueValuesEnum(_messages.Enum):
    r"""The deprecation state of this resource. This can be ACTIVE,
    DEPRECATED, OBSOLETE, or DELETED. Operations which communicate the end of
    life date for an image, can use ACTIVE. Operations which create a new
    resource using a DEPRECATED resource will return successfully, but with a
    warning indicating the deprecated resource and recommending its
    replacement. Operations which use OBSOLETE or DELETED resources will be
    rejected and result in an error.

    Values:
      ACTIVE: <no description>
      DELETED: <no description>
      DEPRECATED: <no description>
      OBSOLETE: <no description>
    """
    ACTIVE = 0
    DELETED = 1
    DEPRECATED = 2
    OBSOLETE = 3

  deleted = _messages.StringField(1)
  deprecated = _messages.StringField(2)
  obsolete = _messages.StringField(3)
  replacement = _messages.StringField(4)
  state = _messages.EnumField('StateValueValuesEnum', 5)


class Disk(_messages.Message):
  r"""Represents a Persistent Disk resource.  Google Compute Engine has two
  Disk resources:  *
  [Zonal](/compute/docs/reference/rest/{$api_version}/disks) *
  [Regional](/compute/docs/reference/rest/{$api_version}/regionDisks)
  Persistent disks are required for running your VM instances. Create both
  boot and non-boot (data) persistent disks. For more information, read
  Persistent Disks. For more storage options, read Storage options.  The disks
  resource represents a zonal persistent disk. For more information, read
  Zonal persistent disks.  The regionDisks resource represents a regional
  persistent disk. For more information, read  Regional resources. (==
  resource_for {$api_version}.disks ==) (== resource_for
  {$api_version}.regionDisks ==)

  Enums:
    StatusValueValuesEnum: [Output Only] The status of disk creation.
      CREATING: Disk is provisioning. RESTORING: Source data is being copied
      into the disk. FAILED: Disk creation failed. READY: Disk is ready for
      use. DELETING: Disk is deleting.
    StorageTypeValueValuesEnum: [Deprecated] Storage type of the persistent
      disk.

  Messages:
    LabelsValue: Labels to apply to this disk. These can be later modified by
      the setLabels method.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    diskEncryptionKey: Encrypts the disk using a customer-supplied encryption
      key.  After you encrypt a disk with a customer-supplied key, you must
      provide the same key if you use the disk later (e.g. to create a disk
      snapshot, to create a disk image, to create a machine image, or to
      attach the disk to a virtual machine).  Customer-supplied encryption
      keys do not protect access to metadata of the disk.  If you do not
      provide an encryption key when creating the disk, then the disk will be
      encrypted using an automatically generated key and you do not need to
      provide a key to use the disk later.
    eraseWindowsVssSignature: Specifies whether the disk restored from a
      source snapshot should erase Windows specific VSS signature.
    guestOsFeatures: A list of features to enable on the guest operating
      system. Applicable only for bootable images. Read  Enabling guest
      operating system features to see a list of available options.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#disk for disks.
    labelFingerprint: A fingerprint for the labels being applied to this disk,
      which is essentially a hash of the labels set used for optimistic
      locking. The fingerprint is initially generated by Compute Engine and
      changes after every request to modify or update labels. You must always
      provide an up-to-date fingerprint hash in order to update or change
      labels, otherwise the request will fail with error 412 conditionNotMet.
      To see the latest fingerprint, make a get() request to retrieve a disk.
    labels: Labels to apply to this disk. These can be later modified by the
      setLabels method.
    lastAttachTimestamp: [Output Only] Last attach timestamp in RFC3339 text
      format.
    lastDetachTimestamp: [Output Only] Last detach timestamp in RFC3339 text
      format.
    licenseCodes: Integer license codes indicating which licenses are attached
      to this disk.
    licenses: A list of publicly visible licenses. Reserved for Google's use.
    multiWriter: Indicates whether or not the disk can be read/write attached
      to more than one instance.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    options: Internal use only.
    physicalBlockSizeBytes: Physical block size of the persistent disk, in
      bytes. If not present in a request, a default value is used. Currently
      supported sizes are 4096 and 16384, other sizes may be added in the
      future. If an unsupported value is requested, the error message will
      list the supported values for the caller's project.
    region: [Output Only] URL of the region where the disk resides. Only
      applicable for regional resources. You must specify this field as part
      of the HTTP request URL. It is not settable as a field in the request
      body.
    replicaZones: URLs of the zones where the disk should be replicated to.
      Only applicable for regional resources.
    resourcePolicies: Resource policies applied to this disk for automatic
      snapshot creations.
    selfLink: [Output Only] Server-defined fully-qualified URL for this
      resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource's
      resource id.
    sizeGb: Size of the persistent disk, specified in GB. You can specify this
      field when creating a persistent disk using the sourceImage or
      sourceSnapshot parameter, or specify it alone to create an empty
      persistent disk.  If you specify this field along with sourceImage or
      sourceSnapshot, the value of sizeGb must not be less than the size of
      the sourceImage or the size of the snapshot. Acceptable values are 1 to
      65536, inclusive.
    sourceDisk: The source disk used to create this disk. You can provide this
      as a partial or full URL to the resource. For example, the following are
      valid values:   - https://www.googleapis.com/compute/v1/projects/project
      /zones/zone/disks/disk  - projects/project/zones/zone/disks/disk  -
      zones/zone/disks/disk
    sourceDiskId: [Output Only] The unique ID of the disk used to create this
      disk. This value identifies the exact disk that was used to create this
      persistent disk. For example, if you created the persistent disk from a
      disk that was later deleted and recreated under the same name, the
      source disk ID would identify the exact version of the disk that was
      used.
    sourceImage: The source image used to create this disk. If the source
      image is deleted, this field will not be set.  To create a disk with one
      of the public operating system images, specify the image by its family
      name. For example, specify family/debian-9 to use the latest Debian 9
      image: projects/debian-cloud/global/images/family/debian-9
      Alternatively, use a specific version of a public operating system
      image: projects/debian-cloud/global/images/debian-9-stretch-vYYYYMMDD
      To create a disk with a custom image that you created, specify the image
      name in the following format: global/images/my-custom-image   You can
      also specify a custom image by its image family, which returns the
      latest version of the image in that family. Replace the image name with
      family/family-name: global/images/family/my-image-family
    sourceImageEncryptionKey: The customer-supplied encryption key of the
      source image. Required if the source image is protected by a customer-
      supplied encryption key.
    sourceImageId: [Output Only] The ID value of the image used to create this
      disk. This value identifies the exact image that was used to create this
      persistent disk. For example, if you created the persistent disk from an
      image that was later deleted and recreated under the same name, the
      source image ID would identify the exact version of the image that was
      used.
    sourceInPlaceSnapshot: The source in-place snapshot used to create this
      disk. You can provide this as a partial or full URL to the resource. For
      example, the following are valid values:   - https://www.googleapis.com/
      compute/v1/projects/project/global/inPlaceSnapshots/inPlaceSnapshots  -
      projects/project/global/inPlaceSnapshots/inPlaceSnapshots  -
      global/inPlaceSnapshots/inPlaceSnapshots
    sourceInPlaceSnapshotId: [Output Only] The unique ID of the in-place
      snapshot used to create this disk. This value identifies the exact in-
      place snapshot that was used to create this persistent disk. For
      example, if you created the persistent disk from an in-place snapshot
      that was later deleted and recreated under the same name, the source in-
      place snapshot ID would identify the exact version of the in-place
      snapshot that was used.
    sourceSnapshot: The source snapshot used to create this disk. You can
      provide this as a partial or full URL to the resource. For example, the
      following are valid values:   - https://www.googleapis.com/compute/v1/pr
      ojects/project/global/snapshots/snapshot  -
      projects/project/global/snapshots/snapshot  - global/snapshots/snapshot
    sourceSnapshotEncryptionKey: The customer-supplied encryption key of the
      source snapshot. Required if the source snapshot is protected by a
      customer-supplied encryption key.
    sourceSnapshotId: [Output Only] The unique ID of the snapshot used to
      create this disk. This value identifies the exact snapshot that was used
      to create this persistent disk. For example, if you created the
      persistent disk from a snapshot that was later deleted and recreated
      under the same name, the source snapshot ID would identify the exact
      version of the snapshot that was used.
    sourceStorageObject: The full Google Cloud Storage URI where the disk
      image is stored. This file must be a gzip-compressed tarball whose name
      ends in .tar.gz or virtual machine disk whose name ends in vmdk. Valid
      URIs may start with gs:// or https://storage.googleapis.com/.
    status: [Output Only] The status of disk creation. CREATING: Disk is
      provisioning. RESTORING: Source data is being copied into the disk.
      FAILED: Disk creation failed. READY: Disk is ready for use. DELETING:
      Disk is deleting.
    storageType: [Deprecated] Storage type of the persistent disk.
    type: URL of the disk type resource describing which disk type to use to
      create the disk. Provide this when creating the disk. For example:
      projects/project/zones/zone/diskTypes/pd-standard or pd-ssd
    users: [Output Only] Links to the users of the disk (attached instances)
      in form: projects/project/zones/zone/instances/instance
    zone: [Output Only] URL of the zone where the disk resides. You must
      specify this field as part of the HTTP request URL. It is not settable
      as a field in the request body.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of disk creation. CREATING: Disk is
    provisioning. RESTORING: Source data is being copied into the disk.
    FAILED: Disk creation failed. READY: Disk is ready for use. DELETING: Disk
    is deleting.

    Values:
      CREATING: <no description>
      DELETING: <no description>
      FAILED: <no description>
      READY: <no description>
      RESTORING: <no description>
    """
    CREATING = 0
    DELETING = 1
    FAILED = 2
    READY = 3
    RESTORING = 4

  class StorageTypeValueValuesEnum(_messages.Enum):
    r"""[Deprecated] Storage type of the persistent disk.

    Values:
      HDD: <no description>
      SSD: <no description>
    """
    HDD = 0
    SSD = 1

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels to apply to this disk. These can be later modified by the
    setLabels method.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  diskEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 3)
  eraseWindowsVssSignature = _messages.BooleanField(4)
  guestOsFeatures = _messages.MessageField('GuestOsFeature', 5, repeated=True)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(7, default=u'compute#disk')
  labelFingerprint = _messages.BytesField(8)
  labels = _messages.MessageField('LabelsValue', 9)
  lastAttachTimestamp = _messages.StringField(10)
  lastDetachTimestamp = _messages.StringField(11)
  licenseCodes = _messages.IntegerField(12, repeated=True)
  licenses = _messages.StringField(13, repeated=True)
  multiWriter = _messages.BooleanField(14)
  name = _messages.StringField(15)
  options = _messages.StringField(16)
  physicalBlockSizeBytes = _messages.IntegerField(17)
  region = _messages.StringField(18)
  replicaZones = _messages.StringField(19, repeated=True)
  resourcePolicies = _messages.StringField(20, repeated=True)
  selfLink = _messages.StringField(21)
  selfLinkWithId = _messages.StringField(22)
  sizeGb = _messages.IntegerField(23)
  sourceDisk = _messages.StringField(24)
  sourceDiskId = _messages.StringField(25)
  sourceImage = _messages.StringField(26)
  sourceImageEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 27)
  sourceImageId = _messages.StringField(28)
  sourceInPlaceSnapshot = _messages.StringField(29)
  sourceInPlaceSnapshotId = _messages.StringField(30)
  sourceSnapshot = _messages.StringField(31)
  sourceSnapshotEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 32)
  sourceSnapshotId = _messages.StringField(33)
  sourceStorageObject = _messages.StringField(34)
  status = _messages.EnumField('StatusValueValuesEnum', 35)
  storageType = _messages.EnumField('StorageTypeValueValuesEnum', 36)
  type = _messages.StringField(37)
  users = _messages.StringField(38, repeated=True)
  zone = _messages.StringField(39)


class DiskAggregatedList(_messages.Message):
  r"""A DiskAggregatedList object.

  Messages:
    ItemsValue: A list of DisksScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of DisksScopedList resources.
    kind: [Output Only] Type of resource. Always compute#diskAggregatedList
      for aggregated lists of persistent disks.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of DisksScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of disks.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A DisksScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('DisksScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#diskAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class DiskInstantiationConfig(_messages.Message):
  r"""A specification of the desired way to instantiate a disk in the instance
  template when its created from a source instance.

  Enums:
    InstantiateFromValueValuesEnum: Specifies whether to include the disk and
      what image to use. Possible values are:   - source-image: to use the
      same image that was used to create the source instance's corresponding
      disk. Applicable to the boot disk and additional read-write disks.  -
      source-image-family: to use the same image family that was used to
      create the source instance's corresponding disk. Applicable to the boot
      disk and additional read-write disks.  - custom-image: to use a user-
      provided image url for disk creation. Applicable to the boot disk and
      additional read-write disks.  - attach-read-only: to attach a read-only
      disk. Applicable to read-only disks.  - do-not-include: to exclude a
      disk from the template. Applicable to additional read-write disks, local
      SSDs, and read-only disks.

  Fields:
    autoDelete: Specifies whether the disk will be auto-deleted when the
      instance is deleted (but not when the disk is detached from the
      instance).
    customImage: The custom source image to be used to restore this disk when
      instantiating this instance template.
    deviceName: Specifies the device name of the disk to which the
      configurations apply to.
    instantiateFrom: Specifies whether to include the disk and what image to
      use. Possible values are:   - source-image: to use the same image that
      was used to create the source instance's corresponding disk. Applicable
      to the boot disk and additional read-write disks.  - source-image-
      family: to use the same image family that was used to create the source
      instance's corresponding disk. Applicable to the boot disk and
      additional read-write disks.  - custom-image: to use a user-provided
      image url for disk creation. Applicable to the boot disk and additional
      read-write disks.  - attach-read-only: to attach a read-only disk.
      Applicable to read-only disks.  - do-not-include: to exclude a disk from
      the template. Applicable to additional read-write disks, local SSDs, and
      read-only disks.
  """

  class InstantiateFromValueValuesEnum(_messages.Enum):
    r"""Specifies whether to include the disk and what image to use. Possible
    values are:   - source-image: to use the same image that was used to
    create the source instance's corresponding disk. Applicable to the boot
    disk and additional read-write disks.  - source-image-family: to use the
    same image family that was used to create the source instance's
    corresponding disk. Applicable to the boot disk and additional read-write
    disks.  - custom-image: to use a user-provided image url for disk
    creation. Applicable to the boot disk and additional read-write disks.  -
    attach-read-only: to attach a read-only disk. Applicable to read-only
    disks.  - do-not-include: to exclude a disk from the template. Applicable
    to additional read-write disks, local SSDs, and read-only disks.

    Values:
      ATTACH_READ_ONLY: <no description>
      BLANK: <no description>
      CUSTOM_IMAGE: <no description>
      DEFAULT: <no description>
      DO_NOT_INCLUDE: <no description>
      SOURCE_IMAGE: <no description>
      SOURCE_IMAGE_FAMILY: <no description>
    """
    ATTACH_READ_ONLY = 0
    BLANK = 1
    CUSTOM_IMAGE = 2
    DEFAULT = 3
    DO_NOT_INCLUDE = 4
    SOURCE_IMAGE = 5
    SOURCE_IMAGE_FAMILY = 6

  autoDelete = _messages.BooleanField(1)
  customImage = _messages.StringField(2)
  deviceName = _messages.StringField(3)
  instantiateFrom = _messages.EnumField('InstantiateFromValueValuesEnum', 4)


class DiskList(_messages.Message):
  r"""A list of Disk resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Disk resources.
    kind: [Output Only] Type of resource. Always compute#diskList for lists of
      disks.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Disk', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#diskList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class DiskMoveRequest(_messages.Message):
  r"""A DiskMoveRequest object.

  Fields:
    destinationZone: The URL of the destination zone to move the disk. This
      can be a full or partial URL. For example, the following are all valid
      URLs to a zone:   -
      https://www.googleapis.com/compute/v1/projects/project/zones/zone  -
      projects/project/zones/zone  - zones/zone
    targetDisk: The URL of the target disk to move. This can be a full or
      partial URL. For example, the following are all valid URLs to a disk:
      - https://www.googleapis.com/compute/v1/projects/project/zones/zone/disk
      s/disk  - projects/project/zones/zone/disks/disk  -
      zones/zone/disks/disk
  """

  destinationZone = _messages.StringField(1)
  targetDisk = _messages.StringField(2)


class DiskType(_messages.Message):
  r"""Represents a Disk Type resource.  Google Compute Engine has two Disk
  Type resources:  *
  [Regional](/compute/docs/reference/rest/{$api_version}/regionDiskTypes) *
  [Zonal](/compute/docs/reference/rest/{$api_version}/diskTypes)  You can
  choose from a variety of disk types based on your needs. For more
  information, read Storage options.  The diskTypes resource represents disk
  types for a zonal persistent disk. For more information, read Zonal
  persistent disks.  The regionDiskTypes resource represents disk types for a
  regional persistent disk. For more information, read Regional persistent
  disks. (== resource_for {$api_version}.diskTypes ==) (== resource_for
  {$api_version}.regionDiskTypes ==)

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    defaultDiskSizeGb: [Output Only] Server-defined default disk size in GB.
    deprecated: [Output Only] The deprecation status associated with this disk
      type.
    description: [Output Only] An optional description of this resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#diskType for disk
      types.
    name: [Output Only] Name of the resource.
    region: [Output Only] URL of the region where the disk type resides. Only
      applicable for regional resources. You must specify this field as part
      of the HTTP request URL. It is not settable as a field in the request
      body.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    validDiskSize: [Output Only] An optional textual description of the valid
      disk size, such as "10GB-10TB".
    zone: [Output Only] URL of the zone where the disk type resides. You must
      specify this field as part of the HTTP request URL. It is not settable
      as a field in the request body.
  """

  creationTimestamp = _messages.StringField(1)
  defaultDiskSizeGb = _messages.IntegerField(2)
  deprecated = _messages.MessageField('DeprecationStatus', 3)
  description = _messages.StringField(4)
  id = _messages.IntegerField(5, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(6, default=u'compute#diskType')
  name = _messages.StringField(7)
  region = _messages.StringField(8)
  selfLink = _messages.StringField(9)
  selfLinkWithId = _messages.StringField(10)
  validDiskSize = _messages.StringField(11)
  zone = _messages.StringField(12)


class DiskTypeAggregatedList(_messages.Message):
  r"""A DiskTypeAggregatedList object.

  Messages:
    ItemsValue: A list of DiskTypesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of DiskTypesScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#diskTypeAggregatedList.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of DiskTypesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of disk types.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A DiskTypesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('DiskTypesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#diskTypeAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class DiskTypeList(_messages.Message):
  r"""Contains a list of disk types.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of DiskType resources.
    kind: [Output Only] Type of resource. Always compute#diskTypeList for disk
      types.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('DiskType', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#diskTypeList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class DiskTypesScopedList(_messages.Message):
  r"""A DiskTypesScopedList object.

  Messages:
    WarningValue: [Output Only] Informational warning which replaces the list
      of disk types when the list is empty.

  Fields:
    diskTypes: [Output Only] A list of disk types contained in this scope.
    warning: [Output Only] Informational warning which replaces the list of
      disk types when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning which replaces the list of disk
    types when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  diskTypes = _messages.MessageField('DiskType', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class DisksAddResourcePoliciesRequest(_messages.Message):
  r"""A DisksAddResourcePoliciesRequest object.

  Fields:
    resourcePolicies: Resource policies to be added to this disk. Currently
      you can only specify one policy here.
  """

  resourcePolicies = _messages.StringField(1, repeated=True)


class DisksRemoveResourcePoliciesRequest(_messages.Message):
  r"""A DisksRemoveResourcePoliciesRequest object.

  Fields:
    resourcePolicies: Resource policies to be removed from this disk.
  """

  resourcePolicies = _messages.StringField(1, repeated=True)


class DisksResizeRequest(_messages.Message):
  r"""A DisksResizeRequest object.

  Fields:
    sizeGb: The new size of the persistent disk, which is specified in GB.
  """

  sizeGb = _messages.IntegerField(1)


class DisksScopedList(_messages.Message):
  r"""A DisksScopedList object.

  Messages:
    WarningValue: [Output Only] Informational warning which replaces the list
      of disks when the list is empty.

  Fields:
    disks: [Output Only] A list of disks contained in this scope.
    warning: [Output Only] Informational warning which replaces the list of
      disks when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning which replaces the list of disks
    when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  disks = _messages.MessageField('Disk', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class DisplayDevice(_messages.Message):
  r"""A set of Display Device options

  Fields:
    enableDisplay: Defines whether the instance has Display enabled.
  """

  enableDisplay = _messages.BooleanField(1)


class DistributionPolicy(_messages.Message):
  r"""A DistributionPolicy object.

  Enums:
    TargetShapeValueValuesEnum: The shape to which the group converges either
      proactively or on resize events (depending on the value set in
      updatePolicy.instanceRedistributionType). The possible values are EVEN
      and ANY. For EVEN the group attempts to preserve a balanced number of
      instances across zones. For ANY the group creates new instances where
      resources are available to fulfill the request; as a result, instances
      may be distributed unevenly across zones in this mode. The default value
      is EVEN.

  Fields:
    targetShape: The shape to which the group converges either proactively or
      on resize events (depending on the value set in
      updatePolicy.instanceRedistributionType). The possible values are EVEN
      and ANY. For EVEN the group attempts to preserve a balanced number of
      instances across zones. For ANY the group creates new instances where
      resources are available to fulfill the request; as a result, instances
      may be distributed unevenly across zones in this mode. The default value
      is EVEN.
    zones: Zones where the regional managed instance group will create and
      manage instances.
  """

  class TargetShapeValueValuesEnum(_messages.Enum):
    r"""The shape to which the group converges either proactively or on resize
    events (depending on the value set in
    updatePolicy.instanceRedistributionType). The possible values are EVEN and
    ANY. For EVEN the group attempts to preserve a balanced number of
    instances across zones. For ANY the group creates new instances where
    resources are available to fulfill the request; as a result, instances may
    be distributed unevenly across zones in this mode. The default value is
    EVEN.

    Values:
      ANY: <no description>
      EVEN: <no description>
    """
    ANY = 0
    EVEN = 1

  targetShape = _messages.EnumField('TargetShapeValueValuesEnum', 1)
  zones = _messages.MessageField('DistributionPolicyZoneConfiguration', 2, repeated=True)


class DistributionPolicyZoneConfiguration(_messages.Message):
  r"""A DistributionPolicyZoneConfiguration object.

  Fields:
    zone: The URL of the zone. The zone must exist in the region where the
      managed instance group is located.
  """

  zone = _messages.StringField(1)


class Duration(_messages.Message):
  r"""A Duration represents a fixed-length span of time represented as a count
  of seconds and fractions of seconds at nanosecond resolution. It is
  independent of any calendar and concepts like "day" or "month". Range is
  approximately 10,000 years.

  Fields:
    nanos: Span of time that's a fraction of a second at nanosecond
      resolution. Durations less than one second are represented with a 0
      `seconds` field and a positive `nanos` field. Must be from 0 to
      999,999,999 inclusive.
    seconds: Span of time at a resolution of a second. Must be from 0 to
      315,576,000,000 inclusive. Note: these bounds are computed from: 60
      sec/min * 60 min/hr * 24 hr/day * 365.25 days/year * 10000 years
  """

  nanos = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  seconds = _messages.IntegerField(2)


class ExchangedPeeringRoute(_messages.Message):
  r"""A ExchangedPeeringRoute object.

  Enums:
    TypeValueValuesEnum: The type of the peering route.

  Fields:
    destRange: The destination range of the route.
    imported: True if the peering route has been imported from a peer. The
      actual import happens if the field networkPeering.importCustomRoutes is
      true for this network, and networkPeering.exportCustomRoutes is true for
      the peer network, and the import does not result in a route conflict.
    nextHopRegion: The region of peering route next hop, only applies to
      dynamic routes.
    priority: The priority of the peering route.
    type: The type of the peering route.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""The type of the peering route.

    Values:
      DYNAMIC_PEERING_ROUTE: <no description>
      STATIC_PEERING_ROUTE: <no description>
      SUBNET_PEERING_ROUTE: <no description>
    """
    DYNAMIC_PEERING_ROUTE = 0
    STATIC_PEERING_ROUTE = 1
    SUBNET_PEERING_ROUTE = 2

  destRange = _messages.StringField(1)
  imported = _messages.BooleanField(2)
  nextHopRegion = _messages.StringField(3)
  priority = _messages.IntegerField(4, variant=_messages.Variant.UINT32)
  type = _messages.EnumField('TypeValueValuesEnum', 5)


class ExchangedPeeringRoutesList(_messages.Message):
  r"""A ExchangedPeeringRoutesList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of ExchangedPeeringRoute resources.
    kind: [Output Only] Type of resource. Always
      compute#exchangedPeeringRoutesList for exchanged peering routes lists.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ExchangedPeeringRoute', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#exchangedPeeringRoutesList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class Expr(_messages.Message):
  r"""Represents a textual expression in the Common Expression Language (CEL)
  syntax. CEL is a C-like expression language. The syntax and semantics of CEL
  are documented at https://github.com/google/cel-spec.  Example (Comparison):
  title: "Summary size limit" description: "Determines if a summary is less
  than 100 chars" expression: "document.summary.size() < 100"  Example
  (Equality):  title: "Requestor is owner" description: "Determines if
  requestor is the document owner" expression: "document.owner ==
  request.auth.claims.email"  Example (Logic):  title: "Public documents"
  description: "Determine whether the document should be publicly visible"
  expression: "document.type != 'private' && document.type != 'internal'"
  Example (Data Manipulation):  title: "Notification string" description:
  "Create a notification string with a timestamp." expression: "'New message
  received at ' + string(document.create_time)"  The exact variables and
  functions that may be referenced within an expression are determined by the
  service that evaluates it. See the service documentation for additional
  information.

  Fields:
    description: Optional. Description of the expression. This is a longer
      text which describes the expression, e.g. when hovered over it in a UI.
    expression: Textual representation of an expression in Common Expression
      Language syntax.
    location: Optional. String indicating the location of the expression for
      error reporting, e.g. a file name and a position in the file.
    title: Optional. Title for the expression, i.e. a short string describing
      its purpose. This can be used e.g. in UIs which allow to enter the
      expression.
  """

  description = _messages.StringField(1)
  expression = _messages.StringField(2)
  location = _messages.StringField(3)
  title = _messages.StringField(4)


class ExternalVpnGateway(_messages.Message):
  r"""Represents an external VPN gateway.  External VPN gateway is the on-
  premises VPN gateway(s) or another cloud provider's VPN gateway that
  connects to your Google Cloud VPN gateway.  To create a highly available VPN
  from Google Cloud Platform to your VPN gateway or another cloud provider's
  VPN gateway, you must create a external VPN gateway resource with
  information about the other gateway.  For more information about using
  external VPN gateways, see  Creating an HA VPN gateway and tunnel pair to a
  peer VPN. (== resource_for {$api_version}.externalVpnGateways ==)

  Enums:
    RedundancyTypeValueValuesEnum: Indicates the user-supplied redundancy type
      of this external VPN gateway.

  Messages:
    LabelsValue: Labels for this resource. These can only be added or modified
      by the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    interfaces: List of interfaces for this external VPN gateway.
    kind: [Output Only] Type of the resource. Always
      compute#externalVpnGateway for externalVpnGateways.
    labelFingerprint: A fingerprint for the labels being applied to this
      ExternalVpnGateway, which is essentially a hash of the labels set used
      for optimistic locking. The fingerprint is initially generated by
      Compute Engine and changes after every request to modify or update
      labels. You must always provide an up-to-date fingerprint hash in order
      to update or change labels, otherwise the request will fail with error
      412 conditionNotMet.  To see the latest fingerprint, make a get()
      request to retrieve an ExternalVpnGateway.
    labels: Labels for this resource. These can only be added or modified by
      the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    redundancyType: Indicates the user-supplied redundancy type of this
      external VPN gateway.
    selfLink: [Output Only] Server-defined URL for the resource.
  """

  class RedundancyTypeValueValuesEnum(_messages.Enum):
    r"""Indicates the user-supplied redundancy type of this external VPN
    gateway.

    Values:
      FOUR_IPS_REDUNDANCY: <no description>
      SINGLE_IP_INTERNALLY_REDUNDANT: <no description>
      TWO_IPS_REDUNDANCY: <no description>
    """
    FOUR_IPS_REDUNDANCY = 0
    SINGLE_IP_INTERNALLY_REDUNDANT = 1
    TWO_IPS_REDUNDANCY = 2

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels for this resource. These can only be added or modified by the
    setLabels method. Each label key/value pair must comply with RFC1035.
    Label values may be empty.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  id = _messages.IntegerField(3, variant=_messages.Variant.UINT64)
  interfaces = _messages.MessageField('ExternalVpnGatewayInterface', 4, repeated=True)
  kind = _messages.StringField(5, default=u'compute#externalVpnGateway')
  labelFingerprint = _messages.BytesField(6)
  labels = _messages.MessageField('LabelsValue', 7)
  name = _messages.StringField(8)
  redundancyType = _messages.EnumField('RedundancyTypeValueValuesEnum', 9)
  selfLink = _messages.StringField(10)


class ExternalVpnGatewayInterface(_messages.Message):
  r"""The interface for the external VPN gateway.

  Fields:
    id: The numeric ID of this interface. The allowed input values for this id
      for different redundancy types of external VPN gateway:
      SINGLE_IP_INTERNALLY_REDUNDANT - 0 TWO_IPS_REDUNDANCY - 0, 1
      FOUR_IPS_REDUNDANCY - 0, 1, 2, 3
    ipAddress: IP address of the interface in the external VPN gateway. Only
      IPv4 is supported. This IP address can be either from your on-premise
      gateway or another Cloud provider's VPN gateway, it cannot be an IP
      address from Google Compute Engine.
  """

  id = _messages.IntegerField(1, variant=_messages.Variant.UINT32)
  ipAddress = _messages.StringField(2)


class ExternalVpnGatewayList(_messages.Message):
  r"""Response to the list request, and contains a list of
  externalVpnGateways.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of ExternalVpnGateway resources.
    kind: [Output Only] Type of resource. Always
      compute#externalVpnGatewayList  for lists of externalVpnGateways.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('ExternalVpnGateway', 3, repeated=True)
  kind = _messages.StringField(4, default=u'compute#externalVpnGatewayList')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  warning = _messages.MessageField('WarningValue', 7)


class FileContentBuffer(_messages.Message):
  r"""A FileContentBuffer object.

  Enums:
    FileTypeValueValuesEnum: The file type of source file.

  Fields:
    content: The raw content in the secure keys file.
    fileType: The file type of source file.
  """

  class FileTypeValueValuesEnum(_messages.Enum):
    r"""The file type of source file.

    Values:
      BIN: <no description>
      UNDEFINED: <no description>
      X509: <no description>
    """
    BIN = 0
    UNDEFINED = 1
    X509 = 2

  content = _messages.BytesField(1)
  fileType = _messages.EnumField('FileTypeValueValuesEnum', 2)


class Firewall(_messages.Message):
  r"""Represents a Firewall Rule resource.  Firewall rules allow or deny
  ingress traffic to, and egress traffic from your instances. For more
  information, read Firewall rules.

  Enums:
    DirectionValueValuesEnum: Direction of traffic to which this firewall
      applies, either `INGRESS` or `EGRESS`. The default is `INGRESS`. For
      `INGRESS` traffic, you cannot specify the destinationRanges field, and
      for `EGRESS` traffic, you cannot specify the sourceRanges or sourceTags
      fields.

  Messages:
    AllowedValueListEntry: A AllowedValueListEntry object.
    DeniedValueListEntry: A DeniedValueListEntry object.

  Fields:
    allowed: The list of ALLOW rules specified by this firewall. Each rule
      specifies a protocol and port-range tuple that describes a permitted
      connection.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    denied: The list of DENY rules specified by this firewall. Each rule
      specifies a protocol and port-range tuple that describes a denied
      connection.
    description: An optional description of this resource. Provide this field
      when you create the resource.
    destinationRanges: If destination ranges are specified, the firewall rule
      applies only to traffic that has destination IP address in these ranges.
      These ranges must be expressed in CIDR format. Only IPv4 is supported.
    direction: Direction of traffic to which this firewall applies, either
      `INGRESS` or `EGRESS`. The default is `INGRESS`. For `INGRESS` traffic,
      you cannot specify the destinationRanges field, and for `EGRESS`
      traffic, you cannot specify the sourceRanges or sourceTags fields.
    disabled: Denotes whether the firewall rule is disabled. When set to true,
      the firewall rule is not enforced and the network behaves as if it did
      not exist. If this is unspecified, the firewall rule will be enabled.
    enableLogging: Deprecated in favor of enable in LogConfig. This field
      denotes whether to enable logging for a particular firewall rule. If
      logging is enabled, logs will be exported to Stackdriver.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#firewall for
      firewall rules.
    logConfig: This field denotes the logging options for a particular
      firewall rule. If logging is enabled, logs will be exported to
      Stackdriver.
    name: Name of the resource; provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?. The first character must
      be a lowercase letter, and all following characters (except for the last
      character) must be a dash, lowercase letter, or digit. The last
      character must be a lowercase letter or digit.
    network: URL of the network resource for this firewall rule. If not
      specified when creating a firewall rule, the default network is used:
      global/networks/default If you choose to specify this field, you can
      specify the network as a full or partial URL. For example, the following
      are all valid URLs:   -
      https://www.googleapis.com/compute/v1/projects/myproject/global/networks
      /my-network  - projects/myproject/global/networks/my-network  -
      global/networks/default
    priority: Priority for this rule. This is an integer between `0` and
      `65535`, both inclusive. The default value is `1000`. Relative
      priorities determine which rule takes effect if multiple rules apply.
      Lower values indicate higher priority. For example, a rule with priority
      `0` has higher precedence than a rule with priority `1`. DENY rules take
      precedence over ALLOW rules if they have equal priority. Note that VPC
      networks have implied rules with a priority of `65535`. To avoid
      conflicts with the implied rules, use a priority number less than
      `65535`.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    sourceRanges: If source ranges are specified, the firewall rule applies
      only to traffic that has a source IP address in these ranges. These
      ranges must be expressed in CIDR format. One or both of sourceRanges and
      sourceTags may be set. If both fields are set, the rule applies to
      traffic that has a source IP address within sourceRanges OR a source IP
      from a resource with a matching tag listed in the sourceTags field. The
      connection does not need to match both fields for the rule to apply.
      Only IPv4 is supported.
    sourceServiceAccounts: If source service accounts are specified, the
      firewall rules apply only to traffic originating from an instance with a
      service account in this list. Source service accounts cannot be used to
      control traffic to an instance's external IP address because service
      accounts are associated with an instance, not an IP address.
      sourceRanges can be set at the same time as sourceServiceAccounts. If
      both are set, the firewall applies to traffic that has a source IP
      address within the sourceRanges OR a source IP that belongs to an
      instance with service account listed in sourceServiceAccount. The
      connection does not need to match both fields for the firewall to apply.
      sourceServiceAccounts cannot be used at the same time as sourceTags or
      targetTags.
    sourceTags: If source tags are specified, the firewall rule applies only
      to traffic with source IPs that match the primary network interfaces of
      VM instances that have the tag and are in the same VPC network. Source
      tags cannot be used to control traffic to an instance's external IP
      address, it only applies to traffic between instances in the same
      virtual network. Because tags are associated with instances, not IP
      addresses. One or both of sourceRanges and sourceTags may be set. If
      both fields are set, the firewall applies to traffic that has a source
      IP address within sourceRanges OR a source IP from a resource with a
      matching tag listed in the sourceTags field. The connection does not
      need to match both fields for the firewall to apply.
    targetServiceAccounts: A list of service accounts indicating sets of
      instances located in the network that may make network connections as
      specified in allowed[]. targetServiceAccounts cannot be used at the same
      time as targetTags or sourceTags. If neither targetServiceAccounts nor
      targetTags are specified, the firewall rule applies to all instances on
      the specified network.
    targetTags: A list of tags that controls which instances the firewall rule
      applies to. If targetTags are specified, then the firewall rule applies
      only to instances in the VPC network that have one of those tags. If no
      targetTags are specified, the firewall rule applies to all instances on
      the specified network.
  """

  class DirectionValueValuesEnum(_messages.Enum):
    r"""Direction of traffic to which this firewall applies, either `INGRESS`
    or `EGRESS`. The default is `INGRESS`. For `INGRESS` traffic, you cannot
    specify the destinationRanges field, and for `EGRESS` traffic, you cannot
    specify the sourceRanges or sourceTags fields.

    Values:
      EGRESS: <no description>
      INGRESS: <no description>
    """
    EGRESS = 0
    INGRESS = 1

  class AllowedValueListEntry(_messages.Message):
    r"""A AllowedValueListEntry object.

    Fields:
      IPProtocol: The IP protocol to which this rule applies. The protocol
        type is required when creating a firewall rule. This value can either
        be one of the following well known protocol strings (tcp, udp, icmp,
        esp, ah, ipip, sctp) or the IP protocol number.
      ports: An optional list of ports to which this rule applies. This field
        is only applicable for the UDP or TCP protocol. Each entry must be
        either an integer or a range. If not specified, this rule applies to
        connections through any port.  Example inputs include: ["22"],
        ["80","443"], and ["12345-12349"].
    """

    IPProtocol = _messages.StringField(1)
    ports = _messages.StringField(2, repeated=True)

  class DeniedValueListEntry(_messages.Message):
    r"""A DeniedValueListEntry object.

    Fields:
      IPProtocol: The IP protocol to which this rule applies. The protocol
        type is required when creating a firewall rule. This value can either
        be one of the following well known protocol strings (tcp, udp, icmp,
        esp, ah, ipip, sctp) or the IP protocol number.
      ports: An optional list of ports to which this rule applies. This field
        is only applicable for the UDP or TCP protocol. Each entry must be
        either an integer or a range. If not specified, this rule applies to
        connections through any port.  Example inputs include: ["22"],
        ["80","443"], and ["12345-12349"].
    """

    IPProtocol = _messages.StringField(1)
    ports = _messages.StringField(2, repeated=True)

  allowed = _messages.MessageField('AllowedValueListEntry', 1, repeated=True)
  creationTimestamp = _messages.StringField(2)
  denied = _messages.MessageField('DeniedValueListEntry', 3, repeated=True)
  description = _messages.StringField(4)
  destinationRanges = _messages.StringField(5, repeated=True)
  direction = _messages.EnumField('DirectionValueValuesEnum', 6)
  disabled = _messages.BooleanField(7)
  enableLogging = _messages.BooleanField(8)
  id = _messages.IntegerField(9, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(10, default=u'compute#firewall')
  logConfig = _messages.MessageField('FirewallLogConfig', 11)
  name = _messages.StringField(12)
  network = _messages.StringField(13)
  priority = _messages.IntegerField(14, variant=_messages.Variant.INT32)
  selfLink = _messages.StringField(15)
  selfLinkWithId = _messages.StringField(16)
  sourceRanges = _messages.StringField(17, repeated=True)
  sourceServiceAccounts = _messages.StringField(18, repeated=True)
  sourceTags = _messages.StringField(19, repeated=True)
  targetServiceAccounts = _messages.StringField(20, repeated=True)
  targetTags = _messages.StringField(21, repeated=True)


class FirewallList(_messages.Message):
  r"""Contains a list of firewalls.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Firewall resources.
    kind: [Output Only] Type of resource. Always compute#firewallList for
      lists of firewalls.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Firewall', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#firewallList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class FirewallLogConfig(_messages.Message):
  r"""The available logging options for a firewall rule.

  Enums:
    MetadataValueValuesEnum: This field can only be specified for a particular
      firewall rule if logging is enabled for that rule. This field denotes
      whether to include or exclude metadata for firewall logs.

  Fields:
    enable: This field denotes whether to enable logging for a particular
      firewall rule.
    metadata: This field can only be specified for a particular firewall rule
      if logging is enabled for that rule. This field denotes whether to
      include or exclude metadata for firewall logs.
  """

  class MetadataValueValuesEnum(_messages.Enum):
    r"""This field can only be specified for a particular firewall rule if
    logging is enabled for that rule. This field denotes whether to include or
    exclude metadata for firewall logs.

    Values:
      EXCLUDE_ALL_METADATA: <no description>
      INCLUDE_ALL_METADATA: <no description>
    """
    EXCLUDE_ALL_METADATA = 0
    INCLUDE_ALL_METADATA = 1

  enable = _messages.BooleanField(1)
  metadata = _messages.EnumField('MetadataValueValuesEnum', 2)


class FixedOrPercent(_messages.Message):
  r"""Encapsulates numeric value that can be either absolute or relative.

  Fields:
    calculated: [Output Only] Absolute value of VM instances calculated based
      on the specific mode.    - If the value is fixed, then the calculated
      value is equal to the fixed value.  - If the value is a percent, then
      the calculated value is percent/100 * targetSize. For example, the
      calculated value of a 80% of a managed instance group with 150 instances
      would be (80/100 * 150) = 120 VM instances. If there is a remainder, the
      number is rounded up.
    fixed: Specifies a fixed number of VM instances. This must be a positive
      integer.
    percent: Specifies a percentage of instances between 0 to 100%, inclusive.
      For example, specify 80 for 80%.
  """

  calculated = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  fixed = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  percent = _messages.IntegerField(3, variant=_messages.Variant.INT32)


class ForwardingRule(_messages.Message):
  r"""Represents a Forwarding Rule resource.  Forwarding rule resources in GCP
  can be either regional or global in scope:  *
  [Global](/compute/docs/reference/rest/{$api_version}/globalForwardingRules)
  * [Regional](/compute/docs/reference/rest/{$api_version}/forwardingRules)  A
  forwarding rule and its corresponding IP address represent the frontend
  configuration of a Google Cloud Platform load balancer. Forwarding rules can
  also reference target instances and Cloud VPN Classic gateways
  (targetVpnGateway).  For more information, read Forwarding rule concepts and
  Using protocol forwarding.  (== resource_for {$api_version}.forwardingRules
  ==) (== resource_for {$api_version}.globalForwardingRules ==) (==
  resource_for {$api_version}.regionForwardingRules ==)

  Enums:
    IPProtocolValueValuesEnum: The IP protocol to which this rule applies. For
      protocol forwarding, valid options are TCP, UDP, ESP, AH, SCTP or ICMP.
      For Internal TCP/UDP Load Balancing, the load balancing scheme is
      INTERNAL, and one of TCP or UDP are valid. For Traffic Director, the
      load balancing scheme is INTERNAL_SELF_MANAGED, and only TCPis valid.
      For Internal HTTP(S) Load Balancing, the load balancing scheme is
      INTERNAL_MANAGED, and only TCP is valid. For HTTP(S), SSL Proxy, and TCP
      Proxy Load Balancing, the load balancing scheme is EXTERNAL and only TCP
      is valid. For Network TCP/UDP Load Balancing, the load balancing scheme
      is EXTERNAL, and one of TCP or UDP is valid.
    IpVersionValueValuesEnum: The IP Version that will be used by this
      forwarding rule. Valid options are IPV4 or IPV6. This can only be
      specified for an external global forwarding rule.
    LoadBalancingSchemeValueValuesEnum: Specifies the forwarding rule type.
      - EXTERNAL is used for:   - Classic Cloud VPN gateways  - Protocol
      forwarding to VMs from an external IP address  - The following load
      balancers: HTTP(S), SSL Proxy, TCP Proxy, and Network TCP/UDP     -
      INTERNAL is used for:   - Protocol forwarding to VMs from an internal IP
      address  - Internal TCP/UDP load balancers    - INTERNAL_MANAGED is used
      for:   - Internal HTTP(S) load balancers    - INTERNAL_SELF_MANAGED is
      used for:   - Traffic Director      For more information about
      forwarding rules, refer to Forwarding rule concepts.
    NetworkTierValueValuesEnum: This signifies the networking tier used for
      configuring this load balancer and can only take the following values:
      PREMIUM, STANDARD.  For regional ForwardingRule, the valid values are
      PREMIUM and STANDARD. For GlobalForwardingRule, the valid value is
      PREMIUM.  If this field is not specified, it is assumed to be PREMIUM.
      If IPAddress is specified, this value must be equal to the networkTier
      of the Address.

  Messages:
    LabelsValue: Labels for this resource. These can only be added or modified
      by the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.

  Fields:
    IPAddress: IP address that this forwarding rule serves. When a client
      sends traffic to this IP address, the forwarding rule directs the
      traffic to the target that you specify in the forwarding rule.  If you
      don't specify a reserved IP address, an ephemeral IP address is
      assigned. Methods for specifying an IP address:  * IPv4 dotted decimal,
      as in `100.1.2.3` * Full URL, as in https://www.googleapis.com/compute/v
      1/projects/project_id/regions/region/addresses/address-name * Partial
      URL or by name, as in: * projects/project_id/regions/region/addresses
      /address-name * regions/region/addresses/address-name * global/addresses
      /address-name * address-name   The loadBalancingScheme and the
      forwarding rule's target determine the type of IP address that you can
      use. For detailed information, refer to [IP address specifications
      ](/load-balancing/docs/forwarding-rule-
      concepts#ip_address_specifications).
    IPProtocol: The IP protocol to which this rule applies. For protocol
      forwarding, valid options are TCP, UDP, ESP, AH, SCTP or ICMP.  For
      Internal TCP/UDP Load Balancing, the load balancing scheme is INTERNAL,
      and one of TCP or UDP are valid. For Traffic Director, the load
      balancing scheme is INTERNAL_SELF_MANAGED, and only TCPis valid. For
      Internal HTTP(S) Load Balancing, the load balancing scheme is
      INTERNAL_MANAGED, and only TCP is valid. For HTTP(S), SSL Proxy, and TCP
      Proxy Load Balancing, the load balancing scheme is EXTERNAL and only TCP
      is valid. For Network TCP/UDP Load Balancing, the load balancing scheme
      is EXTERNAL, and one of TCP or UDP is valid.
    allPorts: This field is used along with the backend_service field for
      internal load balancing or with the target field for internal
      TargetInstance. This field cannot be used with port or portRange fields.
      When the load balancing scheme is INTERNAL and protocol is TCP/UDP,
      specify this field to allow packets addressed to any ports will be
      forwarded to the backends configured with this forwarding rule.
    allowGlobalAccess: This field is used along with the backend_service field
      for internal load balancing or with the target field for internal
      TargetInstance. If the field is set to TRUE, clients can access ILB from
      all regions. Otherwise only allows access from clients in the same
      region as the internal load balancer.
    backendService: This field is only used for INTERNAL load balancing.  For
      internal load balancing, this field identifies the BackendService
      resource to receive the matched traffic.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    fingerprint: Fingerprint of this resource. A hash of the contents stored
      in this object. This field is used in optimistic locking. This field
      will be ignored when inserting a ForwardingRule. Include the fingerprint
      in patch request to ensure that you do not overwrite changes that were
      applied from another concurrent request.  To see the latest fingerprint,
      make a get() request to retrieve a ForwardingRule.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    ipVersion: The IP Version that will be used by this forwarding rule. Valid
      options are IPV4 or IPV6. This can only be specified for an external
      global forwarding rule.
    isMirroringCollector: Indicates whether or not this load balancer can be
      used as a collector for packet mirroring. To prevent mirroring loops,
      instances behind this load balancer will not have their traffic mirrored
      even if a PacketMirroring rule applies to them. This can only be set to
      true for load balancers that have their loadBalancingScheme set to
      INTERNAL.
    kind: [Output Only] Type of the resource. Always compute#forwardingRule
      for Forwarding Rule resources.
    labelFingerprint: A fingerprint for the labels being applied to this
      resource, which is essentially a hash of the labels set used for
      optimistic locking. The fingerprint is initially generated by Compute
      Engine and changes after every request to modify or update labels. You
      must always provide an up-to-date fingerprint hash in order to update or
      change labels, otherwise the request will fail with error 412
      conditionNotMet.  To see the latest fingerprint, make a get() request to
      retrieve a ForwardingRule.
    labels: Labels for this resource. These can only be added or modified by
      the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.
    loadBalancingScheme: Specifies the forwarding rule type.    - EXTERNAL is
      used for:   - Classic Cloud VPN gateways  - Protocol forwarding to VMs
      from an external IP address  - The following load balancers: HTTP(S),
      SSL Proxy, TCP Proxy, and Network TCP/UDP     - INTERNAL is used for:
      - Protocol forwarding to VMs from an internal IP address  - Internal
      TCP/UDP load balancers    - INTERNAL_MANAGED is used for:   - Internal
      HTTP(S) load balancers    - INTERNAL_SELF_MANAGED is used for:   -
      Traffic Director      For more information about forwarding rules, refer
      to Forwarding rule concepts.
    metadataFilters: Opaque filter criteria used by Loadbalancer to restrict
      routing configuration to a limited set of xDS compliant clients. In
      their xDS requests to Loadbalancer, xDS clients present node metadata.
      If a match takes place, the relevant configuration is made available to
      those proxies. Otherwise, all the resources (e.g. TargetHttpProxy,
      UrlMap) referenced by the ForwardingRule will not be visible to those
      proxies. For each metadataFilter in this list, if its
      filterMatchCriteria is set to MATCH_ANY, at least one of the
      filterLabels must match the corresponding label provided in the
      metadata. If its filterMatchCriteria is set to MATCH_ALL, then all of
      its filterLabels must match with corresponding labels provided in the
      metadata. metadataFilters specified here will be applifed before those
      specified in the UrlMap that this ForwardingRule references.
      metadataFilters only applies to Loadbalancers that have their
      loadBalancingScheme set to INTERNAL_SELF_MANAGED.
    name: Name of the resource; provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    network: This field is not used for external load balancing.  For INTERNAL
      and INTERNAL_SELF_MANAGED load balancing, this field identifies the
      network that the load balanced IP should belong to for this Forwarding
      Rule. If this field is not specified, the default network will be used.
    networkTier: This signifies the networking tier used for configuring this
      load balancer and can only take the following values: PREMIUM, STANDARD.
      For regional ForwardingRule, the valid values are PREMIUM and STANDARD.
      For GlobalForwardingRule, the valid value is PREMIUM.  If this field is
      not specified, it is assumed to be PREMIUM. If IPAddress is specified,
      this value must be equal to the networkTier of the Address.
    portRange: When the load balancing scheme is EXTERNAL,
      INTERNAL_SELF_MANAGED and INTERNAL_MANAGED, you can specify a
      port_range. Use with a forwarding rule that points to a target proxy or
      a target pool. Do not use with a forwarding rule that points to a
      backend service. This field is used along with the target field for
      TargetHttpProxy, TargetHttpsProxy, TargetSslProxy, TargetTcpProxy,
      TargetVpnGateway, TargetPool, TargetInstance.  Applicable only when
      IPProtocol is TCP, UDP, or SCTP, only packets addressed to ports in the
      specified range will be forwarded to target. Forwarding rules with the
      same [IPAddress, IPProtocol] pair must have disjoint port ranges.  Some
      types of forwarding target have constraints on the acceptable ports:   -
      TargetHttpProxy: 80, 8080  - TargetHttpsProxy: 443  - TargetTcpProxy:
      25, 43, 110, 143, 195, 443, 465, 587, 700, 993, 995, 1688, 1883, 5222  -
      TargetSslProxy: 25, 43, 110, 143, 195, 443, 465, 587, 700, 993, 995,
      1688, 1883, 5222  - TargetVpnGateway: 500, 4500
    ports: This field is used along with the backend_service field for
      internal load balancing.  When the load balancing scheme is INTERNAL, a
      list of ports can be configured, for example, ['80'], ['8000','9000'].
      Only packets addressed to these ports are forwarded to the backends
      configured with the forwarding rule.  If the forwarding rule's
      loadBalancingScheme is INTERNAL, you can specify ports in one of the
      following ways:  * A list of up to five ports, which can be non-
      contiguous * Keyword ALL, which causes the forwarding rule to forward
      traffic on any port of the forwarding rule's protocol.
    region: [Output Only] URL of the region where the regional forwarding rule
      resides. This field is not applicable to global forwarding rules. You
      must specify this field as part of the HTTP request URL. It is not
      settable as a field in the request body.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    serviceLabel: An optional prefix to the service name for this Forwarding
      Rule. If specified, the prefix is the first label of the fully qualified
      service name.  The label must be 1-63 characters long, and comply with
      RFC1035. Specifically, the label must be 1-63 characters long and match
      the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the
      first character must be a lowercase letter, and all following characters
      must be a dash, lowercase letter, or digit, except the last character,
      which cannot be a dash.  This field is only used for internal load
      balancing.
    serviceName: [Output Only] The internal fully qualified service name for
      this Forwarding Rule.  This field is only used for internal load
      balancing.
    subnetwork: This field is only used for INTERNAL load balancing.  For
      internal load balancing, this field identifies the subnetwork that the
      load balanced IP should belong to for this Forwarding Rule.  If the
      network specified is in auto subnet mode, this field is optional.
      However, if the network is in custom subnet mode, a subnetwork must be
      specified.
    target: The URL of the target resource to receive the matched traffic. For
      regional forwarding rules, this target must live in the same region as
      the forwarding rule. For global forwarding rules, this target must be a
      global load balancing resource. The forwarded traffic must be of a type
      appropriate to the target object. For INTERNAL_SELF_MANAGED load
      balancing, only targetHttpProxy is valid, not targetHttpsProxy.
  """

  class IPProtocolValueValuesEnum(_messages.Enum):
    r"""The IP protocol to which this rule applies. For protocol forwarding,
    valid options are TCP, UDP, ESP, AH, SCTP or ICMP.  For Internal TCP/UDP
    Load Balancing, the load balancing scheme is INTERNAL, and one of TCP or
    UDP are valid. For Traffic Director, the load balancing scheme is
    INTERNAL_SELF_MANAGED, and only TCPis valid. For Internal HTTP(S) Load
    Balancing, the load balancing scheme is INTERNAL_MANAGED, and only TCP is
    valid. For HTTP(S), SSL Proxy, and TCP Proxy Load Balancing, the load
    balancing scheme is EXTERNAL and only TCP is valid. For Network TCP/UDP
    Load Balancing, the load balancing scheme is EXTERNAL, and one of TCP or
    UDP is valid.

    Values:
      AH: <no description>
      ESP: <no description>
      ICMP: <no description>
      SCTP: <no description>
      TCP: <no description>
      UDP: <no description>
    """
    AH = 0
    ESP = 1
    ICMP = 2
    SCTP = 3
    TCP = 4
    UDP = 5

  class IpVersionValueValuesEnum(_messages.Enum):
    r"""The IP Version that will be used by this forwarding rule. Valid
    options are IPV4 or IPV6. This can only be specified for an external
    global forwarding rule.

    Values:
      IPV4: <no description>
      IPV6: <no description>
      UNSPECIFIED_VERSION: <no description>
    """
    IPV4 = 0
    IPV6 = 1
    UNSPECIFIED_VERSION = 2

  class LoadBalancingSchemeValueValuesEnum(_messages.Enum):
    r"""Specifies the forwarding rule type.    - EXTERNAL is used for:   -
    Classic Cloud VPN gateways  - Protocol forwarding to VMs from an external
    IP address  - The following load balancers: HTTP(S), SSL Proxy, TCP Proxy,
    and Network TCP/UDP     - INTERNAL is used for:   - Protocol forwarding to
    VMs from an internal IP address  - Internal TCP/UDP load balancers    -
    INTERNAL_MANAGED is used for:   - Internal HTTP(S) load balancers    -
    INTERNAL_SELF_MANAGED is used for:   - Traffic Director      For more
    information about forwarding rules, refer to Forwarding rule concepts.

    Values:
      EXTERNAL: <no description>
      INTERNAL: <no description>
      INTERNAL_MANAGED: <no description>
      INTERNAL_SELF_MANAGED: <no description>
      INVALID: <no description>
    """
    EXTERNAL = 0
    INTERNAL = 1
    INTERNAL_MANAGED = 2
    INTERNAL_SELF_MANAGED = 3
    INVALID = 4

  class NetworkTierValueValuesEnum(_messages.Enum):
    r"""This signifies the networking tier used for configuring this load
    balancer and can only take the following values: PREMIUM, STANDARD.  For
    regional ForwardingRule, the valid values are PREMIUM and STANDARD. For
    GlobalForwardingRule, the valid value is PREMIUM.  If this field is not
    specified, it is assumed to be PREMIUM. If IPAddress is specified, this
    value must be equal to the networkTier of the Address.

    Values:
      PREMIUM: <no description>
      SELECT: <no description>
      STANDARD: <no description>
    """
    PREMIUM = 0
    SELECT = 1
    STANDARD = 2

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels for this resource. These can only be added or modified by the
    setLabels method. Each label key/value pair must comply with RFC1035.
    Label values may be empty.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  IPAddress = _messages.StringField(1)
  IPProtocol = _messages.EnumField('IPProtocolValueValuesEnum', 2)
  allPorts = _messages.BooleanField(3)
  allowGlobalAccess = _messages.BooleanField(4)
  backendService = _messages.StringField(5)
  creationTimestamp = _messages.StringField(6)
  description = _messages.StringField(7)
  fingerprint = _messages.BytesField(8)
  id = _messages.IntegerField(9, variant=_messages.Variant.UINT64)
  ipVersion = _messages.EnumField('IpVersionValueValuesEnum', 10)
  isMirroringCollector = _messages.BooleanField(11)
  kind = _messages.StringField(12, default=u'compute#forwardingRule')
  labelFingerprint = _messages.BytesField(13)
  labels = _messages.MessageField('LabelsValue', 14)
  loadBalancingScheme = _messages.EnumField('LoadBalancingSchemeValueValuesEnum', 15)
  metadataFilters = _messages.MessageField('MetadataFilter', 16, repeated=True)
  name = _messages.StringField(17)
  network = _messages.StringField(18)
  networkTier = _messages.EnumField('NetworkTierValueValuesEnum', 19)
  portRange = _messages.StringField(20)
  ports = _messages.StringField(21, repeated=True)
  region = _messages.StringField(22)
  selfLink = _messages.StringField(23)
  selfLinkWithId = _messages.StringField(24)
  serviceLabel = _messages.StringField(25)
  serviceName = _messages.StringField(26)
  subnetwork = _messages.StringField(27)
  target = _messages.StringField(28)


class ForwardingRuleAggregatedList(_messages.Message):
  r"""A ForwardingRuleAggregatedList object.

  Messages:
    ItemsValue: A list of ForwardingRulesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of ForwardingRulesScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#forwardingRuleAggregatedList for lists of forwarding rules.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of ForwardingRulesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        addresses.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A ForwardingRulesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('ForwardingRulesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#forwardingRuleAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class ForwardingRuleList(_messages.Message):
  r"""Contains a list of ForwardingRule resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of ForwardingRule resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ForwardingRule', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#forwardingRuleList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class ForwardingRuleReference(_messages.Message):
  r"""A ForwardingRuleReference object.

  Fields:
    forwardingRule: A string attribute.
  """

  forwardingRule = _messages.StringField(1)


class ForwardingRulesScopedList(_messages.Message):
  r"""A ForwardingRulesScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of forwarding
      rules when the list is empty.

  Fields:
    forwardingRules: A list of forwarding rules contained in this scope.
    warning: Informational warning which replaces the list of forwarding rules
      when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of forwarding rules when
    the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  forwardingRules = _messages.MessageField('ForwardingRule', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class GRPCHealthCheck(_messages.Message):
  r"""A GRPCHealthCheck object.

  Enums:
    PortSpecificationValueValuesEnum: Specifies how port is selected for
      health checking, can be one of following values: USE_FIXED_PORT: The
      port number in port is used for health checking. USE_NAMED_PORT: The
      portName is used for health checking. USE_SERVING_PORT: For
      NetworkEndpointGroup, the port specified for each network endpoint is
      used for health checking. For other backends, the port or named port
      specified in the Backend Service is used for health checking.   If not
      specified, gRPC health check follows behavior specified in port and
      portName fields.

  Fields:
    grpcServiceName: The gRPC service name for the health check. This field is
      optional. The value of grpc_service_name has the following meanings by
      convention: - Empty service_name means the overall status of all
      services at the backend. - Non-empty service_name means the health of
      that gRPC service, as defined by the owner of the service. The
      grpc_service_name can only be ASCII.
    port: The port number for the health check request. Must be specified if
      port_name and port_specification are not set or if port_specification is
      USE_FIXED_PORT. Valid values are 1 through 65535.
    portName: Port name as defined in InstanceGroup#NamedPort#name. If both
      port and port_name are defined, port takes precedence. The port_name
      should conform to RFC1035.
    portSpecification: Specifies how port is selected for health checking, can
      be one of following values: USE_FIXED_PORT: The port number in port is
      used for health checking. USE_NAMED_PORT: The portName is used for
      health checking. USE_SERVING_PORT: For NetworkEndpointGroup, the port
      specified for each network endpoint is used for health checking. For
      other backends, the port or named port specified in the Backend Service
      is used for health checking.   If not specified, gRPC health check
      follows behavior specified in port and portName fields.
  """

  class PortSpecificationValueValuesEnum(_messages.Enum):
    r"""Specifies how port is selected for health checking, can be one of
    following values: USE_FIXED_PORT: The port number in port is used for
    health checking. USE_NAMED_PORT: The portName is used for health checking.
    USE_SERVING_PORT: For NetworkEndpointGroup, the port specified for each
    network endpoint is used for health checking. For other backends, the port
    or named port specified in the Backend Service is used for health
    checking.   If not specified, gRPC health check follows behavior specified
    in port and portName fields.

    Values:
      USE_FIXED_PORT: <no description>
      USE_NAMED_PORT: <no description>
      USE_SERVING_PORT: <no description>
    """
    USE_FIXED_PORT = 0
    USE_NAMED_PORT = 1
    USE_SERVING_PORT = 2

  grpcServiceName = _messages.StringField(1)
  port = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  portName = _messages.StringField(3)
  portSpecification = _messages.EnumField('PortSpecificationValueValuesEnum', 4)


class GlobalNetworkEndpointGroupsAttachEndpointsRequest(_messages.Message):
  r"""A GlobalNetworkEndpointGroupsAttachEndpointsRequest object.

  Fields:
    networkEndpoints: The list of network endpoints to be attached.
  """

  networkEndpoints = _messages.MessageField('NetworkEndpoint', 1, repeated=True)


class GlobalNetworkEndpointGroupsDetachEndpointsRequest(_messages.Message):
  r"""A GlobalNetworkEndpointGroupsDetachEndpointsRequest object.

  Fields:
    networkEndpoints: The list of network endpoints to be detached.
  """

  networkEndpoints = _messages.MessageField('NetworkEndpoint', 1, repeated=True)


class GlobalSetLabelsRequest(_messages.Message):
  r"""A GlobalSetLabelsRequest object.

  Messages:
    LabelsValue: A list of labels to apply for this resource. Each label key &
      value must comply with RFC1035. Specifically, the name must be 1-63
      characters long and match the regular expression
      `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a
      lowercase letter, and all following characters must be a dash, lowercase
      letter, or digit, except the last character, which cannot be a dash. For
      example, "webserver-frontend": "images". A label value can also be empty
      (e.g. "my-label": "").

  Fields:
    labelFingerprint: The fingerprint of the previous set of labels for this
      resource, used to detect conflicts. The fingerprint is initially
      generated by Compute Engine and changes after every request to modify or
      update labels. You must always provide an up-to-date fingerprint hash
      when updating or changing labels, otherwise the request will fail with
      error 412 conditionNotMet. Make a get() request to the resource to get
      the latest fingerprint.
    labels: A list of labels to apply for this resource. Each label key &
      value must comply with RFC1035. Specifically, the name must be 1-63
      characters long and match the regular expression
      `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first character must be a
      lowercase letter, and all following characters must be a dash, lowercase
      letter, or digit, except the last character, which cannot be a dash. For
      example, "webserver-frontend": "images". A label value can also be empty
      (e.g. "my-label": "").
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""A list of labels to apply for this resource. Each label key & value
    must comply with RFC1035. Specifically, the name must be 1-63 characters
    long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which
    means the first character must be a lowercase letter, and all following
    characters must be a dash, lowercase letter, or digit, except the last
    character, which cannot be a dash. For example, "webserver-frontend":
    "images". A label value can also be empty (e.g. "my-label": "").

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  labelFingerprint = _messages.BytesField(1)
  labels = _messages.MessageField('LabelsValue', 2)


class GlobalSetPolicyRequest(_messages.Message):
  r"""A GlobalSetPolicyRequest object.

  Fields:
    bindings: Flatten Policy to create a backward compatible wire-format.
      Deprecated. Use 'policy' to specify bindings.
    etag: Flatten Policy to create a backward compatible wire-format.
      Deprecated. Use 'policy' to specify the etag.
    policy: REQUIRED: The complete policy to be applied to the 'resource'. The
      size of the policy is limited to a few 10s of KB. An empty policy is in
      general a valid policy but certain services (like Projects) might reject
      them.
  """

  bindings = _messages.MessageField('Binding', 1, repeated=True)
  etag = _messages.BytesField(2)
  policy = _messages.MessageField('Policy', 3)


class GrpcServiceConfig(_messages.Message):
  r"""[Deprecated] gRPC config to access the SDS server. gRPC config to access
  the SDS server.

  Fields:
    callCredentials: The call credentials to access the SDS server.
    channelCredentials: The channel credentials to access the SDS server.
    targetUri: The target URI of the SDS server.
  """

  callCredentials = _messages.MessageField('CallCredentials', 1)
  channelCredentials = _messages.MessageField('ChannelCredentials', 2)
  targetUri = _messages.StringField(3)


class GuestAttributes(_messages.Message):
  r"""A guest attributes entry.

  Fields:
    kind: [Output Only] Type of the resource. Always compute#guestAttributes
      for guest attributes entry.
    queryPath: The path to be queried. This can be the default namespace ('/')
      or a nested namespace ('/\/') or a specified key ('/\/\')
    queryValue: [Output Only] The value of the requested queried path.
    selfLink: [Output Only] Server-defined URL for this resource.
    variableKey: The key to search for.
    variableValue: [Output Only] The value found for the requested key.
  """

  kind = _messages.StringField(1, default=u'compute#guestAttributes')
  queryPath = _messages.StringField(2)
  queryValue = _messages.MessageField('GuestAttributesValue', 3)
  selfLink = _messages.StringField(4)
  variableKey = _messages.StringField(5)
  variableValue = _messages.StringField(6)


class GuestAttributesEntry(_messages.Message):
  r"""A guest attributes namespace/key/value entry.

  Fields:
    key: Key for the guest attribute entry.
    namespace: Namespace for the guest attribute entry.
    value: Value for the guest attribute entry.
  """

  key = _messages.StringField(1)
  namespace = _messages.StringField(2)
  value = _messages.StringField(3)


class GuestAttributesValue(_messages.Message):
  r"""Array of guest attribute namespace/key/value tuples.

  Fields:
    items: A GuestAttributesEntry attribute.
  """

  items = _messages.MessageField('GuestAttributesEntry', 1, repeated=True)


class GuestOsFeature(_messages.Message):
  r"""Guest OS features.

  Enums:
    TypeValueValuesEnum: The ID of a supported feature. Read  Enabling guest
      operating system features to see a list of available options.

  Fields:
    type: The ID of a supported feature. Read  Enabling guest operating system
      features to see a list of available options.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""The ID of a supported feature. Read  Enabling guest operating system
    features to see a list of available options.

    Values:
      BARE_METAL_LINUX_COMPATIBLE: <no description>
      FEATURE_TYPE_UNSPECIFIED: <no description>
      GVNIC: <no description>
      MULTI_IP_SUBNET: <no description>
      SECURE_BOOT: <no description>
      UEFI_COMPATIBLE: <no description>
      VIRTIO_SCSI_MULTIQUEUE: <no description>
      WINDOWS: <no description>
    """
    BARE_METAL_LINUX_COMPATIBLE = 0
    FEATURE_TYPE_UNSPECIFIED = 1
    GVNIC = 2
    MULTI_IP_SUBNET = 3
    SECURE_BOOT = 4
    UEFI_COMPATIBLE = 5
    VIRTIO_SCSI_MULTIQUEUE = 6
    WINDOWS = 7

  type = _messages.EnumField('TypeValueValuesEnum', 1)


class HTTP2HealthCheck(_messages.Message):
  r"""A HTTP2HealthCheck object.

  Enums:
    PortSpecificationValueValuesEnum: Specifies how port is selected for
      health checking, can be one of following values: USE_FIXED_PORT: The
      port number in port is used for health checking. USE_NAMED_PORT: The
      portName is used for health checking. USE_SERVING_PORT: For
      NetworkEndpointGroup, the port specified for each network endpoint is
      used for health checking. For other backends, the port or named port
      specified in the Backend Service is used for health checking.   If not
      specified, HTTP2 health check follows behavior specified in port and
      portName fields.
    ProxyHeaderValueValuesEnum: Specifies the type of proxy header to append
      before sending data to the backend, either NONE or PROXY_V1. The default
      is NONE.

  Fields:
    host: The value of the host header in the HTTP/2 health check request. If
      left empty (default value), the IP on behalf of which this health check
      is performed will be used.
    port: The TCP port number for the health check request. The default value
      is 443. Valid values are 1 through 65535.
    portName: Port name as defined in InstanceGroup#NamedPort#name. If both
      port and port_name are defined, port takes precedence.
    portSpecification: Specifies how port is selected for health checking, can
      be one of following values: USE_FIXED_PORT: The port number in port is
      used for health checking. USE_NAMED_PORT: The portName is used for
      health checking. USE_SERVING_PORT: For NetworkEndpointGroup, the port
      specified for each network endpoint is used for health checking. For
      other backends, the port or named port specified in the Backend Service
      is used for health checking.   If not specified, HTTP2 health check
      follows behavior specified in port and portName fields.
    proxyHeader: Specifies the type of proxy header to append before sending
      data to the backend, either NONE or PROXY_V1. The default is NONE.
    requestPath: The request path of the HTTP/2 health check request. The
      default value is /.
    response: The string to match anywhere in the first 1024 bytes of the
      response body. If left empty (the default value), the status code
      determines health. The response data can only be ASCII.
  """

  class PortSpecificationValueValuesEnum(_messages.Enum):
    r"""Specifies how port is selected for health checking, can be one of
    following values: USE_FIXED_PORT: The port number in port is used for
    health checking. USE_NAMED_PORT: The portName is used for health checking.
    USE_SERVING_PORT: For NetworkEndpointGroup, the port specified for each
    network endpoint is used for health checking. For other backends, the port
    or named port specified in the Backend Service is used for health
    checking.   If not specified, HTTP2 health check follows behavior
    specified in port and portName fields.

    Values:
      USE_FIXED_PORT: <no description>
      USE_NAMED_PORT: <no description>
      USE_SERVING_PORT: <no description>
    """
    USE_FIXED_PORT = 0
    USE_NAMED_PORT = 1
    USE_SERVING_PORT = 2

  class ProxyHeaderValueValuesEnum(_messages.Enum):
    r"""Specifies the type of proxy header to append before sending data to
    the backend, either NONE or PROXY_V1. The default is NONE.

    Values:
      NONE: <no description>
      PROXY_V1: <no description>
    """
    NONE = 0
    PROXY_V1 = 1

  host = _messages.StringField(1)
  port = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  portName = _messages.StringField(3)
  portSpecification = _messages.EnumField('PortSpecificationValueValuesEnum', 4)
  proxyHeader = _messages.EnumField('ProxyHeaderValueValuesEnum', 5)
  requestPath = _messages.StringField(6)
  response = _messages.StringField(7)


class HTTPHealthCheck(_messages.Message):
  r"""A HTTPHealthCheck object.

  Enums:
    PortSpecificationValueValuesEnum: Specifies how port is selected for
      health checking, can be one of following values: USE_FIXED_PORT: The
      port number in port is used for health checking. USE_NAMED_PORT: The
      portName is used for health checking. USE_SERVING_PORT: For
      NetworkEndpointGroup, the port specified for each network endpoint is
      used for health checking. For other backends, the port or named port
      specified in the Backend Service is used for health checking.   If not
      specified, HTTP health check follows behavior specified in port and
      portName fields.
    ProxyHeaderValueValuesEnum: Specifies the type of proxy header to append
      before sending data to the backend, either NONE or PROXY_V1. The default
      is NONE.

  Fields:
    host: The value of the host header in the HTTP health check request. If
      left empty (default value), the IP on behalf of which this health check
      is performed will be used.
    port: The TCP port number for the health check request. The default value
      is 80. Valid values are 1 through 65535.
    portName: Port name as defined in InstanceGroup#NamedPort#name. If both
      port and port_name are defined, port takes precedence.
    portSpecification: Specifies how port is selected for health checking, can
      be one of following values: USE_FIXED_PORT: The port number in port is
      used for health checking. USE_NAMED_PORT: The portName is used for
      health checking. USE_SERVING_PORT: For NetworkEndpointGroup, the port
      specified for each network endpoint is used for health checking. For
      other backends, the port or named port specified in the Backend Service
      is used for health checking.   If not specified, HTTP health check
      follows behavior specified in port and portName fields.
    proxyHeader: Specifies the type of proxy header to append before sending
      data to the backend, either NONE or PROXY_V1. The default is NONE.
    requestPath: The request path of the HTTP health check request. The
      default value is /.
    response: The string to match anywhere in the first 1024 bytes of the
      response body. If left empty (the default value), the status code
      determines health. The response data can only be ASCII.
  """

  class PortSpecificationValueValuesEnum(_messages.Enum):
    r"""Specifies how port is selected for health checking, can be one of
    following values: USE_FIXED_PORT: The port number in port is used for
    health checking. USE_NAMED_PORT: The portName is used for health checking.
    USE_SERVING_PORT: For NetworkEndpointGroup, the port specified for each
    network endpoint is used for health checking. For other backends, the port
    or named port specified in the Backend Service is used for health
    checking.   If not specified, HTTP health check follows behavior specified
    in port and portName fields.

    Values:
      USE_FIXED_PORT: <no description>
      USE_NAMED_PORT: <no description>
      USE_SERVING_PORT: <no description>
    """
    USE_FIXED_PORT = 0
    USE_NAMED_PORT = 1
    USE_SERVING_PORT = 2

  class ProxyHeaderValueValuesEnum(_messages.Enum):
    r"""Specifies the type of proxy header to append before sending data to
    the backend, either NONE or PROXY_V1. The default is NONE.

    Values:
      NONE: <no description>
      PROXY_V1: <no description>
    """
    NONE = 0
    PROXY_V1 = 1

  host = _messages.StringField(1)
  port = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  portName = _messages.StringField(3)
  portSpecification = _messages.EnumField('PortSpecificationValueValuesEnum', 4)
  proxyHeader = _messages.EnumField('ProxyHeaderValueValuesEnum', 5)
  requestPath = _messages.StringField(6)
  response = _messages.StringField(7)


class HTTPSHealthCheck(_messages.Message):
  r"""A HTTPSHealthCheck object.

  Enums:
    PortSpecificationValueValuesEnum: Specifies how port is selected for
      health checking, can be one of following values: USE_FIXED_PORT: The
      port number in port is used for health checking. USE_NAMED_PORT: The
      portName is used for health checking. USE_SERVING_PORT: For
      NetworkEndpointGroup, the port specified for each network endpoint is
      used for health checking. For other backends, the port or named port
      specified in the Backend Service is used for health checking.   If not
      specified, HTTPS health check follows behavior specified in port and
      portName fields.
    ProxyHeaderValueValuesEnum: Specifies the type of proxy header to append
      before sending data to the backend, either NONE or PROXY_V1. The default
      is NONE.

  Fields:
    host: The value of the host header in the HTTPS health check request. If
      left empty (default value), the IP on behalf of which this health check
      is performed will be used.
    port: The TCP port number for the health check request. The default value
      is 443. Valid values are 1 through 65535.
    portName: Port name as defined in InstanceGroup#NamedPort#name. If both
      port and port_name are defined, port takes precedence.
    portSpecification: Specifies how port is selected for health checking, can
      be one of following values: USE_FIXED_PORT: The port number in port is
      used for health checking. USE_NAMED_PORT: The portName is used for
      health checking. USE_SERVING_PORT: For NetworkEndpointGroup, the port
      specified for each network endpoint is used for health checking. For
      other backends, the port or named port specified in the Backend Service
      is used for health checking.   If not specified, HTTPS health check
      follows behavior specified in port and portName fields.
    proxyHeader: Specifies the type of proxy header to append before sending
      data to the backend, either NONE or PROXY_V1. The default is NONE.
    requestPath: The request path of the HTTPS health check request. The
      default value is /.
    response: The string to match anywhere in the first 1024 bytes of the
      response body. If left empty (the default value), the status code
      determines health. The response data can only be ASCII.
  """

  class PortSpecificationValueValuesEnum(_messages.Enum):
    r"""Specifies how port is selected for health checking, can be one of
    following values: USE_FIXED_PORT: The port number in port is used for
    health checking. USE_NAMED_PORT: The portName is used for health checking.
    USE_SERVING_PORT: For NetworkEndpointGroup, the port specified for each
    network endpoint is used for health checking. For other backends, the port
    or named port specified in the Backend Service is used for health
    checking.   If not specified, HTTPS health check follows behavior
    specified in port and portName fields.

    Values:
      USE_FIXED_PORT: <no description>
      USE_NAMED_PORT: <no description>
      USE_SERVING_PORT: <no description>
    """
    USE_FIXED_PORT = 0
    USE_NAMED_PORT = 1
    USE_SERVING_PORT = 2

  class ProxyHeaderValueValuesEnum(_messages.Enum):
    r"""Specifies the type of proxy header to append before sending data to
    the backend, either NONE or PROXY_V1. The default is NONE.

    Values:
      NONE: <no description>
      PROXY_V1: <no description>
    """
    NONE = 0
    PROXY_V1 = 1

  host = _messages.StringField(1)
  port = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  portName = _messages.StringField(3)
  portSpecification = _messages.EnumField('PortSpecificationValueValuesEnum', 4)
  proxyHeader = _messages.EnumField('ProxyHeaderValueValuesEnum', 5)
  requestPath = _messages.StringField(6)
  response = _messages.StringField(7)


class HealthCheck(_messages.Message):
  r"""Represents a Health Check resource.  Google Compute Engine has two
  Health Check resources:  *
  [Global](/compute/docs/reference/rest/{$api_version}/healthChecks) *
  [Regional](/compute/docs/reference/rest/{$api_version}/regionHealthChecks)
  Internal HTTP(S) load balancers use regional health checks. All other types
  of GCP load balancers and managed instance group auto-healing use global
  health checks. For more information, read Health Check Concepts.  To perform
  health checks on network load balancers, you must use either
  httpHealthChecks or httpsHealthChecks.

  Enums:
    TypeValueValuesEnum: Specifies the type of the healthCheck, either TCP,
      SSL, HTTP, HTTPS or HTTP2. If not specified, the default is TCP. Exactly
      one of the protocol-specific health check field must be specified, which
      must match type field.

  Fields:
    checkIntervalSec: How often (in seconds) to send a health check. The
      default value is 5 seconds.
    creationTimestamp: [Output Only] Creation timestamp in 3339 text format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    grpcHealthCheck: A GRPCHealthCheck attribute.
    healthyThreshold: A so-far unhealthy instance will be marked healthy after
      this many consecutive successes. The default value is 2.
    http2HealthCheck: A HTTP2HealthCheck attribute.
    httpHealthCheck: A HTTPHealthCheck attribute.
    httpsHealthCheck: A HTTPSHealthCheck attribute.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: Type of the resource.
    logConfig: Configure logging on this health check.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    region: [Output Only] Region where the health check resides. Not
      applicable to global health checks.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    sslHealthCheck: A SSLHealthCheck attribute.
    tcpHealthCheck: A TCPHealthCheck attribute.
    timeoutSec: How long (in seconds) to wait before claiming failure. The
      default value is 5 seconds. It is invalid for timeoutSec to have greater
      value than checkIntervalSec.
    type: Specifies the type of the healthCheck, either TCP, SSL, HTTP, HTTPS
      or HTTP2. If not specified, the default is TCP. Exactly one of the
      protocol-specific health check field must be specified, which must match
      type field.
    udpHealthCheck: A UDPHealthCheck attribute.
    unhealthyThreshold: A so-far healthy instance will be marked unhealthy
      after this many consecutive failures. The default value is 2.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""Specifies the type of the healthCheck, either TCP, SSL, HTTP, HTTPS or
    HTTP2. If not specified, the default is TCP. Exactly one of the protocol-
    specific health check field must be specified, which must match type
    field.

    Values:
      GRPC: <no description>
      HTTP: <no description>
      HTTP2: <no description>
      HTTPS: <no description>
      INVALID: <no description>
      SSL: <no description>
      TCP: <no description>
      UDP: <no description>
    """
    GRPC = 0
    HTTP = 1
    HTTP2 = 2
    HTTPS = 3
    INVALID = 4
    SSL = 5
    TCP = 6
    UDP = 7

  checkIntervalSec = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  grpcHealthCheck = _messages.MessageField('GRPCHealthCheck', 4)
  healthyThreshold = _messages.IntegerField(5, variant=_messages.Variant.INT32)
  http2HealthCheck = _messages.MessageField('HTTP2HealthCheck', 6)
  httpHealthCheck = _messages.MessageField('HTTPHealthCheck', 7)
  httpsHealthCheck = _messages.MessageField('HTTPSHealthCheck', 8)
  id = _messages.IntegerField(9, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(10, default=u'compute#healthCheck')
  logConfig = _messages.MessageField('HealthCheckLogConfig', 11)
  name = _messages.StringField(12)
  region = _messages.StringField(13)
  selfLink = _messages.StringField(14)
  selfLinkWithId = _messages.StringField(15)
  sslHealthCheck = _messages.MessageField('SSLHealthCheck', 16)
  tcpHealthCheck = _messages.MessageField('TCPHealthCheck', 17)
  timeoutSec = _messages.IntegerField(18, variant=_messages.Variant.INT32)
  type = _messages.EnumField('TypeValueValuesEnum', 19)
  udpHealthCheck = _messages.MessageField('UDPHealthCheck', 20)
  unhealthyThreshold = _messages.IntegerField(21, variant=_messages.Variant.INT32)


class HealthCheckList(_messages.Message):
  r"""Contains a list of HealthCheck resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of HealthCheck resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('HealthCheck', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#healthCheckList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class HealthCheckLogConfig(_messages.Message):
  r"""Configuration of logging on a health check. If logging is enabled, logs
  will be exported to Stackdriver.

  Fields:
    enable: Indicates whether or not to export logs. This is false by default,
      which means no health check logging will be done.
  """

  enable = _messages.BooleanField(1)


class HealthCheckReference(_messages.Message):
  r"""A full or valid partial URL to a health check. For example, the
  following are valid URLs:   -
  https://www.googleapis.com/compute/beta/projects/project-
  id/global/httpHealthChecks/health-check  - projects/project-
  id/global/httpHealthChecks/health-check  - global/httpHealthChecks/health-
  check

  Fields:
    healthCheck: A string attribute.
  """

  healthCheck = _messages.StringField(1)


class HealthCheckService(_messages.Message):
  r"""Represents a Health-Check as a Service resource.  (== resource_for
  {$api_version}.regionHealthCheckServices ==)

  Enums:
    HealthStatusAggregationPolicyValueValuesEnum: Optional. Policy for how the
      results from multiple health checks for the same endpoint are
      aggregated. Defaults to NO_AGGREGATION if unspecified.   -
      NO_AGGREGATION. An EndpointHealth message is returned for each backend
      in the health check service.  - AND. If any backend's health check
      reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire
      health check service. If all backend's are healthy, the HealthState of
      the health check service is HEALTHY. .
    HealthStatusAggregationStrategyValueValuesEnum: Policy for how the results
      from multiple health checks for the same endpoint are aggregated.   -
      NO_AGGREGATION. An EndpointHealth message is returned for each backend
      in the health check service.  - AND. If any backend's health check
      reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire
      health check service. If all backend's are healthy, the HealthState of
      the health check service is HEALTHY. .

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    fingerprint: Fingerprint of this resource. A hash of the contents stored
      in this object. This field is used in optimistic locking. This field
      will be ignored when inserting a HealthCheckService. An up-to-date
      fingerprint must be provided in order to patch/update the
      HealthCheckService; Otherwise, the request will fail with error 412
      conditionNotMet. To see the latest fingerprint, make a get() request to
      retrieve the HealthCheckService.
    healthChecks: List of URLs to the HealthCheck resources. Must have at
      least one HealthCheck, and not more than 10. HealthCheck resources must
      have portSpecification=USE_SERVING_PORT. For regional
      HealthCheckService, the HealthCheck must be regional and in the same
      region. For global HealthCheckService, HealthCheck must be global. Mix
      of regional and global HealthChecks is not supported. Multiple regional
      HealthChecks must belong to the same region. Regional
      HealthChecks</code? must belong to the same region as zones of NEGs.
    healthStatusAggregationPolicy: Optional. Policy for how the results from
      multiple health checks for the same endpoint are aggregated. Defaults to
      NO_AGGREGATION if unspecified.   - NO_AGGREGATION. An EndpointHealth
      message is returned for each backend in the health check service.  -
      AND. If any backend's health check reports UNHEALTHY, then UNHEALTHY is
      the HealthState of the entire health check service. If all backend's are
      healthy, the HealthState of the health check service is HEALTHY. .
    healthStatusAggregationStrategy: Policy for how the results from multiple
      health checks for the same endpoint are aggregated.   - NO_AGGREGATION.
      An EndpointHealth message is returned for each backend in the health
      check service.  - AND. If any backend's health check reports UNHEALTHY,
      then UNHEALTHY is the HealthState of the entire health check service. If
      all backend's are healthy, the HealthState of the health check service
      is HEALTHY. .
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output only] Type of the resource. Always
      compute#healthCheckServicefor health check services.
    name: Name of the resource. The name must be 1-63 characters long, and
      comply with RFC1035. Specifically, the name must be 1-63 characters long
      and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which
      means the first character must be a lowercase letter, and all following
      characters must be a dash, lowercase letter, or digit, except the last
      character, which cannot be a dash.
    networkEndpointGroups: List of URLs to the NetworkEndpointGroup resources.
      Must not have more than 100. For regional HealthCheckService, NEGs must
      be in zones in the region of the HealthCheckService.
    notificationEndpoints: List of URLs to the NotificationEndpoint resources.
      Must not have more than 10. A list of endpoints for receiving
      notifications of change in health status. For regional
      HealthCheckService, NotificationEndpoint must be regional and in the
      same region. For global HealthCheckService, NotificationEndpoint must be
      global.
    region: [Output Only] URL of the region where the health check service
      resides. This field is not applicable to global health check services.
      You must specify this field as part of the HTTP request URL. It is not
      settable as a field in the request body.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL with id for the resource.
  """

  class HealthStatusAggregationPolicyValueValuesEnum(_messages.Enum):
    r"""Optional. Policy for how the results from multiple health checks for
    the same endpoint are aggregated. Defaults to NO_AGGREGATION if
    unspecified.   - NO_AGGREGATION. An EndpointHealth message is returned for
    each backend in the health check service.  - AND. If any backend's health
    check reports UNHEALTHY, then UNHEALTHY is the HealthState of the entire
    health check service. If all backend's are healthy, the HealthState of the
    health check service is HEALTHY. .

    Values:
      AND: <no description>
      NO_AGGREGATION: <no description>
    """
    AND = 0
    NO_AGGREGATION = 1

  class HealthStatusAggregationStrategyValueValuesEnum(_messages.Enum):
    r"""Policy for how the results from multiple health checks for the same
    endpoint are aggregated.   - NO_AGGREGATION. An EndpointHealth message is
    returned for each backend in the health check service.  - AND. If any
    backend's health check reports UNHEALTHY, then UNHEALTHY is the
    HealthState of the entire health check service. If all backend's are
    healthy, the HealthState of the health check service is HEALTHY. .

    Values:
      AND: <no description>
      NO_AGGREGATION: <no description>
    """
    AND = 0
    NO_AGGREGATION = 1

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  fingerprint = _messages.BytesField(3)
  healthChecks = _messages.StringField(4, repeated=True)
  healthStatusAggregationPolicy = _messages.EnumField('HealthStatusAggregationPolicyValueValuesEnum', 5)
  healthStatusAggregationStrategy = _messages.EnumField('HealthStatusAggregationStrategyValueValuesEnum', 6)
  id = _messages.IntegerField(7, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(8, default=u'compute#healthCheckService')
  name = _messages.StringField(9)
  networkEndpointGroups = _messages.StringField(10, repeated=True)
  notificationEndpoints = _messages.StringField(11, repeated=True)
  region = _messages.StringField(12)
  selfLink = _messages.StringField(13)
  selfLinkWithId = _messages.StringField(14)


class HealthCheckServiceReference(_messages.Message):
  r"""A full or valid partial URL to a health check service. For example, the
  following are valid URLs:   -
  https://www.googleapis.com/compute/beta/projects/project-id/regions/us-
  west1/healthCheckServices/health-check-service  - projects/project-
  id/regions/us-west1/healthCheckServices/health-check-service  - regions/us-
  west1/healthCheckServices/health-check-service

  Fields:
    healthCheckService: A string attribute.
  """

  healthCheckService = _messages.StringField(1)


class HealthCheckServicesList(_messages.Message):
  r"""A HealthCheckServicesList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of HealthCheckService resources.
    kind: [Output Only] Type of the resource. Always
      compute#healthCheckServicesList for lists of HealthCheckServices.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('HealthCheckService', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#healthCheckServicesList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class HealthChecksAggregatedList(_messages.Message):
  r"""A HealthChecksAggregatedList object.

  Messages:
    ItemsValue: A list of HealthChecksScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of HealthChecksScopedList resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of HealthChecksScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        HealthChecks.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A HealthChecksScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('HealthChecksScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#healthChecksAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class HealthChecksScopedList(_messages.Message):
  r"""A HealthChecksScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of backend
      services when the list is empty.

  Fields:
    healthChecks: A list of HealthChecks contained in this scope.
    warning: Informational warning which replaces the list of backend services
      when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of backend services when
    the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  healthChecks = _messages.MessageField('HealthCheck', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class HealthStatus(_messages.Message):
  r"""A HealthStatus object.

  Enums:
    HealthStateValueValuesEnum: Health state of the instance.

  Messages:
    AnnotationsValue: Metadata defined as annotations for network endpoint.

  Fields:
    annotations: Metadata defined as annotations for network endpoint.
    healthState: Health state of the instance.
    instance: URL of the instance resource.
    ipAddress: A forwarding rule IP address assigned to this instance.
    port: The named port of the instance group, not necessarily the port that
      is health-checked.
  """

  class HealthStateValueValuesEnum(_messages.Enum):
    r"""Health state of the instance.

    Values:
      HEALTHY: <no description>
      UNHEALTHY: <no description>
    """
    HEALTHY = 0
    UNHEALTHY = 1

  @encoding.MapUnrecognizedFields('additionalProperties')
  class AnnotationsValue(_messages.Message):
    r"""Metadata defined as annotations for network endpoint.

    Messages:
      AdditionalProperty: An additional property for a AnnotationsValue
        object.

    Fields:
      additionalProperties: Additional properties of type AnnotationsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a AnnotationsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  annotations = _messages.MessageField('AnnotationsValue', 1)
  healthState = _messages.EnumField('HealthStateValueValuesEnum', 2)
  instance = _messages.StringField(3)
  ipAddress = _messages.StringField(4)
  port = _messages.IntegerField(5, variant=_messages.Variant.INT32)


class HealthStatusForNetworkEndpoint(_messages.Message):
  r"""A HealthStatusForNetworkEndpoint object.

  Enums:
    HealthStateValueValuesEnum: Health state of the network endpoint
      determined based on the health checks configured.

  Fields:
    backendService: URL of the backend service associated with the health
      state of the network endpoint.
    forwardingRule: URL of the forwarding rule associated with the health
      state of the network endpoint.
    healthCheck: URL of the health check associated with the health state of
      the network endpoint.
    healthCheckService: URL of the health check service associated with the
      health state of the network endpoint.
    healthState: Health state of the network endpoint determined based on the
      health checks configured.
  """

  class HealthStateValueValuesEnum(_messages.Enum):
    r"""Health state of the network endpoint determined based on the health
    checks configured.

    Values:
      DRAINING: <no description>
      HEALTHY: <no description>
      UNHEALTHY: <no description>
      UNKNOWN: <no description>
    """
    DRAINING = 0
    HEALTHY = 1
    UNHEALTHY = 2
    UNKNOWN = 3

  backendService = _messages.MessageField('BackendServiceReference', 1)
  forwardingRule = _messages.MessageField('ForwardingRuleReference', 2)
  healthCheck = _messages.MessageField('HealthCheckReference', 3)
  healthCheckService = _messages.MessageField('HealthCheckServiceReference', 4)
  healthState = _messages.EnumField('HealthStateValueValuesEnum', 5)


class HostRule(_messages.Message):
  r"""UrlMaps A host-matching rule for a URL. If matched, will use the named
  PathMatcher to select the BackendService.

  Fields:
    description: An optional description of this resource. Provide this
      property when you create the resource.
    hosts: The list of host patterns to match. They must be valid hostnames
      with optional port numbers in the format host:port. * matches any string
      of ([a-z0-9-.]*). In that case, * must be the first character and must
      be followed in the pattern by either - or ..
    pathMatcher: The name of the PathMatcher to use to match the path portion
      of the URL if the hostRule matches the URL's host portion.
  """

  description = _messages.StringField(1)
  hosts = _messages.StringField(2, repeated=True)
  pathMatcher = _messages.StringField(3)


class HttpFaultAbort(_messages.Message):
  r"""Specification for how requests are aborted as part of fault injection.

  Fields:
    httpStatus: The HTTP status code used to abort the request. The value must
      be between 200 and 599 inclusive.
    percentage: The percentage of traffic (connections/operations/requests)
      which will be aborted as part of fault injection. The value must be
      between 0.0 and 100.0 inclusive.
  """

  httpStatus = _messages.IntegerField(1, variant=_messages.Variant.UINT32)
  percentage = _messages.FloatField(2)


class HttpFaultDelay(_messages.Message):
  r"""Specifies the delay introduced by Loadbalancer before forwarding the
  request to the backend service as part of fault injection.

  Fields:
    fixedDelay: Specifies the value of the fixed delay interval.
    percentage: The percentage of traffic (connections/operations/requests) on
      which delay will be introduced as part of fault injection. The value
      must be between 0.0 and 100.0 inclusive.
  """

  fixedDelay = _messages.MessageField('Duration', 1)
  percentage = _messages.FloatField(2)


class HttpFaultInjection(_messages.Message):
  r"""The specification for fault injection introduced into traffic to test
  the resiliency of clients to backend service failure. As part of fault
  injection, when clients send requests to a backend service, delays can be
  introduced by Loadbalancer on a percentage of requests before sending those
  request to the backend service. Similarly requests from clients can be
  aborted by the Loadbalancer for a percentage of requests.

  Fields:
    abort: The specification for how client requests are aborted as part of
      fault injection.
    delay: The specification for how client requests are delayed as part of
      fault injection, before being sent to a backend service.
  """

  abort = _messages.MessageField('HttpFaultAbort', 1)
  delay = _messages.MessageField('HttpFaultDelay', 2)


class HttpFilterConfig(_messages.Message):
  r"""HttpFilterConfiguration supplies additional contextual settings for
  networkservices.HttpFilter resources enabled by Traffic Director.

  Fields:
    config: The configuration needed to enable the networkservices.HttpFilter
      resource. The configuration must be YAML formatted and only contain
      fields defined in the protobuf identified in configTypeUrl
    configTypeUrl: The fully qualified versioned proto3 type url of the
      protobuf that the filter expects for its contextual settings, for
      example: type.googleapis.com/google.protobuf.Struct
    filterName: Name of the networkservices.HttpFilter resource this
      configuration belongs to. This name must be known to the xDS client.
      Example: envoy.wasm
  """

  config = _messages.StringField(1)
  configTypeUrl = _messages.StringField(2)
  filterName = _messages.StringField(3)


class HttpHeaderAction(_messages.Message):
  r"""The request and response header transformations that take effect before
  the request is passed along to the selected backendService.

  Fields:
    requestHeadersToAdd: Headers to add to a matching request prior to
      forwarding the request to the backendService.
    requestHeadersToRemove: A list of header names for headers that need to be
      removed from the request prior to forwarding the request to the
      backendService.
    responseHeadersToAdd: Headers to add the response prior to sending the
      response back to the client.
    responseHeadersToRemove: A list of header names for headers that need to
      be removed from the response prior to sending the response back to the
      client.
  """

  requestHeadersToAdd = _messages.MessageField('HttpHeaderOption', 1, repeated=True)
  requestHeadersToRemove = _messages.StringField(2, repeated=True)
  responseHeadersToAdd = _messages.MessageField('HttpHeaderOption', 3, repeated=True)
  responseHeadersToRemove = _messages.StringField(4, repeated=True)


class HttpHeaderMatch(_messages.Message):
  r"""matchRule criteria for request header matches.

  Fields:
    exactMatch: The value should exactly match contents of exactMatch. Only
      one of exactMatch, prefixMatch, suffixMatch, regexMatch, presentMatch or
      rangeMatch must be set.
    headerName: The name of the HTTP header to match. For matching against the
      HTTP request's authority, use a headerMatch with the header name
      ":authority". For matching a request's method, use the headerName
      ":method".
    invertMatch: If set to false, the headerMatch is considered a match if the
      match criteria above are met. If set to true, the headerMatch is
      considered a match if the match criteria above are NOT met. The default
      setting is false.
    prefixMatch: The value of the header must start with the contents of
      prefixMatch. Only one of exactMatch, prefixMatch, suffixMatch,
      regexMatch, presentMatch or rangeMatch must be set.
    presentMatch: A header with the contents of headerName must exist. The
      match takes place whether or not the request's header has a value. Only
      one of exactMatch, prefixMatch, suffixMatch, regexMatch, presentMatch or
      rangeMatch must be set.
    rangeMatch: The header value must be an integer and its value must be in
      the range specified in rangeMatch. If the header does not contain an
      integer, number or is empty, the match fails. For example for a range
      [-5, 0]   - -3 will match.  - 0 will not match.  - 0.25 will not match.
      - -3someString will not match.   Only one of exactMatch, prefixMatch,
      suffixMatch, regexMatch, presentMatch or rangeMatch must be set. Note
      that rangeMatch is not supported for Loadbalancers that have their
      loadBalancingScheme set to EXTERNAL.
    regexMatch: The value of the header must match the regular expression
      specified in regexMatch. For regular expression grammar, please see:
      en.cppreference.com/w/cpp/regex/ecmascript  For matching against a port
      specified in the HTTP request, use a headerMatch with headerName set to
      PORT and a regular expression that satisfies the RFC2616 Host header's
      port specifier. Only one of exactMatch, prefixMatch, suffixMatch,
      regexMatch, presentMatch or rangeMatch must be set. Note that regexMatch
      only applies to Loadbalancers that have their loadBalancingScheme set to
      INTERNAL_SELF_MANAGED.
    suffixMatch: The value of the header must end with the contents of
      suffixMatch. Only one of exactMatch, prefixMatch, suffixMatch,
      regexMatch, presentMatch or rangeMatch must be set.
  """

  exactMatch = _messages.StringField(1)
  headerName = _messages.StringField(2)
  invertMatch = _messages.BooleanField(3)
  prefixMatch = _messages.StringField(4)
  presentMatch = _messages.BooleanField(5)
  rangeMatch = _messages.MessageField('Int64RangeMatch', 6)
  regexMatch = _messages.StringField(7)
  suffixMatch = _messages.StringField(8)


class HttpHeaderOption(_messages.Message):
  r"""Specification determining how headers are added to requests or
  responses.

  Fields:
    headerName: The name of the header.
    headerValue: The value of the header to add.
    replace: If false, headerValue is appended to any values that already
      exist for the header. If true, headerValue is set for the header,
      discarding any values that were set for that header. The default value
      is false.
  """

  headerName = _messages.StringField(1)
  headerValue = _messages.StringField(2)
  replace = _messages.BooleanField(3)


class HttpHealthCheck(_messages.Message):
  r"""Represents a legacy HTTP Health Check resource.  Legacy health checks
  are required by network load balancers. For more information, read Health
  Check Concepts.

  Fields:
    checkIntervalSec: How often (in seconds) to send a health check. The
      default value is 5 seconds.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    healthyThreshold: A so-far unhealthy instance will be marked healthy after
      this many consecutive successes. The default value is 2.
    host: The value of the host header in the HTTP health check request. If
      left empty (default value), the public IP on behalf of which this health
      check is performed will be used.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#httpHealthCheck
      for HTTP health checks.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    port: The TCP port number for the HTTP health check request. The default
      value is 80.
    requestPath: The request path of the HTTP health check request. The
      default value is /. This field does not support query parameters.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    timeoutSec: How long (in seconds) to wait before claiming failure. The
      default value is 5 seconds. It is invalid for timeoutSec to have greater
      value than checkIntervalSec.
    unhealthyThreshold: A so-far healthy instance will be marked unhealthy
      after this many consecutive failures. The default value is 2.
  """

  checkIntervalSec = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  healthyThreshold = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  host = _messages.StringField(5)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(7, default=u'compute#httpHealthCheck')
  name = _messages.StringField(8)
  port = _messages.IntegerField(9, variant=_messages.Variant.INT32)
  requestPath = _messages.StringField(10)
  selfLink = _messages.StringField(11)
  selfLinkWithId = _messages.StringField(12)
  timeoutSec = _messages.IntegerField(13, variant=_messages.Variant.INT32)
  unhealthyThreshold = _messages.IntegerField(14, variant=_messages.Variant.INT32)


class HttpHealthCheckList(_messages.Message):
  r"""Contains a list of HttpHealthCheck resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of HttpHealthCheck resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('HttpHealthCheck', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#httpHealthCheckList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class HttpQueryParameterMatch(_messages.Message):
  r"""HttpRouteRuleMatch criteria for a request's query parameter.

  Fields:
    exactMatch: The queryParameterMatch matches if the value of the parameter
      exactly matches the contents of exactMatch. Only one of presentMatch,
      exactMatch or regexMatch must be set.
    name: The name of the query parameter to match. The query parameter must
      exist in the request, in the absence of which the request match fails.
    presentMatch: Specifies that the queryParameterMatch matches if the
      request contains the query parameter, irrespective of whether the
      parameter has a value or not. Only one of presentMatch, exactMatch or
      regexMatch must be set.
    regexMatch: The queryParameterMatch matches if the value of the parameter
      matches the regular expression specified by regexMatch. For the regular
      expression grammar, please see
      en.cppreference.com/w/cpp/regex/ecmascript  Only one of presentMatch,
      exactMatch or regexMatch must be set. Note that regexMatch only applies
      when the loadBalancingScheme is set to INTERNAL_SELF_MANAGED.
  """

  exactMatch = _messages.StringField(1)
  name = _messages.StringField(2)
  presentMatch = _messages.BooleanField(3)
  regexMatch = _messages.StringField(4)


class HttpRedirectAction(_messages.Message):
  r"""Specifies settings for an HTTP redirect.

  Enums:
    RedirectResponseCodeValueValuesEnum: The HTTP Status code to use for this
      RedirectAction. Supported values are:   - MOVED_PERMANENTLY_DEFAULT,
      which is the default value and corresponds to 301.  - FOUND, which
      corresponds to 302.  - SEE_OTHER which corresponds to 303.  -
      TEMPORARY_REDIRECT, which corresponds to 307. In this case, the request
      method will be retained.  - PERMANENT_REDIRECT, which corresponds to
      308. In this case, the request method will be retained.

  Fields:
    hostRedirect: The host that will be used in the redirect response instead
      of the one that was supplied in the request. The value must be between 1
      and 255 characters.
    httpsRedirect: If set to true, the URL scheme in the redirected request is
      set to https. If set to false, the URL scheme of the redirected request
      will remain the same as that of the request. This must only be set for
      UrlMaps used in TargetHttpProxys. Setting this true for TargetHttpsProxy
      is not permitted. The default is set to false.
    pathRedirect: The path that will be used in the redirect response instead
      of the one that was supplied in the request. pathRedirect cannot be
      supplied together with prefixRedirect. Supply one alone or neither. If
      neither is supplied, the path of the original request will be used for
      the redirect. The value must be between 1 and 1024 characters.
    prefixRedirect: The prefix that replaces the prefixMatch specified in the
      HttpRouteRuleMatch, retaining the remaining portion of the URL before
      redirecting the request. prefixRedirect cannot be supplied together with
      pathRedirect. Supply one alone or neither. If neither is supplied, the
      path of the original request will be used for the redirect. The value
      must be between 1 and 1024 characters.
    redirectResponseCode: The HTTP Status code to use for this RedirectAction.
      Supported values are:   - MOVED_PERMANENTLY_DEFAULT, which is the
      default value and corresponds to 301.  - FOUND, which corresponds to
      302.  - SEE_OTHER which corresponds to 303.  - TEMPORARY_REDIRECT, which
      corresponds to 307. In this case, the request method will be retained.
      - PERMANENT_REDIRECT, which corresponds to 308. In this case, the
      request method will be retained.
    stripQuery: If set to true, any accompanying query portion of the original
      URL is removed prior to redirecting the request. If set to false, the
      query portion of the original URL is retained. The default is set to
      false.
  """

  class RedirectResponseCodeValueValuesEnum(_messages.Enum):
    r"""The HTTP Status code to use for this RedirectAction. Supported values
    are:   - MOVED_PERMANENTLY_DEFAULT, which is the default value and
    corresponds to 301.  - FOUND, which corresponds to 302.  - SEE_OTHER which
    corresponds to 303.  - TEMPORARY_REDIRECT, which corresponds to 307. In
    this case, the request method will be retained.  - PERMANENT_REDIRECT,
    which corresponds to 308. In this case, the request method will be
    retained.

    Values:
      FOUND: <no description>
      MOVED_PERMANENTLY_DEFAULT: <no description>
      PERMANENT_REDIRECT: <no description>
      SEE_OTHER: <no description>
      TEMPORARY_REDIRECT: <no description>
    """
    FOUND = 0
    MOVED_PERMANENTLY_DEFAULT = 1
    PERMANENT_REDIRECT = 2
    SEE_OTHER = 3
    TEMPORARY_REDIRECT = 4

  hostRedirect = _messages.StringField(1)
  httpsRedirect = _messages.BooleanField(2)
  pathRedirect = _messages.StringField(3)
  prefixRedirect = _messages.StringField(4)
  redirectResponseCode = _messages.EnumField('RedirectResponseCodeValueValuesEnum', 5)
  stripQuery = _messages.BooleanField(6)


class HttpRetryPolicy(_messages.Message):
  r"""The retry policy associates with HttpRouteRule

  Fields:
    numRetries: Specifies the allowed number retries. This number must be > 0.
      If not specified, defaults to 1.
    perTryTimeout: Specifies a non-zero timeout per retry attempt. If not
      specified, will use the timeout set in HttpRouteAction. If timeout in
      HttpRouteAction is not set, will use the largest timeout among all
      backend services associated with the route.
    retryConditions: Specfies one or more conditions when this retry rule
      applies. Valid values are:   - 5xx: Loadbalancer will attempt a retry if
      the backend service responds with any 5xx response code, or if the
      backend service does not respond at all, example: disconnects, reset,
      read timeout, connection failure, and refused streams.  - gateway-error:
      Similar to 5xx, but only applies to response codes 502, 503 or 504. -  -
      connect-failure: Loadbalancer will retry on failures connecting to
      backend services, for example due to connection timeouts.  - retriable-
      4xx: Loadbalancer will retry for retriable 4xx response codes. Currently
      the only retriable error supported is 409.  - refused-
      stream:Loadbalancer will retry if the backend service resets the stream
      with a REFUSED_STREAM error code. This reset type indicates that it is
      safe to retry.  - cancelledLoadbalancer will retry if the gRPC status
      code in the response header is set to cancelled  - deadline-exceeded:
      Loadbalancer will retry if the gRPC status code in the response header
      is set to deadline-exceeded  - resource-exhausted: Loadbalancer will
      retry if the gRPC status code in the response header is set to resource-
      exhausted  - unavailable: Loadbalancer will retry if the gRPC status
      code in the response header is set to unavailable
  """

  numRetries = _messages.IntegerField(1, variant=_messages.Variant.UINT32)
  perTryTimeout = _messages.MessageField('Duration', 2)
  retryConditions = _messages.StringField(3, repeated=True)


class HttpRouteAction(_messages.Message):
  r"""A HttpRouteAction object.

  Fields:
    corsPolicy: The specification for allowing client side cross-origin
      requests. Please see W3C Recommendation for Cross Origin Resource
      Sharing
    faultInjectionPolicy: The specification for fault injection introduced
      into traffic to test the resiliency of clients to backend service
      failure. As part of fault injection, when clients send requests to a
      backend service, delays can be introduced by Loadbalancer on a
      percentage of requests before sending those request to the backend
      service. Similarly requests from clients can be aborted by the
      Loadbalancer for a percentage of requests. timeout and retry_policy will
      be ignored by clients that are configured with a fault_injection_policy.
    requestMirrorPolicy: Specifies the policy on how requests intended for the
      route's backends are shadowed to a separate mirrored backend service.
      Loadbalancer does not wait for responses from the shadow service. Prior
      to sending traffic to the shadow service, the host / authority header is
      suffixed with -shadow.
    retryPolicy: Specifies the retry policy associated with this route.
    timeout: Specifies the timeout for the selected route. Timeout is computed
      from the time the request has been fully processed (i.e. end-of-stream)
      up until the response has been completely processed. Timeout includes
      all retries. If not specified, will use the largest timeout among all
      backend services associated with the route.
    urlRewrite: The spec to modify the URL of the request, prior to forwarding
      the request to the matched service.
    weightedBackendServices: A list of weighted backend services to send
      traffic to when a route match occurs. The weights determine the fraction
      of traffic that flows to their corresponding backend service. If all
      traffic needs to go to a single backend service, there must be one
      weightedBackendService with weight set to a non 0 number. Once a
      backendService is identified and before forwarding the request to the
      backend service, advanced routing actions like Url rewrites and header
      transformations are applied depending on additional settings specified
      in this HttpRouteAction.
  """

  corsPolicy = _messages.MessageField('CorsPolicy', 1)
  faultInjectionPolicy = _messages.MessageField('HttpFaultInjection', 2)
  requestMirrorPolicy = _messages.MessageField('RequestMirrorPolicy', 3)
  retryPolicy = _messages.MessageField('HttpRetryPolicy', 4)
  timeout = _messages.MessageField('Duration', 5)
  urlRewrite = _messages.MessageField('UrlRewrite', 6)
  weightedBackendServices = _messages.MessageField('WeightedBackendService', 7, repeated=True)


class HttpRouteRule(_messages.Message):
  r"""An HttpRouteRule specifies how to match an HTTP request and the
  corresponding routing action that load balancing proxies will perform.

  Fields:
    description: The short description conveying the intent of this routeRule.
      The description can have a maximum length of 1024 characters.
    headerAction: Specifies changes to request and response headers that need
      to take effect for the selected backendService. The headerAction
      specified here are applied before the matching
      pathMatchers[].headerAction and after pathMatchers[].routeRules[].routeA
      ction.weightedBackendService.backendServiceWeightAction[].headerAction
    httpFilterConfigs: Outbound route specific configuration for
      networkservices.HttpFilter resources enabled by Traffic Director.
      httpFilterConfigs only applies for Loadbalancers with
      loadBalancingScheme set to INTERNAL_SELF_MANAGED. See ForwardingRule for
      more details.
    httpFilterMetadata: Outbound route specific metadata supplied to
      networkservices.HttpFilter resources enabled by Traffic Director.
      httpFilterMetadata only applies for Loadbalancers with
      loadBalancingScheme set to INTERNAL_SELF_MANAGED. See ForwardingRule for
      more details. The only configTypeUrl supported is
      type.googleapis.com/google.protobuf.Struct
    matchRules: A HttpRouteRuleMatch attribute.
    priority: For routeRules within a given pathMatcher, priority determines
      the order in which load balancer will interpret routeRules. RouteRules
      are evaluated in order of priority, from the lowest to highest number.
      The priority of a rule decreases as its number increases (1, 2, 3, N+1).
      The first rule that matches the request is applied. You cannot configure
      two or more routeRules with the same priority. Priority for each rule
      must be set to a number between 0 and 2147483647 inclusive. Priority
      numbers can have gaps, which enable you to add or remove rules in the
      future without affecting the rest of the rules. For example, 1, 2, 3, 4,
      5, 9, 12, 16 is a valid series of priority numbers to which you could
      add rules numbered from 6 to 8, 10 to 11, and 13 to 15 in the future
      without any impact on existing rules.
    routeAction: In response to a matching matchRule, the load balancer
      performs advanced routing actions like URL rewrites, header
      transformations, etc. prior to forwarding the request to the selected
      backend. If  routeAction specifies any  weightedBackendServices, service
      must not be set. Conversely if service is set, routeAction cannot
      contain any  weightedBackendServices. Only one of urlRedirect, service
      or routeAction.weightedBackendService must be set.
    service: The full or partial URL of the backend service resource to which
      traffic is directed if this rule is matched. If routeAction is
      additionally specified, advanced routing actions like URL Rewrites, etc.
      take effect prior to sending the request to the backend. However, if
      service is specified, routeAction cannot contain any
      weightedBackendService s. Conversely, if routeAction specifies any
      weightedBackendServices, service must not be specified. Only one of
      urlRedirect, service or routeAction.weightedBackendService must be set.
    urlRedirect: When this rule is matched, the request is redirected to a URL
      specified by urlRedirect. If urlRedirect is specified, service or
      routeAction must not be set.
  """

  description = _messages.StringField(1)
  headerAction = _messages.MessageField('HttpHeaderAction', 2)
  httpFilterConfigs = _messages.MessageField('HttpFilterConfig', 3, repeated=True)
  httpFilterMetadata = _messages.MessageField('HttpFilterConfig', 4, repeated=True)
  matchRules = _messages.MessageField('HttpRouteRuleMatch', 5, repeated=True)
  priority = _messages.IntegerField(6, variant=_messages.Variant.INT32)
  routeAction = _messages.MessageField('HttpRouteAction', 7)
  service = _messages.StringField(8)
  urlRedirect = _messages.MessageField('HttpRedirectAction', 9)


class HttpRouteRuleMatch(_messages.Message):
  r"""HttpRouteRuleMatch specifies a set of criteria for matching requests to
  an HttpRouteRule. All specified criteria must be satisfied for a match to
  occur.

  Fields:
    fullPathMatch: For satisfying the matchRule condition, the path of the
      request must exactly match the value specified in fullPathMatch after
      removing any query parameters and anchor that may be part of the
      original URL. fullPathMatch must be between 1 and 1024 characters. Only
      one of prefixMatch, fullPathMatch or regexMatch must be specified.
    headerMatches: Specifies a list of header match criteria, all of which
      must match corresponding headers in the request.
    ignoreCase: Specifies that prefixMatch and fullPathMatch matches are case
      sensitive. The default value is false. ignoreCase must not be used with
      regexMatch.
    metadataFilters: Opaque filter criteria used by Loadbalancer to restrict
      routing configuration to a limited set of xDS compliant clients. In
      their xDS requests to Loadbalancer, xDS clients present node metadata.
      If a match takes place, the relevant routing configuration is made
      available to those proxies. For each metadataFilter in this list, if its
      filterMatchCriteria is set to MATCH_ANY, at least one of the
      filterLabels must match the corresponding label provided in the
      metadata. If its filterMatchCriteria is set to MATCH_ALL, then all of
      its filterLabels must match with corresponding labels provided in the
      metadata. metadataFilters specified here will be applied after those
      specified in ForwardingRule that refers to the UrlMap this
      HttpRouteRuleMatch belongs to. metadataFilters only applies to
      Loadbalancers that have their loadBalancingScheme set to
      INTERNAL_SELF_MANAGED.
    prefixMatch: For satisfying the matchRule condition, the request's path
      must begin with the specified prefixMatch. prefixMatch must begin with a
      /. The value must be between 1 and 1024 characters. Only one of
      prefixMatch, fullPathMatch or regexMatch must be specified.
    queryParameterMatches: Specifies a list of query parameter match criteria,
      all of which must match corresponding query parameters in the request.
    regexMatch: For satisfying the matchRule condition, the path of the
      request must satisfy the regular expression specified in regexMatch
      after removing any query parameters and anchor supplied with the
      original URL. For regular expression grammar please see
      en.cppreference.com/w/cpp/regex/ecmascript  Only one of prefixMatch,
      fullPathMatch or regexMatch must be specified. Note that regexMatch only
      applies to Loadbalancers that have their loadBalancingScheme set to
      INTERNAL_SELF_MANAGED.
  """

  fullPathMatch = _messages.StringField(1)
  headerMatches = _messages.MessageField('HttpHeaderMatch', 2, repeated=True)
  ignoreCase = _messages.BooleanField(3)
  metadataFilters = _messages.MessageField('MetadataFilter', 4, repeated=True)
  prefixMatch = _messages.StringField(5)
  queryParameterMatches = _messages.MessageField('HttpQueryParameterMatch', 6, repeated=True)
  regexMatch = _messages.StringField(7)


class HttpsHealthCheck(_messages.Message):
  r"""Represents a legacy HTTPS Health Check resource.  Legacy health checks
  are required by network load balancers. For more information, read Health
  Check Concepts.

  Fields:
    checkIntervalSec: How often (in seconds) to send a health check. The
      default value is 5 seconds.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    healthyThreshold: A so-far unhealthy instance will be marked healthy after
      this many consecutive successes. The default value is 2.
    host: The value of the host header in the HTTPS health check request. If
      left empty (default value), the public IP on behalf of which this health
      check is performed will be used.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: Type of the resource.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    port: The TCP port number for the HTTPS health check request. The default
      value is 443.
    requestPath: The request path of the HTTPS health check request. The
      default value is "/".
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    timeoutSec: How long (in seconds) to wait before claiming failure. The
      default value is 5 seconds. It is invalid for timeoutSec to have a
      greater value than checkIntervalSec.
    unhealthyThreshold: A so-far healthy instance will be marked unhealthy
      after this many consecutive failures. The default value is 2.
  """

  checkIntervalSec = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  healthyThreshold = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  host = _messages.StringField(5)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(7, default=u'compute#httpsHealthCheck')
  name = _messages.StringField(8)
  port = _messages.IntegerField(9, variant=_messages.Variant.INT32)
  requestPath = _messages.StringField(10)
  selfLink = _messages.StringField(11)
  selfLinkWithId = _messages.StringField(12)
  timeoutSec = _messages.IntegerField(13, variant=_messages.Variant.INT32)
  unhealthyThreshold = _messages.IntegerField(14, variant=_messages.Variant.INT32)


class HttpsHealthCheckList(_messages.Message):
  r"""Contains a list of HttpsHealthCheck resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of HttpsHealthCheck resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('HttpsHealthCheck', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#httpsHealthCheckList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class Image(_messages.Message):
  r"""Represents an Image resource.  You can use images to create boot disks
  for your VM instances. For more information, read Images. (== resource_for
  {$api_version}.images ==)

  Enums:
    SourceTypeValueValuesEnum: The type of the image used to create this disk.
      The default and only value is RAW
    StatusValueValuesEnum: [Output Only] The status of the image. An image can
      be used to create other resources, such as instances, only after the
      image has been successfully created and the status is set to READY.
      Possible values are FAILED, PENDING, or READY.

  Messages:
    LabelsValue: Labels to apply to this image. These can be later modified by
      the setLabels method.
    RawDiskValue: The parameters of the raw disk image.

  Fields:
    archiveSizeBytes: Size of the image tar.gz archive stored in Google Cloud
      Storage (in bytes).
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    deprecated: The deprecation status associated with this image.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    diskSizeGb: Size of the image when restored onto a persistent disk (in
      GB).
    family: The name of the image family to which this image belongs. You can
      create disks by specifying an image family instead of a specific image
      name. The image family always returns its latest image that is not
      deprecated. The name of the image family must comply with RFC1035.
    guestOsFeatures: A list of features to enable on the guest operating
      system. Applicable only for bootable images. Read  Enabling guest
      operating system features to see a list of available options.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    imageEncryptionKey: Encrypts the image using a customer-supplied
      encryption key.  After you encrypt an image with a customer-supplied
      key, you must provide the same key if you use the image later (e.g. to
      create a disk from the image).  Customer-supplied encryption keys do not
      protect access to metadata of the disk.  If you do not provide an
      encryption key when creating the image, then the disk will be encrypted
      using an automatically generated key and you do not need to provide a
      key to use the image later.
    kind: [Output Only] Type of the resource. Always compute#image for images.
    labelFingerprint: A fingerprint for the labels being applied to this
      image, which is essentially a hash of the labels used for optimistic
      locking. The fingerprint is initially generated by Compute Engine and
      changes after every request to modify or update labels. You must always
      provide an up-to-date fingerprint hash in order to update or change
      labels, otherwise the request will fail with error 412 conditionNotMet.
      To see the latest fingerprint, make a get() request to retrieve an
      image.
    labels: Labels to apply to this image. These can be later modified by the
      setLabels method.
    licenseCodes: Integer license codes indicating which licenses are attached
      to this image.
    licenses: Any applicable license URI.
    name: Name of the resource; provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    rawDisk: The parameters of the raw disk image.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource's
      resource id.
    shieldedInstanceInitialState: Set the secure boot keys of shielded
      instance.
    sourceDisk: URL of the source disk used to create this image. This can be
      a full or valid partial URL. You must provide either this property or
      the rawDisk.source property but not both to create an image. For
      example, the following are valid values:   - https://www.googleapis.com/
      compute/v1/projects/project/zones/zone/disks/disk  -
      projects/project/zones/zone/disks/disk  - zones/zone/disks/disk
    sourceDiskEncryptionKey: The customer-supplied encryption key of the
      source disk. Required if the source disk is protected by a customer-
      supplied encryption key.
    sourceDiskId: [Output Only] The ID value of the disk used to create this
      image. This value may be used to determine whether the image was taken
      from the current or a previous instance of a given disk name.
    sourceImage: URL of the source image used to create this image. This can
      be a full or valid partial URL. You must provide exactly one of:   -
      this property, or   - the rawDisk.source property, or   - the sourceDisk
      property   in order to create an image.
    sourceImageEncryptionKey: The customer-supplied encryption key of the
      source image. Required if the source image is protected by a customer-
      supplied encryption key.
    sourceImageId: [Output Only] The ID value of the image used to create this
      image. This value may be used to determine whether the image was taken
      from the current or a previous instance of a given image name.
    sourceSnapshot: URL of the source snapshot used to create this image. This
      can be a full or valid partial URL. You must provide exactly one of:   -
      this property, or   - the sourceImage property, or   - the
      rawDisk.source property, or   - the sourceDisk property   in order to
      create an image.
    sourceSnapshotEncryptionKey: The customer-supplied encryption key of the
      source snapshot. Required if the source snapshot is protected by a
      customer-supplied encryption key.
    sourceSnapshotId: [Output Only] The ID value of the snapshot used to
      create this image. This value may be used to determine whether the
      snapshot was taken from the current or a previous instance of a given
      snapshot name.
    sourceType: The type of the image used to create this disk. The default
      and only value is RAW
    status: [Output Only] The status of the image. An image can be used to
      create other resources, such as instances, only after the image has been
      successfully created and the status is set to READY. Possible values are
      FAILED, PENDING, or READY.
    storageLocations: Cloud Storage bucket storage location of the image
      (regional or multi-regional).
  """

  class SourceTypeValueValuesEnum(_messages.Enum):
    r"""The type of the image used to create this disk. The default and only
    value is RAW

    Values:
      RAW: <no description>
    """
    RAW = 0

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the image. An image can be used to create
    other resources, such as instances, only after the image has been
    successfully created and the status is set to READY. Possible values are
    FAILED, PENDING, or READY.

    Values:
      DELETING: <no description>
      FAILED: <no description>
      PENDING: <no description>
      READY: <no description>
    """
    DELETING = 0
    FAILED = 1
    PENDING = 2
    READY = 3

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels to apply to this image. These can be later modified by the
    setLabels method.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class RawDiskValue(_messages.Message):
    r"""The parameters of the raw disk image.

    Enums:
      ContainerTypeValueValuesEnum: The format used to encode and transmit the
        block device, which should be TAR. This is just a container and
        transmission format and not a runtime format. Provided by the client
        when the disk image is created.

    Fields:
      containerType: The format used to encode and transmit the block device,
        which should be TAR. This is just a container and transmission format
        and not a runtime format. Provided by the client when the disk image
        is created.
      sha1Checksum: [Deprecated] This field is deprecated. An optional SHA1
        checksum of the disk image before unpackaging provided by the client
        when the disk image is created.
      source: The full Google Cloud Storage URL where the disk image is
        stored. You must provide either this property or the sourceDisk
        property but not both.
    """

    class ContainerTypeValueValuesEnum(_messages.Enum):
      r"""The format used to encode and transmit the block device, which
      should be TAR. This is just a container and transmission format and not
      a runtime format. Provided by the client when the disk image is created.

      Values:
        TAR: <no description>
      """
      TAR = 0

    containerType = _messages.EnumField('ContainerTypeValueValuesEnum', 1)
    sha1Checksum = _messages.StringField(2)
    source = _messages.StringField(3)

  archiveSizeBytes = _messages.IntegerField(1)
  creationTimestamp = _messages.StringField(2)
  deprecated = _messages.MessageField('DeprecationStatus', 3)
  description = _messages.StringField(4)
  diskSizeGb = _messages.IntegerField(5)
  family = _messages.StringField(6)
  guestOsFeatures = _messages.MessageField('GuestOsFeature', 7, repeated=True)
  id = _messages.IntegerField(8, variant=_messages.Variant.UINT64)
  imageEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 9)
  kind = _messages.StringField(10, default=u'compute#image')
  labelFingerprint = _messages.BytesField(11)
  labels = _messages.MessageField('LabelsValue', 12)
  licenseCodes = _messages.IntegerField(13, repeated=True)
  licenses = _messages.StringField(14, repeated=True)
  name = _messages.StringField(15)
  rawDisk = _messages.MessageField('RawDiskValue', 16)
  selfLink = _messages.StringField(17)
  selfLinkWithId = _messages.StringField(18)
  shieldedInstanceInitialState = _messages.MessageField('InitialStateConfig', 19)
  sourceDisk = _messages.StringField(20)
  sourceDiskEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 21)
  sourceDiskId = _messages.StringField(22)
  sourceImage = _messages.StringField(23)
  sourceImageEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 24)
  sourceImageId = _messages.StringField(25)
  sourceSnapshot = _messages.StringField(26)
  sourceSnapshotEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 27)
  sourceSnapshotId = _messages.StringField(28)
  sourceType = _messages.EnumField('SourceTypeValueValuesEnum', 29, default=u'RAW')
  status = _messages.EnumField('StatusValueValuesEnum', 30)
  storageLocations = _messages.StringField(31, repeated=True)


class ImageList(_messages.Message):
  r"""Contains a list of images.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Image resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Image', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#imageList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class InPlaceSnapshot(_messages.Message):
  r"""Represents a InPlaceSnapshot resource.  You can use in-place snapshots
  to create disk rollback points quickly.. (== resource_for
  {$api_version}.inPlaceSnapshots ==)

  Enums:
    StatusValueValuesEnum: [Output Only] The status of the inPlaceSnapshot.
      This can be CREATING, DELETING, FAILED, or READY.

  Messages:
    LabelsValue: Labels to apply to this InPlaceSnapshot. These can be later
      modified by the setLabels method. Label values may be empty.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    diskSizeGb: [Output Only] Size of the source disk, specified in GB.
    guestFlush: Specifies to create an application consistent in-place
      snapshot by informing the OS to prepare for the snapshot process.
      Currently only supported on Windows instances using the Volume Shadow
      Copy Service (VSS).
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#inPlaceSnapshot
      for InPlaceSnapshot resources.
    labelFingerprint: A fingerprint for the labels being applied to this
      InPlaceSnapshot, which is essentially a hash of the labels set used for
      optimistic locking. The fingerprint is initially generated by Compute
      Engine and changes after every request to modify or update labels. You
      must always provide an up-to-date fingerprint hash in order to update or
      change labels, otherwise the request will fail with error 412
      conditionNotMet.  To see the latest fingerprint, make a get() request to
      retrieve a InPlaceSnapshot.
    labels: Labels to apply to this InPlaceSnapshot. These can be later
      modified by the setLabels method. Label values may be empty.
    name: Name of the resource; provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    region: [Output Only] URL of the region where the in-place snapshot
      resides. You must specify this field as part of the HTTP request URL. It
      is not settable as a field in the request body.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource's
      resource id.
    sourceDisk: URL of the source disk used to create this in-place snapshot.
      Note that the source disk must be in the same zone/region as the in-
      place snapshot to be created. This can be a full or valid partial URL.
      For example, the following are valid values:   - https://www.googleapis.
      com/compute/v1/projects/project/zones/zone/disks/disk  -
      projects/project/zones/zone/disks/disk  - zones/zone/disks/disk
    sourceDiskId: [Output Only] The ID value of the disk used to create this
      InPlaceSnapshot. This value may be used to determine whether the
      InPlaceSnapshot was taken from the current or a previous instance of a
      given disk name.
    status: [Output Only] The status of the inPlaceSnapshot. This can be
      CREATING, DELETING, FAILED, or READY.
    zone: [Output Only] URL of the zone where the in-place snapshot resides.
      You must specify this field as part of the HTTP request URL. It is not
      settable as a field in the request body.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the inPlaceSnapshot. This can be CREATING,
    DELETING, FAILED, or READY.

    Values:
      CREATING: <no description>
      DELETING: <no description>
      FAILED: <no description>
      READY: <no description>
    """
    CREATING = 0
    DELETING = 1
    FAILED = 2
    READY = 3

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels to apply to this InPlaceSnapshot. These can be later modified
    by the setLabels method. Label values may be empty.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  diskSizeGb = _messages.IntegerField(3)
  guestFlush = _messages.BooleanField(4)
  id = _messages.IntegerField(5, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(6, default=u'compute#inPlaceSnapshot')
  labelFingerprint = _messages.BytesField(7)
  labels = _messages.MessageField('LabelsValue', 8)
  name = _messages.StringField(9)
  region = _messages.StringField(10)
  selfLink = _messages.StringField(11)
  selfLinkWithId = _messages.StringField(12)
  sourceDisk = _messages.StringField(13)
  sourceDiskId = _messages.StringField(14)
  status = _messages.EnumField('StatusValueValuesEnum', 15)
  zone = _messages.StringField(16)


class InPlaceSnapshotList(_messages.Message):
  r"""Contains a list of InPlaceSnapshot resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InPlaceSnapshot resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('InPlaceSnapshot', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#inPlaceSnapshotList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class InitialStateConfig(_messages.Message):
  r"""Initial State for shielded instance, these are public keys which are
  safe to store in public

  Fields:
    dbs: The Key Database (db).
    dbxs: The forbidden key database (dbx).
    keks: The Key Exchange Key (KEK).
    pk: The Platform Key (PK).
  """

  dbs = _messages.MessageField('FileContentBuffer', 1, repeated=True)
  dbxs = _messages.MessageField('FileContentBuffer', 2, repeated=True)
  keks = _messages.MessageField('FileContentBuffer', 3, repeated=True)
  pk = _messages.MessageField('FileContentBuffer', 4)


class Instance(_messages.Message):
  r"""Represents an Instance resource.  An instance is a virtual machine that
  is hosted on Google Cloud Platform. For more information, read Virtual
  Machine Instances. (== resource_for {$api_version}.instances ==)

  Enums:
    PostKeyRevocationActionTypeValueValuesEnum: Specifies whether this
      instance will be shut down on key revocation.
    PrivateIpv6GoogleAccessValueValuesEnum: The private IPv6 google access
      type for the VM. If not specified, use  INHERIT_FROM_SUBNETWORK as
      default.
    StatusValueValuesEnum: [Output Only] The status of the instance. One of
      the following values: PROVISIONING, STAGING, RUNNING, STOPPING, STOPPED,
      SUSPENDING, SUSPENDED, and TERMINATED.

  Messages:
    LabelsValue: Labels to apply to this instance. These can be later modified
      by the setLabels method.

  Fields:
    canIpForward: Allows this instance to send and receive packets with non-
      matching destination or source IPs. This is required if you plan to use
      this instance to forward routes. For more information, see Enabling IP
      Forwarding.
    confidentialInstanceConfig: A ConfidentialInstanceConfig attribute.
    cpuPlatform: [Output Only] The CPU platform used by this instance.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    deletionProtection: Whether the resource should be protected against
      deletion.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    disks: Array of disks associated with this instance. Persistent disks must
      be created before you can assign them.
    displayDevice: Enables display device for the instance.
    eraseWindowsVssSignature: Specifies whether the disks restored from source
      snapshots or source machine image should erase Windows specific VSS
      signature.
    fingerprint: Specifies a fingerprint for this resource, which is
      essentially a hash of the instance's contents and used for optimistic
      locking. The fingerprint is initially generated by Compute Engine and
      changes after every request to modify or update the instance. You must
      always provide an up-to-date fingerprint hash in order to update the
      instance.  To see the latest fingerprint, make get() request to the
      instance.
    guestAccelerators: A list of the type and count of accelerator cards
      attached to the instance.
    hostname: Specifies the hostname of the instance. The specified hostname
      must be RFC1035 compliant. If hostname is not specified, the default
      hostname is [INSTANCE_NAME].c.[PROJECT_ID].internal when using the
      global DNS, and [INSTANCE_NAME].[ZONE].c.[PROJECT_ID].internal when
      using zonal DNS.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    instanceEncryptionKey: Encrypts or decrypts data for an instance with a
      customer-supplied encryption key.  If you are creating a new instance,
      this field encrypts the local SSD and in-memory contents of the instance
      using a key that you provide.  If you are restarting an instance
      protected with a customer-supplied encryption key, you must provide the
      correct key in order to successfully restart the instance.  If you do
      not provide an encryption key when creating the instance, then the local
      SSD and in-memory contents will be encrypted using an automatically
      generated key and you do not need to provide a key to start the instance
      later.  Instance templates do not store customer-supplied encryption
      keys, so you cannot use your own keys to encrypt local SSDs and in-
      memory content in a managed instance group.
    kind: [Output Only] Type of the resource. Always compute#instance for
      instances.
    labelFingerprint: A fingerprint for this request, which is essentially a
      hash of the label's contents and used for optimistic locking. The
      fingerprint is initially generated by Compute Engine and changes after
      every request to modify or update labels. You must always provide an up-
      to-date fingerprint hash in order to update or change labels.  To see
      the latest fingerprint, make get() request to the instance.
    labels: Labels to apply to this instance. These can be later modified by
      the setLabels method.
    machineType: Full or partial URL of the machine type resource to use for
      this instance, in the format: zones/zone/machineTypes/machine-type. This
      is provided by the client when the instance is created. For example, the
      following is a valid partial url to a predefined machine type: zones/us-
      central1-f/machineTypes/n1-standard-1   To create a custom machine type,
      provide a URL to a machine type in the following format, where CPUS is 1
      or an even number up to 32 (2, 4, 6, ... 24, etc), and MEMORY is the
      total memory for this instance. Memory must be a multiple of 256 MB and
      must be supplied in MB (e.g. 5 GB of memory is 5120 MB):
      zones/zone/machineTypes/custom-CPUS-MEMORY   For example: zones/us-
      central1-f/machineTypes/custom-4-5120   For a full list of restrictions,
      read the Specifications for custom machine types.
    metadata: The metadata key/value pairs assigned to this instance. This
      includes custom metadata and predefined keys.
    minCpuPlatform: Specifies a minimum CPU platform for the VM instance.
      Applicable values are the friendly names of CPU platforms, such as
      minCpuPlatform: "Intel Haswell" or minCpuPlatform: "Intel Sandy Bridge".
    name: The name of the resource, provided by the client when initially
      creating the resource. The resource name must be 1-63 characters long,
      and comply with RFC1035. Specifically, the name must be 1-63 characters
      long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which
      means the first character must be a lowercase letter, and all following
      characters must be a dash, lowercase letter, or digit, except the last
      character, which cannot be a dash.
    networkInterfaces: An array of network configurations for this instance.
      These specify how interfaces are configured to interact with other
      network services, such as connecting to the internet. Multiple
      interfaces are supported per instance.
    postKeyRevocationActionType: Specifies whether this instance will be shut
      down on key revocation.
    preservedStateSizeGb: Total amount of preserved state for SUSPENDED
      instances. Read-only in the api.
    privateIpv6GoogleAccess: The private IPv6 google access type for the VM.
      If not specified, use  INHERIT_FROM_SUBNETWORK as default.
    reservationAffinity: Specifies the reservations that this instance can
      consume from.
    resourcePolicies: Resource policies applied to this instance.
    scheduling: Sets the scheduling options for this instance.
    selfLink: [Output Only] Server-defined URL for this resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    serviceAccounts: A list of service accounts, with their specified scopes,
      authorized for this instance. Only one service account per VM instance
      is supported.  Service accounts generate access tokens that can be
      accessed through the metadata server and used to authenticate
      applications on the instance. See Service Accounts for more information.
    shieldedInstanceConfig: A ShieldedInstanceConfig attribute.
    shieldedInstanceIntegrityPolicy: A ShieldedInstanceIntegrityPolicy
      attribute.
    shieldedVmConfig: A ShieldedVmConfig attribute.
    shieldedVmIntegrityPolicy: A ShieldedVmIntegrityPolicy attribute.
    sourceMachineImage: Source machine image
    sourceMachineImageEncryptionKey: Source GMI encryption key when creating
      an instance from GMI.
    startRestricted: [Output Only] Whether a VM has been restricted for start
      because Compute Engine has detected suspicious activity.
    status: [Output Only] The status of the instance. One of the following
      values: PROVISIONING, STAGING, RUNNING, STOPPING, STOPPED, SUSPENDING,
      SUSPENDED, and TERMINATED.
    statusMessage: [Output Only] An optional, human-readable explanation of
      the status.
    tags: Tags to apply to this instance. Tags are used to identify valid
      sources or targets for network firewalls and are specified by the client
      during instance creation. The tags can be later modified by the setTags
      method. Each tag within the list must comply with RFC1035. Multiple tags
      can be specified via the 'tags.items' field.
    upcomingMaintenance: [Output Only] Specifies upcoming maintenance for the
      instance.
    zone: [Output Only] URL of the zone where the instance resides. You must
      specify this field as part of the HTTP request URL. It is not settable
      as a field in the request body.
  """

  class PostKeyRevocationActionTypeValueValuesEnum(_messages.Enum):
    r"""Specifies whether this instance will be shut down on key revocation.

    Values:
      NOOP: <no description>
      SHUTDOWN: <no description>
      UNSPECIFIED: <no description>
    """
    NOOP = 0
    SHUTDOWN = 1
    UNSPECIFIED = 2

  class PrivateIpv6GoogleAccessValueValuesEnum(_messages.Enum):
    r"""The private IPv6 google access type for the VM. If not specified, use
    INHERIT_FROM_SUBNETWORK as default.

    Values:
      ENABLE_BIDIRECTIONAL_ACCESS_TO_GOOGLE: <no description>
      ENABLE_OUTBOUND_VM_ACCESS_TO_GOOGLE: <no description>
      INHERIT_FROM_SUBNETWORK: <no description>
    """
    ENABLE_BIDIRECTIONAL_ACCESS_TO_GOOGLE = 0
    ENABLE_OUTBOUND_VM_ACCESS_TO_GOOGLE = 1
    INHERIT_FROM_SUBNETWORK = 2

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the instance. One of the following values:
    PROVISIONING, STAGING, RUNNING, STOPPING, STOPPED, SUSPENDING, SUSPENDED,
    and TERMINATED.

    Values:
      DEPROVISIONING: <no description>
      PROVISIONING: <no description>
      REPAIRING: <no description>
      RUNNING: <no description>
      STAGING: <no description>
      STOPPED: <no description>
      STOPPING: <no description>
      SUSPENDED: <no description>
      SUSPENDING: <no description>
      TERMINATED: <no description>
    """
    DEPROVISIONING = 0
    PROVISIONING = 1
    REPAIRING = 2
    RUNNING = 3
    STAGING = 4
    STOPPED = 5
    STOPPING = 6
    SUSPENDED = 7
    SUSPENDING = 8
    TERMINATED = 9

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels to apply to this instance. These can be later modified by the
    setLabels method.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  canIpForward = _messages.BooleanField(1)
  confidentialInstanceConfig = _messages.MessageField('ConfidentialInstanceConfig', 2)
  cpuPlatform = _messages.StringField(3)
  creationTimestamp = _messages.StringField(4)
  deletionProtection = _messages.BooleanField(5)
  description = _messages.StringField(6)
  disks = _messages.MessageField('AttachedDisk', 7, repeated=True)
  displayDevice = _messages.MessageField('DisplayDevice', 8)
  eraseWindowsVssSignature = _messages.BooleanField(9)
  fingerprint = _messages.BytesField(10)
  guestAccelerators = _messages.MessageField('AcceleratorConfig', 11, repeated=True)
  hostname = _messages.StringField(12)
  id = _messages.IntegerField(13, variant=_messages.Variant.UINT64)
  instanceEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 14)
  kind = _messages.StringField(15, default=u'compute#instance')
  labelFingerprint = _messages.BytesField(16)
  labels = _messages.MessageField('LabelsValue', 17)
  machineType = _messages.StringField(18)
  metadata = _messages.MessageField('Metadata', 19)
  minCpuPlatform = _messages.StringField(20)
  name = _messages.StringField(21)
  networkInterfaces = _messages.MessageField('NetworkInterface', 22, repeated=True)
  postKeyRevocationActionType = _messages.EnumField('PostKeyRevocationActionTypeValueValuesEnum', 23)
  preservedStateSizeGb = _messages.IntegerField(24)
  privateIpv6GoogleAccess = _messages.EnumField('PrivateIpv6GoogleAccessValueValuesEnum', 25)
  reservationAffinity = _messages.MessageField('ReservationAffinity', 26)
  resourcePolicies = _messages.StringField(27, repeated=True)
  scheduling = _messages.MessageField('Scheduling', 28)
  selfLink = _messages.StringField(29)
  selfLinkWithId = _messages.StringField(30)
  serviceAccounts = _messages.MessageField('ServiceAccount', 31, repeated=True)
  shieldedInstanceConfig = _messages.MessageField('ShieldedInstanceConfig', 32)
  shieldedInstanceIntegrityPolicy = _messages.MessageField('ShieldedInstanceIntegrityPolicy', 33)
  shieldedVmConfig = _messages.MessageField('ShieldedVmConfig', 34)
  shieldedVmIntegrityPolicy = _messages.MessageField('ShieldedVmIntegrityPolicy', 35)
  sourceMachineImage = _messages.StringField(36)
  sourceMachineImageEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 37)
  startRestricted = _messages.BooleanField(38)
  status = _messages.EnumField('StatusValueValuesEnum', 39)
  statusMessage = _messages.StringField(40)
  tags = _messages.MessageField('Tags', 41)
  upcomingMaintenance = _messages.MessageField('UpcomingMaintenance', 42)
  zone = _messages.StringField(43)


class InstanceAggregatedList(_messages.Message):
  r"""A InstanceAggregatedList object.

  Messages:
    ItemsValue: An object that contains a list of instances scoped by zone.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: An object that contains a list of instances scoped by zone.
    kind: [Output Only] Type of resource. Always
      compute#instanceAggregatedList for aggregated lists of Instance
      resources.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""An object that contains a list of instances scoped by zone.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of instances.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A InstancesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('InstancesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#instanceAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class InstanceGroup(_messages.Message):
  r"""Represents an Instance Group resource.  Instance Groups can be used to
  configure a target for load balancing.  Instance groups can either be
  managed or unmanaged.  To create  managed instance groups, use the
  instanceGroupManager or regionInstanceGroupManager resource instead.  Use
  zonal unmanaged instance groups if you need to apply load balancing to
  groups of heterogeneous instances or if you need to manage the instances
  yourself. You cannot create regional unmanaged instance groups.  For more
  information, read Instance groups.  (== resource_for
  {$api_version}.instanceGroups ==) (== resource_for
  {$api_version}.regionInstanceGroups ==)

  Fields:
    creationTimestamp: [Output Only] The creation timestamp for this instance
      group in RFC3339 text format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    fingerprint: [Output Only] The fingerprint of the named ports. The system
      uses this fingerprint to detect conflicts when multiple users change the
      named ports concurrently.
    id: [Output Only] A unique identifier for this instance group, generated
      by the server.
    kind: [Output Only] The resource type, which is always
      compute#instanceGroup for instance groups.
    name: The name of the instance group. The name must be 1-63 characters
      long, and comply with RFC1035.
    namedPorts: Assigns a name to a port number. For example: {name: "http",
      port: 80}  This allows the system to reference ports by the assigned
      name instead of a port number. Named ports can also contain multiple
      ports. For example: [{name: "http", port: 80},{name: "http", port:
      8080}]   Named ports apply to all instances in this instance group.
    network: [Output Only] The URL of the network to which all instances in
      the instance group belong. If your instance has multiple network
      interfaces, then the network and subnetwork fields only refer to the
      network and subnet used by your primary interface (nic0).
    region: [Output Only] The URL of the region where the instance group is
      located (for regional resources).
    selfLink: [Output Only] The URL for this instance group. The server
      generates this URL.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    size: [Output Only] The total number of instances in the instance group.
    subnetwork: [Output Only] The URL of the subnetwork to which all instances
      in the instance group belong. If your instance has multiple network
      interfaces, then the network and subnetwork fields only refer to the
      network and subnet used by your primary interface (nic0).
    zone: [Output Only] The URL of the zone where the instance group is
      located (for zonal resources).
  """

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  fingerprint = _messages.BytesField(3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default=u'compute#instanceGroup')
  name = _messages.StringField(6)
  namedPorts = _messages.MessageField('NamedPort', 7, repeated=True)
  network = _messages.StringField(8)
  region = _messages.StringField(9)
  selfLink = _messages.StringField(10)
  selfLinkWithId = _messages.StringField(11)
  size = _messages.IntegerField(12, variant=_messages.Variant.INT32)
  subnetwork = _messages.StringField(13)
  zone = _messages.StringField(14)


class InstanceGroupAggregatedList(_messages.Message):
  r"""A InstanceGroupAggregatedList object.

  Messages:
    ItemsValue: A list of InstanceGroupsScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InstanceGroupsScopedList resources.
    kind: [Output Only] The resource type, which is always
      compute#instanceGroupAggregatedList for aggregated lists of instance
      groups.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of InstanceGroupsScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: The name of the scope that contains this set of
        instance groups.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A InstanceGroupsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('InstanceGroupsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#instanceGroupAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class InstanceGroupList(_messages.Message):
  r"""A list of InstanceGroup resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InstanceGroup resources.
    kind: [Output Only] The resource type, which is always
      compute#instanceGroupList for instance group lists.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('InstanceGroup', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#instanceGroupList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class InstanceGroupManager(_messages.Message):
  r"""Represents a Managed Instance Group resource.  An instance group is a
  collection of VM instances that you can manage as a single entity. For more
  information, read Instance groups.  For zonal Managed Instance Group, use
  the instanceGroupManagers resource.  For regional Managed Instance Group,
  use the regionInstanceGroupManagers resource. (== resource_for
  {$api_version}.instanceGroupManagers ==) (== resource_for
  {$api_version}.regionInstanceGroupManagers ==)

  Enums:
    FailoverActionValueValuesEnum: The action to perform in case of zone
      failure. Only one value is supported, NO_FAILOVER. The default is
      NO_FAILOVER.

  Fields:
    autoHealingPolicies: The autohealing policy for this managed instance
      group. You can specify only one value.
    baseInstanceName: The base instance name to use for instances in this
      group. The value must be 1-58 characters long. Instances are named by
      appending a hyphen and a random four-character string to the base
      instance name. The base instance name must comply with RFC1035.
    creationTimestamp: [Output Only] The creation timestamp for this managed
      instance group in RFC3339 text format.
    currentActions: [Output Only] The list of instance actions and the number
      of instances in this managed instance group that are scheduled for each
      of those actions.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    distributionPolicy: Policy specifying intended distribution of instances
      in regional managed instance group.
    failoverAction: The action to perform in case of zone failure. Only one
      value is supported, NO_FAILOVER. The default is NO_FAILOVER.
    fingerprint: Fingerprint of this resource. This field may be used in
      optimistic locking. It will be ignored when inserting an
      InstanceGroupManager. An up-to-date fingerprint must be provided in
      order to update the InstanceGroupManager, otherwise the request will
      fail with error 412 conditionNotMet.  To see the latest fingerprint,
      make a get() request to retrieve an InstanceGroupManager.
    id: [Output Only] A unique identifier for this resource type. The server
      generates this identifier.
    instanceGroup: [Output Only] The URL of the Instance Group resource.
    instanceTemplate: The URL of the instance template that is specified for
      this managed instance group. The group uses this template to create all
      new instances in the managed instance group.
    kind: [Output Only] The resource type, which is always
      compute#instanceGroupManager for managed instance groups.
    name: The name of the managed instance group. The name must be 1-63
      characters long, and comply with RFC1035.
    namedPorts: Named ports configured for the Instance Groups complementary
      to this Instance Group Manager.
    pendingActions: [Deprecated] This field is deprecated and will be removed.
      Prefer using the status field instead. Please contact cloud-updater-
      feedback@google.com to leave feedback if your workload relies on this
      field. [Output Only] The list of instance actions and the number of
      instances in this managed instance group that are pending for each of
      those actions.
    region: [Output Only] The URL of the region where the managed instance
      group resides (for regional resources).
    selfLink: [Output Only] The URL for this managed instance group. The
      server defines this URL.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    serviceAccount: The service account to be used as credentials for all
      operations performed by the managed instance group on instances. The
      service accounts needs all permissions required to create and delete
      instances. By default, the service account
      {projectNumber}@cloudservices.gserviceaccount.com is used.
    statefulPolicy: Stateful configuration for this Instanced Group Manager
    status: [Output Only] The status of this managed instance group.
    targetPools: The URLs for all TargetPool resources to which instances in
      the instanceGroup field are added. The target pools automatically apply
      to all of the instances in the managed instance group.
    targetSize: The target number of running instances for this managed
      instance group. You can reduce this number by using the
      instanceGroupManager deleteInstances or abandonInstances methods.
      Resizing the group also changes this number.
    updatePolicy: The update policy for this managed instance group.
    versions: Specifies the instance templates used by this managed instance
      group to create instances.  Each version is defined by an
      instanceTemplate and a name. Every version can appear at most once per
      instance group. This field overrides the top-level instanceTemplate
      field. Read more about the relationships between these fields. Exactly
      one version must leave the targetSize field unset. That version will be
      applied to all remaining instances. For more information, read about
      canary updates.
    zone: [Output Only] The URL of the zone where the managed instance group
      is located (for zonal resources).
  """

  class FailoverActionValueValuesEnum(_messages.Enum):
    r"""The action to perform in case of zone failure. Only one value is
    supported, NO_FAILOVER. The default is NO_FAILOVER.

    Values:
      NO_FAILOVER: <no description>
      UNKNOWN: <no description>
    """
    NO_FAILOVER = 0
    UNKNOWN = 1

  autoHealingPolicies = _messages.MessageField('InstanceGroupManagerAutoHealingPolicy', 1, repeated=True)
  baseInstanceName = _messages.StringField(2)
  creationTimestamp = _messages.StringField(3)
  currentActions = _messages.MessageField('InstanceGroupManagerActionsSummary', 4)
  description = _messages.StringField(5)
  distributionPolicy = _messages.MessageField('DistributionPolicy', 6)
  failoverAction = _messages.EnumField('FailoverActionValueValuesEnum', 7)
  fingerprint = _messages.BytesField(8)
  id = _messages.IntegerField(9, variant=_messages.Variant.UINT64)
  instanceGroup = _messages.StringField(10)
  instanceTemplate = _messages.StringField(11)
  kind = _messages.StringField(12, default=u'compute#instanceGroupManager')
  name = _messages.StringField(13)
  namedPorts = _messages.MessageField('NamedPort', 14, repeated=True)
  pendingActions = _messages.MessageField('InstanceGroupManagerPendingActionsSummary', 15)
  region = _messages.StringField(16)
  selfLink = _messages.StringField(17)
  selfLinkWithId = _messages.StringField(18)
  serviceAccount = _messages.StringField(19)
  statefulPolicy = _messages.MessageField('StatefulPolicy', 20)
  status = _messages.MessageField('InstanceGroupManagerStatus', 21)
  targetPools = _messages.StringField(22, repeated=True)
  targetSize = _messages.IntegerField(23, variant=_messages.Variant.INT32)
  updatePolicy = _messages.MessageField('InstanceGroupManagerUpdatePolicy', 24)
  versions = _messages.MessageField('InstanceGroupManagerVersion', 25, repeated=True)
  zone = _messages.StringField(26)


class InstanceGroupManagerActionsSummary(_messages.Message):
  r"""A InstanceGroupManagerActionsSummary object.

  Fields:
    abandoning: [Output Only] The total number of instances in the managed
      instance group that are scheduled to be abandoned. Abandoning an
      instance removes it from the managed instance group without deleting it.
    creating: [Output Only] The number of instances in the managed instance
      group that are scheduled to be created or are currently being created.
      If the group fails to create any of these instances, it tries again
      until it creates the instance successfully.  If you have disabled
      creation retries, this field will not be populated; instead, the
      creatingWithoutRetries field will be populated.
    creatingWithoutRetries: [Output Only] The number of instances that the
      managed instance group will attempt to create. The group attempts to
      create each instance only once. If the group fails to create any of
      these instances, it decreases the group's targetSize value accordingly.
    deleting: [Output Only] The number of instances in the managed instance
      group that are scheduled to be deleted or are currently being deleted.
    none: [Output Only] The number of instances in the managed instance group
      that are running and have no scheduled actions.
    recreating: [Output Only] The number of instances in the managed instance
      group that are scheduled to be recreated or are currently being being
      recreated. Recreating an instance deletes the existing root persistent
      disk and creates a new disk from the image that is defined in the
      instance template.
    refreshing: [Output Only] The number of instances in the managed instance
      group that are being reconfigured with properties that do not require a
      restart or a recreate action. For example, setting or removing target
      pools for the instance.
    restarting: [Output Only] The number of instances in the managed instance
      group that are scheduled to be restarted or are currently being
      restarted.
    verifying: [Output Only] The number of instances in the managed instance
      group that are being verified. See the managedInstances[].currentAction
      property in the listManagedInstances method documentation.
  """

  abandoning = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  creating = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  creatingWithoutRetries = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  deleting = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  none = _messages.IntegerField(5, variant=_messages.Variant.INT32)
  recreating = _messages.IntegerField(6, variant=_messages.Variant.INT32)
  refreshing = _messages.IntegerField(7, variant=_messages.Variant.INT32)
  restarting = _messages.IntegerField(8, variant=_messages.Variant.INT32)
  verifying = _messages.IntegerField(9, variant=_messages.Variant.INT32)


class InstanceGroupManagerAggregatedList(_messages.Message):
  r"""A InstanceGroupManagerAggregatedList object.

  Messages:
    ItemsValue: A list of InstanceGroupManagersScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InstanceGroupManagersScopedList resources.
    kind: [Output Only] The resource type, which is always
      compute#instanceGroupManagerAggregatedList for an aggregated list of
      managed instance groups.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of InstanceGroupManagersScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] The name of the scope that contains
        this set of managed instance groups.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A InstanceGroupManagersScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('InstanceGroupManagersScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#instanceGroupManagerAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class InstanceGroupManagerAutoHealingPolicy(_messages.Message):
  r"""InstanceGroupManagerAutoHealingPolicy message type.

  Fields:
    healthCheck: The URL for the health check that signals autohealing.
    initialDelaySec: The number of seconds that the managed instance group
      waits before it applies autohealing policies to new instances or
      recently recreated instances. This initial delay allows instances to
      initialize and run their startup scripts before the instance group
      determines that they are UNHEALTHY. This prevents the managed instance
      group from recreating its instances prematurely. This value must be from
      range [0, 3600].
    maxUnavailable: Maximum number of instances that can be unavailable when
      autohealing. When 'percent' is used, the value is rounded UP. The
      instance is considered available if all of the following conditions are
      satisfied: 1. Instance's status is RUNNING. 2. Instance's currentAction
      is NONE (in particular its liveness health check result was observed to
      be HEALTHY at least once as it passed VERIFYING). 3. There is no
      outgoing action on an instance triggered by IGM.  By default, number of
      concurrently autohealed instances is smaller than the managed instance
      group target size. However, if a zonal managed instance group has only
      one instance, or a regional managed instance group has only one instance
      per zone, autohealing will recreate these instances when they become
      unhealthy.
  """

  healthCheck = _messages.StringField(1)
  initialDelaySec = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  maxUnavailable = _messages.MessageField('FixedOrPercent', 3)


class InstanceGroupManagerList(_messages.Message):
  r"""[Output Only] A list of managed instance groups.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InstanceGroupManager resources.
    kind: [Output Only] The resource type, which is always
      compute#instanceGroupManagerList for a list of managed instance groups.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('InstanceGroupManager', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#instanceGroupManagerList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class InstanceGroupManagerPendingActionsSummary(_messages.Message):
  r"""A InstanceGroupManagerPendingActionsSummary object.

  Fields:
    creating: [Deprecated] This field is deprecated and will be removed.
      Prefer using the status field instead. Please contact cloud-updater-
      feedback@google.com to leave feedback if your workload relies on this
      field. [Output Only] The number of instances in the managed instance
      group that are pending to be created.
    deleting: [Deprecated] This field is deprecated and will be removed.
      Prefer using the status field instead. Please contact cloud-updater-
      feedback@google.com to leave feedback if your workload relies on this
      field. [Output Only] The number of instances in the managed instance
      group that are pending to be deleted.
    recreating: [Deprecated] This field is deprecated and will be removed.
      Prefer using the status field instead. Please contact cloud-updater-
      feedback@google.com to leave feedback if your workload relies on this
      field. [Output Only] The number of instances in the managed instance
      group that are pending to be recreated.
    restarting: [Deprecated] This field is deprecated and will be removed.
      Prefer using the status field instead. Please contact cloud-updater-
      feedback@google.com to leave feedback if your workload relies on this
      field. [Output Only] The number of instances in the managed instance
      group that are pending to be restarted.
  """

  creating = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  deleting = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  recreating = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  restarting = _messages.IntegerField(4, variant=_messages.Variant.INT32)


class InstanceGroupManagerStatus(_messages.Message):
  r"""A InstanceGroupManagerStatus object.

  Fields:
    autoscaler: [Output Only] The URL of the Autoscaler that targets this
      instance group manager.
    isStable: [Output Only] A bit indicating whether the managed instance
      group is in a stable state. A stable state means that: none of the
      instances in the managed instance group is currently undergoing any type
      of change (for example, creation, restart, or deletion); no future
      changes are scheduled for instances in the managed instance group; and
      the managed instance group itself is not being modified.
    stateful: [Output Only] Stateful status of the given Instance Group
      Manager.
    versionTarget: [Output Only] A status of consistency of Instances'
      versions with their target version specified by version field on
      Instance Group Manager.
  """

  autoscaler = _messages.StringField(1)
  isStable = _messages.BooleanField(2)
  stateful = _messages.MessageField('InstanceGroupManagerStatusStateful', 3)
  versionTarget = _messages.MessageField('InstanceGroupManagerStatusVersionTarget', 4)


class InstanceGroupManagerStatusStateful(_messages.Message):
  r"""A InstanceGroupManagerStatusStateful object.

  Fields:
    hasStatefulConfig: [Output Only] A bit indicating whether the managed
      instance group has stateful configuration, that is, if you have
      configured any items in a stateful policy or in per-instance configs.
      The group might report that it has no stateful config even when there is
      still some preserved state on a managed instance, for example, if you
      have deleted all PICs but not yet applied those deletions.
    isStateful: [Output Only] A bit indicating whether the managed instance
      group has stateful configuration, that is, if you have configured any
      items in a stateful policy or in per-instance configs. The group might
      report that it has no stateful config even when there is still some
      preserved state on a managed instance, for example, if you have deleted
      all PICs but not yet applied those deletions. This field is deprecated
      in favor of has_stateful_config.
  """

  hasStatefulConfig = _messages.BooleanField(1)
  isStateful = _messages.BooleanField(2)


class InstanceGroupManagerStatusVersionTarget(_messages.Message):
  r"""A InstanceGroupManagerStatusVersionTarget object.

  Fields:
    isReached: [Output Only] A bit indicating whether version target has been
      reached in this managed instance group, i.e. all instances are in their
      target version. Instances' target version are specified by version field
      on Instance Group Manager.
  """

  isReached = _messages.BooleanField(1)


class InstanceGroupManagerUpdatePolicy(_messages.Message):
  r"""A InstanceGroupManagerUpdatePolicy object.

  Enums:
    InstanceRedistributionTypeValueValuesEnum: The  instance redistribution
      policy for regional managed instance groups. Valid values are:   -
      PROACTIVE (default): The group attempts to maintain an even distribution
      of VM instances across zones in the region.  - NONE: For non-autoscaled
      groups, proactive redistribution is disabled.
    MinimalActionValueValuesEnum: Minimal action to be taken on an instance.
      You can specify either RESTART to restart existing instances or REPLACE
      to delete and create new instances from the target template. If you
      specify a RESTART, the Updater will attempt to perform that action only.
      However, if the Updater determines that the minimal action you specify
      is not enough to perform the update, it might perform a more disruptive
      action.
    ReplacementMethodValueValuesEnum: What action should be used to replace
      instances. See minimal_action.REPLACE
    TypeValueValuesEnum: The type of update process. You can specify either
      PROACTIVE so that the instance group manager proactively executes
      actions in order to bring instances to their target versions or
      OPPORTUNISTIC so that no action is proactively executed but the update
      will be performed as part of other actions (for example, resizes or
      recreateInstances calls).

  Fields:
    instanceRedistributionType: The  instance redistribution policy for
      regional managed instance groups. Valid values are:   - PROACTIVE
      (default): The group attempts to maintain an even distribution of VM
      instances across zones in the region.  - NONE: For non-autoscaled
      groups, proactive redistribution is disabled.
    maxSurge: The maximum number of instances that can be created above the
      specified targetSize during the update process. By default, a fixed
      value of 1 is used. This value can be either a fixed number or a
      percentage if the instance group has 10 or more instances. If you set a
      percentage, the number of instances will be rounded up if necessary.  At
      least one of either maxSurge or maxUnavailable must be greater than 0.
      Learn more about maxSurge.
    maxUnavailable: The maximum number of instances that can be unavailable
      during the update process. An instance is considered available if all of
      the following conditions are satisfied:    - The instance's status is
      RUNNING.  - If there is a health check on the instance group, the
      instance's liveness health check result must be HEALTHY at least once.
      If there is no health check on the group, then the instance only needs
      to have a status of RUNNING to be considered available.  By default, a
      fixed value of 1 is used. This value can be either a fixed number or a
      percentage if the instance group has 10 or more instances. If you set a
      percentage, the number of instances will be rounded up if necessary.  At
      least one of either maxSurge or maxUnavailable must be greater than 0.
      Learn more about maxUnavailable.
    minReadySec: Minimum number of seconds to wait for after a newly created
      instance becomes available. This value must be from range [0, 3600].
    minimalAction: Minimal action to be taken on an instance. You can specify
      either RESTART to restart existing instances or REPLACE to delete and
      create new instances from the target template. If you specify a RESTART,
      the Updater will attempt to perform that action only. However, if the
      Updater determines that the minimal action you specify is not enough to
      perform the update, it might perform a more disruptive action.
    replacementMethod: What action should be used to replace instances. See
      minimal_action.REPLACE
    type: The type of update process. You can specify either PROACTIVE so that
      the instance group manager proactively executes actions in order to
      bring instances to their target versions or OPPORTUNISTIC so that no
      action is proactively executed but the update will be performed as part
      of other actions (for example, resizes or recreateInstances calls).
  """

  class InstanceRedistributionTypeValueValuesEnum(_messages.Enum):
    r"""The  instance redistribution policy for regional managed instance
    groups. Valid values are:   - PROACTIVE (default): The group attempts to
    maintain an even distribution of VM instances across zones in the region.
    - NONE: For non-autoscaled groups, proactive redistribution is disabled.

    Values:
      NONE: <no description>
      PROACTIVE: <no description>
    """
    NONE = 0
    PROACTIVE = 1

  class MinimalActionValueValuesEnum(_messages.Enum):
    r"""Minimal action to be taken on an instance. You can specify either
    RESTART to restart existing instances or REPLACE to delete and create new
    instances from the target template. If you specify a RESTART, the Updater
    will attempt to perform that action only. However, if the Updater
    determines that the minimal action you specify is not enough to perform
    the update, it might perform a more disruptive action.

    Values:
      NONE: <no description>
      REFRESH: <no description>
      REPLACE: <no description>
      RESTART: <no description>
    """
    NONE = 0
    REFRESH = 1
    REPLACE = 2
    RESTART = 3

  class ReplacementMethodValueValuesEnum(_messages.Enum):
    r"""What action should be used to replace instances. See
    minimal_action.REPLACE

    Values:
      RECREATE: <no description>
      SUBSTITUTE: <no description>
    """
    RECREATE = 0
    SUBSTITUTE = 1

  class TypeValueValuesEnum(_messages.Enum):
    r"""The type of update process. You can specify either PROACTIVE so that
    the instance group manager proactively executes actions in order to bring
    instances to their target versions or OPPORTUNISTIC so that no action is
    proactively executed but the update will be performed as part of other
    actions (for example, resizes or recreateInstances calls).

    Values:
      OPPORTUNISTIC: <no description>
      PROACTIVE: <no description>
    """
    OPPORTUNISTIC = 0
    PROACTIVE = 1

  instanceRedistributionType = _messages.EnumField('InstanceRedistributionTypeValueValuesEnum', 1)
  maxSurge = _messages.MessageField('FixedOrPercent', 2)
  maxUnavailable = _messages.MessageField('FixedOrPercent', 3)
  minReadySec = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  minimalAction = _messages.EnumField('MinimalActionValueValuesEnum', 5)
  replacementMethod = _messages.EnumField('ReplacementMethodValueValuesEnum', 6)
  type = _messages.EnumField('TypeValueValuesEnum', 7)


class InstanceGroupManagerVersion(_messages.Message):
  r"""A InstanceGroupManagerVersion object.

  Fields:
    instanceTemplate: The URL of the instance template that is specified for
      this managed instance group. The group uses this template to create new
      instances in the managed instance group until the `targetSize` for this
      version is reached.
    name: Name of the version. Unique among all versions in the scope of this
      managed instance group.
    tag: Tag describing the version. Used to trigger rollout of a target
      version even if instance_template remains unchanged. Deprecated in favor
      of 'name'.
    targetSize: Specifies the intended number of instances to be created from
      the instanceTemplate. The final number of instances created from the
      template will be equal to:   - If expressed as a fixed number, the
      minimum of either targetSize.fixed or instanceGroupManager.targetSize is
      used.  - if expressed as a percent, the targetSize would be
      (targetSize.percent/100 * InstanceGroupManager.targetSize) If there is a
      remainder, the number is rounded up.  If unset, this version will update
      any remaining instances not updated by another version. Read Starting a
      canary update for more information.
  """

  instanceTemplate = _messages.StringField(1)
  name = _messages.StringField(2)
  tag = _messages.StringField(3)
  targetSize = _messages.MessageField('FixedOrPercent', 4)


class InstanceGroupManagersAbandonInstancesRequest(_messages.Message):
  r"""A InstanceGroupManagersAbandonInstancesRequest object.

  Fields:
    instances: The URLs of one or more instances to abandon. This can be a
      full URL or a partial URL, such as
      zones/[ZONE]/instances/[INSTANCE_NAME].
  """

  instances = _messages.StringField(1, repeated=True)


class InstanceGroupManagersApplyUpdatesRequest(_messages.Message):
  r"""InstanceGroupManagers.applyUpdatesToInstances

  Enums:
    MaximalActionValueValuesEnum: The maximal action that should be performed
      on the instances. By default REPLACE. This field is deprecated, please
      use most_disruptive_allowed_action.
    MinimalActionValueValuesEnum: The minimal action that you want to perform
      on each instance during the update:   - REPLACE: At minimum, delete the
      instance and create it again.  - RESTART: Stop the instance and start it
      again.  - REFRESH: Do not stop the instance.  - NONE: Do not disrupt the
      instance at all.  By default, the minimum action is NONE. If your update
      requires a more disruptive action than you set with this flag, the
      necessary action is performed to execute the update.
    MostDisruptiveAllowedActionValueValuesEnum: The most disruptive action
      that you want to perform on each instance during the update:   -
      REPLACE: Delete the instance and create it again.  - RESTART: Stop the
      instance and start it again.  - REFRESH: Do not stop the instance.  -
      NONE: Do not disrupt the instance at all.  By default, the most
      disruptive allowed action is REPLACE. If your update requires a more
      disruptive action than you set with this flag, the update request will
      fail.

  Fields:
    instances: The list of URLs of one or more instances for which you want to
      apply updates. Each URL can be a full URL or a partial URL, such as
      zones/[ZONE]/instances/[INSTANCE_NAME].
    maximalAction: The maximal action that should be performed on the
      instances. By default REPLACE. This field is deprecated, please use
      most_disruptive_allowed_action.
    minimalAction: The minimal action that you want to perform on each
      instance during the update:   - REPLACE: At minimum, delete the instance
      and create it again.  - RESTART: Stop the instance and start it again.
      - REFRESH: Do not stop the instance.  - NONE: Do not disrupt the
      instance at all.  By default, the minimum action is NONE. If your update
      requires a more disruptive action than you set with this flag, the
      necessary action is performed to execute the update.
    mostDisruptiveAllowedAction: The most disruptive action that you want to
      perform on each instance during the update:   - REPLACE: Delete the
      instance and create it again.  - RESTART: Stop the instance and start it
      again.  - REFRESH: Do not stop the instance.  - NONE: Do not disrupt the
      instance at all.  By default, the most disruptive allowed action is
      REPLACE. If your update requires a more disruptive action than you set
      with this flag, the update request will fail.
  """

  class MaximalActionValueValuesEnum(_messages.Enum):
    r"""The maximal action that should be performed on the instances. By
    default REPLACE. This field is deprecated, please use
    most_disruptive_allowed_action.

    Values:
      NONE: <no description>
      REFRESH: <no description>
      REPLACE: <no description>
      RESTART: <no description>
    """
    NONE = 0
    REFRESH = 1
    REPLACE = 2
    RESTART = 3

  class MinimalActionValueValuesEnum(_messages.Enum):
    r"""The minimal action that you want to perform on each instance during
    the update:   - REPLACE: At minimum, delete the instance and create it
    again.  - RESTART: Stop the instance and start it again.  - REFRESH: Do
    not stop the instance.  - NONE: Do not disrupt the instance at all.  By
    default, the minimum action is NONE. If your update requires a more
    disruptive action than you set with this flag, the necessary action is
    performed to execute the update.

    Values:
      NONE: <no description>
      REFRESH: <no description>
      REPLACE: <no description>
      RESTART: <no description>
    """
    NONE = 0
    REFRESH = 1
    REPLACE = 2
    RESTART = 3

  class MostDisruptiveAllowedActionValueValuesEnum(_messages.Enum):
    r"""The most disruptive action that you want to perform on each instance
    during the update:   - REPLACE: Delete the instance and create it again.
    - RESTART: Stop the instance and start it again.  - REFRESH: Do not stop
    the instance.  - NONE: Do not disrupt the instance at all.  By default,
    the most disruptive allowed action is REPLACE. If your update requires a
    more disruptive action than you set with this flag, the update request
    will fail.

    Values:
      NONE: <no description>
      REFRESH: <no description>
      REPLACE: <no description>
      RESTART: <no description>
    """
    NONE = 0
    REFRESH = 1
    REPLACE = 2
    RESTART = 3

  instances = _messages.StringField(1, repeated=True)
  maximalAction = _messages.EnumField('MaximalActionValueValuesEnum', 2)
  minimalAction = _messages.EnumField('MinimalActionValueValuesEnum', 3)
  mostDisruptiveAllowedAction = _messages.EnumField('MostDisruptiveAllowedActionValueValuesEnum', 4)


class InstanceGroupManagersCreateInstancesRequest(_messages.Message):
  r"""InstanceGroupManagers.createInstances

  Fields:
    instances: [Required] List of specifications of per-instance configs.
  """

  instances = _messages.MessageField('PerInstanceConfig', 1, repeated=True)


class InstanceGroupManagersDeleteInstancesRequest(_messages.Message):
  r"""A InstanceGroupManagersDeleteInstancesRequest object.

  Fields:
    instances: The URLs of one or more instances to delete. This can be a full
      URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
  """

  instances = _messages.StringField(1, repeated=True)


class InstanceGroupManagersDeletePerInstanceConfigsReq(_messages.Message):
  r"""InstanceGroupManagers.deletePerInstanceConfigs

  Fields:
    names: The list of instance names for which we want to delete per-instance
      configs on this managed instance group.
  """

  names = _messages.StringField(1, repeated=True)


class InstanceGroupManagersListErrorsResponse(_messages.Message):
  r"""A InstanceGroupManagersListErrorsResponse object.

  Fields:
    items: [Output Only] The list of errors of the managed instance group.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
  """

  items = _messages.MessageField('InstanceManagedByIgmError', 1, repeated=True)
  nextPageToken = _messages.StringField(2)


class InstanceGroupManagersListManagedInstancesResponse(_messages.Message):
  r"""A InstanceGroupManagersListManagedInstancesResponse object.

  Fields:
    managedInstances: [Output Only] The list of instances in the managed
      instance group.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
  """

  managedInstances = _messages.MessageField('ManagedInstance', 1, repeated=True)
  nextPageToken = _messages.StringField(2)


class InstanceGroupManagersListPerInstanceConfigsResp(_messages.Message):
  r"""A InstanceGroupManagersListPerInstanceConfigsResp object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    items: [Output Only] The list of PerInstanceConfig.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  items = _messages.MessageField('PerInstanceConfig', 1, repeated=True)
  nextPageToken = _messages.StringField(2)
  warning = _messages.MessageField('WarningValue', 3)


class InstanceGroupManagersPatchPerInstanceConfigsReq(_messages.Message):
  r"""InstanceGroupManagers.patchPerInstanceConfigs

  Fields:
    perInstanceConfigs: The list of per-instance configs to insert or patch on
      this managed instance group.
  """

  perInstanceConfigs = _messages.MessageField('PerInstanceConfig', 1, repeated=True)


class InstanceGroupManagersRecreateInstancesRequest(_messages.Message):
  r"""A InstanceGroupManagersRecreateInstancesRequest object.

  Fields:
    instances: The URLs of one or more instances to recreate. This can be a
      full URL or a partial URL, such as
      zones/[ZONE]/instances/[INSTANCE_NAME].
  """

  instances = _messages.StringField(1, repeated=True)


class InstanceGroupManagersResizeAdvancedRequest(_messages.Message):
  r"""A InstanceGroupManagersResizeAdvancedRequest object.

  Fields:
    noCreationRetries: If this flag is true, the managed instance group
      attempts to create all instances initiated by this resize request only
      once. If there is an error during creation, the managed instance group
      does not retry create this instance, and we will decrease the targetSize
      of the request instead. If the flag is false, the group attempts to
      recreate each instance continuously until it succeeds.  This flag
      matters only in the first attempt of creation of an instance. After an
      instance is successfully created while this flag is enabled, the
      instance behaves the same way as all the other instances created with a
      regular resize request. In particular, if a running instance dies
      unexpectedly at a later time and needs to be recreated, this mode does
      not affect the recreation behavior in that scenario.  This flag is
      applicable only to the current resize request. It does not influence
      other resize requests in any way.  You can see which instances is being
      creating in which mode by calling the get or listManagedInstances API.
    targetSize: The number of running instances that the managed instance
      group should maintain at any given time. The group automatically adds or
      removes instances to maintain the number of instances specified by this
      parameter.
  """

  noCreationRetries = _messages.BooleanField(1)
  targetSize = _messages.IntegerField(2, variant=_messages.Variant.INT32)


class InstanceGroupManagersScopedList(_messages.Message):
  r"""A InstanceGroupManagersScopedList object.

  Messages:
    WarningValue: [Output Only] The warning that replaces the list of managed
      instance groups when the list is empty.

  Fields:
    instanceGroupManagers: [Output Only] The list of managed instance groups
      that are contained in the specified project and zone.
    warning: [Output Only] The warning that replaces the list of managed
      instance groups when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] The warning that replaces the list of managed instance
    groups when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  instanceGroupManagers = _messages.MessageField('InstanceGroupManager', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class InstanceGroupManagersSetAutoHealingRequest(_messages.Message):
  r"""A InstanceGroupManagersSetAutoHealingRequest object.

  Fields:
    autoHealingPolicies: A InstanceGroupManagerAutoHealingPolicy attribute.
  """

  autoHealingPolicies = _messages.MessageField('InstanceGroupManagerAutoHealingPolicy', 1, repeated=True)


class InstanceGroupManagersSetInstanceTemplateRequest(_messages.Message):
  r"""A InstanceGroupManagersSetInstanceTemplateRequest object.

  Fields:
    instanceTemplate: The URL of the instance template that is specified for
      this managed instance group. The group uses this template to create all
      new instances in the managed instance group.
  """

  instanceTemplate = _messages.StringField(1)


class InstanceGroupManagersSetTargetPoolsRequest(_messages.Message):
  r"""A InstanceGroupManagersSetTargetPoolsRequest object.

  Fields:
    fingerprint: The fingerprint of the target pools information. Use this
      optional property to prevent conflicts when multiple users change the
      target pools settings concurrently. Obtain the fingerprint with the
      instanceGroupManagers.get method. Then, include the fingerprint in your
      request to ensure that you do not overwrite changes that were applied
      from another concurrent request.
    targetPools: The list of target pool URLs that instances in this managed
      instance group belong to. The managed instance group applies these
      target pools to all of the instances in the group. Existing instances
      and new instances in the group all receive these target pool settings.
  """

  fingerprint = _messages.BytesField(1)
  targetPools = _messages.StringField(2, repeated=True)


class InstanceGroupManagersUpdatePerInstanceConfigsReq(_messages.Message):
  r"""InstanceGroupManagers.updatePerInstanceConfigs

  Fields:
    perInstanceConfigs: The list of per-instance configs to insert or patch on
      this managed instance group.
  """

  perInstanceConfigs = _messages.MessageField('PerInstanceConfig', 1, repeated=True)


class InstanceGroupsAddInstancesRequest(_messages.Message):
  r"""A InstanceGroupsAddInstancesRequest object.

  Fields:
    instances: The list of instances to add to the instance group.
  """

  instances = _messages.MessageField('InstanceReference', 1, repeated=True)


class InstanceGroupsListInstances(_messages.Message):
  r"""A InstanceGroupsListInstances object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InstanceWithNamedPorts resources.
    kind: [Output Only] The resource type, which is always
      compute#instanceGroupsListInstances for the list of instances in the
      specified instance group.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('InstanceWithNamedPorts', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#instanceGroupsListInstances')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class InstanceGroupsListInstancesRequest(_messages.Message):
  r"""A InstanceGroupsListInstancesRequest object.

  Enums:
    InstanceStateValueValuesEnum: A filter for the state of the instances in
      the instance group. Valid options are ALL or RUNNING. If you do not
      specify this parameter the list includes all instances regardless of
      their state.

  Fields:
    instanceState: A filter for the state of the instances in the instance
      group. Valid options are ALL or RUNNING. If you do not specify this
      parameter the list includes all instances regardless of their state.
  """

  class InstanceStateValueValuesEnum(_messages.Enum):
    r"""A filter for the state of the instances in the instance group. Valid
    options are ALL or RUNNING. If you do not specify this parameter the list
    includes all instances regardless of their state.

    Values:
      ALL: <no description>
      RUNNING: <no description>
    """
    ALL = 0
    RUNNING = 1

  instanceState = _messages.EnumField('InstanceStateValueValuesEnum', 1)


class InstanceGroupsRemoveInstancesRequest(_messages.Message):
  r"""A InstanceGroupsRemoveInstancesRequest object.

  Fields:
    instances: The list of instances to remove from the instance group.
  """

  instances = _messages.MessageField('InstanceReference', 1, repeated=True)


class InstanceGroupsScopedList(_messages.Message):
  r"""A InstanceGroupsScopedList object.

  Messages:
    WarningValue: [Output Only] An informational warning that replaces the
      list of instance groups when the list is empty.

  Fields:
    instanceGroups: [Output Only] The list of instance groups that are
      contained in this scope.
    warning: [Output Only] An informational warning that replaces the list of
      instance groups when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] An informational warning that replaces the list of
    instance groups when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  instanceGroups = _messages.MessageField('InstanceGroup', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class InstanceGroupsSetNamedPortsRequest(_messages.Message):
  r"""A InstanceGroupsSetNamedPortsRequest object.

  Fields:
    fingerprint: The fingerprint of the named ports information for this
      instance group. Use this optional property to prevent conflicts when
      multiple users change the named ports settings concurrently. Obtain the
      fingerprint with the instanceGroups.get method. Then, include the
      fingerprint in your request to ensure that you do not overwrite changes
      that were applied from another concurrent request. A request with an
      incorrect fingerprint will fail with error 412 conditionNotMet.
    namedPorts: The list of named ports to set for this instance group.
  """

  fingerprint = _messages.BytesField(1)
  namedPorts = _messages.MessageField('NamedPort', 2, repeated=True)


class InstanceList(_messages.Message):
  r"""Contains a list of instances.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Instance resources.
    kind: [Output Only] Type of resource. Always compute#instanceList for
      lists of Instance resources.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Instance', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#instanceList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class InstanceListReferrers(_messages.Message):
  r"""Contains a list of instance referrers.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Reference resources.
    kind: [Output Only] Type of resource. Always compute#instanceListReferrers
      for lists of Instance referrers.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Reference', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#instanceListReferrers')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class InstanceManagedByIgmError(_messages.Message):
  r"""A InstanceManagedByIgmError object.

  Fields:
    error: [Output Only] Contents of the error.
    instanceActionDetails: [Output Only] Details of the instance action that
      triggered this error. May be null, if the error was not caused by an
      action on an instance. This field is optional.
    timestamp: [Output Only] The time that this error occurred. This value is
      in RFC3339 text format.
  """

  error = _messages.MessageField('InstanceManagedByIgmErrorManagedInstanceError', 1)
  instanceActionDetails = _messages.MessageField('InstanceManagedByIgmErrorInstanceActionDetails', 2)
  timestamp = _messages.StringField(3)


class InstanceManagedByIgmErrorInstanceActionDetails(_messages.Message):
  r"""A InstanceManagedByIgmErrorInstanceActionDetails object.

  Enums:
    ActionValueValuesEnum: [Output Only] Action that managed instance group
      was executing on the instance when the error occurred. Possible values:

  Fields:
    action: [Output Only] Action that managed instance group was executing on
      the instance when the error occurred. Possible values:
    instance: [Output Only] The URL of the instance. The URL can be set even
      if the instance has not yet been created.
    version: [Output Only] Version this instance was created from, or was
      being created from, but the creation failed. Corresponds to one of the
      versions that were set on the Instance Group Manager resource at the
      time this instance was being created.
  """

  class ActionValueValuesEnum(_messages.Enum):
    r"""[Output Only] Action that managed instance group was executing on the
    instance when the error occurred. Possible values:

    Values:
      ABANDONING: <no description>
      CREATING: <no description>
      CREATING_WITHOUT_RETRIES: <no description>
      DELETING: <no description>
      NONE: <no description>
      RECREATING: <no description>
      REFRESHING: <no description>
      RESTARTING: <no description>
      VERIFYING: <no description>
    """
    ABANDONING = 0
    CREATING = 1
    CREATING_WITHOUT_RETRIES = 2
    DELETING = 3
    NONE = 4
    RECREATING = 5
    REFRESHING = 6
    RESTARTING = 7
    VERIFYING = 8

  action = _messages.EnumField('ActionValueValuesEnum', 1)
  instance = _messages.StringField(2)
  version = _messages.MessageField('ManagedInstanceVersion', 3)


class InstanceManagedByIgmErrorManagedInstanceError(_messages.Message):
  r"""A InstanceManagedByIgmErrorManagedInstanceError object.

  Fields:
    code: [Output Only] Error code.
    message: [Output Only] Error message.
  """

  code = _messages.StringField(1)
  message = _messages.StringField(2)


class InstanceMoveRequest(_messages.Message):
  r"""A InstanceMoveRequest object.

  Fields:
    destinationZone: The URL of the destination zone to move the instance.
      This can be a full or partial URL. For example, the following are all
      valid URLs to a zone:   -
      https://www.googleapis.com/compute/v1/projects/project/zones/zone  -
      projects/project/zones/zone  - zones/zone
    targetInstance: The URL of the target instance to move. This can be a full
      or partial URL. For example, the following are all valid URLs to an
      instance:   - https://www.googleapis.com/compute/v1/projects/project/zon
      es/zone/instances/instance  -
      projects/project/zones/zone/instances/instance  -
      zones/zone/instances/instance
  """

  destinationZone = _messages.StringField(1)
  targetInstance = _messages.StringField(2)


class InstanceProperties(_messages.Message):
  r"""InstanceProperties message type.

  Enums:
    PostKeyRevocationActionTypeValueValuesEnum: Specifies whether this
      instance will be shut down on key revocation.
    PrivateIpv6GoogleAccessValueValuesEnum: The private IPv6 google access
      type for the VM. If not specified, use  INHERIT_FROM_SUBNETWORK as
      default.

  Messages:
    LabelsValue: Labels to apply to instances that are created from this
      template.

  Fields:
    canIpForward: Enables instances created based on this template to send
      packets with source IP addresses other than their own and receive
      packets with destination IP addresses other than their own. If these
      instances will be used as an IP gateway or it will be set as the next-
      hop in a Route resource, specify true. If unsure, leave this set to
      false. See the Enable IP forwarding documentation for more information.
    confidentialInstanceConfig: Specifies the Confidential Instance options.
    description: An optional text description for the instances that are
      created from this instance template.
    disks: An array of disks that are associated with the instances that are
      created from this template.
    displayDevice: Display Device properties to enable support for remote
      display products like: Teradici, VNC and TeamViewer
    guestAccelerators: A list of guest accelerator cards' type and count to
      use for instances created from the instance template.
    labels: Labels to apply to instances that are created from this template.
    machineType: The machine type to use for instances that are created from
      this template.
    metadata: The metadata key/value pairs to assign to instances that are
      created from this template. These pairs can consist of custom metadata
      or predefined keys. See Project and instance metadata for more
      information.
    minCpuPlatform: Minimum cpu/platform to be used by this instance. The
      instance may be scheduled on the specified or newer cpu/platform.
      Applicable values are the friendly names of CPU platforms, such as
      minCpuPlatform: "Intel Haswell" or minCpuPlatform: "Intel Sandy Bridge".
      For more information, read Specifying a Minimum CPU Platform.
    networkInterfaces: An array of network access configurations for this
      interface.
    postKeyRevocationActionType: Specifies whether this instance will be shut
      down on key revocation.
    privateIpv6GoogleAccess: The private IPv6 google access type for the VM.
      If not specified, use  INHERIT_FROM_SUBNETWORK as default.
    reservationAffinity: Specifies the reservations that this instance can
      consume from.
    resourcePolicies: Resource policies (names, not ULRs) applied to instances
      created from this template.
    scheduling: Specifies the scheduling options for the instances that are
      created from this template.
    serviceAccounts: A list of service accounts with specified scopes. Access
      tokens for these service accounts are available to the instances that
      are created from this template. Use metadata queries to obtain the
      access tokens for these instances.
    shieldedInstanceConfig: A ShieldedInstanceConfig attribute.
    shieldedVmConfig: Specifies the Shielded VM options for the instances that
      are created from this template.
    tags: A list of tags to apply to the instances that are created from this
      template. The tags identify valid sources or targets for network
      firewalls. The setTags method can modify this list of tags. Each tag
      within the list must comply with RFC1035.
  """

  class PostKeyRevocationActionTypeValueValuesEnum(_messages.Enum):
    r"""Specifies whether this instance will be shut down on key revocation.

    Values:
      NOOP: <no description>
      SHUTDOWN: <no description>
      UNSPECIFIED: <no description>
    """
    NOOP = 0
    SHUTDOWN = 1
    UNSPECIFIED = 2

  class PrivateIpv6GoogleAccessValueValuesEnum(_messages.Enum):
    r"""The private IPv6 google access type for the VM. If not specified, use
    INHERIT_FROM_SUBNETWORK as default.

    Values:
      ENABLE_BIDIRECTIONAL_ACCESS_TO_GOOGLE: <no description>
      ENABLE_OUTBOUND_VM_ACCESS_TO_GOOGLE: <no description>
      INHERIT_FROM_SUBNETWORK: <no description>
    """
    ENABLE_BIDIRECTIONAL_ACCESS_TO_GOOGLE = 0
    ENABLE_OUTBOUND_VM_ACCESS_TO_GOOGLE = 1
    INHERIT_FROM_SUBNETWORK = 2

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels to apply to instances that are created from this template.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  canIpForward = _messages.BooleanField(1)
  confidentialInstanceConfig = _messages.MessageField('ConfidentialInstanceConfig', 2)
  description = _messages.StringField(3)
  disks = _messages.MessageField('AttachedDisk', 4, repeated=True)
  displayDevice = _messages.MessageField('DisplayDevice', 5)
  guestAccelerators = _messages.MessageField('AcceleratorConfig', 6, repeated=True)
  labels = _messages.MessageField('LabelsValue', 7)
  machineType = _messages.StringField(8)
  metadata = _messages.MessageField('Metadata', 9)
  minCpuPlatform = _messages.StringField(10)
  networkInterfaces = _messages.MessageField('NetworkInterface', 11, repeated=True)
  postKeyRevocationActionType = _messages.EnumField('PostKeyRevocationActionTypeValueValuesEnum', 12)
  privateIpv6GoogleAccess = _messages.EnumField('PrivateIpv6GoogleAccessValueValuesEnum', 13)
  reservationAffinity = _messages.MessageField('ReservationAffinity', 14)
  resourcePolicies = _messages.StringField(15, repeated=True)
  scheduling = _messages.MessageField('Scheduling', 16)
  serviceAccounts = _messages.MessageField('ServiceAccount', 17, repeated=True)
  shieldedInstanceConfig = _messages.MessageField('ShieldedInstanceConfig', 18)
  shieldedVmConfig = _messages.MessageField('ShieldedVmConfig', 19)
  tags = _messages.MessageField('Tags', 20)


class InstanceReference(_messages.Message):
  r"""A InstanceReference object.

  Fields:
    instance: The URL for a specific instance.
  """

  instance = _messages.StringField(1)


class InstanceTemplate(_messages.Message):
  r"""Represents an Instance Template resource.  You can use instance
  templates to create VM instances and managed instance groups. For more
  information, read Instance Templates. (== resource_for
  {$api_version}.instanceTemplates ==)

  Fields:
    creationTimestamp: [Output Only] The creation timestamp for this instance
      template in RFC3339 text format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    id: [Output Only] A unique identifier for this instance template. The
      server defines this identifier.
    kind: [Output Only] The resource type, which is always
      compute#instanceTemplate for instance templates.
    name: Name of the resource; provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    properties: The instance properties for this instance template.
    selfLink: [Output Only] The URL for this instance template. The server
      defines this URL.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    sourceInstance: The source instance used to create the template. You can
      provide this as a partial or full URL to the resource. For example, the
      following are valid values:   - https://www.googleapis.com/compute/v1/pr
      ojects/project/zones/zone/instances/instance  -
      projects/project/zones/zone/instances/instance
    sourceInstanceParams: The source instance params to use to create this
      instance template.
  """

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  id = _messages.IntegerField(3, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(4, default=u'compute#instanceTemplate')
  name = _messages.StringField(5)
  properties = _messages.MessageField('InstanceProperties', 6)
  selfLink = _messages.StringField(7)
  selfLinkWithId = _messages.StringField(8)
  sourceInstance = _messages.StringField(9)
  sourceInstanceParams = _messages.MessageField('SourceInstanceParams', 10)


class InstanceTemplateList(_messages.Message):
  r"""A list of instance templates.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InstanceTemplate resources.
    kind: [Output Only] The resource type, which is always
      compute#instanceTemplatesListResponse for instance template lists.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('InstanceTemplate', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#instanceTemplateList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class InstanceWithNamedPorts(_messages.Message):
  r"""A InstanceWithNamedPorts object.

  Enums:
    StatusValueValuesEnum: [Output Only] The status of the instance.

  Fields:
    instance: [Output Only] The URL of the instance.
    namedPorts: [Output Only] The named ports that belong to this instance
      group.
    status: [Output Only] The status of the instance.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the instance.

    Values:
      DEPROVISIONING: <no description>
      PROVISIONING: <no description>
      REPAIRING: <no description>
      RUNNING: <no description>
      STAGING: <no description>
      STOPPED: <no description>
      STOPPING: <no description>
      SUSPENDED: <no description>
      SUSPENDING: <no description>
      TERMINATED: <no description>
    """
    DEPROVISIONING = 0
    PROVISIONING = 1
    REPAIRING = 2
    RUNNING = 3
    STAGING = 4
    STOPPED = 5
    STOPPING = 6
    SUSPENDED = 7
    SUSPENDING = 8
    TERMINATED = 9

  instance = _messages.StringField(1)
  namedPorts = _messages.MessageField('NamedPort', 2, repeated=True)
  status = _messages.EnumField('StatusValueValuesEnum', 3)


class InstancesAddResourcePoliciesRequest(_messages.Message):
  r"""A InstancesAddResourcePoliciesRequest object.

  Fields:
    resourcePolicies: Resource policies to be added to this instance.
  """

  resourcePolicies = _messages.StringField(1, repeated=True)


class InstancesGetEffectiveFirewallsResponse(_messages.Message):
  r"""A InstancesGetEffectiveFirewallsResponse object.

  Fields:
    firewalls: Effective firewalls on the instance.
    organizationFirewalls: Effective firewalls from organization policies.
  """

  firewalls = _messages.MessageField('Firewall', 1, repeated=True)
  organizationFirewalls = _messages.MessageField('InstancesGetEffectiveFirewallsResponseOrganizationFirewallPolicy', 2, repeated=True)


class InstancesGetEffectiveFirewallsResponseOrganizationFirewallPolicy(_messages.Message):
  r"""A pruned SecurityPolicy containing ID and any applicable firewall rules.

  Fields:
    id: The unique identifier for the security policy. This identifier is
      defined by the server.
    rules: The rules that apply to the network.
  """

  id = _messages.IntegerField(1, variant=_messages.Variant.UINT64)
  rules = _messages.MessageField('SecurityPolicyRule', 2, repeated=True)


class InstancesRemoveResourcePoliciesRequest(_messages.Message):
  r"""A InstancesRemoveResourcePoliciesRequest object.

  Fields:
    resourcePolicies: Resource policies to be removed from this instance.
  """

  resourcePolicies = _messages.StringField(1, repeated=True)


class InstancesResumeRequest(_messages.Message):
  r"""A InstancesResumeRequest object.

  Fields:
    disks: Array of disks associated with this instance that are protected
      with a customer-supplied encryption key.  In order to resume the
      instance, the disk url and its corresponding key must be provided.  If
      the disk is not protected with a customer-supplied encryption key it
      should not be specified.
    instanceEncryptionKey: Decrypts data associated with an instance that is
      protected with a customer-supplied encryption key.  If the instance you
      are starting is protected with a customer-supplied encryption key, the
      correct key must be provided otherwise the instance resume will not
      succeed.
  """

  disks = _messages.MessageField('CustomerEncryptionKeyProtectedDisk', 1, repeated=True)
  instanceEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 2)


class InstancesScopedList(_messages.Message):
  r"""A InstancesScopedList object.

  Messages:
    WarningValue: [Output Only] Informational warning which replaces the list
      of instances when the list is empty.

  Fields:
    instances: [Output Only] A list of instances contained in this scope.
    warning: [Output Only] Informational warning which replaces the list of
      instances when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning which replaces the list of
    instances when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  instances = _messages.MessageField('Instance', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class InstancesSetLabelsRequest(_messages.Message):
  r"""A InstancesSetLabelsRequest object.

  Messages:
    LabelsValue: A LabelsValue object.

  Fields:
    labelFingerprint: Fingerprint of the previous set of labels for this
      resource, used to prevent conflicts. Provide the latest fingerprint
      value when making a request to add or change labels.
    labels: A LabelsValue attribute.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""A LabelsValue object.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  labelFingerprint = _messages.BytesField(1)
  labels = _messages.MessageField('LabelsValue', 2)


class InstancesSetMachineResourcesRequest(_messages.Message):
  r"""A InstancesSetMachineResourcesRequest object.

  Fields:
    guestAccelerators: A list of the type and count of accelerator cards
      attached to the instance.
  """

  guestAccelerators = _messages.MessageField('AcceleratorConfig', 1, repeated=True)


class InstancesSetMachineTypeRequest(_messages.Message):
  r"""A InstancesSetMachineTypeRequest object.

  Fields:
    machineType: Full or partial URL of the machine type resource. See Machine
      Types for a full list of machine types. For example: zones/us-
      central1-f/machineTypes/n1-standard-1
  """

  machineType = _messages.StringField(1)


class InstancesSetMinCpuPlatformRequest(_messages.Message):
  r"""A InstancesSetMinCpuPlatformRequest object.

  Fields:
    minCpuPlatform: Minimum cpu/platform this instance should be started at.
  """

  minCpuPlatform = _messages.StringField(1)


class InstancesSetNameRequest(_messages.Message):
  r"""A InstancesSetNameRequest object.

  Fields:
    currentName: The current name of this resource, used to prevent conflicts.
      Provide the latest name when making a request to change name.
    name: The name to be applied to the instance. Needs to be RFC 1035
      compliant.
  """

  currentName = _messages.StringField(1)
  name = _messages.StringField(2)


class InstancesSetServiceAccountRequest(_messages.Message):
  r"""A InstancesSetServiceAccountRequest object.

  Fields:
    email: Email address of the service account.
    scopes: The list of scopes to be made available for this service account.
  """

  email = _messages.StringField(1)
  scopes = _messages.StringField(2, repeated=True)


class InstancesStartWithEncryptionKeyRequest(_messages.Message):
  r"""A InstancesStartWithEncryptionKeyRequest object.

  Fields:
    disks: Array of disks associated with this instance that are protected
      with a customer-supplied encryption key.  In order to start the
      instance, the disk url and its corresponding key must be provided.  If
      the disk is not protected with a customer-supplied encryption key it
      should not be specified.
    instanceEncryptionKey: Decrypts data associated with an instance that is
      protected with a customer-supplied encryption key.  If the instance you
      are starting is protected with a customer-supplied encryption key, the
      correct key must be provided otherwise the instance start will not
      succeed.
  """

  disks = _messages.MessageField('CustomerEncryptionKeyProtectedDisk', 1, repeated=True)
  instanceEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 2)


class Int64RangeMatch(_messages.Message):
  r"""HttpRouteRuleMatch criteria for field values that must stay within the
  specified integer range.

  Fields:
    rangeEnd: The end of the range (exclusive) in signed long integer format.
    rangeStart: The start of the range (inclusive) in signed long integer
      format.
  """

  rangeEnd = _messages.IntegerField(1)
  rangeStart = _messages.IntegerField(2)


class Interconnect(_messages.Message):
  r"""Represents an Interconnect resource.  An Interconnect resource is a
  dedicated connection between the GCP network and your on-premises network.
  For more information, read the  Dedicated Interconnect Overview. (==
  resource_for {$api_version}.interconnects ==)

  Enums:
    InterconnectTypeValueValuesEnum: Type of interconnect, which can take one
      of the following values:  - PARTNER: A partner-managed interconnection
      shared between customers though a partner.  - DEDICATED: A dedicated
      physical interconnection with the customer. Note that a value IT_PRIVATE
      has been deprecated in favor of DEDICATED.
    LinkTypeValueValuesEnum: Type of link requested, which can take one of the
      following values:  - LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR
      optics  - LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics.
      Note that this field indicates the speed of each of the links in the
      bundle, not the speed of the entire bundle.
    OperationalStatusValueValuesEnum: [Output Only] The current status of this
      Interconnect's functionality, which can take one of the following
      values:  - OS_ACTIVE: A valid Interconnect, which is turned up and is
      ready to use. Attachments may be provisioned on this Interconnect.  -
      OS_UNPROVISIONED: An Interconnect that has not completed turnup. No
      attachments may be provisioned on this Interconnect.  -
      OS_UNDER_MAINTENANCE: An Interconnect that is undergoing internal
      maintenance. No attachments may be provisioned or updated on this
      Interconnect.
    StateValueValuesEnum: [Output Only] The current state of Interconnect
      functionality, which can take one of the following values:  - ACTIVE:
      The Interconnect is valid, turned up and ready to use. Attachments may
      be provisioned on this Interconnect.  - UNPROVISIONED: The Interconnect
      has not completed turnup. No attachments may be provisioned on this
      Interconnect.  - UNDER_MAINTENANCE: The Interconnect is undergoing
      internal maintenance. No attachments may be provisioned or updated on
      this Interconnect.

  Messages:
    LabelsValue: Labels for this resource. These can only be added or modified
      by the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.

  Fields:
    adminEnabled: Administrative status of the interconnect. When this is set
      to true, the Interconnect is functional and can carry traffic. When set
      to false, no packets can be carried over the interconnect and no BGP
      routes are exchanged over it. By default, the status is set to true.
    circuitInfos: [Output Only] A list of CircuitInfo objects, that describe
      the individual circuits in this LAG.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    customerName: Customer name, to put in the Letter of Authorization as the
      party authorized to request a crossconnect.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    expectedOutages: [Output Only] A list of outages expected for this
      Interconnect.
    googleIpAddress: [Output Only] IP address configured on the Google side of
      the Interconnect link. This can be used only for ping tests.
    googleReferenceId: [Output Only] Google reference ID to be used when
      raising support tickets with Google or otherwise to debug backend
      connectivity issues.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    interconnectAttachments: [Output Only] A list of the URLs of all
      InterconnectAttachments configured to use this Interconnect.
    interconnectType: Type of interconnect, which can take one of the
      following values:  - PARTNER: A partner-managed interconnection shared
      between customers though a partner.  - DEDICATED: A dedicated physical
      interconnection with the customer. Note that a value IT_PRIVATE has been
      deprecated in favor of DEDICATED.
    kind: [Output Only] Type of the resource. Always compute#interconnect for
      interconnects.
    labelFingerprint: A fingerprint for the labels being applied to this
      Interconnect, which is essentially a hash of the labels set used for
      optimistic locking. The fingerprint is initially generated by Compute
      Engine and changes after every request to modify or update labels. You
      must always provide an up-to-date fingerprint hash in order to update or
      change labels, otherwise the request will fail with error 412
      conditionNotMet.  To see the latest fingerprint, make a get() request to
      retrieve an Interconnect.
    labels: Labels for this resource. These can only be added or modified by
      the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.
    linkType: Type of link requested, which can take one of the following
      values:  - LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics  -
      LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics. Note that
      this field indicates the speed of each of the links in the bundle, not
      the speed of the entire bundle.
    location: URL of the InterconnectLocation object that represents where
      this connection is to be provisioned.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    nocContactEmail: Email address to contact the customer NOC for operations
      and maintenance notifications regarding this Interconnect. If specified,
      this will be used for notifications in addition to all other forms
      described, such as Stackdriver logs alerting and Cloud Notifications.
    operationalStatus: [Output Only] The current status of this Interconnect's
      functionality, which can take one of the following values:  - OS_ACTIVE:
      A valid Interconnect, which is turned up and is ready to use.
      Attachments may be provisioned on this Interconnect.  -
      OS_UNPROVISIONED: An Interconnect that has not completed turnup. No
      attachments may be provisioned on this Interconnect.  -
      OS_UNDER_MAINTENANCE: An Interconnect that is undergoing internal
      maintenance. No attachments may be provisioned or updated on this
      Interconnect.
    peerIpAddress: [Output Only] IP address configured on the customer side of
      the Interconnect link. The customer should configure this IP address
      during turnup when prompted by Google NOC. This can be used only for
      ping tests.
    provisionedLinkCount: [Output Only] Number of links actually provisioned
      in this interconnect.
    requestedLinkCount: Target number of physical links in the link bundle, as
      requested by the customer.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    state: [Output Only] The current state of Interconnect functionality,
      which can take one of the following values:  - ACTIVE: The Interconnect
      is valid, turned up and ready to use. Attachments may be provisioned on
      this Interconnect.  - UNPROVISIONED: The Interconnect has not completed
      turnup. No attachments may be provisioned on this Interconnect.  -
      UNDER_MAINTENANCE: The Interconnect is undergoing internal maintenance.
      No attachments may be provisioned or updated on this Interconnect.
  """

  class InterconnectTypeValueValuesEnum(_messages.Enum):
    r"""Type of interconnect, which can take one of the following values:  -
    PARTNER: A partner-managed interconnection shared between customers though
    a partner.  - DEDICATED: A dedicated physical interconnection with the
    customer. Note that a value IT_PRIVATE has been deprecated in favor of
    DEDICATED.

    Values:
      DEDICATED: <no description>
      IT_PRIVATE: <no description>
      PARTNER: <no description>
    """
    DEDICATED = 0
    IT_PRIVATE = 1
    PARTNER = 2

  class LinkTypeValueValuesEnum(_messages.Enum):
    r"""Type of link requested, which can take one of the following values:  -
    LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics  -
    LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics. Note that this
    field indicates the speed of each of the links in the bundle, not the
    speed of the entire bundle.

    Values:
      LINK_TYPE_ETHERNET_100G_LR: <no description>
      LINK_TYPE_ETHERNET_10G_LR: <no description>
    """
    LINK_TYPE_ETHERNET_100G_LR = 0
    LINK_TYPE_ETHERNET_10G_LR = 1

  class OperationalStatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The current status of this Interconnect's functionality,
    which can take one of the following values:  - OS_ACTIVE: A valid
    Interconnect, which is turned up and is ready to use. Attachments may be
    provisioned on this Interconnect.  - OS_UNPROVISIONED: An Interconnect
    that has not completed turnup. No attachments may be provisioned on this
    Interconnect.  - OS_UNDER_MAINTENANCE: An Interconnect that is undergoing
    internal maintenance. No attachments may be provisioned or updated on this
    Interconnect.

    Values:
      OS_ACTIVE: <no description>
      OS_UNPROVISIONED: <no description>
    """
    OS_ACTIVE = 0
    OS_UNPROVISIONED = 1

  class StateValueValuesEnum(_messages.Enum):
    r"""[Output Only] The current state of Interconnect functionality, which
    can take one of the following values:  - ACTIVE: The Interconnect is
    valid, turned up and ready to use. Attachments may be provisioned on this
    Interconnect.  - UNPROVISIONED: The Interconnect has not completed turnup.
    No attachments may be provisioned on this Interconnect.  -
    UNDER_MAINTENANCE: The Interconnect is undergoing internal maintenance. No
    attachments may be provisioned or updated on this Interconnect.

    Values:
      ACTIVE: <no description>
      UNPROVISIONED: <no description>
    """
    ACTIVE = 0
    UNPROVISIONED = 1

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels for this resource. These can only be added or modified by the
    setLabels method. Each label key/value pair must comply with RFC1035.
    Label values may be empty.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  adminEnabled = _messages.BooleanField(1)
  circuitInfos = _messages.MessageField('InterconnectCircuitInfo', 2, repeated=True)
  creationTimestamp = _messages.StringField(3)
  customerName = _messages.StringField(4)
  description = _messages.StringField(5)
  expectedOutages = _messages.MessageField('InterconnectOutageNotification', 6, repeated=True)
  googleIpAddress = _messages.StringField(7)
  googleReferenceId = _messages.StringField(8)
  id = _messages.IntegerField(9, variant=_messages.Variant.UINT64)
  interconnectAttachments = _messages.StringField(10, repeated=True)
  interconnectType = _messages.EnumField('InterconnectTypeValueValuesEnum', 11)
  kind = _messages.StringField(12, default=u'compute#interconnect')
  labelFingerprint = _messages.BytesField(13)
  labels = _messages.MessageField('LabelsValue', 14)
  linkType = _messages.EnumField('LinkTypeValueValuesEnum', 15)
  location = _messages.StringField(16)
  name = _messages.StringField(17)
  nocContactEmail = _messages.StringField(18)
  operationalStatus = _messages.EnumField('OperationalStatusValueValuesEnum', 19)
  peerIpAddress = _messages.StringField(20)
  provisionedLinkCount = _messages.IntegerField(21, variant=_messages.Variant.INT32)
  requestedLinkCount = _messages.IntegerField(22, variant=_messages.Variant.INT32)
  selfLink = _messages.StringField(23)
  selfLinkWithId = _messages.StringField(24)
  state = _messages.EnumField('StateValueValuesEnum', 25)


class InterconnectAttachment(_messages.Message):
  r"""Represents an Interconnect Attachment (VLAN) resource.  You can use
  Interconnect attachments (VLANS) to connect your Virtual Private Cloud
  networks to your on-premises networks through an Interconnect. For more
  information, read  Creating VLAN Attachments. (== resource_for
  {$api_version}.interconnectAttachments ==)

  Enums:
    BandwidthValueValuesEnum: Provisioned bandwidth capacity for the
      interconnect attachment. For attachments of type DEDICATED, the user can
      set the bandwidth. For attachments of type PARTNER, the Google Partner
      that is operating the interconnect must set the bandwidth. Output only
      for PARTNER type, mutable for PARTNER_PROVIDER and DEDICATED, and can
      take one of the following values:  - BPS_50M: 50 Mbit/s  - BPS_100M: 100
      Mbit/s  - BPS_200M: 200 Mbit/s  - BPS_300M: 300 Mbit/s  - BPS_400M: 400
      Mbit/s  - BPS_500M: 500 Mbit/s  - BPS_1G: 1 Gbit/s  - BPS_2G: 2 Gbit/s
      - BPS_5G: 5 Gbit/s  - BPS_10G: 10 Gbit/s  - BPS_20G: 20 Gbit/s  -
      BPS_50G: 50 Gbit/s
    EdgeAvailabilityDomainValueValuesEnum: Desired availability domain for the
      attachment. Only available for type PARTNER, at creation time, and can
      take one of the following values:  - AVAILABILITY_DOMAIN_ANY  -
      AVAILABILITY_DOMAIN_1  - AVAILABILITY_DOMAIN_2 For improved reliability,
      customers should configure a pair of attachments, one per availability
      domain. The selected availability domain will be provided to the Partner
      via the pairing key, so that the provisioned circuit will lie in the
      specified domain. If not specified, the value will default to
      AVAILABILITY_DOMAIN_ANY.
    OperationalStatusValueValuesEnum: [Output Only] The current status of
      whether or not this interconnect attachment is functional, which can
      take one of the following values:  - OS_ACTIVE: The attachment has been
      turned up and is ready to use.  - OS_UNPROVISIONED: The attachment is
      not ready to use yet, because turnup is not complete.
    StateValueValuesEnum: [Output Only] The current state of this attachment's
      functionality. Enum values ACTIVE and UNPROVISIONED are shared by
      DEDICATED/PRIVATE, PARTNER, and PARTNER_PROVIDER interconnect
      attachments, while enum values PENDING_PARTNER,
      PARTNER_REQUEST_RECEIVED, and PENDING_CUSTOMER are used for only PARTNER
      and PARTNER_PROVIDER interconnect attachments. This state can take one
      of the following values:  - ACTIVE: The attachment has been turned up
      and is ready to use.  - UNPROVISIONED: The attachment is not ready to
      use yet, because turnup is not complete.  - PENDING_PARTNER: A newly-
      created PARTNER attachment that has not yet been configured on the
      Partner side.  - PARTNER_REQUEST_RECEIVED: A PARTNER attachment is in
      the process of provisioning after a PARTNER_PROVIDER attachment was
      created that references it.  - PENDING_CUSTOMER: A PARTNER or
      PARTNER_PROVIDER attachment that is waiting for a customer to activate
      it.  - DEFUNCT: The attachment was deleted externally and is no longer
      functional. This could be because the associated Interconnect was
      removed, or because the other side of a Partner attachment was deleted.
    TypeValueValuesEnum: The type of interconnect attachment this is, which
      can take one of the following values:  - DEDICATED: an attachment to a
      Dedicated Interconnect.  - PARTNER: an attachment to a Partner
      Interconnect, created by the customer.  - PARTNER_PROVIDER: an
      attachment to a Partner Interconnect, created by the partner.

  Messages:
    LabelsValue: Labels for this resource. These can only be added or modified
      by the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.

  Fields:
    adminEnabled: Determines whether this Attachment will carry packets. Not
      present for PARTNER_PROVIDER.
    bandwidth: Provisioned bandwidth capacity for the interconnect attachment.
      For attachments of type DEDICATED, the user can set the bandwidth. For
      attachments of type PARTNER, the Google Partner that is operating the
      interconnect must set the bandwidth. Output only for PARTNER type,
      mutable for PARTNER_PROVIDER and DEDICATED, and can take one of the
      following values:  - BPS_50M: 50 Mbit/s  - BPS_100M: 100 Mbit/s  -
      BPS_200M: 200 Mbit/s  - BPS_300M: 300 Mbit/s  - BPS_400M: 400 Mbit/s  -
      BPS_500M: 500 Mbit/s  - BPS_1G: 1 Gbit/s  - BPS_2G: 2 Gbit/s  - BPS_5G:
      5 Gbit/s  - BPS_10G: 10 Gbit/s  - BPS_20G: 20 Gbit/s  - BPS_50G: 50
      Gbit/s
    candidateSubnets: Up to 16 candidate prefixes that can be used to restrict
      the allocation of cloudRouterIpAddress and customerRouterIpAddress for
      this attachment. All prefixes must be within link-local address space
      (169.254.0.0/16) and must be /29 or shorter (/28, /27, etc). Google will
      attempt to select an unused /29 from the supplied candidate prefix(es).
      The request will fail if all possible /29s are in use on Google's edge.
      If not supplied, Google will randomly select an unused /29 from all of
      link-local space.
    cloudRouterIpAddress: [Output Only] IPv4 address + prefix length to be
      configured on Cloud Router Interface for this interconnect attachment.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    customerRouterIpAddress: [Output Only] IPv4 address + prefix length to be
      configured on the customer router subinterface for this interconnect
      attachment.
    description: An optional description of this resource.
    edgeAvailabilityDomain: Desired availability domain for the attachment.
      Only available for type PARTNER, at creation time, and can take one of
      the following values:  - AVAILABILITY_DOMAIN_ANY  -
      AVAILABILITY_DOMAIN_1  - AVAILABILITY_DOMAIN_2 For improved reliability,
      customers should configure a pair of attachments, one per availability
      domain. The selected availability domain will be provided to the Partner
      via the pairing key, so that the provisioned circuit will lie in the
      specified domain. If not specified, the value will default to
      AVAILABILITY_DOMAIN_ANY.
    googleReferenceId: [Output Only] Google reference ID, to be used when
      raising support tickets with Google or otherwise to debug backend
      connectivity issues. [Deprecated] This field is not used.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    interconnect: URL of the underlying Interconnect object that this
      attachment's traffic will traverse through.
    kind: [Output Only] Type of the resource. Always
      compute#interconnectAttachment for interconnect attachments.
    labelFingerprint: A fingerprint for the labels being applied to this
      InterconnectAttachment, which is essentially a hash of the labels set
      used for optimistic locking. The fingerprint is initially generated by
      Compute Engine and changes after every request to modify or update
      labels. You must always provide an up-to-date fingerprint hash in order
      to update or change labels, otherwise the request will fail with error
      412 conditionNotMet.  To see the latest fingerprint, make a get()
      request to retrieve an InterconnectAttachment.
    labels: Labels for this resource. These can only be added or modified by
      the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.
    mtu: Maximum Transmission Unit (MTU), in bytes, of packets passing through
      this interconnect attachment. Only 1440 and 1500 are allowed. If not
      specified, the value will default to 1440.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    operationalStatus: [Output Only] The current status of whether or not this
      interconnect attachment is functional, which can take one of the
      following values:  - OS_ACTIVE: The attachment has been turned up and is
      ready to use.  - OS_UNPROVISIONED: The attachment is not ready to use
      yet, because turnup is not complete.
    pairingKey: [Output only for type PARTNER. Input only for
      PARTNER_PROVIDER. Not present for DEDICATED]. The opaque identifier of
      an PARTNER attachment used to initiate provisioning with a selected
      partner. Of the form "XXXXX/region/domain"
    partnerAsn: Optional BGP ASN for the router supplied by a Layer 3 Partner
      if they configured BGP on behalf of the customer. Output only for
      PARTNER type, input only for PARTNER_PROVIDER, not available for
      DEDICATED.
    partnerMetadata: Informational metadata about Partner attachments from
      Partners to display to customers. Output only for for PARTNER type,
      mutable for PARTNER_PROVIDER, not available for DEDICATED.
    privateInterconnectInfo: [Output Only] Information specific to an
      InterconnectAttachment. This property is populated if the interconnect
      that this is attached to is of type DEDICATED.
    region: [Output Only] URL of the region where the regional interconnect
      attachment resides. You must specify this field as part of the HTTP
      request URL. It is not settable as a field in the request body.
    router: URL of the Cloud Router to be used for dynamic routing. This
      router must be in the same region as this InterconnectAttachment. The
      InterconnectAttachment will automatically connect the Interconnect to
      the network & region within which the Cloud Router is configured.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    state: [Output Only] The current state of this attachment's functionality.
      Enum values ACTIVE and UNPROVISIONED are shared by DEDICATED/PRIVATE,
      PARTNER, and PARTNER_PROVIDER interconnect attachments, while enum
      values PENDING_PARTNER, PARTNER_REQUEST_RECEIVED, and PENDING_CUSTOMER
      are used for only PARTNER and PARTNER_PROVIDER interconnect attachments.
      This state can take one of the following values:  - ACTIVE: The
      attachment has been turned up and is ready to use.  - UNPROVISIONED: The
      attachment is not ready to use yet, because turnup is not complete.  -
      PENDING_PARTNER: A newly-created PARTNER attachment that has not yet
      been configured on the Partner side.  - PARTNER_REQUEST_RECEIVED: A
      PARTNER attachment is in the process of provisioning after a
      PARTNER_PROVIDER attachment was created that references it.  -
      PENDING_CUSTOMER: A PARTNER or PARTNER_PROVIDER attachment that is
      waiting for a customer to activate it.  - DEFUNCT: The attachment was
      deleted externally and is no longer functional. This could be because
      the associated Interconnect was removed, or because the other side of a
      Partner attachment was deleted.
    type: The type of interconnect attachment this is, which can take one of
      the following values:  - DEDICATED: an attachment to a Dedicated
      Interconnect.  - PARTNER: an attachment to a Partner Interconnect,
      created by the customer.  - PARTNER_PROVIDER: an attachment to a Partner
      Interconnect, created by the partner.
    vlanTag8021q: The IEEE 802.1Q VLAN tag for this attachment, in the range
      2-4094. Only specified at creation time.
  """

  class BandwidthValueValuesEnum(_messages.Enum):
    r"""Provisioned bandwidth capacity for the interconnect attachment. For
    attachments of type DEDICATED, the user can set the bandwidth. For
    attachments of type PARTNER, the Google Partner that is operating the
    interconnect must set the bandwidth. Output only for PARTNER type, mutable
    for PARTNER_PROVIDER and DEDICATED, and can take one of the following
    values:  - BPS_50M: 50 Mbit/s  - BPS_100M: 100 Mbit/s  - BPS_200M: 200
    Mbit/s  - BPS_300M: 300 Mbit/s  - BPS_400M: 400 Mbit/s  - BPS_500M: 500
    Mbit/s  - BPS_1G: 1 Gbit/s  - BPS_2G: 2 Gbit/s  - BPS_5G: 5 Gbit/s  -
    BPS_10G: 10 Gbit/s  - BPS_20G: 20 Gbit/s  - BPS_50G: 50 Gbit/s

    Values:
      BPS_100M: <no description>
      BPS_10G: <no description>
      BPS_1G: <no description>
      BPS_200M: <no description>
      BPS_20G: <no description>
      BPS_2G: <no description>
      BPS_300M: <no description>
      BPS_400M: <no description>
      BPS_500M: <no description>
      BPS_50G: <no description>
      BPS_50M: <no description>
      BPS_5G: <no description>
    """
    BPS_100M = 0
    BPS_10G = 1
    BPS_1G = 2
    BPS_200M = 3
    BPS_20G = 4
    BPS_2G = 5
    BPS_300M = 6
    BPS_400M = 7
    BPS_500M = 8
    BPS_50G = 9
    BPS_50M = 10
    BPS_5G = 11

  class EdgeAvailabilityDomainValueValuesEnum(_messages.Enum):
    r"""Desired availability domain for the attachment. Only available for
    type PARTNER, at creation time, and can take one of the following values:
    - AVAILABILITY_DOMAIN_ANY  - AVAILABILITY_DOMAIN_1  -
    AVAILABILITY_DOMAIN_2 For improved reliability, customers should configure
    a pair of attachments, one per availability domain. The selected
    availability domain will be provided to the Partner via the pairing key,
    so that the provisioned circuit will lie in the specified domain. If not
    specified, the value will default to AVAILABILITY_DOMAIN_ANY.

    Values:
      AVAILABILITY_DOMAIN_1: <no description>
      AVAILABILITY_DOMAIN_2: <no description>
      AVAILABILITY_DOMAIN_ANY: <no description>
    """
    AVAILABILITY_DOMAIN_1 = 0
    AVAILABILITY_DOMAIN_2 = 1
    AVAILABILITY_DOMAIN_ANY = 2

  class OperationalStatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The current status of whether or not this interconnect
    attachment is functional, which can take one of the following values:  -
    OS_ACTIVE: The attachment has been turned up and is ready to use.  -
    OS_UNPROVISIONED: The attachment is not ready to use yet, because turnup
    is not complete.

    Values:
      OS_ACTIVE: <no description>
      OS_UNPROVISIONED: <no description>
    """
    OS_ACTIVE = 0
    OS_UNPROVISIONED = 1

  class StateValueValuesEnum(_messages.Enum):
    r"""[Output Only] The current state of this attachment's functionality.
    Enum values ACTIVE and UNPROVISIONED are shared by DEDICATED/PRIVATE,
    PARTNER, and PARTNER_PROVIDER interconnect attachments, while enum values
    PENDING_PARTNER, PARTNER_REQUEST_RECEIVED, and PENDING_CUSTOMER are used
    for only PARTNER and PARTNER_PROVIDER interconnect attachments. This state
    can take one of the following values:  - ACTIVE: The attachment has been
    turned up and is ready to use.  - UNPROVISIONED: The attachment is not
    ready to use yet, because turnup is not complete.  - PENDING_PARTNER: A
    newly-created PARTNER attachment that has not yet been configured on the
    Partner side.  - PARTNER_REQUEST_RECEIVED: A PARTNER attachment is in the
    process of provisioning after a PARTNER_PROVIDER attachment was created
    that references it.  - PENDING_CUSTOMER: A PARTNER or PARTNER_PROVIDER
    attachment that is waiting for a customer to activate it.  - DEFUNCT: The
    attachment was deleted externally and is no longer functional. This could
    be because the associated Interconnect was removed, or because the other
    side of a Partner attachment was deleted.

    Values:
      ACTIVE: <no description>
      DEFUNCT: <no description>
      PARTNER_REQUEST_RECEIVED: <no description>
      PENDING_CUSTOMER: <no description>
      PENDING_PARTNER: <no description>
      STATE_UNSPECIFIED: <no description>
      UNPROVISIONED: <no description>
    """
    ACTIVE = 0
    DEFUNCT = 1
    PARTNER_REQUEST_RECEIVED = 2
    PENDING_CUSTOMER = 3
    PENDING_PARTNER = 4
    STATE_UNSPECIFIED = 5
    UNPROVISIONED = 6

  class TypeValueValuesEnum(_messages.Enum):
    r"""The type of interconnect attachment this is, which can take one of the
    following values:  - DEDICATED: an attachment to a Dedicated Interconnect.
    - PARTNER: an attachment to a Partner Interconnect, created by the
    customer.  - PARTNER_PROVIDER: an attachment to a Partner Interconnect,
    created by the partner.

    Values:
      DEDICATED: <no description>
      PARTNER: <no description>
      PARTNER_PROVIDER: <no description>
    """
    DEDICATED = 0
    PARTNER = 1
    PARTNER_PROVIDER = 2

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels for this resource. These can only be added or modified by the
    setLabels method. Each label key/value pair must comply with RFC1035.
    Label values may be empty.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  adminEnabled = _messages.BooleanField(1)
  bandwidth = _messages.EnumField('BandwidthValueValuesEnum', 2)
  candidateSubnets = _messages.StringField(3, repeated=True)
  cloudRouterIpAddress = _messages.StringField(4)
  creationTimestamp = _messages.StringField(5)
  customerRouterIpAddress = _messages.StringField(6)
  description = _messages.StringField(7)
  edgeAvailabilityDomain = _messages.EnumField('EdgeAvailabilityDomainValueValuesEnum', 8)
  googleReferenceId = _messages.StringField(9)
  id = _messages.IntegerField(10, variant=_messages.Variant.UINT64)
  interconnect = _messages.StringField(11)
  kind = _messages.StringField(12, default=u'compute#interconnectAttachment')
  labelFingerprint = _messages.BytesField(13)
  labels = _messages.MessageField('LabelsValue', 14)
  mtu = _messages.IntegerField(15, variant=_messages.Variant.INT32)
  name = _messages.StringField(16)
  operationalStatus = _messages.EnumField('OperationalStatusValueValuesEnum', 17)
  pairingKey = _messages.StringField(18)
  partnerAsn = _messages.IntegerField(19)
  partnerMetadata = _messages.MessageField('InterconnectAttachmentPartnerMetadata', 20)
  privateInterconnectInfo = _messages.MessageField('InterconnectAttachmentPrivateInfo', 21)
  region = _messages.StringField(22)
  router = _messages.StringField(23)
  selfLink = _messages.StringField(24)
  selfLinkWithId = _messages.StringField(25)
  state = _messages.EnumField('StateValueValuesEnum', 26)
  type = _messages.EnumField('TypeValueValuesEnum', 27)
  vlanTag8021q = _messages.IntegerField(28, variant=_messages.Variant.INT32)


class InterconnectAttachmentAggregatedList(_messages.Message):
  r"""A InterconnectAttachmentAggregatedList object.

  Messages:
    ItemsValue: A list of InterconnectAttachmentsScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InterconnectAttachmentsScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#interconnectAttachmentAggregatedList for aggregated lists of
      interconnect attachments.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of InterconnectAttachmentsScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        interconnect attachments.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A InterconnectAttachmentsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('InterconnectAttachmentsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#interconnectAttachmentAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class InterconnectAttachmentList(_messages.Message):
  r"""Response to the list request, and contains a list of interconnect
  attachments.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InterconnectAttachment resources.
    kind: [Output Only] Type of resource. Always
      compute#interconnectAttachmentList for lists of interconnect
      attachments.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('InterconnectAttachment', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#interconnectAttachmentList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class InterconnectAttachmentPartnerMetadata(_messages.Message):
  r"""Informational metadata about Partner attachments from Partners to
  display to customers. These fields are propagated from PARTNER_PROVIDER
  attachments to their corresponding PARTNER attachments.

  Fields:
    interconnectName: Plain text name of the Interconnect this attachment is
      connected to, as displayed in the Partner's portal. For instance
      "Chicago 1". This value may be validated to match approved Partner
      values.
    partnerName: Plain text name of the Partner providing this attachment.
      This value may be validated to match approved Partner values.
    portalUrl: URL of the Partner's portal for this Attachment. Partners may
      customise this to be a deep link to the specific resource on the Partner
      portal. This value may be validated to match approved Partner values.
  """

  interconnectName = _messages.StringField(1)
  partnerName = _messages.StringField(2)
  portalUrl = _messages.StringField(3)


class InterconnectAttachmentPrivateInfo(_messages.Message):
  r"""Information for an interconnect attachment when this belongs to an
  interconnect of type DEDICATED.

  Fields:
    tag8021q: [Output Only] 802.1q encapsulation tag to be used for traffic
      between Google and the customer, going to and from this network and
      region.
  """

  tag8021q = _messages.IntegerField(1, variant=_messages.Variant.UINT32)


class InterconnectAttachmentsScopedList(_messages.Message):
  r"""A InterconnectAttachmentsScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of addresses
      when the list is empty.

  Fields:
    interconnectAttachments: A list of interconnect attachments contained in
      this scope.
    warning: Informational warning which replaces the list of addresses when
      the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of addresses when the
    list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  interconnectAttachments = _messages.MessageField('InterconnectAttachment', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class InterconnectCircuitInfo(_messages.Message):
  r"""Describes a single physical circuit between the Customer and Google.
  CircuitInfo objects are created by Google, so all fields are output only.
  Next id: 4

  Fields:
    customerDemarcId: Customer-side demarc ID for this circuit.
    googleCircuitId: Google-assigned unique ID for this circuit. Assigned at
      circuit turn-up.
    googleDemarcId: Google-side demarc ID for this circuit. Assigned at
      circuit turn-up and provided by Google to the customer in the LOA.
  """

  customerDemarcId = _messages.StringField(1)
  googleCircuitId = _messages.StringField(2)
  googleDemarcId = _messages.StringField(3)


class InterconnectDiagnostics(_messages.Message):
  r"""Diagnostics information about interconnect, contains detailed and
  current technical information about Google's side of the connection.

  Fields:
    arpCaches: A list of InterconnectDiagnostics.ARPEntry objects, describing
      individual neighbors currently seen by the Google router in the ARP
      cache for the Interconnect. This will be empty when the Interconnect is
      not bundled.
    links: A list of InterconnectDiagnostics.LinkStatus objects, describing
      the status for each link on the Interconnect.
    macAddress: The MAC address of the Interconnect's bundle interface.
  """

  arpCaches = _messages.MessageField('InterconnectDiagnosticsARPEntry', 1, repeated=True)
  links = _messages.MessageField('InterconnectDiagnosticsLinkStatus', 2, repeated=True)
  macAddress = _messages.StringField(3)


class InterconnectDiagnosticsARPEntry(_messages.Message):
  r"""Describing the ARP neighbor entries seen on this link

  Fields:
    ipAddress: The IP address of this ARP neighbor.
    macAddress: The MAC address of this ARP neighbor.
  """

  ipAddress = _messages.StringField(1)
  macAddress = _messages.StringField(2)


class InterconnectDiagnosticsLinkLACPStatus(_messages.Message):
  r"""A InterconnectDiagnosticsLinkLACPStatus object.

  Enums:
    StateValueValuesEnum: The state of a LACP link, which can take one of the
      following values:  - ACTIVE: The link is configured and active within
      the bundle.  - DETACHED: The link is not configured within the bundle.
      This means that the rest of the object should be empty.

  Fields:
    googleSystemId: System ID of the port on Google's side of the LACP
      exchange.
    neighborSystemId: System ID of the port on the neighbor's side of the LACP
      exchange.
    state: The state of a LACP link, which can take one of the following
      values:  - ACTIVE: The link is configured and active within the bundle.
      - DETACHED: The link is not configured within the bundle. This means
      that the rest of the object should be empty.
  """

  class StateValueValuesEnum(_messages.Enum):
    r"""The state of a LACP link, which can take one of the following values:
    - ACTIVE: The link is configured and active within the bundle.  -
    DETACHED: The link is not configured within the bundle. This means that
    the rest of the object should be empty.

    Values:
      ACTIVE: <no description>
      DETACHED: <no description>
    """
    ACTIVE = 0
    DETACHED = 1

  googleSystemId = _messages.StringField(1)
  neighborSystemId = _messages.StringField(2)
  state = _messages.EnumField('StateValueValuesEnum', 3)


class InterconnectDiagnosticsLinkOpticalPower(_messages.Message):
  r"""A InterconnectDiagnosticsLinkOpticalPower object.

  Enums:
    StateValueValuesEnum: The status of the current value when compared to the
      warning and alarm levels for the receiving or transmitting transceiver.
      Possible states include:   - OK: The value has not crossed a warning
      threshold.  - LOW_WARNING: The value has crossed below the low warning
      threshold.  - HIGH_WARNING: The value has crossed above the high warning
      threshold.  - LOW_ALARM: The value has crossed below the low alarm
      threshold.  - HIGH_ALARM: The value has crossed above the high alarm
      threshold.

  Fields:
    state: The status of the current value when compared to the warning and
      alarm levels for the receiving or transmitting transceiver. Possible
      states include:   - OK: The value has not crossed a warning threshold.
      - LOW_WARNING: The value has crossed below the low warning threshold.  -
      HIGH_WARNING: The value has crossed above the high warning threshold.  -
      LOW_ALARM: The value has crossed below the low alarm threshold.  -
      HIGH_ALARM: The value has crossed above the high alarm threshold.
    value: Value of the current receiving or transmitting optical power, read
      in dBm. Take a known good optical value, give it a 10% margin and
      trigger warnings relative to that value. In general, a -7dBm warning and
      a -11dBm alarm are good optical value estimates for most links.
  """

  class StateValueValuesEnum(_messages.Enum):
    r"""The status of the current value when compared to the warning and alarm
    levels for the receiving or transmitting transceiver. Possible states
    include:   - OK: The value has not crossed a warning threshold.  -
    LOW_WARNING: The value has crossed below the low warning threshold.  -
    HIGH_WARNING: The value has crossed above the high warning threshold.  -
    LOW_ALARM: The value has crossed below the low alarm threshold.  -
    HIGH_ALARM: The value has crossed above the high alarm threshold.

    Values:
      HIGH_ALARM: <no description>
      HIGH_WARNING: <no description>
      LOW_ALARM: <no description>
      LOW_WARNING: <no description>
      OK: <no description>
    """
    HIGH_ALARM = 0
    HIGH_WARNING = 1
    LOW_ALARM = 2
    LOW_WARNING = 3
    OK = 4

  state = _messages.EnumField('StateValueValuesEnum', 1)
  value = _messages.FloatField(2, variant=_messages.Variant.FLOAT)


class InterconnectDiagnosticsLinkStatus(_messages.Message):
  r"""A InterconnectDiagnosticsLinkStatus object.

  Fields:
    arpCaches: A list of InterconnectDiagnostics.ARPEntry objects, describing
      the ARP neighbor entries seen on this link. This will be empty if the
      link is bundled
    circuitId: The unique ID for this link assigned during turn up by Google.
    googleDemarc: The Demarc address assigned by Google and provided in the
      LoA.
    lacpStatus: A InterconnectDiagnosticsLinkLACPStatus attribute.
    receivingOpticalPower: An InterconnectDiagnostics.LinkOpticalPower object,
      describing the current value and status of the received light level.
    transmittingOpticalPower: An InterconnectDiagnostics.LinkOpticalPower
      object, describing the current value and status of the transmitted light
      level.
  """

  arpCaches = _messages.MessageField('InterconnectDiagnosticsARPEntry', 1, repeated=True)
  circuitId = _messages.StringField(2)
  googleDemarc = _messages.StringField(3)
  lacpStatus = _messages.MessageField('InterconnectDiagnosticsLinkLACPStatus', 4)
  receivingOpticalPower = _messages.MessageField('InterconnectDiagnosticsLinkOpticalPower', 5)
  transmittingOpticalPower = _messages.MessageField('InterconnectDiagnosticsLinkOpticalPower', 6)


class InterconnectList(_messages.Message):
  r"""Response to the list request, and contains a list of interconnects.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Interconnect resources.
    kind: [Output Only] Type of resource. Always compute#interconnectList for
      lists of interconnects.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Interconnect', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#interconnectList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class InterconnectLocation(_messages.Message):
  r"""Represents an Interconnect Attachment (VLAN) Location resource.  You can
  use this resource to find location details about an Interconnect attachment
  (VLAN). For more information about interconnect attachments, read  Creating
  VLAN Attachments.

  Enums:
    ContinentValueValuesEnum: [Output Only] Continent for this location, which
      can take one of the following values:  - AFRICA  - ASIA_PAC  - EUROPE  -
      NORTH_AMERICA  - SOUTH_AMERICA
    StatusValueValuesEnum: [Output Only] The status of this
      InterconnectLocation, which can take one of the following values:  -
      CLOSED: The InterconnectLocation is closed and is unavailable for
      provisioning new Interconnects.  - AVAILABLE: The InterconnectLocation
      is available for provisioning new Interconnects.

  Fields:
    address: [Output Only] The postal address of the Point of Presence, each
      line in the address is separated by a newline character.
    availabilityZone: [Output Only] Availability zone for this
      InterconnectLocation. Within a metropolitan area (metro), maintenance
      will not be simultaneously scheduled in more than one availability zone.
      Example: "zone1" or "zone2".
    city: [Output Only] Metropolitan area designator that indicates which city
      an interconnect is located. For example: "Chicago, IL", "Amsterdam,
      Netherlands".
    continent: [Output Only] Continent for this location, which can take one
      of the following values:  - AFRICA  - ASIA_PAC  - EUROPE  -
      NORTH_AMERICA  - SOUTH_AMERICA
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: [Output Only] An optional description of the resource.
    facilityProvider: [Output Only] The name of the provider for this facility
      (e.g., EQUINIX).
    facilityProviderFacilityId: [Output Only] A provider-assigned Identifier
      for this facility (e.g., Ashburn-DC1).
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always
      compute#interconnectLocation for interconnect locations.
    name: [Output Only] Name of the resource.
    peeringdbFacilityId: [Output Only] The peeringdb identifier for this
      facility (corresponding with a netfac type in peeringdb).
    regionInfos: [Output Only] A list of InterconnectLocation.RegionInfo
      objects, that describe parameters pertaining to the relation between
      this InterconnectLocation and various Google Cloud regions.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    status: [Output Only] The status of this InterconnectLocation, which can
      take one of the following values:  - CLOSED: The InterconnectLocation is
      closed and is unavailable for provisioning new Interconnects.  -
      AVAILABLE: The InterconnectLocation is available for provisioning new
      Interconnects.
  """

  class ContinentValueValuesEnum(_messages.Enum):
    r"""[Output Only] Continent for this location, which can take one of the
    following values:  - AFRICA  - ASIA_PAC  - EUROPE  - NORTH_AMERICA  -
    SOUTH_AMERICA

    Values:
      AFRICA: <no description>
      ASIA_PAC: <no description>
      C_AFRICA: <no description>
      C_ASIA_PAC: <no description>
      C_EUROPE: <no description>
      C_NORTH_AMERICA: <no description>
      C_SOUTH_AMERICA: <no description>
      EUROPE: <no description>
      NORTH_AMERICA: <no description>
      SOUTH_AMERICA: <no description>
    """
    AFRICA = 0
    ASIA_PAC = 1
    C_AFRICA = 2
    C_ASIA_PAC = 3
    C_EUROPE = 4
    C_NORTH_AMERICA = 5
    C_SOUTH_AMERICA = 6
    EUROPE = 7
    NORTH_AMERICA = 8
    SOUTH_AMERICA = 9

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of this InterconnectLocation, which can take
    one of the following values:  - CLOSED: The InterconnectLocation is closed
    and is unavailable for provisioning new Interconnects.  - AVAILABLE: The
    InterconnectLocation is available for provisioning new Interconnects.

    Values:
      AVAILABLE: <no description>
      CLOSED: <no description>
    """
    AVAILABLE = 0
    CLOSED = 1

  address = _messages.StringField(1)
  availabilityZone = _messages.StringField(2)
  city = _messages.StringField(3)
  continent = _messages.EnumField('ContinentValueValuesEnum', 4)
  creationTimestamp = _messages.StringField(5)
  description = _messages.StringField(6)
  facilityProvider = _messages.StringField(7)
  facilityProviderFacilityId = _messages.StringField(8)
  id = _messages.IntegerField(9, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(10, default=u'compute#interconnectLocation')
  name = _messages.StringField(11)
  peeringdbFacilityId = _messages.StringField(12)
  regionInfos = _messages.MessageField('InterconnectLocationRegionInfo', 13, repeated=True)
  selfLink = _messages.StringField(14)
  selfLinkWithId = _messages.StringField(15)
  status = _messages.EnumField('StatusValueValuesEnum', 16)


class InterconnectLocationList(_messages.Message):
  r"""Response to the list request, and contains a list of interconnect
  locations.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InterconnectLocation resources.
    kind: [Output Only] Type of resource. Always
      compute#interconnectLocationList for lists of interconnect locations.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('InterconnectLocation', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#interconnectLocationList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class InterconnectLocationRegionInfo(_messages.Message):
  r"""Information about any potential InterconnectAttachments between an
  Interconnect at a specific InterconnectLocation, and a specific Cloud
  Region.

  Enums:
    LocationPresenceValueValuesEnum: Identifies the network presence of this
      location.

  Fields:
    expectedRttMs: Expected round-trip time in milliseconds, from this
      InterconnectLocation to a VM in this region.
    locationPresence: Identifies the network presence of this location.
    region: URL for the region of this location.
  """

  class LocationPresenceValueValuesEnum(_messages.Enum):
    r"""Identifies the network presence of this location.

    Values:
      GLOBAL: <no description>
      LOCAL_REGION: <no description>
      LP_GLOBAL: <no description>
      LP_LOCAL_REGION: <no description>
    """
    GLOBAL = 0
    LOCAL_REGION = 1
    LP_GLOBAL = 2
    LP_LOCAL_REGION = 3

  expectedRttMs = _messages.IntegerField(1)
  locationPresence = _messages.EnumField('LocationPresenceValueValuesEnum', 2)
  region = _messages.StringField(3)


class InterconnectOutageNotification(_messages.Message):
  r"""Description of a planned outage on this Interconnect. Next id: 9

  Enums:
    IssueTypeValueValuesEnum: Form this outage is expected to take, which can
      take one of the following values:  - OUTAGE: The Interconnect may be
      completely out of service for some or all of the specified window.  -
      PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole
      should remain up, but with reduced bandwidth. Note that the versions of
      this enum prefixed with "IT_" have been deprecated in favor of the
      unprefixed values.
    SourceValueValuesEnum: The party that generated this notification, which
      can take the following value:  - GOOGLE: this notification as generated
      by Google. Note that the value of NSRC_GOOGLE has been deprecated in
      favor of GOOGLE.
    StateValueValuesEnum: State of this notification, which can take one of
      the following values:  - ACTIVE: This outage notification is active. The
      event could be in the past, present, or future. See start_time and
      end_time for scheduling.  - CANCELLED: The outage associated with this
      notification was cancelled before the outage was due to start. Note that
      the versions of this enum prefixed with "NS_" have been deprecated in
      favor of the unprefixed values.

  Fields:
    affectedCircuits: If issue_type is IT_PARTIAL_OUTAGE, a list of the
      Google-side circuit IDs that will be affected.
    description: A description about the purpose of the outage.
    endTime: Scheduled end time for the outage (milliseconds since Unix
      epoch).
    issueType: Form this outage is expected to take, which can take one of the
      following values:  - OUTAGE: The Interconnect may be completely out of
      service for some or all of the specified window.  - PARTIAL_OUTAGE: Some
      circuits comprising the Interconnect as a whole should remain up, but
      with reduced bandwidth. Note that the versions of this enum prefixed
      with "IT_" have been deprecated in favor of the unprefixed values.
    name: Unique identifier for this outage notification.
    source: The party that generated this notification, which can take the
      following value:  - GOOGLE: this notification as generated by Google.
      Note that the value of NSRC_GOOGLE has been deprecated in favor of
      GOOGLE.
    startTime: Scheduled start time for the outage (milliseconds since Unix
      epoch).
    state: State of this notification, which can take one of the following
      values:  - ACTIVE: This outage notification is active. The event could
      be in the past, present, or future. See start_time and end_time for
      scheduling.  - CANCELLED: The outage associated with this notification
      was cancelled before the outage was due to start. Note that the versions
      of this enum prefixed with "NS_" have been deprecated in favor of the
      unprefixed values.
  """

  class IssueTypeValueValuesEnum(_messages.Enum):
    r"""Form this outage is expected to take, which can take one of the
    following values:  - OUTAGE: The Interconnect may be completely out of
    service for some or all of the specified window.  - PARTIAL_OUTAGE: Some
    circuits comprising the Interconnect as a whole should remain up, but with
    reduced bandwidth. Note that the versions of this enum prefixed with "IT_"
    have been deprecated in favor of the unprefixed values.

    Values:
      IT_OUTAGE: <no description>
      IT_PARTIAL_OUTAGE: <no description>
      OUTAGE: <no description>
      PARTIAL_OUTAGE: <no description>
    """
    IT_OUTAGE = 0
    IT_PARTIAL_OUTAGE = 1
    OUTAGE = 2
    PARTIAL_OUTAGE = 3

  class SourceValueValuesEnum(_messages.Enum):
    r"""The party that generated this notification, which can take the
    following value:  - GOOGLE: this notification as generated by Google. Note
    that the value of NSRC_GOOGLE has been deprecated in favor of GOOGLE.

    Values:
      GOOGLE: <no description>
      NSRC_GOOGLE: <no description>
    """
    GOOGLE = 0
    NSRC_GOOGLE = 1

  class StateValueValuesEnum(_messages.Enum):
    r"""State of this notification, which can take one of the following
    values:  - ACTIVE: This outage notification is active. The event could be
    in the past, present, or future. See start_time and end_time for
    scheduling.  - CANCELLED: The outage associated with this notification was
    cancelled before the outage was due to start. Note that the versions of
    this enum prefixed with "NS_" have been deprecated in favor of the
    unprefixed values.

    Values:
      ACTIVE: <no description>
      CANCELLED: <no description>
      COMPLETED: <no description>
      NS_ACTIVE: <no description>
      NS_CANCELED: <no description>
    """
    ACTIVE = 0
    CANCELLED = 1
    COMPLETED = 2
    NS_ACTIVE = 3
    NS_CANCELED = 4

  affectedCircuits = _messages.StringField(1, repeated=True)
  description = _messages.StringField(2)
  endTime = _messages.IntegerField(3)
  issueType = _messages.EnumField('IssueTypeValueValuesEnum', 4)
  name = _messages.StringField(5)
  source = _messages.EnumField('SourceValueValuesEnum', 6)
  startTime = _messages.IntegerField(7)
  state = _messages.EnumField('StateValueValuesEnum', 8)


class InterconnectsGetDiagnosticsResponse(_messages.Message):
  r"""Response for the InterconnectsGetDiagnosticsRequest.

  Fields:
    result: A InterconnectDiagnostics attribute.
  """

  result = _messages.MessageField('InterconnectDiagnostics', 1)


class InternalIpAddress(_messages.Message):
  r"""A InternalIpAddress object.

  Enums:
    TypeValueValuesEnum: The type of the internal IP address.

  Fields:
    cidr: IP CIDR address or range.
    owner: The owner of the internal IP address.
    purpose: The purpose of the internal IP address if applicable.
    region: The region of the internal IP address if applicable.
    type: The type of the internal IP address.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""The type of the internal IP address.

    Values:
      PEER_RESERVED: <no description>
      PEER_USED: <no description>
      REMOTE_RESERVED: <no description>
      REMOTE_USED: <no description>
      RESERVED: <no description>
      SUBNETWORK: <no description>
      TYPE_UNSPECIFIED: <no description>
    """
    PEER_RESERVED = 0
    PEER_USED = 1
    REMOTE_RESERVED = 2
    REMOTE_USED = 3
    RESERVED = 4
    SUBNETWORK = 5
    TYPE_UNSPECIFIED = 6

  cidr = _messages.StringField(1)
  owner = _messages.StringField(2)
  purpose = _messages.StringField(3)
  region = _messages.StringField(4)
  type = _messages.EnumField('TypeValueValuesEnum', 5)


class InternalIpOwner(_messages.Message):
  r"""A InternalIpOwner object.

  Fields:
    ipCidrRange: IP CIDR range being owned.
    owners: URLs of the IP owners of the IP CIDR range.
    systemOwned: Whether this IP CIDR range is reserved for system use.
  """

  ipCidrRange = _messages.StringField(1)
  owners = _messages.StringField(2, repeated=True)
  systemOwned = _messages.BooleanField(3)


class IpAddressesList(_messages.Message):
  r"""A IpAddressesList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InternalIpAddress resources.
    kind: [Output Only] Type of resource. Always compute#ipAddressesList for
      IP addresses lists.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('InternalIpAddress', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#ipAddressesList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class IpOwnerList(_messages.Message):
  r"""Contains a list of IP owners.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InternalIpOwner resources.
    kind: [Output Only] Type of resource. Always compute#ipOwnerList for lists
      of IP owners.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('InternalIpOwner', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#ipOwnerList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class Jwt(_messages.Message):
  r"""[Deprecated] JWT configuration for origin authentication. JWT
  configuration for origin authentication.

  Fields:
    audiences: A JWT containing any of these audiences will be accepted. The
      service name will be accepted if audiences is empty. Examples:
      bookstore_android.apps.googleusercontent.com,
      bookstore_web.apps.googleusercontent.com
    issuer: Identifies the issuer that issued the JWT, which is usually a URL
      or an email address. Examples: https://securetoken.google.com,
      1234567-compute@developer.gserviceaccount.com
    jwksPublicKeys: The provider's public key set to validate the signature of
      the JWT.
    jwtHeaders: jwt_headers and jwt_params define where to extract the JWT
      from an HTTP request. If no explicit location is specified, the
      following default locations are tried in order:  1. The Authorization
      header using the Bearer schema. See `here `_. Example:  Authorization:
      Bearer .  2. `access_token` query parameter. See `this `_  Multiple JWTs
      can be verified for a request. Each JWT has to be extracted from the
      locations its issuer specified or from the default locations.  This
      field is set if JWT is sent in a request header. This field specifies
      the header name. For example, if `header=x-goog-iap-jwt-assertion`, the
      header format will be x-goog-iap-jwt-assertion: .
    jwtParams: This field is set if JWT is sent in a query parameter. This
      field specifies the query parameter name. For example, if jwt_params[0]
      is jwt_token, the JWT format in the query parameter is /path?jwt_token=.
  """

  audiences = _messages.StringField(1, repeated=True)
  issuer = _messages.StringField(2)
  jwksPublicKeys = _messages.StringField(3)
  jwtHeaders = _messages.MessageField('JwtHeader', 4, repeated=True)
  jwtParams = _messages.StringField(5, repeated=True)


class JwtHeader(_messages.Message):
  r"""[Deprecated] This message specifies a header location to extract JWT
  token. This message specifies a header location to extract JWT token.

  Fields:
    name: The HTTP header name.
    valuePrefix: The value prefix. The value format is "value_prefix" For
      example, for "Authorization: Bearer ", value_prefix="Bearer " with a
      space at the end.
  """

  name = _messages.StringField(1)
  valuePrefix = _messages.StringField(2)


class License(_messages.Message):
  r"""Represents a License resource.  A License represents billing and
  aggregate usage data for public and marketplace images.  Caution This
  resource is intended for use only by third-party partners who are creating
  Cloud Marketplace images. (== resource_for {$api_version}.licenses ==)

  Fields:
    chargesUseFee: [Output Only] Deprecated. This field no longer reflects
      whether a license charges a usage fee.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional textual description of the resource; provided by
      the client when the resource is created.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of resource. Always compute#license for licenses.
    licenseCode: [Output Only] The unique code used to attach this license to
      images, snapshots, and disks.
    name: Name of the resource. The name must be 1-63 characters long and
      comply with RFC1035.
    resourceRequirements: A LicenseResourceRequirements attribute.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    transferable: If false, licenses will not be copied from the source
      resource when creating an image from a disk, disk from snapshot, or
      snapshot from disk.
  """

  chargesUseFee = _messages.BooleanField(1)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default=u'compute#license')
  licenseCode = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  name = _messages.StringField(7)
  resourceRequirements = _messages.MessageField('LicenseResourceRequirements', 8)
  selfLink = _messages.StringField(9)
  selfLinkWithId = _messages.StringField(10)
  transferable = _messages.BooleanField(11)


class LicenseCode(_messages.Message):
  r"""Represents a License Code resource.  A License Code is a unique
  identifier used to represent a license resource.  Caution This resource is
  intended for use only by third-party partners who are creating Cloud
  Marketplace images. (== resource_for {$api_version}.licenseCodes ==)

  Enums:
    StateValueValuesEnum: [Output Only] Current state of this License Code.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: [Output Only] Description of this License Code.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of resource. Always compute#licenseCode for
      licenses.
    licenseAlias: [Output Only] URL and description aliases of Licenses with
      the same License Code.
    name: [Output Only] Name of the resource. The name is 1-20 characters long
      and must be a valid 64 bit integer.
    selfLink: [Output Only] Server-defined URL for the resource.
    state: [Output Only] Current state of this License Code.
    transferable: [Output Only] If true, the license will remain attached when
      creating images or snapshots from disks. Otherwise, the license is not
      transferred.
  """

  class StateValueValuesEnum(_messages.Enum):
    r"""[Output Only] Current state of this License Code.

    Values:
      DISABLED: <no description>
      ENABLED: <no description>
      RESTRICTED: <no description>
      STATE_UNSPECIFIED: <no description>
      TERMINATED: <no description>
    """
    DISABLED = 0
    ENABLED = 1
    RESTRICTED = 2
    STATE_UNSPECIFIED = 3
    TERMINATED = 4

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  id = _messages.IntegerField(3, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(4, default=u'compute#licenseCode')
  licenseAlias = _messages.MessageField('LicenseCodeLicenseAlias', 5, repeated=True)
  name = _messages.StringField(6)
  selfLink = _messages.StringField(7)
  state = _messages.EnumField('StateValueValuesEnum', 8)
  transferable = _messages.BooleanField(9)


class LicenseCodeLicenseAlias(_messages.Message):
  r"""A LicenseCodeLicenseAlias object.

  Fields:
    description: [Output Only] Description of this License Code.
    selfLink: [Output Only] URL of license corresponding to this License Code.
  """

  description = _messages.StringField(1)
  selfLink = _messages.StringField(2)


class LicenseResourceCommitment(_messages.Message):
  r"""Commitment for a particular license resource.

  Fields:
    amount: The number of licenses purchased.
    coresPerLicense: Specifies the core range of the instance for which this
      license applies.
    license: Any applicable license URI.
  """

  amount = _messages.IntegerField(1)
  coresPerLicense = _messages.StringField(2)
  license = _messages.StringField(3)


class LicenseResourceRequirements(_messages.Message):
  r"""A LicenseResourceRequirements object.

  Fields:
    minGuestCpuCount: Minimum number of guest cpus required to use the
      Instance. Enforced at Instance creation and Instance start.
    minMemoryMb: Minimum memory required to use the Instance. Enforced at
      Instance creation and Instance start.
  """

  minGuestCpuCount = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  minMemoryMb = _messages.IntegerField(2, variant=_messages.Variant.INT32)


class LicensesListResponse(_messages.Message):
  r"""A LicensesListResponse object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of License resources.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('License', 2, repeated=True)
  nextPageToken = _messages.StringField(3)
  selfLink = _messages.StringField(4)
  warning = _messages.MessageField('WarningValue', 5)


class LocalDisk(_messages.Message):
  r"""A LocalDisk object.

  Fields:
    diskCount: Specifies the number of such disks.
    diskSizeGb: Specifies the size of the disk in base-2 GB.
    diskType: Specifies the desired disk type on the node. This disk type must
      be a local storage type (e.g.: local-ssd). Note that for nodeTemplates,
      this should be the name of the disk type and not its URL.
  """

  diskCount = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  diskSizeGb = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  diskType = _messages.StringField(3)


class LogConfig(_messages.Message):
  r"""Specifies what kind of log the caller must write

  Fields:
    cloudAudit: Cloud audit options.
    counter: Counter options.
    dataAccess: Data access options.
  """

  cloudAudit = _messages.MessageField('LogConfigCloudAuditOptions', 1)
  counter = _messages.MessageField('LogConfigCounterOptions', 2)
  dataAccess = _messages.MessageField('LogConfigDataAccessOptions', 3)


class LogConfigCloudAuditOptions(_messages.Message):
  r"""Write a Cloud Audit log

  Enums:
    LogNameValueValuesEnum: The log_name to populate in the Cloud Audit
      Record.

  Fields:
    authorizationLoggingOptions: Information used by the Cloud Audit Logging
      pipeline.
    logName: The log_name to populate in the Cloud Audit Record.
  """

  class LogNameValueValuesEnum(_messages.Enum):
    r"""The log_name to populate in the Cloud Audit Record.

    Values:
      ADMIN_ACTIVITY: <no description>
      DATA_ACCESS: <no description>
      UNSPECIFIED_LOG_NAME: <no description>
    """
    ADMIN_ACTIVITY = 0
    DATA_ACCESS = 1
    UNSPECIFIED_LOG_NAME = 2

  authorizationLoggingOptions = _messages.MessageField('AuthorizationLoggingOptions', 1)
  logName = _messages.EnumField('LogNameValueValuesEnum', 2)


class LogConfigCounterOptions(_messages.Message):
  r"""Increment a streamz counter with the specified metric and field names.
  Metric names should start with a '/', generally be lowercase-only, and end
  in "_count". Field names should not contain an initial slash. The actual
  exported metric names will have "/iam/policy" prepended.  Field names
  correspond to IAM request parameters and field values are their respective
  values.  Supported field names: - "authority", which is "[token]" if
  IAMContext.token is present, otherwise the value of
  IAMContext.authority_selector if present, and otherwise a representation of
  IAMContext.principal; or - "iam_principal", a representation of
  IAMContext.principal even if a token or authority selector is present; or -
  "" (empty string), resulting in a counter with no fields.  Examples: counter
  { metric: "/debug_access_count" field: "iam_principal" } ==> increment
  counter /iam/policy/debug_access_count {iam_principal=[value of
  IAMContext.principal]}

  Fields:
    customFields: Custom fields.
    field: The field value to attribute.
    metric: The metric to update.
  """

  customFields = _messages.MessageField('LogConfigCounterOptionsCustomField', 1, repeated=True)
  field = _messages.StringField(2)
  metric = _messages.StringField(3)


class LogConfigCounterOptionsCustomField(_messages.Message):
  r"""Custom fields. These can be used to create a counter with arbitrary
  field/value pairs. See: go/rpcsp-custom-fields.

  Fields:
    name: Name is the field name.
    value: Value is the field value. It is important that in contrast to the
      CounterOptions.field, the value here is a constant that is not derived
      from the IAMContext.
  """

  name = _messages.StringField(1)
  value = _messages.StringField(2)


class LogConfigDataAccessOptions(_messages.Message):
  r"""Write a Data Access (Gin) log

  Enums:
    LogModeValueValuesEnum:

  Fields:
    logMode:
  """

  class LogModeValueValuesEnum(_messages.Enum):
    r"""LogModeValueValuesEnum enum type.

    Values:
      LOG_FAIL_CLOSED: <no description>
      LOG_MODE_UNSPECIFIED: <no description>
    """
    LOG_FAIL_CLOSED = 0
    LOG_MODE_UNSPECIFIED = 1

  logMode = _messages.EnumField('LogModeValueValuesEnum', 1)


class MachineImage(_messages.Message):
  r"""Represents a machine image resource.  A machine image is a Compute
  Engine resource that stores all the configuration, metadata, permissions,
  and data from one or more disks required to create a Virtual machine (VM)
  instance. For more information, see Machine images. (== resource_for
  {$api_version}.machineImages ==)

  Enums:
    StatusValueValuesEnum: [Output Only] The status of the machine image. One
      of the following values: INVALID, CREATING, READY, DELETING, and
      UPLOADING.

  Fields:
    creationTimestamp: [Output Only] The creation timestamp for this machine
      image in RFC3339 text format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    guestFlush: [Input Only] Specifies to create an application consistent
      machine image by informing the OS to prepare for the snapshot process.
      Currently only supported on Windows instances using the Volume Shadow
      Copy Service (VSS).
    id: [Output Only] A unique identifier for this machine image. The server
      defines this identifier.
    kind: [Output Only] The resource type, which is always
      compute#machineImage for machine image.
    machineImageEncryptionKey: Encrypts the machine image using a customer-
      supplied encryption key.  After you encrypt a machine image using a
      customer-supplied key, you must provide the same key if you use the
      machine image later. For example, you must provide the encryption key
      when you create an instance from the encrypted machine image in a future
      request.  Customer-supplied encryption keys do not protect access to
      metadata of the machine image.  If you do not provide an encryption key
      when creating the machine image, then the machine image will be
      encrypted using an automatically generated key and you do not need to
      provide a key to use the machine image later.
    name: Name of the resource; provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    selfLink: [Output Only] The URL for this machine image. The server defines
      this URL.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    sourceDiskEncryptionKeys: [Input Only] The customer-supplied encryption
      key of the disks attached to the source instance. Required if the source
      disk is protected by a customer-supplied encryption key.
    sourceInstance: The source instance used to create the machine image. You
      can provide this as a partial or full URL to the resource. For example,
      the following are valid values:   - https://www.googleapis.com/compute/v
      1/projects/project/zones/zone/instances/instance  -
      projects/project/zones/zone/instances/instance
    sourceInstanceProperties: [Output Only] Properties of source instance.
    status: [Output Only] The status of the machine image. One of the
      following values: INVALID, CREATING, READY, DELETING, and UPLOADING.
    storageLocations: GCS bucket storage location of the machine image
      (regional or multi-regional).
    totalStorageBytes: [Output Only] Total size of the storage used by the
      machine image.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the machine image. One of the following
    values: INVALID, CREATING, READY, DELETING, and UPLOADING.

    Values:
      CREATING: <no description>
      DELETING: <no description>
      INVALID: <no description>
      READY: <no description>
      UPLOADING: <no description>
    """
    CREATING = 0
    DELETING = 1
    INVALID = 2
    READY = 3
    UPLOADING = 4

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  guestFlush = _messages.BooleanField(3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default=u'compute#machineImage')
  machineImageEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 6)
  name = _messages.StringField(7)
  selfLink = _messages.StringField(8)
  selfLinkWithId = _messages.StringField(9)
  sourceDiskEncryptionKeys = _messages.MessageField('SourceDiskEncryptionKey', 10, repeated=True)
  sourceInstance = _messages.StringField(11)
  sourceInstanceProperties = _messages.MessageField('SourceInstanceProperties', 12)
  status = _messages.EnumField('StatusValueValuesEnum', 13)
  storageLocations = _messages.StringField(14, repeated=True)
  totalStorageBytes = _messages.IntegerField(15)


class MachineImageList(_messages.Message):
  r"""A list of machine images.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of MachineImage resources.
    kind: [Output Only] The resource type, which is always
      compute#machineImagesListResponse for machine image lists.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('MachineImage', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#machineImageList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class MachineType(_messages.Message):
  r"""Represents a Machine Type resource.  You can use specific machine types
  for your VM instances based on performance and pricing requirements. For
  more information, read Machine Types. (== resource_for
  {$api_version}.machineTypes ==)

  Messages:
    AcceleratorsValueListEntry: A AcceleratorsValueListEntry object.

  Fields:
    accelerators: [Output Only] A list of accelerator configurations assigned
      to this machine type.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    deprecated: [Output Only] The deprecation status associated with this
      machine type.
    description: [Output Only] An optional textual description of the
      resource.
    guestCpus: [Output Only] The number of virtual CPUs that are available to
      the instance.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    isSharedCpu: [Output Only] Whether this machine type has a shared CPU. See
      Shared-core machine types for more information.
    kind: [Output Only] The type of the resource. Always compute#machineType
      for machine types.
    maximumPersistentDisks: [Output Only] Maximum persistent disks allowed.
    maximumPersistentDisksSizeGb: [Output Only] Maximum total persistent disks
      size (GB) allowed.
    memoryMb: [Output Only] The amount of physical memory available to the
      instance, defined in MB.
    name: [Output Only] Name of the resource.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    zone: [Output Only] The name of the zone where the machine type resides,
      such as us-central1-a.
  """

  class AcceleratorsValueListEntry(_messages.Message):
    r"""A AcceleratorsValueListEntry object.

    Fields:
      guestAcceleratorCount: Number of accelerator cards exposed to the guest.
      guestAcceleratorType: The accelerator type resource name, not a full
        URL, e.g. 'nvidia-tesla-k80'.
    """

    guestAcceleratorCount = _messages.IntegerField(1, variant=_messages.Variant.INT32)
    guestAcceleratorType = _messages.StringField(2)

  accelerators = _messages.MessageField('AcceleratorsValueListEntry', 1, repeated=True)
  creationTimestamp = _messages.StringField(2)
  deprecated = _messages.MessageField('DeprecationStatus', 3)
  description = _messages.StringField(4)
  guestCpus = _messages.IntegerField(5, variant=_messages.Variant.INT32)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  isSharedCpu = _messages.BooleanField(7)
  kind = _messages.StringField(8, default=u'compute#machineType')
  maximumPersistentDisks = _messages.IntegerField(9, variant=_messages.Variant.INT32)
  maximumPersistentDisksSizeGb = _messages.IntegerField(10)
  memoryMb = _messages.IntegerField(11, variant=_messages.Variant.INT32)
  name = _messages.StringField(12)
  selfLink = _messages.StringField(13)
  selfLinkWithId = _messages.StringField(14)
  zone = _messages.StringField(15)


class MachineTypeAggregatedList(_messages.Message):
  r"""A MachineTypeAggregatedList object.

  Messages:
    ItemsValue: A list of MachineTypesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of MachineTypesScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#machineTypeAggregatedList for aggregated lists of machine types.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of MachineTypesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of machine types.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A MachineTypesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('MachineTypesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#machineTypeAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class MachineTypeList(_messages.Message):
  r"""Contains a list of machine types.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of MachineType resources.
    kind: [Output Only] Type of resource. Always compute#machineTypeList for
      lists of machine types.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('MachineType', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#machineTypeList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class MachineTypesScopedList(_messages.Message):
  r"""A MachineTypesScopedList object.

  Messages:
    WarningValue: [Output Only] An informational warning that appears when the
      machine types list is empty.

  Fields:
    machineTypes: [Output Only] A list of machine types contained in this
      scope.
    warning: [Output Only] An informational warning that appears when the
      machine types list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] An informational warning that appears when the machine
    types list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  machineTypes = _messages.MessageField('MachineType', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class ManagedInstance(_messages.Message):
  r"""A Managed Instance resource.

  Enums:
    CurrentActionValueValuesEnum: [Output Only] The current action that the
      managed instance group has scheduled for the instance. Possible values:
      - NONE The instance is running, and the managed instance group does not
      have any scheduled actions for this instance.  - CREATING The managed
      instance group is creating this instance. If the group fails to create
      this instance, it will try again until it is successful.  -
      CREATING_WITHOUT_RETRIES The managed instance group is attempting to
      create this instance only once. If the group fails to create this
      instance, it does not try again and the group's targetSize value is
      decreased instead.  - RECREATING The managed instance group is
      recreating this instance.  - DELETING The managed instance group is
      permanently deleting this instance.  - ABANDONING The managed instance
      group is abandoning this instance. The instance will be removed from the
      instance group and from any target pools that are associated with this
      group.  - RESTARTING The managed instance group is restarting the
      instance.  - REFRESHING The managed instance group is applying
      configuration changes to the instance without stopping it. For example,
      the group can update the target pool list for an instance without
      stopping that instance.  - VERIFYING The managed instance group has
      created the instance and it is in the process of being verified.
    InstanceStatusValueValuesEnum: [Output Only] The status of the instance.
      This field is empty when the instance does not exist.

  Fields:
    currentAction: [Output Only] The current action that the managed instance
      group has scheduled for the instance. Possible values:  - NONE The
      instance is running, and the managed instance group does not have any
      scheduled actions for this instance.  - CREATING The managed instance
      group is creating this instance. If the group fails to create this
      instance, it will try again until it is successful.  -
      CREATING_WITHOUT_RETRIES The managed instance group is attempting to
      create this instance only once. If the group fails to create this
      instance, it does not try again and the group's targetSize value is
      decreased instead.  - RECREATING The managed instance group is
      recreating this instance.  - DELETING The managed instance group is
      permanently deleting this instance.  - ABANDONING The managed instance
      group is abandoning this instance. The instance will be removed from the
      instance group and from any target pools that are associated with this
      group.  - RESTARTING The managed instance group is restarting the
      instance.  - REFRESHING The managed instance group is applying
      configuration changes to the instance without stopping it. For example,
      the group can update the target pool list for an instance without
      stopping that instance.  - VERIFYING The managed instance group has
      created the instance and it is in the process of being verified.
    id: [Output only] The unique identifier for this resource. This field is
      empty when instance does not exist.
    instance: [Output Only] The URL of the instance. The URL can exist even if
      the instance has not yet been created.
    instanceHealth: [Output Only] Health state of the instance per health-
      check.
    instanceStatus: [Output Only] The status of the instance. This field is
      empty when the instance does not exist.
    instanceTemplate: [Output Only] The intended template of the instance.
      This field is empty when current_action is one of { DELETING, ABANDONING
      }.
    lastAttempt: [Output Only] Information about the last attempt to create or
      delete the instance.
    preservedStateFromConfig: [Output Only] Preserved state applied from per-
      instance config for this instance.
    preservedStateFromPolicy: [Output Only] Preserved state generated based on
      stateful policy for this instance.
    tag: [Output Only] Tag describing the version.
    version: [Output Only] Intended version of this instance.
  """

  class CurrentActionValueValuesEnum(_messages.Enum):
    r"""[Output Only] The current action that the managed instance group has
    scheduled for the instance. Possible values:  - NONE The instance is
    running, and the managed instance group does not have any scheduled
    actions for this instance.  - CREATING The managed instance group is
    creating this instance. If the group fails to create this instance, it
    will try again until it is successful.  - CREATING_WITHOUT_RETRIES The
    managed instance group is attempting to create this instance only once. If
    the group fails to create this instance, it does not try again and the
    group's targetSize value is decreased instead.  - RECREATING The managed
    instance group is recreating this instance.  - DELETING The managed
    instance group is permanently deleting this instance.  - ABANDONING The
    managed instance group is abandoning this instance. The instance will be
    removed from the instance group and from any target pools that are
    associated with this group.  - RESTARTING The managed instance group is
    restarting the instance.  - REFRESHING The managed instance group is
    applying configuration changes to the instance without stopping it. For
    example, the group can update the target pool list for an instance without
    stopping that instance.  - VERIFYING The managed instance group has
    created the instance and it is in the process of being verified.

    Values:
      ABANDONING: <no description>
      CREATING: <no description>
      CREATING_WITHOUT_RETRIES: <no description>
      DELETING: <no description>
      NONE: <no description>
      RECREATING: <no description>
      REFRESHING: <no description>
      RESTARTING: <no description>
      VERIFYING: <no description>
    """
    ABANDONING = 0
    CREATING = 1
    CREATING_WITHOUT_RETRIES = 2
    DELETING = 3
    NONE = 4
    RECREATING = 5
    REFRESHING = 6
    RESTARTING = 7
    VERIFYING = 8

  class InstanceStatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the instance. This field is empty when the
    instance does not exist.

    Values:
      DEPROVISIONING: <no description>
      PROVISIONING: <no description>
      REPAIRING: <no description>
      RUNNING: <no description>
      STAGING: <no description>
      STOPPED: <no description>
      STOPPING: <no description>
      SUSPENDED: <no description>
      SUSPENDING: <no description>
      TERMINATED: <no description>
    """
    DEPROVISIONING = 0
    PROVISIONING = 1
    REPAIRING = 2
    RUNNING = 3
    STAGING = 4
    STOPPED = 5
    STOPPING = 6
    SUSPENDED = 7
    SUSPENDING = 8
    TERMINATED = 9

  currentAction = _messages.EnumField('CurrentActionValueValuesEnum', 1)
  id = _messages.IntegerField(2, variant=_messages.Variant.UINT64)
  instance = _messages.StringField(3)
  instanceHealth = _messages.MessageField('ManagedInstanceInstanceHealth', 4, repeated=True)
  instanceStatus = _messages.EnumField('InstanceStatusValueValuesEnum', 5)
  instanceTemplate = _messages.StringField(6)
  lastAttempt = _messages.MessageField('ManagedInstanceLastAttempt', 7)
  preservedStateFromConfig = _messages.MessageField('PreservedState', 8)
  preservedStateFromPolicy = _messages.MessageField('PreservedState', 9)
  tag = _messages.StringField(10)
  version = _messages.MessageField('ManagedInstanceVersion', 11)


class ManagedInstanceInstanceHealth(_messages.Message):
  r"""A ManagedInstanceInstanceHealth object.

  Enums:
    DetailedHealthStateValueValuesEnum: [Output Only] The current detailed
      instance health state.
    HealthStateValueValuesEnum: [Output Only] The current instance health
      state. This field will not get promoted to beta/GA and might be removed
      from alpha APIs after 01/12/2019. Please use detailed_health_state field
      instead.

  Fields:
    detailedHealthState: [Output Only] The current detailed instance health
      state.
    healthCheck: [Output Only] The URL for the health check that verifies
      whether the instance is healthy.
    healthState: [Output Only] The current instance health state. This field
      will not get promoted to beta/GA and might be removed from alpha APIs
      after 01/12/2019. Please use detailed_health_state field instead.
  """

  class DetailedHealthStateValueValuesEnum(_messages.Enum):
    r"""[Output Only] The current detailed instance health state.

    Values:
      DRAINING: <no description>
      HEALTHY: <no description>
      TIMEOUT: <no description>
      UNHEALTHY: <no description>
      UNKNOWN: <no description>
    """
    DRAINING = 0
    HEALTHY = 1
    TIMEOUT = 2
    UNHEALTHY = 3
    UNKNOWN = 4

  class HealthStateValueValuesEnum(_messages.Enum):
    r"""[Output Only] The current instance health state. This field will not
    get promoted to beta/GA and might be removed from alpha APIs after
    01/12/2019. Please use detailed_health_state field instead.

    Values:
      HEALTHY: <no description>
      UNHEALTHY: <no description>
    """
    HEALTHY = 0
    UNHEALTHY = 1

  detailedHealthState = _messages.EnumField('DetailedHealthStateValueValuesEnum', 1)
  healthCheck = _messages.StringField(2)
  healthState = _messages.EnumField('HealthStateValueValuesEnum', 3)


class ManagedInstanceLastAttempt(_messages.Message):
  r"""A ManagedInstanceLastAttempt object.

  Messages:
    ErrorsValue: [Output Only] Encountered errors during the last attempt to
      create or delete the instance.

  Fields:
    errors: [Output Only] Encountered errors during the last attempt to create
      or delete the instance.
  """

  class ErrorsValue(_messages.Message):
    r"""[Output Only] Encountered errors during the last attempt to create or
    delete the instance.

    Messages:
      ErrorsValueListEntry: A ErrorsValueListEntry object.

    Fields:
      errors: [Output Only] The array of errors encountered while processing
        this operation.
    """

    class ErrorsValueListEntry(_messages.Message):
      r"""A ErrorsValueListEntry object.

      Fields:
        code: [Output Only] The error type identifier for this error.
        location: [Output Only] Indicates the field in the request that caused
          the error. This property is optional.
        message: [Output Only] An optional, human-readable error message.
      """

      code = _messages.StringField(1)
      location = _messages.StringField(2)
      message = _messages.StringField(3)

    errors = _messages.MessageField('ErrorsValueListEntry', 1, repeated=True)

  errors = _messages.MessageField('ErrorsValue', 1)


class ManagedInstanceVersion(_messages.Message):
  r"""A ManagedInstanceVersion object.

  Fields:
    instanceTemplate: [Output Only] The intended template of the instance.
      This field is empty when current_action is one of { DELETING, ABANDONING
      }.
    name: [Output Only] Name of the version.
  """

  instanceTemplate = _messages.StringField(1)
  name = _messages.StringField(2)


class Metadata(_messages.Message):
  r"""A metadata key/value entry.

  Messages:
    ItemsValueListEntry: A ItemsValueListEntry object.

  Fields:
    fingerprint: Specifies a fingerprint for this request, which is
      essentially a hash of the metadata's contents and used for optimistic
      locking. The fingerprint is initially generated by Compute Engine and
      changes after every request to modify or update metadata. You must
      always provide an up-to-date fingerprint hash in order to update or
      change metadata, otherwise the request will fail with error 412
      conditionNotMet.  To see the latest fingerprint, make a get() request to
      retrieve the resource.
    items: Array of key/value pairs. The total size of all keys and values
      must be less than 512 KB.
    kind: [Output Only] Type of the resource. Always compute#metadata for
      metadata.
  """

  class ItemsValueListEntry(_messages.Message):
    r"""A ItemsValueListEntry object.

    Fields:
      key: Key for the metadata entry. Keys must conform to the following
        regexp: [a-zA-Z0-9-_]+, and be less than 128 bytes in length. This is
        reflected as part of a URL in the metadata server. Additionally, to
        avoid ambiguity, keys must not conflict with any other metadata keys
        for the project.
      value: Value for the metadata entry. These are free-form strings, and
        only have meaning as interpreted by the image running in the instance.
        The only restriction placed on values is that their size must be less
        than or equal to 262144 bytes (256 KiB).
    """

    key = _messages.StringField(1)
    value = _messages.StringField(2)

  fingerprint = _messages.BytesField(1)
  items = _messages.MessageField('ItemsValueListEntry', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#metadata')


class MetadataCredentialsFromPlugin(_messages.Message):
  r"""[Deprecated] Custom authenticator credentials. Custom authenticator
  credentials.

  Fields:
    name: Plugin name.
    structConfig: A text proto that conforms to a Struct type definition
      interpreted by the plugin.
  """

  name = _messages.StringField(1)
  structConfig = _messages.StringField(2)


class MetadataFilter(_messages.Message):
  r"""Opaque filter criteria used by loadbalancers to restrict routing
  configuration to a limited set of loadbalancing proxies. Proxies and
  sidecars involved in loadbalancing would typically present metadata to the
  loadbalancers which need to match criteria specified here. If a match takes
  place, the relevant configuration is made available to those proxies. For
  each metadataFilter in this list, if its filterMatchCriteria is set to
  MATCH_ANY, at least one of the filterLabels must match the corresponding
  label provided in the metadata. If its filterMatchCriteria is set to
  MATCH_ALL, then all of its filterLabels must match with corresponding labels
  provided in the metadata. An example for using metadataFilters would be: if
  loadbalancing involves  Envoys, they will only receive routing configuration
  when values in metadataFilters match values supplied in <a href="https://www
  .envoyproxy.io/docs/envoy/latest/api-v2/api/v2/core/base.proto#envoy-api-
  msg-core-node" Node metadata of their XDS requests to loadbalancers.

  Enums:
    FilterMatchCriteriaValueValuesEnum: Specifies how individual filterLabel
      matches within the list of filterLabels contribute towards the overall
      metadataFilter match. Supported values are:   - MATCH_ANY: At least one
      of the filterLabels must have a matching label in the provided metadata.
      - MATCH_ALL: All filterLabels must have matching labels in the provided
      metadata.

  Fields:
    filterLabels: The list of label value pairs that must match labels in the
      provided metadata based on filterMatchCriteria  This list must not be
      empty and can have at the most 64 entries.
    filterMatchCriteria: Specifies how individual filterLabel matches within
      the list of filterLabels contribute towards the overall metadataFilter
      match. Supported values are:   - MATCH_ANY: At least one of the
      filterLabels must have a matching label in the provided metadata.  -
      MATCH_ALL: All filterLabels must have matching labels in the provided
      metadata.
  """

  class FilterMatchCriteriaValueValuesEnum(_messages.Enum):
    r"""Specifies how individual filterLabel matches within the list of
    filterLabels contribute towards the overall metadataFilter match.
    Supported values are:   - MATCH_ANY: At least one of the filterLabels must
    have a matching label in the provided metadata.  - MATCH_ALL: All
    filterLabels must have matching labels in the provided metadata.

    Values:
      MATCH_ALL: <no description>
      MATCH_ANY: <no description>
      NOT_SET: <no description>
    """
    MATCH_ALL = 0
    MATCH_ANY = 1
    NOT_SET = 2

  filterLabels = _messages.MessageField('MetadataFilterLabelMatch', 1, repeated=True)
  filterMatchCriteria = _messages.EnumField('FilterMatchCriteriaValueValuesEnum', 2)


class MetadataFilterLabelMatch(_messages.Message):
  r"""MetadataFilter label name value pairs that are expected to match
  corresponding labels presented as metadata to the loadbalancer.

  Fields:
    name: Name of metadata label. The name can have a maximum length of 1024
      characters and must be at least 1 character long.
    value: The value of the label must match the specified value. value can
      have a maximum length of 1024 characters.
  """

  name = _messages.StringField(1)
  value = _messages.StringField(2)


class MutualTls(_messages.Message):
  r"""[Deprecated] Configuration for the mutual Tls mode for peer
  authentication. Configuration for the mutual Tls mode for peer
  authentication.

  Enums:
    ModeValueValuesEnum: Specifies if the server TLS is configured to be
      strict or permissive. This field can be set to one of the following:
      STRICT: Client certificate must be presented, connection is in TLS.
      PERMISSIVE: Client certificate can be omitted, connection can be either
      plaintext or TLS.

  Fields:
    mode: Specifies if the server TLS is configured to be strict or
      permissive. This field can be set to one of the following: STRICT:
      Client certificate must be presented, connection is in TLS. PERMISSIVE:
      Client certificate can be omitted, connection can be either plaintext or
      TLS.
  """

  class ModeValueValuesEnum(_messages.Enum):
    r"""Specifies if the server TLS is configured to be strict or permissive.
    This field can be set to one of the following: STRICT: Client certificate
    must be presented, connection is in TLS. PERMISSIVE: Client certificate
    can be omitted, connection can be either plaintext or TLS.

    Values:
      INVALID: <no description>
      PERMISSIVE: <no description>
      STRICT: <no description>
    """
    INVALID = 0
    PERMISSIVE = 1
    STRICT = 2

  mode = _messages.EnumField('ModeValueValuesEnum', 1)


class NamedPort(_messages.Message):
  r"""The named port. For example: .

  Fields:
    name: The name for this named port. The name must be 1-63 characters long,
      and comply with RFC1035.
    port: The port number, which can be a value between 1 and 65535.
  """

  name = _messages.StringField(1)
  port = _messages.IntegerField(2, variant=_messages.Variant.INT32)


class Network(_messages.Message):
  r"""Represents a VPC Network resource.  Networks connect resources to each
  other and to the internet. For more information, read Virtual Private Cloud
  (VPC) Network. (== resource_for {$api_version}.networks ==)

  Fields:
    IPv4Range: Deprecated in favor of subnet mode networks. The range of
      internal addresses that are legal on this network. This range is a CIDR
      specification, for example: 192.168.0.0/16. Provided by the client when
      the network is created.
    autoCreateSubnetworks: When set to true, the VPC network is created in
      "auto" mode. When set to false, the VPC network is created in "custom"
      mode.  An auto mode VPC network starts with one subnet per region. Each
      subnet has a predetermined range as described in Auto mode VPC network
      IP ranges.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this field
      when you create the resource.
    gatewayIPv4: [Output Only] The gateway address for default routing out of
      the network, selected by GCP.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#network for
      networks.
    mtu: Maximum Transmission Unit in bytes. The minimum value for this field
      is 1460 and the maximum value is 1500 bytes.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?`. The first character
      must be a lowercase letter, and all following characters (except for the
      last character) must be a dash, lowercase letter, or digit. The last
      character must be a lowercase letter or digit.
    peerings: [Output Only] A list of network peerings for the resource.
    routingConfig: The network-level routing configuration for this network.
      Used by Cloud Router to determine what type of network-wide routing
      behavior to enforce.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    subnetworks: [Output Only] Server-defined fully-qualified URLs for all
      subnetworks in this VPC network.
  """

  IPv4Range = _messages.StringField(1)
  autoCreateSubnetworks = _messages.BooleanField(2)
  creationTimestamp = _messages.StringField(3)
  description = _messages.StringField(4)
  gatewayIPv4 = _messages.StringField(5)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(7, default=u'compute#network')
  mtu = _messages.IntegerField(8, variant=_messages.Variant.INT32)
  name = _messages.StringField(9)
  peerings = _messages.MessageField('NetworkPeering', 10, repeated=True)
  routingConfig = _messages.MessageField('NetworkRoutingConfig', 11)
  selfLink = _messages.StringField(12)
  selfLinkWithId = _messages.StringField(13)
  subnetworks = _messages.StringField(14, repeated=True)


class NetworkEndpoint(_messages.Message):
  r"""The network endpoint. Next ID: 7

  Messages:
    AnnotationsValue: Metadata defined as annotations on the network endpoint.

  Fields:
    annotations: Metadata defined as annotations on the network endpoint.
    fqdn: Optional fully qualified domain name of network endpoint. This can
      only be specified when NetworkEndpointGroup.network_endpoint_type is
      NON_GCP_FQDN_PORT.
    instance: The name for a specific VM instance that the IP address belongs
      to. This is required for network endpoints of type GCE_VM_IP_PORT. The
      instance must be in the same zone of network endpoint group.  The name
      must be 1-63 characters long, and comply with RFC1035.
    ipAddress: Optional IPv4 address of network endpoint. The IP address must
      belong to a VM in Compute Engine (either the primary IP or as part of an
      aliased IP range). If the IP address is not specified, then the primary
      IP address for the VM instance in the network that the network endpoint
      group belongs to will be used.
    port: Optional port number of network endpoint. If not specified and the
      NetworkEndpointGroup.network_endpoint_type is GCE_IP_PORT, the
      defaultPort for the network endpoint group will be used.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class AnnotationsValue(_messages.Message):
    r"""Metadata defined as annotations on the network endpoint.

    Messages:
      AdditionalProperty: An additional property for a AnnotationsValue
        object.

    Fields:
      additionalProperties: Additional properties of type AnnotationsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a AnnotationsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  annotations = _messages.MessageField('AnnotationsValue', 1)
  fqdn = _messages.StringField(2)
  instance = _messages.StringField(3)
  ipAddress = _messages.StringField(4)
  port = _messages.IntegerField(5, variant=_messages.Variant.INT32)


class NetworkEndpointGroup(_messages.Message):
  r"""Represents a collection of network endpoints.  A network endpoint group
  (NEG) defines how a set of endpoints should be reached, whether they are
  reachable, and where they are located. For more information about using
  NEGs, see  Setting up internet NEGs or  Setting up zonal NEGs. (==
  resource_for {$api_version}.networkEndpointGroups ==) (== resource_for
  {$api_version}.globalNetworkEndpointGroups ==)

  Enums:
    NetworkEndpointTypeValueValuesEnum: Type of network endpoints in this
      network endpoint group.
    TypeValueValuesEnum: Specify the type of this network endpoint group. Only
      LOAD_BALANCING is valid for now.

  Messages:
    AnnotationsValue: Metadata defined as annotations on the network endpoint
      group.

  Fields:
    annotations: Metadata defined as annotations on the network endpoint
      group.
    appEngine: Only valid when networkEndpointType is "SERVERLESS". Only one
      of cloudRun, appEngine or cloudFunction may be set.
    cloudFunction: Only valid when networkEndpointType is "SERVERLESS". Only
      one of cloudRun, appEngine or cloudFunction may be set.
    cloudRun: Only valid when networkEndpointType is "SERVERLESS". Only one of
      cloudRun, appEngine or cloudFunction may be set.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    defaultPort: The default port used if the port number is not specified in
      the network endpoint.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always
      compute#networkEndpointGroup for network endpoint group.
    loadBalancer: This field is only valid when the network endpoint group is
      used for load balancing. [Deprecated] This field is deprecated.
    name: Name of the resource; provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    network: The URL of the network to which all network endpoints in the NEG
      belong. Uses "default" project network if unspecified.
    networkEndpointType: Type of network endpoints in this network endpoint
      group.
    region: [Output Only] The URL of the region where the network endpoint
      group is located.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    size: [Output only] Number of network endpoints in the network endpoint
      group.
    subnetwork: Optional URL of the subnetwork to which all network endpoints
      in the NEG belong.
    type: Specify the type of this network endpoint group. Only LOAD_BALANCING
      is valid for now.
    zone: [Output Only] The URL of the zone where the network endpoint group
      is located.
  """

  class NetworkEndpointTypeValueValuesEnum(_messages.Enum):
    r"""Type of network endpoints in this network endpoint group.

    Values:
      GCE_VM_IP_PORT: <no description>
      GCE_VM_PRIMARY_IP: <no description>
      INTERNET_FQDN_PORT: <no description>
      INTERNET_IP_PORT: <no description>
      NON_GCP_PRIVATE_IP_PORT: <no description>
      SERVERLESS: <no description>
    """
    GCE_VM_IP_PORT = 0
    GCE_VM_PRIMARY_IP = 1
    INTERNET_FQDN_PORT = 2
    INTERNET_IP_PORT = 3
    NON_GCP_PRIVATE_IP_PORT = 4
    SERVERLESS = 5

  class TypeValueValuesEnum(_messages.Enum):
    r"""Specify the type of this network endpoint group. Only LOAD_BALANCING
    is valid for now.

    Values:
      LOAD_BALANCING: <no description>
    """
    LOAD_BALANCING = 0

  @encoding.MapUnrecognizedFields('additionalProperties')
  class AnnotationsValue(_messages.Message):
    r"""Metadata defined as annotations on the network endpoint group.

    Messages:
      AdditionalProperty: An additional property for a AnnotationsValue
        object.

    Fields:
      additionalProperties: Additional properties of type AnnotationsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a AnnotationsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  annotations = _messages.MessageField('AnnotationsValue', 1)
  appEngine = _messages.MessageField('NetworkEndpointGroupAppEngine', 2)
  cloudFunction = _messages.MessageField('NetworkEndpointGroupCloudFunction', 3)
  cloudRun = _messages.MessageField('NetworkEndpointGroupCloudRun', 4)
  creationTimestamp = _messages.StringField(5)
  defaultPort = _messages.IntegerField(6, variant=_messages.Variant.INT32)
  description = _messages.StringField(7)
  id = _messages.IntegerField(8, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(9, default=u'compute#networkEndpointGroup')
  loadBalancer = _messages.MessageField('NetworkEndpointGroupLbNetworkEndpointGroup', 10)
  name = _messages.StringField(11)
  network = _messages.StringField(12)
  networkEndpointType = _messages.EnumField('NetworkEndpointTypeValueValuesEnum', 13)
  region = _messages.StringField(14)
  selfLink = _messages.StringField(15)
  selfLinkWithId = _messages.StringField(16)
  size = _messages.IntegerField(17, variant=_messages.Variant.INT32)
  subnetwork = _messages.StringField(18)
  type = _messages.EnumField('TypeValueValuesEnum', 19)
  zone = _messages.StringField(20)


class NetworkEndpointGroupAggregatedList(_messages.Message):
  r"""A NetworkEndpointGroupAggregatedList object.

  Messages:
    ItemsValue: A list of NetworkEndpointGroupsScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of NetworkEndpointGroupsScopedList resources.
    kind: [Output Only] The resource type, which is always
      compute#networkEndpointGroupAggregatedList for aggregated lists of
      network endpoint groups.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of NetworkEndpointGroupsScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: The name of the scope that contains this set of
        network endpoint groups.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A NetworkEndpointGroupsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('NetworkEndpointGroupsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#networkEndpointGroupAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class NetworkEndpointGroupAppEngine(_messages.Message):
  r"""Configuration for an App Engine network endpoint group (NEG). The
  service is optional, may be provided explicitly or in the URL mask. The
  version is optional and can only be provided explicitly or in the URL mask
  when service is present.  Note: App Engine service must be in the same
  project and located in the same region as the Serverless NEG.

  Fields:
    service: Optional serving service.  The service name must be 1-63
      characters long, and comply with RFC1035.  Example value: "default",
      "my-service".
    urlMask: A template to parse service and version fields from a request
      URL. URL mask allows for routing to multiple App Engine services without
      having to create multiple Network Endpoint Groups and backend services.
      For example, the request URLs "foo1-dot-appname.appspot.com/v1" and
      "foo1-dot-appname.appspot.com/v2" can be backed by the same Serverless
      NEG with URL mask "-dot-appname.appspot.com/". The URL mask will parse
      them to { service = "foo1", version = "v1" } and { service = "foo1",
      version = "v2" } respectively.
    version: Optional serving version.  The version must be 1-63 characters
      long, and comply with RFC1035.  Example value: "v1", "v2".
  """

  service = _messages.StringField(1)
  urlMask = _messages.StringField(2)
  version = _messages.StringField(3)


class NetworkEndpointGroupCloudFunction(_messages.Message):
  r"""Configuration for a Cloud Function network endpoint group (NEG). The
  function must be provided explicitly or in the URL mask.  Note: Cloud
  Function must be in the same project and located in the same region as the
  Serverless NEG.

  Fields:
    function: A user-defined name of the Cloud Function.  The function name is
      case-sensitive and must be 1-63 characters long.  Example value:
      "func1".
    urlMask: A template to parse function field from a request URL. URL mask
      allows for routing to multiple Cloud Functions without having to create
      multiple Network Endpoint Groups and backend services.  For example,
      request URLs "mydomain.com/function1" and "mydomain.com/function2" can
      be backed by the same Serverless NEG with URL mask "/". The URL mask
      will parse them to { function = "function1" } and { function =
      "function2" } respectively.
  """

  function = _messages.StringField(1)
  urlMask = _messages.StringField(2)


class NetworkEndpointGroupCloudRun(_messages.Message):
  r"""Configuration for a Cloud Run network endpoint group (NEG). The service
  must be provided explicitly or in the URL mask. The tag is optional, may be
  provided explicitly or in the URL mask.  Note: Cloud Run service must be in
  the same project and located in the same region as the Serverless NEG.

  Fields:
    service: Cloud Run service is the main resource of Cloud Run.  The service
      must be 1-63 characters long, and comply with RFC1035.  Example value:
      "run-service".
    tag: Optional Cloud Run tag represents the "named-revision" to provide
      additional fine-grained traffic routing information.  The tag must be
      1-63 characters long, and comply with RFC1035.  Example value:
      "revision-0010".
    urlMask: A template to parse service and tag fields from a request URL.
      URL mask allows for routing to multiple Run services without having to
      create multiple network endpoint groups and backend services.  For
      example, request URLs "foo1.domain.com/bar1" and "foo1.domain.com/bar2"
      can be backed by the same Serverless Network Endpoint Group (NEG) with
      URL mask ".domain.com/". The URL mask will parse them to {
      service="bar1", tag="foo1" } and { service="bar2", tag="foo2" }
      respectively.
  """

  service = _messages.StringField(1)
  tag = _messages.StringField(2)
  urlMask = _messages.StringField(3)


class NetworkEndpointGroupLbNetworkEndpointGroup(_messages.Message):
  r"""Load balancing specific fields for network endpoint group.

  Fields:
    defaultPort: The default port used if the port number is not specified in
      the network endpoint. [Deprecated] This field is deprecated.
    network: The URL of the network to which all network endpoints in the NEG
      belong. Uses "default" project network if unspecified. [Deprecated] This
      field is deprecated.
    subnetwork: Optional URL of the subnetwork to which all network endpoints
      in the NEG belong. [Deprecated] This field is deprecated.
    zone: [Output Only] The URL of the zone where the network endpoint group
      is located. [Deprecated] This field is deprecated.
  """

  defaultPort = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  network = _messages.StringField(2)
  subnetwork = _messages.StringField(3)
  zone = _messages.StringField(4)


class NetworkEndpointGroupList(_messages.Message):
  r"""A NetworkEndpointGroupList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of NetworkEndpointGroup resources.
    kind: [Output Only] The resource type, which is always
      compute#networkEndpointGroupList for network endpoint group lists.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('NetworkEndpointGroup', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#networkEndpointGroupList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class NetworkEndpointGroupsAttachEndpointsRequest(_messages.Message):
  r"""A NetworkEndpointGroupsAttachEndpointsRequest object.

  Fields:
    networkEndpoints: The list of network endpoints to be attached.
  """

  networkEndpoints = _messages.MessageField('NetworkEndpoint', 1, repeated=True)


class NetworkEndpointGroupsDetachEndpointsRequest(_messages.Message):
  r"""A NetworkEndpointGroupsDetachEndpointsRequest object.

  Fields:
    networkEndpoints: The list of network endpoints to be detached.
  """

  networkEndpoints = _messages.MessageField('NetworkEndpoint', 1, repeated=True)


class NetworkEndpointGroupsListEndpointsRequest(_messages.Message):
  r"""A NetworkEndpointGroupsListEndpointsRequest object.

  Enums:
    HealthStatusValueValuesEnum: Optional query parameter for showing the
      health status of each network endpoint. Valid options are SKIP or SHOW.
      If you don't specify this parameter, the health status of network
      endpoints will not be provided.

  Fields:
    endpointFilters: Optional list of endpoints to query. This is a more
      efficient but also limited version of filter parameter. Endpoints in the
      filter must have ip_address and port fields populated, other fields are
      not supported.
    healthStatus: Optional query parameter for showing the health status of
      each network endpoint. Valid options are SKIP or SHOW. If you don't
      specify this parameter, the health status of network endpoints will not
      be provided.
  """

  class HealthStatusValueValuesEnum(_messages.Enum):
    r"""Optional query parameter for showing the health status of each network
    endpoint. Valid options are SKIP or SHOW. If you don't specify this
    parameter, the health status of network endpoints will not be provided.

    Values:
      SHOW: <no description>
      SKIP: <no description>
    """
    SHOW = 0
    SKIP = 1

  endpointFilters = _messages.MessageField('NetworkEndpointGroupsListEndpointsRequestNetworkEndpointFilter', 1, repeated=True)
  healthStatus = _messages.EnumField('HealthStatusValueValuesEnum', 2)


class NetworkEndpointGroupsListEndpointsRequestNetworkEndpointFilter(_messages.Message):
  r"""A NetworkEndpointGroupsListEndpointsRequestNetworkEndpointFilter object.

  Fields:
    networkEndpoint: A NetworkEndpoint attribute.
  """

  networkEndpoint = _messages.MessageField('NetworkEndpoint', 1)


class NetworkEndpointGroupsListNetworkEndpoints(_messages.Message):
  r"""A NetworkEndpointGroupsListNetworkEndpoints object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of NetworkEndpointWithHealthStatus resources.
    kind: [Output Only] The resource type, which is always
      compute#networkEndpointGroupsListNetworkEndpoints for the list of
      network endpoints in the specified network endpoint group.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('NetworkEndpointWithHealthStatus', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#networkEndpointGroupsListNetworkEndpoints')
  nextPageToken = _messages.StringField(4)
  warning = _messages.MessageField('WarningValue', 5)


class NetworkEndpointGroupsScopedList(_messages.Message):
  r"""A NetworkEndpointGroupsScopedList object.

  Messages:
    WarningValue: [Output Only] An informational warning that replaces the
      list of network endpoint groups when the list is empty.

  Fields:
    networkEndpointGroups: [Output Only] The list of network endpoint groups
      that are contained in this scope.
    warning: [Output Only] An informational warning that replaces the list of
      network endpoint groups when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] An informational warning that replaces the list of
    network endpoint groups when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  networkEndpointGroups = _messages.MessageField('NetworkEndpointGroup', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class NetworkEndpointWithHealthStatus(_messages.Message):
  r"""A NetworkEndpointWithHealthStatus object.

  Fields:
    healths: [Output only] The health status of network endpoint;
    networkEndpoint: [Output only] The network endpoint;
  """

  healths = _messages.MessageField('HealthStatusForNetworkEndpoint', 1, repeated=True)
  networkEndpoint = _messages.MessageField('NetworkEndpoint', 2)


class NetworkInterface(_messages.Message):
  r"""A network interface resource attached to an instance.

  Fields:
    accessConfigs: An array of configurations for this interface. Currently,
      only one access config, ONE_TO_ONE_NAT, is supported. If there are no
      accessConfigs specified, then this instance will have no external
      internet access.
    aliasIpRanges: An array of alias IP ranges for this network interface. You
      can only specify this field for network interfaces in VPC networks.
    fingerprint: Fingerprint hash of contents stored in this network
      interface. This field will be ignored when inserting an Instance or
      adding a NetworkInterface. An up-to-date fingerprint must be provided in
      order to update the NetworkInterface, otherwise the request will fail
      with error 412 conditionNotMet.
    ipv6Address: [Output Only] An IPv6 internal network address for this
      network interface.
    kind: [Output Only] Type of the resource. Always compute#networkInterface
      for network interfaces.
    name: [Output Only] The name of the network interface, which is generated
      by the server. For network devices, these are eth0, eth1, etc.
    network: URL of the network resource for this instance. When creating an
      instance, if neither the network nor the subnetwork is specified, the
      default network global/networks/default is used; if the network is not
      specified but the subnetwork is specified, the network is inferred.  If
      you specify this property, you can specify the network as a full or
      partial URL. For example, the following are all valid URLs:   - https://
      www.googleapis.com/compute/v1/projects/project/global/networks/network
      - projects/project/global/networks/network  - global/networks/default
    networkIP: An IPv4 internal IP address to assign to the instance for this
      network interface. If not specified by the user, an unused internal IP
      is assigned by the system.
    subnetwork: The URL of the Subnetwork resource for this instance. If the
      network resource is in legacy mode, do not specify this field. If the
      network is in auto subnet mode, specifying the subnetwork is optional.
      If the network is in custom subnet mode, specifying the subnetwork is
      required. If you specify this field, you can specify the subnetwork as a
      full or partial URL. For example, the following are all valid URLs:   -
      https://www.googleapis.com/compute/v1/projects/project/regions/region/su
      bnetworks/subnetwork  - regions/region/subnetworks/subnetwork
  """

  accessConfigs = _messages.MessageField('AccessConfig', 1, repeated=True)
  aliasIpRanges = _messages.MessageField('AliasIpRange', 2, repeated=True)
  fingerprint = _messages.BytesField(3)
  ipv6Address = _messages.StringField(4)
  kind = _messages.StringField(5, default=u'compute#networkInterface')
  name = _messages.StringField(6)
  network = _messages.StringField(7)
  networkIP = _messages.StringField(8)
  subnetwork = _messages.StringField(9)


class NetworkList(_messages.Message):
  r"""Contains a list of networks.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Network resources.
    kind: [Output Only] Type of resource. Always compute#networkList for lists
      of networks.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Network', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#networkList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class NetworkPeering(_messages.Message):
  r"""A network peering attached to a network resource. The message includes
  the peering name, peer network, peering state, and a flag indicating whether
  Google Compute Engine should automatically create routes for the peering.

  Enums:
    StateValueValuesEnum: [Output Only] State for the peering, either `ACTIVE`
      or `INACTIVE`. The peering is `ACTIVE` when there's a matching
      configuration in the peer network.

  Fields:
    advertisePeerSubnetsViaRouters: Whether Cloud Routers in this network can
      automatically advertise subnets from the peer network.
    autoCreateRoutes: This field will be deprecated soon. Use the
      exchange_subnet_routes field instead. Indicates whether full mesh
      connectivity is created and managed automatically between peered
      networks. Currently this field should always be true since Google
      Compute Engine will automatically create and manage subnetwork routes
      between two networks when peering state is ACTIVE.
    exchangeSubnetRoutes: Indicates whether full mesh connectivity is created
      and managed automatically between peered networks. Currently this field
      should always be true since Google Compute Engine will automatically
      create and manage subnetwork routes between two networks when peering
      state is ACTIVE.
    exportCustomRoutes: Whether to export the custom routes to peer network.
    exportSubnetRoutesWithPublicIp: Whether subnet routes with public IP range
      are exported. The default value is true, all subnet routes are exported.
      The IPv4 special-use ranges
      (https://en.wikipedia.org/wiki/IPv4#Special_addresses) are always
      exported to peers and are not controlled by this field.
    importCustomRoutes: Whether to import the custom routes from peer network.
    importSubnetRoutesWithPublicIp: Whether subnet routes with public IP range
      are imported. The default value is false. The IPv4 special-use ranges
      (https://en.wikipedia.org/wiki/IPv4#Special_addresses) are always
      imported from peers and are not controlled by this field.
    name: Name of this peering. Provided by the client when the peering is
      created. The name must comply with RFC1035. Specifically, the name must
      be 1-63 characters long and match regular expression
      `[a-z]([-a-z0-9]*[a-z0-9])?`. The first character must be a lowercase
      letter, and all the following characters must be a dash, lowercase
      letter, or digit, except the last character, which cannot be a dash.
    network: The URL of the peer network. It can be either full URL or partial
      URL. The peer network may belong to a different project. If the partial
      URL does not contain project, it is assumed that the peer network is in
      the same project as the current network.
    peerMtu: Maximum Transmission Unit in bytes.
    state: [Output Only] State for the peering, either `ACTIVE` or `INACTIVE`.
      The peering is `ACTIVE` when there's a matching configuration in the
      peer network.
    stateDetails: [Output Only] Details about the current state of the
      peering.
  """

  class StateValueValuesEnum(_messages.Enum):
    r"""[Output Only] State for the peering, either `ACTIVE` or `INACTIVE`.
    The peering is `ACTIVE` when there's a matching configuration in the peer
    network.

    Values:
      ACTIVE: <no description>
      INACTIVE: <no description>
    """
    ACTIVE = 0
    INACTIVE = 1

  advertisePeerSubnetsViaRouters = _messages.BooleanField(1)
  autoCreateRoutes = _messages.BooleanField(2)
  exchangeSubnetRoutes = _messages.BooleanField(3)
  exportCustomRoutes = _messages.BooleanField(4)
  exportSubnetRoutesWithPublicIp = _messages.BooleanField(5)
  importCustomRoutes = _messages.BooleanField(6)
  importSubnetRoutesWithPublicIp = _messages.BooleanField(7)
  name = _messages.StringField(8)
  network = _messages.StringField(9)
  peerMtu = _messages.IntegerField(10, variant=_messages.Variant.INT32)
  state = _messages.EnumField('StateValueValuesEnum', 11)
  stateDetails = _messages.StringField(12)


class NetworkRoutingConfig(_messages.Message):
  r"""A routing configuration attached to a network resource. The message
  includes the list of routers associated with the network, and a flag
  indicating the type of routing behavior to enforce network-wide.

  Enums:
    RoutingModeValueValuesEnum: The network-wide routing mode to use. If set
      to REGIONAL, this network's Cloud Routers will only advertise routes
      with subnets of this network in the same region as the router. If set to
      GLOBAL, this network's Cloud Routers will advertise routes with all
      subnets of this network, across regions.

  Fields:
    routingMode: The network-wide routing mode to use. If set to REGIONAL,
      this network's Cloud Routers will only advertise routes with subnets of
      this network in the same region as the router. If set to GLOBAL, this
      network's Cloud Routers will advertise routes with all subnets of this
      network, across regions.
  """

  class RoutingModeValueValuesEnum(_messages.Enum):
    r"""The network-wide routing mode to use. If set to REGIONAL, this
    network's Cloud Routers will only advertise routes with subnets of this
    network in the same region as the router. If set to GLOBAL, this network's
    Cloud Routers will advertise routes with all subnets of this network,
    across regions.

    Values:
      GLOBAL: <no description>
      REGIONAL: <no description>
    """
    GLOBAL = 0
    REGIONAL = 1

  routingMode = _messages.EnumField('RoutingModeValueValuesEnum', 1)


class NetworksAddPeeringRequest(_messages.Message):
  r"""A NetworksAddPeeringRequest object.

  Fields:
    autoCreateRoutes: This field will be deprecated soon. Use
      exchange_subnet_routes in network_peering instead. Indicates whether
      full mesh connectivity is created and managed automatically between
      peered networks. Currently this field should always be true since Google
      Compute Engine will automatically create and manage subnetwork routes
      between two networks when peering state is ACTIVE.
    exportCustomRoutes: This field will be deprecated soon. Use
      export_custom_routes in network_peering instead. Whether to export the
      custom routes to peer network.
    importCustomRoutes: This field will be deprecated soon. Use
      import_custom_routes in network_peering instead. Whether to import the
      custom routes from peer network.
    name: Name of the peering, which should conform to RFC1035.
    networkPeering: Network peering parameters. In order to specify route
      policies for peering using import and export custom routes, you must
      specify all peering related parameters (name, peer network,
      exchange_subnet_routes) in the network_peering field. The corresponding
      fields in NetworksAddPeeringRequest will be deprecated soon.
    peerNetwork: URL of the peer network. It can be either full URL or partial
      URL. The peer network may belong to a different project. If the partial
      URL does not contain project, it is assumed that the peer network is in
      the same project as the current network.
  """

  autoCreateRoutes = _messages.BooleanField(1)
  exportCustomRoutes = _messages.BooleanField(2)
  importCustomRoutes = _messages.BooleanField(3)
  name = _messages.StringField(4)
  networkPeering = _messages.MessageField('NetworkPeering', 5)
  peerNetwork = _messages.StringField(6)


class NetworksGetEffectiveFirewallsResponse(_messages.Message):
  r"""A NetworksGetEffectiveFirewallsResponse object.

  Fields:
    firewalls: Effective firewalls on the network.
    organizationFirewalls: Effective firewalls from organization policies.
  """

  firewalls = _messages.MessageField('Firewall', 1, repeated=True)
  organizationFirewalls = _messages.MessageField('NetworksGetEffectiveFirewallsResponseOrganizationFirewallPolicy', 2, repeated=True)


class NetworksGetEffectiveFirewallsResponseOrganizationFirewallPolicy(_messages.Message):
  r"""A pruned SecurityPolicy containing ID and any applicable firewall rules.

  Fields:
    id: [Output Only] The unique identifier for the security policy. This
      identifier is defined by the server.
    rules: The rules that apply to the network.
  """

  id = _messages.IntegerField(1, variant=_messages.Variant.UINT64)
  rules = _messages.MessageField('SecurityPolicyRule', 2, repeated=True)


class NetworksRemovePeeringRequest(_messages.Message):
  r"""A NetworksRemovePeeringRequest object.

  Fields:
    name: Name of the peering, which should conform to RFC1035.
  """

  name = _messages.StringField(1)


class NetworksUpdatePeeringRequest(_messages.Message):
  r"""A NetworksUpdatePeeringRequest object.

  Fields:
    networkPeering: A NetworkPeering attribute.
  """

  networkPeering = _messages.MessageField('NetworkPeering', 1)


class NodeGroup(_messages.Message):
  r"""Represent a sole-tenant Node Group resource.  A sole-tenant node is a
  physical server that is dedicated to hosting VM instances only for your
  specific project. Use sole-tenant nodes to keep your instances physically
  separated from instances in other projects, or to group your instances
  together on the same host hardware. For more information, read Sole-tenant
  nodes. (== resource_for {$api_version}.nodeGroups ==)

  Enums:
    MaintenancePolicyValueValuesEnum: Specifies how to handle instances when a
      node in the group undergoes maintenance.
    StatusValueValuesEnum:

  Fields:
    autoscalingPolicy: Specifies how autoscaling should behave.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    fingerprint: A byte attribute.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] The type of the resource. Always compute#nodeGroup for
      node group.
    locationHint: An opaque location hint used to place the Node close to
      other resources. This field is for use by internal tools that use the
      public API. The location hint here on the NodeGroup overrides any
      location_hint present in the NodeTemplate.
    maintenancePolicy: Specifies how to handle instances when a node in the
      group undergoes maintenance.
    maintenanceWindow: A NodeGroupMaintenanceWindow attribute.
    name: The name of the resource, provided by the client when initially
      creating the resource. The resource name must be 1-63 characters long,
      and comply with RFC1035. Specifically, the name must be 1-63 characters
      long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which
      means the first character must be a lowercase letter, and all following
      characters must be a dash, lowercase letter, or digit, except the last
      character, which cannot be a dash.
    nodeTemplate: The URL of the node template to which this node group
      belongs.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    size: [Output Only] The total number of nodes in the node group.
    status: A StatusValueValuesEnum attribute.
    zone: [Output Only] The name of the zone where the node group resides,
      such as us-central1-a.
  """

  class MaintenancePolicyValueValuesEnum(_messages.Enum):
    r"""Specifies how to handle instances when a node in the group undergoes
    maintenance.

    Values:
      DEFAULT: <no description>
      MAINTENANCE_POLICY_UNSPECIFIED: <no description>
      MIGRATE_WITHIN_NODE_GROUP: <no description>
      RESTART_IN_PLACE: <no description>
    """
    DEFAULT = 0
    MAINTENANCE_POLICY_UNSPECIFIED = 1
    MIGRATE_WITHIN_NODE_GROUP = 2
    RESTART_IN_PLACE = 3

  class StatusValueValuesEnum(_messages.Enum):
    r"""StatusValueValuesEnum enum type.

    Values:
      CREATING: <no description>
      DELETING: <no description>
      INVALID: <no description>
      READY: <no description>
    """
    CREATING = 0
    DELETING = 1
    INVALID = 2
    READY = 3

  autoscalingPolicy = _messages.MessageField('NodeGroupAutoscalingPolicy', 1)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  fingerprint = _messages.BytesField(4)
  id = _messages.IntegerField(5, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(6, default=u'compute#nodeGroup')
  locationHint = _messages.StringField(7)
  maintenancePolicy = _messages.EnumField('MaintenancePolicyValueValuesEnum', 8)
  maintenanceWindow = _messages.MessageField('NodeGroupMaintenanceWindow', 9)
  name = _messages.StringField(10)
  nodeTemplate = _messages.StringField(11)
  selfLink = _messages.StringField(12)
  selfLinkWithId = _messages.StringField(13)
  size = _messages.IntegerField(14, variant=_messages.Variant.INT32)
  status = _messages.EnumField('StatusValueValuesEnum', 15)
  zone = _messages.StringField(16)


class NodeGroupAggregatedList(_messages.Message):
  r"""A NodeGroupAggregatedList object.

  Messages:
    ItemsValue: A list of NodeGroupsScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of NodeGroupsScopedList resources.
    kind: [Output Only] Type of resource.Always
      compute#nodeGroupAggregatedList for aggregated lists of node groups.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of NodeGroupsScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of node groups.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A NodeGroupsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('NodeGroupsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#nodeGroupAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class NodeGroupAutoscalingPolicy(_messages.Message):
  r"""A NodeGroupAutoscalingPolicy object.

  Enums:
    ModeValueValuesEnum: The autoscaling mode.

  Fields:
    maxNodes: The maximum number of nodes that the group should have.
    minNodes: The minimum number of nodes that the group should have.
    mode: The autoscaling mode.
  """

  class ModeValueValuesEnum(_messages.Enum):
    r"""The autoscaling mode.

    Values:
      MODE_UNSPECIFIED: <no description>
      OFF: <no description>
      ON: <no description>
      ONLY_SCALE_OUT: <no description>
    """
    MODE_UNSPECIFIED = 0
    OFF = 1
    ON = 2
    ONLY_SCALE_OUT = 3

  maxNodes = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  minNodes = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  mode = _messages.EnumField('ModeValueValuesEnum', 3)


class NodeGroupList(_messages.Message):
  r"""Contains a list of nodeGroups.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of NodeGroup resources.
    kind: [Output Only] Type of resource.Always compute#nodeGroupList for
      lists of node groups.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('NodeGroup', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#nodeGroupList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class NodeGroupMaintenanceWindow(_messages.Message):
  r"""Time window specified for daily maintenance operations. GCE's internal
  maintenance will be performed within this window.

  Fields:
    duration: [Output only] A predetermined duration for the window,
      automatically chosen to be the smallest possible in the given scenario.
    startTime: Start time of the window. This must be in UTC format that
      resolves to one of 00:00, 04:00, 08:00, 12:00, 16:00, or 20:00. For
      example, both 13:00-5 and 08:00 are valid.
  """

  duration = _messages.StringField(1)
  startTime = _messages.StringField(2)


class NodeGroupNode(_messages.Message):
  r"""A NodeGroupNode object.

  Enums:
    CpuOvercommitTypeValueValuesEnum: CPU overcommit.
    StatusValueValuesEnum:

  Fields:
    accelerators: Accelerators for this node.
    cpuOvercommitType: CPU overcommit.
    disks: Local disk configurations.
    instances: Instances scheduled on this node.
    name: The name of the node.
    nodeType: The type of this node.
    serverBinding: Binding properties for the physical server.
    serverId: Server ID associated with this node.
    status: A StatusValueValuesEnum attribute.
  """

  class CpuOvercommitTypeValueValuesEnum(_messages.Enum):
    r"""CPU overcommit.

    Values:
      CPU_OVERCOMMIT_TYPE_UNSPECIFIED: <no description>
      ENABLED: <no description>
      NONE: <no description>
    """
    CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 0
    ENABLED = 1
    NONE = 2

  class StatusValueValuesEnum(_messages.Enum):
    r"""StatusValueValuesEnum enum type.

    Values:
      CREATING: <no description>
      DELETING: <no description>
      INVALID: <no description>
      READY: <no description>
      REPAIRING: <no description>
    """
    CREATING = 0
    DELETING = 1
    INVALID = 2
    READY = 3
    REPAIRING = 4

  accelerators = _messages.MessageField('AcceleratorConfig', 1, repeated=True)
  cpuOvercommitType = _messages.EnumField('CpuOvercommitTypeValueValuesEnum', 2)
  disks = _messages.MessageField('LocalDisk', 3, repeated=True)
  instances = _messages.StringField(4, repeated=True)
  name = _messages.StringField(5)
  nodeType = _messages.StringField(6)
  serverBinding = _messages.MessageField('ServerBinding', 7)
  serverId = _messages.StringField(8)
  status = _messages.EnumField('StatusValueValuesEnum', 9)


class NodeGroupsAddNodesRequest(_messages.Message):
  r"""A NodeGroupsAddNodesRequest object.

  Fields:
    additionalNodeCount: Count of additional nodes to be added to the node
      group.
  """

  additionalNodeCount = _messages.IntegerField(1, variant=_messages.Variant.INT32)


class NodeGroupsDeleteNodesRequest(_messages.Message):
  r"""A NodeGroupsDeleteNodesRequest object.

  Fields:
    nodes: Names of the nodes to delete.
  """

  nodes = _messages.StringField(1, repeated=True)


class NodeGroupsListNodes(_messages.Message):
  r"""A NodeGroupsListNodes object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Node resources.
    kind: [Output Only] The resource type, which is always
      compute.nodeGroupsListNodes for the list of nodes in the specified node
      group.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('NodeGroupNode', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#nodeGroupsListNodes')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class NodeGroupsScopedList(_messages.Message):
  r"""A NodeGroupsScopedList object.

  Messages:
    WarningValue: [Output Only] An informational warning that appears when the
      nodeGroup list is empty.

  Fields:
    nodeGroups: [Output Only] A list of node groups contained in this scope.
    warning: [Output Only] An informational warning that appears when the
      nodeGroup list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] An informational warning that appears when the nodeGroup
    list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  nodeGroups = _messages.MessageField('NodeGroup', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class NodeGroupsSetNodeTemplateRequest(_messages.Message):
  r"""A NodeGroupsSetNodeTemplateRequest object.

  Fields:
    nodeTemplate: Full or partial URL of the node template resource to be
      updated for this node group.
  """

  nodeTemplate = _messages.StringField(1)


class NodeTemplate(_messages.Message):
  r"""Represent a sole-tenant Node Template resource.  You can use a template
  to define properties for nodes in a node group. For more information, read
  Creating node groups and instances. (== resource_for
  {$api_version}.nodeTemplates ==) (== NextID: 19 ==)

  Enums:
    CpuOvercommitTypeValueValuesEnum: CPU overcommit.
    StatusValueValuesEnum: [Output Only] The status of the node template. One
      of the following values: CREATING, READY, and DELETING.

  Messages:
    NodeAffinityLabelsValue: Labels to use for node affinity, which will be
      used in instance scheduling.

  Fields:
    accelerators: A AcceleratorConfig attribute.
    cpuOvercommitType: CPU overcommit.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    disks: A LocalDisk attribute.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] The type of the resource. Always compute#nodeTemplate
      for node templates.
    name: The name of the resource, provided by the client when initially
      creating the resource. The resource name must be 1-63 characters long,
      and comply with RFC1035. Specifically, the name must be 1-63 characters
      long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which
      means the first character must be a lowercase letter, and all following
      characters must be a dash, lowercase letter, or digit, except the last
      character, which cannot be a dash.
    nodeAffinityLabels: Labels to use for node affinity, which will be used in
      instance scheduling.
    nodeType: The node type to use for nodes group that are created from this
      template.
    nodeTypeFlexibility: The flexible properties of the desired node type.
      Node groups that use this node template will create nodes of a type that
      matches these properties.  This field is mutually exclusive with the
      node_type property; you can only define one or the other, but not both.
    region: [Output Only] The name of the region where the node template
      resides, such as us-central1.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    serverBinding: Sets the binding properties for the physical server. Valid
      values include:   - [Default] RESTART_NODE_ON_ANY_SERVER: Restarts VMs
      on any available physical server  - RESTART_NODE_ON_MINIMAL_SERVER:
      Restarts VMs on the same physical server whenever possible    See Sole-
      tenant node options for more information.
    status: [Output Only] The status of the node template. One of the
      following values: CREATING, READY, and DELETING.
    statusMessage: [Output Only] An optional, human-readable explanation of
      the status.
  """

  class CpuOvercommitTypeValueValuesEnum(_messages.Enum):
    r"""CPU overcommit.

    Values:
      CPU_OVERCOMMIT_TYPE_UNSPECIFIED: <no description>
      ENABLED: <no description>
      NONE: <no description>
    """
    CPU_OVERCOMMIT_TYPE_UNSPECIFIED = 0
    ENABLED = 1
    NONE = 2

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the node template. One of the following
    values: CREATING, READY, and DELETING.

    Values:
      CREATING: <no description>
      DELETING: <no description>
      INVALID: <no description>
      READY: <no description>
    """
    CREATING = 0
    DELETING = 1
    INVALID = 2
    READY = 3

  @encoding.MapUnrecognizedFields('additionalProperties')
  class NodeAffinityLabelsValue(_messages.Message):
    r"""Labels to use for node affinity, which will be used in instance
    scheduling.

    Messages:
      AdditionalProperty: An additional property for a NodeAffinityLabelsValue
        object.

    Fields:
      additionalProperties: Additional properties of type
        NodeAffinityLabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a NodeAffinityLabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  accelerators = _messages.MessageField('AcceleratorConfig', 1, repeated=True)
  cpuOvercommitType = _messages.EnumField('CpuOvercommitTypeValueValuesEnum', 2)
  creationTimestamp = _messages.StringField(3)
  description = _messages.StringField(4)
  disks = _messages.MessageField('LocalDisk', 5, repeated=True)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(7, default=u'compute#nodeTemplate')
  name = _messages.StringField(8)
  nodeAffinityLabels = _messages.MessageField('NodeAffinityLabelsValue', 9)
  nodeType = _messages.StringField(10)
  nodeTypeFlexibility = _messages.MessageField('NodeTemplateNodeTypeFlexibility', 11)
  region = _messages.StringField(12)
  selfLink = _messages.StringField(13)
  selfLinkWithId = _messages.StringField(14)
  serverBinding = _messages.MessageField('ServerBinding', 15)
  status = _messages.EnumField('StatusValueValuesEnum', 16)
  statusMessage = _messages.StringField(17)


class NodeTemplateAggregatedList(_messages.Message):
  r"""A NodeTemplateAggregatedList object.

  Messages:
    ItemsValue: A list of NodeTemplatesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of NodeTemplatesScopedList resources.
    kind: [Output Only] Type of resource.Always
      compute#nodeTemplateAggregatedList for aggregated lists of node
      templates.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of NodeTemplatesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of node templates.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A NodeTemplatesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('NodeTemplatesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#nodeTemplateAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class NodeTemplateList(_messages.Message):
  r"""Contains a list of node templates.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of NodeTemplate resources.
    kind: [Output Only] Type of resource.Always compute#nodeTemplateList for
      lists of node templates.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('NodeTemplate', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#nodeTemplateList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class NodeTemplateNodeTypeFlexibility(_messages.Message):
  r"""A NodeTemplateNodeTypeFlexibility object.

  Fields:
    cpus: A string attribute.
    localSsd: A string attribute.
    memory: A string attribute.
  """

  cpus = _messages.StringField(1)
  localSsd = _messages.StringField(2)
  memory = _messages.StringField(3)


class NodeTemplatesScopedList(_messages.Message):
  r"""A NodeTemplatesScopedList object.

  Messages:
    WarningValue: [Output Only] An informational warning that appears when the
      node templates list is empty.

  Fields:
    nodeTemplates: [Output Only] A list of node templates contained in this
      scope.
    warning: [Output Only] An informational warning that appears when the node
      templates list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] An informational warning that appears when the node
    templates list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  nodeTemplates = _messages.MessageField('NodeTemplate', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class NodeType(_messages.Message):
  r"""Represent a sole-tenant Node Type resource.  Each node within a node
  group must have a node type. A node type specifies the total amount of cores
  and memory for that node. Currently, the only available node type is
  n1-node-96-624 node type that has 96 vCPUs and 624 GB of memory, available
  in multiple zones. For more information read Node types. (== resource_for
  {$api_version}.nodeTypes ==)

  Fields:
    cpuPlatform: [Output Only] The CPU platform used by this node type.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    deprecated: [Output Only] The deprecation status associated with this node
      type.
    description: [Output Only] An optional textual description of the
      resource.
    guestCpus: [Output Only] The number of virtual CPUs that are available to
      the node type.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] The type of the resource. Always compute#nodeType for
      node types.
    localSsdGb: [Output Only] Local SSD available to the node type, defined in
      GB.
    memoryMb: [Output Only] The amount of physical memory available to the
      node type, defined in MB.
    name: [Output Only] Name of the resource.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    zone: [Output Only] The name of the zone where the node type resides, such
      as us-central1-a.
  """

  cpuPlatform = _messages.StringField(1)
  creationTimestamp = _messages.StringField(2)
  deprecated = _messages.MessageField('DeprecationStatus', 3)
  description = _messages.StringField(4)
  guestCpus = _messages.IntegerField(5, variant=_messages.Variant.INT32)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(7, default=u'compute#nodeType')
  localSsdGb = _messages.IntegerField(8, variant=_messages.Variant.INT32)
  memoryMb = _messages.IntegerField(9, variant=_messages.Variant.INT32)
  name = _messages.StringField(10)
  selfLink = _messages.StringField(11)
  selfLinkWithId = _messages.StringField(12)
  zone = _messages.StringField(13)


class NodeTypeAggregatedList(_messages.Message):
  r"""A NodeTypeAggregatedList object.

  Messages:
    ItemsValue: A list of NodeTypesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of NodeTypesScopedList resources.
    kind: [Output Only] Type of resource.Always compute#nodeTypeAggregatedList
      for aggregated lists of node types.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of NodeTypesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of node types.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A NodeTypesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('NodeTypesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#nodeTypeAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class NodeTypeList(_messages.Message):
  r"""Contains a list of node types.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of NodeType resources.
    kind: [Output Only] Type of resource.Always compute#nodeTypeList for lists
      of node types.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('NodeType', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#nodeTypeList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class NodeTypesScopedList(_messages.Message):
  r"""A NodeTypesScopedList object.

  Messages:
    WarningValue: [Output Only] An informational warning that appears when the
      node types list is empty.

  Fields:
    nodeTypes: [Output Only] A list of node types contained in this scope.
    warning: [Output Only] An informational warning that appears when the node
      types list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] An informational warning that appears when the node
    types list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  nodeTypes = _messages.MessageField('NodeType', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class NotificationEndpoint(_messages.Message):
  r"""Represents a notification endpoint.  A notification endpoint resource
  defines an endpoint to receive notifications when there are status changes
  detected by the associated health check service.  For more information, see
  Health checks overview. (== resource_for {$api_version}.notificationEndpoint
  ==) (== resource_for {$api_version}.regionNotificationEndpoints ==)

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    grpcSettings: Settings of the gRPC notification endpoint including the
      endpoint URL and the retry duration.
    id: [Output Only] A unique identifier for this resource type. The server
      generates this identifier.
    kind: [Output Only] Type of the resource. Always
      compute#notificationEndpoint for notification endpoints.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    region: [Output Only] URL of the region where the notification endpoint
      resides. This field applies only to the regional resource. You must
      specify this field as part of the HTTP request URL. It is not settable
      as a field in the request body.
    selfLink: [Output Only] Server-defined URL for the resource.
  """

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  grpcSettings = _messages.MessageField('NotificationEndpointGrpcSettings', 3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default=u'compute#notificationEndpoint')
  name = _messages.StringField(6)
  region = _messages.StringField(7)
  selfLink = _messages.StringField(8)


class NotificationEndpointGrpcSettings(_messages.Message):
  r"""Represents a gRPC setting that describes one gRPC notification endpoint
  and the retry duration attempting to send notification to this endpoint.

  Fields:
    authority: Optional. If specified, this field is used to set the authority
      header by the sender of notifications. See
      https://tools.ietf.org/html/rfc7540#section-8.1.2.3
    endpoint: Endpoint to which gRPC notifications are sent. This must be a
      valid gRPCLB DNS name.
    payloadName: Optional. If specified, this field is used to populate the
      "name" field in gRPC requests.
    resendInterval: Optional. This field is used to configure how often to
      send a full update of all non-healthy backends. If unspecified, full
      updates are not sent. If specified, must be in the range between 600
      seconds to 3600 seconds. Nanos are disallowed.
    retryDurationSec: How much time (in seconds) is spent attempting
      notification retries until a successful response is received. Default is
      30s. Limit is 20m (1200s). Must be a positive number.
  """

  authority = _messages.StringField(1)
  endpoint = _messages.StringField(2)
  payloadName = _messages.StringField(3)
  resendInterval = _messages.MessageField('Duration', 4)
  retryDurationSec = _messages.IntegerField(5, variant=_messages.Variant.UINT32)


class NotificationEndpointList(_messages.Message):
  r"""A NotificationEndpointList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of NotificationEndpoint resources.
    kind: [Output Only] Type of the resource. Always
      compute#notificationEndpoint for notification endpoints.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('NotificationEndpoint', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#notificationEndpointList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class Operation(_messages.Message):
  r"""Represents an Operation resource.  Google Compute Engine has three
  Operation resources:  *
  [Global](/compute/docs/reference/rest/{$api_version}/globalOperations) *
  [Regional](/compute/docs/reference/rest/{$api_version}/regionOperations) *
  [Zonal](/compute/docs/reference/rest/{$api_version}/zoneOperations)  You can
  use an operation resource to manage asynchronous API requests. For more
  information, read Handling API responses.  Operations can be global,
  regional or zonal.   - For global operations, use the `globalOperations`
  resource.  - For regional operations, use the `regionOperations` resource.
  - For zonal operations, use the `zonalOperations` resource.    For more
  information, read  Global, Regional, and Zonal Resources. (== resource_for
  {$api_version}.globalOperations ==) (== resource_for
  {$api_version}.regionOperations ==) (== resource_for
  {$api_version}.zoneOperations ==)

  Enums:
    StatusValueValuesEnum: [Output Only] The status of the operation, which
      can be one of the following: `PENDING`, `RUNNING`, or `DONE`.

  Messages:
    ErrorValue: [Output Only] If errors are generated during processing of the
      operation, this field will be populated.
    WarningsValueListEntry: A WarningsValueListEntry object.

  Fields:
    clientOperationId: [Output Only] The value of `requestId` if you provided
      it in the request. Not present otherwise.
    creationTimestamp: [Deprecated] This field is deprecated.
    description: [Output Only] A textual description of the operation, which
      is set when the operation is created.
    endTime: [Output Only] The time that this operation was completed. This
      value is in RFC3339 text format.
    error: [Output Only] If errors are generated during processing of the
      operation, this field will be populated.
    httpErrorMessage: [Output Only] If the operation fails, this field
      contains the HTTP error message that was returned, such as `NOT FOUND`.
    httpErrorStatusCode: [Output Only] If the operation fails, this field
      contains the HTTP error status code that was returned. For example, a
      `404` means the resource was not found.
    id: [Output Only] The unique identifier for the operation. This identifier
      is defined by the server.
    insertTime: [Output Only] The time that this operation was requested. This
      value is in RFC3339 text format.
    kind: [Output Only] Type of the resource. Always `compute#operation` for
      Operation resources.
    name: [Output Only] Name of the operation.
    operationType: [Output Only] The type of operation, such as `insert`,
      `update`, or `delete`, and so on.
    progress: [Output Only] An optional progress indicator that ranges from 0
      to 100. There is no requirement that this be linear or support any
      granularity of operations. This should not be used to guess when the
      operation will be complete. This number should monotonically increase as
      the operation progresses.
    region: [Output Only] The URL of the region where the operation resides.
      Only applicable when performing regional operations.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    startTime: [Output Only] The time that this operation was started by the
      server. This value is in RFC3339 text format.
    status: [Output Only] The status of the operation, which can be one of the
      following: `PENDING`, `RUNNING`, or `DONE`.
    statusMessage: [Output Only] An optional textual description of the
      current status of the operation.
    targetId: [Output Only] The unique target ID, which identifies a specific
      incarnation of the target resource.
    targetLink: [Output Only] The URL of the resource that the operation
      modifies. For operations related to creating a snapshot, this points to
      the persistent disk that the snapshot was created from.
    user: [Output Only] User who requested the operation, for example:
      `user@example.com`.
    warnings: [Output Only] If warning messages are generated during
      processing of the operation, this field will be populated.
    zone: [Output Only] The URL of the zone where the operation resides. Only
      applicable when performing per-zone operations.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the operation, which can be one of the
    following: `PENDING`, `RUNNING`, or `DONE`.

    Values:
      DONE: <no description>
      PENDING: <no description>
      RUNNING: <no description>
    """
    DONE = 0
    PENDING = 1
    RUNNING = 2

  class ErrorValue(_messages.Message):
    r"""[Output Only] If errors are generated during processing of the
    operation, this field will be populated.

    Messages:
      ErrorsValueListEntry: A ErrorsValueListEntry object.

    Fields:
      errors: [Output Only] The array of errors encountered while processing
        this operation.
    """

    class ErrorsValueListEntry(_messages.Message):
      r"""A ErrorsValueListEntry object.

      Fields:
        code: [Output Only] The error type identifier for this error.
        location: [Output Only] Indicates the field in the request that caused
          the error. This property is optional.
        message: [Output Only] An optional, human-readable error message.
      """

      code = _messages.StringField(1)
      location = _messages.StringField(2)
      message = _messages.StringField(3)

    errors = _messages.MessageField('ErrorsValueListEntry', 1, repeated=True)

  class WarningsValueListEntry(_messages.Message):
    r"""A WarningsValueListEntry object.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  clientOperationId = _messages.StringField(1)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  endTime = _messages.StringField(4)
  error = _messages.MessageField('ErrorValue', 5)
  httpErrorMessage = _messages.StringField(6)
  httpErrorStatusCode = _messages.IntegerField(7, variant=_messages.Variant.INT32)
  id = _messages.IntegerField(8, variant=_messages.Variant.UINT64)
  insertTime = _messages.StringField(9)
  kind = _messages.StringField(10, default=u'compute#operation')
  name = _messages.StringField(11)
  operationType = _messages.StringField(12)
  progress = _messages.IntegerField(13, variant=_messages.Variant.INT32)
  region = _messages.StringField(14)
  selfLink = _messages.StringField(15)
  selfLinkWithId = _messages.StringField(16)
  startTime = _messages.StringField(17)
  status = _messages.EnumField('StatusValueValuesEnum', 18)
  statusMessage = _messages.StringField(19)
  targetId = _messages.IntegerField(20, variant=_messages.Variant.UINT64)
  targetLink = _messages.StringField(21)
  user = _messages.StringField(22)
  warnings = _messages.MessageField('WarningsValueListEntry', 23, repeated=True)
  zone = _messages.StringField(24)


class OperationAggregatedList(_messages.Message):
  r"""A OperationAggregatedList object.

  Messages:
    ItemsValue: [Output Only] A map of scoped operation lists.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    items: [Output Only] A map of scoped operation lists.
    kind: [Output Only] Type of resource. Always
      `compute#operationAggregatedList` for aggregated lists of operations.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      `maxResults`, use the `nextPageToken` as a value for the query parameter
      `pageToken` in the next list request. Subsequent list requests will have
      their own `nextPageToken` to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""[Output Only] A map of scoped operation lists.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of operations.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A OperationsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('OperationsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#operationAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class OperationList(_messages.Message):
  r"""Contains a list of Operation resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    items: [Output Only] A list of Operation resources.
    kind: [Output Only] Type of resource. Always `compute#operations` for
      Operations resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      `maxResults`, use the `nextPageToken` as a value for the query parameter
      `pageToken` in the next list request. Subsequent list requests will have
      their own `nextPageToken` to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Operation', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#operationList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class OperationsScopedList(_messages.Message):
  r"""A OperationsScopedList object.

  Messages:
    WarningValue: [Output Only] Informational warning which replaces the list
      of operations when the list is empty.

  Fields:
    operations: [Output Only] A list of operations contained in this scope.
    warning: [Output Only] Informational warning which replaces the list of
      operations when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning which replaces the list of
    operations when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  operations = _messages.MessageField('Operation', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class OrganizationSecurityPoliciesListAssociationsResponse(_messages.Message):
  r"""A OrganizationSecurityPoliciesListAssociationsResponse object.

  Fields:
    associations: A list of associations.
    kind: [Output Only] Type of securityPolicy associations. Always
      compute#organizationSecurityPoliciesListAssociations for lists of
      securityPolicy associations.
  """

  associations = _messages.MessageField('SecurityPolicyAssociation', 1, repeated=True)
  kind = _messages.StringField(2, default=u'compute#organizationSecurityPoliciesListAssociationsResponse')


class OriginAuthenticationMethod(_messages.Message):
  r"""[Deprecated] Configuration for the origin authentication method.
  Configuration for the origin authentication method.

  Fields:
    jwt: A Jwt attribute.
  """

  jwt = _messages.MessageField('Jwt', 1)


class OutlierDetection(_messages.Message):
  r"""Settings controlling the eviction of unhealthy hosts from the load
  balancing pool for the backend service.

  Fields:
    baseEjectionTime: The base time that a host is ejected for. The real
      ejection time is equal to the base ejection time multiplied by the
      number of times the host has been ejected. Defaults to 30000ms or 30s.
    consecutiveErrors: Number of errors before a host is ejected from the
      connection pool. When the backend host is accessed over HTTP, a 5xx
      return code qualifies as an error. Defaults to 5.
    consecutiveGatewayFailure: The number of consecutive gateway failures
      (502, 503, 504 status or connection errors that are mapped to one of
      those status codes) before a consecutive gateway failure ejection
      occurs. Defaults to 3.
    enforcingConsecutiveErrors: The percentage chance that a host will be
      actually ejected when an outlier status is detected through consecutive
      5xx. This setting can be used to disable ejection or to ramp it up
      slowly. Defaults to 0.
    enforcingConsecutiveGatewayFailure: The percentage chance that a host will
      be actually ejected when an outlier status is detected through
      consecutive gateway failures. This setting can be used to disable
      ejection or to ramp it up slowly. Defaults to 100.
    enforcingSuccessRate: The percentage chance that a host will be actually
      ejected when an outlier status is detected through success rate
      statistics. This setting can be used to disable ejection or to ramp it
      up slowly. Defaults to 100.
    interval: Time interval between ejection analysis sweeps. This can result
      in both new ejections as well as hosts being returned to service.
      Defaults to 1 second.
    maxEjectionPercent: Maximum percentage of hosts in the load balancing pool
      for the backend service that can be ejected. Defaults to 50%.
    successRateMinimumHosts: The number of hosts in a cluster that must have
      enough request volume to detect success rate outliers. If the number of
      hosts is less than this setting, outlier detection via success rate
      statistics is not performed for any host in the cluster. Defaults to 5.
    successRateRequestVolume: The minimum number of total requests that must
      be collected in one interval (as defined by the interval duration above)
      to include this host in success rate based outlier detection. If the
      volume is lower than this setting, outlier detection via success rate
      statistics is not performed for that host. Defaults to 100.
    successRateStdevFactor: This factor is used to determine the ejection
      threshold for success rate outlier ejection. The ejection threshold is
      the difference between the mean success rate, and the product of this
      factor and the standard deviation of the mean success rate: mean -
      (stdev * success_rate_stdev_factor). This factor is divided by a
      thousand to get a double. That is, if the desired factor is 1.9, the
      runtime value should be 1900. Defaults to 1900.
  """

  baseEjectionTime = _messages.MessageField('Duration', 1)
  consecutiveErrors = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  consecutiveGatewayFailure = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  enforcingConsecutiveErrors = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  enforcingConsecutiveGatewayFailure = _messages.IntegerField(5, variant=_messages.Variant.INT32)
  enforcingSuccessRate = _messages.IntegerField(6, variant=_messages.Variant.INT32)
  interval = _messages.MessageField('Duration', 7)
  maxEjectionPercent = _messages.IntegerField(8, variant=_messages.Variant.INT32)
  successRateMinimumHosts = _messages.IntegerField(9, variant=_messages.Variant.INT32)
  successRateRequestVolume = _messages.IntegerField(10, variant=_messages.Variant.INT32)
  successRateStdevFactor = _messages.IntegerField(11, variant=_messages.Variant.INT32)


class PacketIntervals(_messages.Message):
  r"""Next free: 7

  Enums:
    DurationValueValuesEnum: From how long ago in the past these intervals
      were observed.
    TypeValueValuesEnum: The type of packets for which inter-packet intervals
      were computed.

  Fields:
    avgMs: Average observed inter-packet interval in milliseconds.
    duration: From how long ago in the past these intervals were observed.
    maxMs: Maximum observed inter-packet interval in milliseconds.
    minMs: Minimum observed inter-packet interval in milliseconds.
    numIntervals: Number of inter-packet intervals from which these statistics
      were derived.
    type: The type of packets for which inter-packet intervals were computed.
  """

  class DurationValueValuesEnum(_messages.Enum):
    r"""From how long ago in the past these intervals were observed.

    Values:
      DURATION_UNSPECIFIED: <no description>
      HOUR: <no description>
      MAX: <no description>
      MINUTE: <no description>
    """
    DURATION_UNSPECIFIED = 0
    HOUR = 1
    MAX = 2
    MINUTE = 3

  class TypeValueValuesEnum(_messages.Enum):
    r"""The type of packets for which inter-packet intervals were computed.

    Values:
      LOOPBACK: <no description>
      RECEIVE: <no description>
      TRANSMIT: <no description>
      TYPE_UNSPECIFIED: <no description>
    """
    LOOPBACK = 0
    RECEIVE = 1
    TRANSMIT = 2
    TYPE_UNSPECIFIED = 3

  avgMs = _messages.IntegerField(1)
  duration = _messages.EnumField('DurationValueValuesEnum', 2)
  maxMs = _messages.IntegerField(3)
  minMs = _messages.IntegerField(4)
  numIntervals = _messages.IntegerField(5)
  type = _messages.EnumField('TypeValueValuesEnum', 6)


class PacketMirroring(_messages.Message):
  r"""Represents a Packet Mirroring resource.  Packet Mirroring clones the
  traffic of specified instances in your Virtual Private Cloud (VPC) network
  and forwards it to a collector destination, such as an instance group of an
  internal TCP/UDP load balancer, for analysis or examination. For more
  information about setting up Packet Mirroring, see Using Packet Mirroring.
  (== resource_for {$api_version}.packetMirrorings ==)

  Enums:
    EnableValueValuesEnum: Indicates whether or not this packet mirroring
      takes effect. If set to FALSE, this packet mirroring policy will not be
      enforced on the network.  The default is TRUE.

  Fields:
    collectorIlb: The Forwarding Rule resource of type
      loadBalancingScheme=INTERNAL that will be used as collector for mirrored
      traffic. The specified forwarding rule must have isMirroringCollector
      set to true.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    enable: Indicates whether or not this packet mirroring takes effect. If
      set to FALSE, this packet mirroring policy will not be enforced on the
      network.  The default is TRUE.
    filter: Filter for mirrored traffic. If unspecified, all traffic is
      mirrored.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#packetMirroring
      for packet mirrorings.
    mirroredResources: PacketMirroring mirroredResourceInfos.
      MirroredResourceInfo specifies a set of mirrored VM instances,
      subnetworks and/or tags for which traffic from/to all VM instances will
      be mirrored.
    name: Name of the resource; provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    network: Specifies the mirrored VPC network. Only packets in this network
      will be mirrored. All mirrored VMs should have a NIC in the given
      network. All mirrored subnetworks should belong to the given network.
    priority: The priority of applying this configuration. Priority is used to
      break ties in cases where there is more than one matching rule. In the
      case of two rules that apply for a given Instance, the one with the
      lowest-numbered priority value wins.  Default value is 1000. Valid range
      is 0 through 65535.
    region: [Output Only] URI of the region where the packetMirroring resides.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
  """

  class EnableValueValuesEnum(_messages.Enum):
    r"""Indicates whether or not this packet mirroring takes effect. If set to
    FALSE, this packet mirroring policy will not be enforced on the network.
    The default is TRUE.

    Values:
      FALSE: <no description>
      TRUE: <no description>
    """
    FALSE = 0
    TRUE = 1

  collectorIlb = _messages.MessageField('PacketMirroringForwardingRuleInfo', 1)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  enable = _messages.EnumField('EnableValueValuesEnum', 4)
  filter = _messages.MessageField('PacketMirroringFilter', 5)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(7, default=u'compute#packetMirroring')
  mirroredResources = _messages.MessageField('PacketMirroringMirroredResourceInfo', 8)
  name = _messages.StringField(9)
  network = _messages.MessageField('PacketMirroringNetworkInfo', 10)
  priority = _messages.IntegerField(11, variant=_messages.Variant.UINT32)
  region = _messages.StringField(12)
  selfLink = _messages.StringField(13)
  selfLinkWithId = _messages.StringField(14)


class PacketMirroringAggregatedList(_messages.Message):
  r"""Contains a list of packetMirrorings.

  Messages:
    ItemsValue: A list of PacketMirroring resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of PacketMirroring resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of PacketMirroring resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        packetMirrorings.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A PacketMirroringsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('PacketMirroringsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#packetMirroringAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class PacketMirroringFilter(_messages.Message):
  r"""A PacketMirroringFilter object.

  Fields:
    IPProtocols: Protocols that apply as filter on mirrored traffic. If no
      protocols are specified, all traffic that matches the specified CIDR
      ranges is mirrored. If neither cidrRanges nor IPProtocols is specified,
      all traffic is mirrored.
    cidrRanges: IP CIDR ranges that apply as filter on the source (ingress) or
      destination (egress) IP in the IP header. Only IPv4 is supported. If no
      ranges are specified, all traffic that matches the specified IPProtocols
      is mirrored. If neither cidrRanges nor IPProtocols is specified, all
      traffic is mirrored.
  """

  IPProtocols = _messages.StringField(1, repeated=True)
  cidrRanges = _messages.StringField(2, repeated=True)


class PacketMirroringForwardingRuleInfo(_messages.Message):
  r"""A PacketMirroringForwardingRuleInfo object.

  Fields:
    canonicalUrl: [Output Only] Unique identifier for the forwarding rule;
      defined by the server.
    url: Resource URL to the forwarding rule representing the ILB configured
      as destination of the mirrored traffic.
  """

  canonicalUrl = _messages.StringField(1)
  url = _messages.StringField(2)


class PacketMirroringList(_messages.Message):
  r"""Contains a list of PacketMirroring resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of PacketMirroring resources.
    kind: [Output Only] Type of resource. Always compute#packetMirroring for
      packetMirrorings.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('PacketMirroring', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#packetMirroringList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class PacketMirroringMirroredResourceInfo(_messages.Message):
  r"""A PacketMirroringMirroredResourceInfo object.

  Fields:
    instances: A set of virtual machine instances that are being mirrored.
      They must live in zones contained in the same region as this
      packetMirroring.  Note that this config will apply only to those network
      interfaces of the Instances that belong to the network specified in this
      packetMirroring.  You may specify a maximum of 50 Instances.
    subnetworks: A set of subnetworks for which traffic from/to all VM
      instances will be mirrored. They must live in the same region as this
      packetMirroring.  You may specify a maximum of 5 subnetworks.
    tags: A set of mirrored tags. Traffic from/to all VM instances that have
      one or more of these tags will be mirrored.
  """

  instances = _messages.MessageField('PacketMirroringMirroredResourceInfoInstanceInfo', 1, repeated=True)
  subnetworks = _messages.MessageField('PacketMirroringMirroredResourceInfoSubnetInfo', 2, repeated=True)
  tags = _messages.StringField(3, repeated=True)


class PacketMirroringMirroredResourceInfoInstanceInfo(_messages.Message):
  r"""A PacketMirroringMirroredResourceInfoInstanceInfo object.

  Fields:
    canonicalUrl: [Output Only] Unique identifier for the instance; defined by
      the server.
    url: Resource URL to the virtual machine instance which is being mirrored.
  """

  canonicalUrl = _messages.StringField(1)
  url = _messages.StringField(2)


class PacketMirroringMirroredResourceInfoSubnetInfo(_messages.Message):
  r"""A PacketMirroringMirroredResourceInfoSubnetInfo object.

  Fields:
    canonicalUrl: [Output Only] Unique identifier for the subnetwork; defined
      by the server.
    url: Resource URL to the subnetwork for which traffic from/to all VM
      instances will be mirrored.
  """

  canonicalUrl = _messages.StringField(1)
  url = _messages.StringField(2)


class PacketMirroringNetworkInfo(_messages.Message):
  r"""A PacketMirroringNetworkInfo object.

  Fields:
    canonicalUrl: [Output Only] Unique identifier for the network; defined by
      the server.
    url: URL of the network resource.
  """

  canonicalUrl = _messages.StringField(1)
  url = _messages.StringField(2)


class PacketMirroringsScopedList(_messages.Message):
  r"""A PacketMirroringsScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of
      packetMirrorings when the list is empty.

  Fields:
    packetMirrorings: A list of packetMirrorings contained in this scope.
    warning: Informational warning which replaces the list of packetMirrorings
      when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of packetMirrorings when
    the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  packetMirrorings = _messages.MessageField('PacketMirroring', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class PathMatcher(_messages.Message):
  r"""A matcher for the path portion of the URL. The BackendService from the
  longest-matched rule will serve the URL. If no rule was matched, the default
  service will be used.

  Fields:
    defaultRouteAction: defaultRouteAction takes effect when none of the
      pathRules or routeRules match. The load balancer performs advanced
      routing actions like URL rewrites, header transformations, etc. prior to
      forwarding the request to the selected backend. If defaultRouteAction
      specifies any weightedBackendServices, defaultService must not be set.
      Conversely if defaultService is set, defaultRouteAction cannot contain
      any  weightedBackendServices. Only one of defaultRouteAction or
      defaultUrlRedirect must be set.
    defaultService: The full or partial URL to the BackendService resource.
      This will be used if none of the pathRules or routeRules defined by this
      PathMatcher are matched. For example, the following are all valid URLs
      to a BackendService resource:   - https://www.googleapis.com/compute/v1/
      projects/project/global/backendServices/backendService  -
      compute/v1/projects/project/global/backendServices/backendService  -
      global/backendServices/backendService  If defaultRouteAction is
      additionally specified, advanced routing actions like URL Rewrites, etc.
      take effect prior to sending the request to the backend. However, if
      defaultService is specified, defaultRouteAction cannot contain any
      weightedBackendServices. Conversely, if defaultRouteAction specifies any
      weightedBackendServices, defaultService must not be specified. Only one
      of defaultService, defaultUrlRedirect  or
      defaultRouteAction.weightedBackendService must be set. Authorization
      requires one or more of the following Google IAM permissions on the
      specified resource default_service:   - compute.backendBuckets.use  -
      compute.backendServices.use
    defaultUrlRedirect: When none of the specified pathRules or routeRules
      match, the request is redirected to a URL specified by
      defaultUrlRedirect. If defaultUrlRedirect is specified, defaultService
      or defaultRouteAction must not be set.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    headerAction: Specifies changes to request and response headers that need
      to take effect for the selected backendService. HeaderAction specified
      here are applied after the matching HttpRouteRule HeaderAction and
      before the HeaderAction in the UrlMap
    name: The name to which this PathMatcher is referred by the HostRule.
    pathRules: The list of path rules. Use this list instead of routeRules
      when routing based on simple path matching is all that's required. The
      order by which path rules are specified does not matter. Matches are
      always done on the longest-path-first basis. For example: a pathRule
      with a path /a/b/c/* will match before /a/b/* irrespective of the order
      in which those paths appear in this list. Within a given pathMatcher,
      only one of pathRules or routeRules must be set.
    routeRules: The list of HTTP route rules. Use this list instead of
      pathRules when advanced route matching and routing actions are desired.
      routeRules are evaluated in order of priority, from the lowest to
      highest number. Within a given pathMatcher, you can set only one of
      pathRules or routeRules.
  """

  defaultRouteAction = _messages.MessageField('HttpRouteAction', 1)
  defaultService = _messages.StringField(2)
  defaultUrlRedirect = _messages.MessageField('HttpRedirectAction', 3)
  description = _messages.StringField(4)
  headerAction = _messages.MessageField('HttpHeaderAction', 5)
  name = _messages.StringField(6)
  pathRules = _messages.MessageField('PathRule', 7, repeated=True)
  routeRules = _messages.MessageField('HttpRouteRule', 8, repeated=True)


class PathRule(_messages.Message):
  r"""A path-matching rule for a URL. If matched, will use the specified
  BackendService to handle the traffic arriving at this URL.

  Fields:
    paths: The list of path patterns to match. Each must start with / and the
      only place a * is allowed is at the end following a /. The string fed to
      the path matcher does not include any text after the first ? or #, and
      those chars are not allowed here.
    routeAction: In response to a matching path, the load balancer performs
      advanced routing actions like URL rewrites, header transformations, etc.
      prior to forwarding the request to the selected backend. If routeAction
      specifies any  weightedBackendServices, service must not be set.
      Conversely if service is set, routeAction cannot contain any
      weightedBackendServices. Only one of routeAction or urlRedirect must be
      set.
    service: The full or partial URL of the backend service resource to which
      traffic is directed if this rule is matched. If routeAction is
      additionally specified, advanced routing actions like URL Rewrites, etc.
      take effect prior to sending the request to the backend. However, if
      service is specified, routeAction cannot contain any
      weightedBackendService s. Conversely, if routeAction specifies any
      weightedBackendServices, service must not be specified. Only one of
      urlRedirect, service or routeAction.weightedBackendService must be set.
    urlRedirect: When a path pattern is matched, the request is redirected to
      a URL specified by urlRedirect. If urlRedirect is specified, service or
      routeAction must not be set.
  """

  paths = _messages.StringField(1, repeated=True)
  routeAction = _messages.MessageField('HttpRouteAction', 2)
  service = _messages.StringField(3)
  urlRedirect = _messages.MessageField('HttpRedirectAction', 4)


class PeerAuthenticationMethod(_messages.Message):
  r"""[Deprecated] Configuration for the peer authentication method.
  Configuration for the peer authentication method.

  Fields:
    mtls: Set if mTLS is used for peer authentication.
  """

  mtls = _messages.MessageField('MutualTls', 1)


class PerInstanceConfig(_messages.Message):
  r"""A PerInstanceConfig object.

  Fields:
    fingerprint: Fingerprint of this per-instance config. This field can be
      used in optimistic locking. It is ignored when inserting a per-instance
      config. An up-to-date fingerprint must be provided in order to update an
      existing per-instance config or the field needs to be unset.
    name: The name of a per-instance config and its corresponding instance.
      Serves as a merge key during UpdatePerInstanceConfigs operations, that
      is, if a per-instance config with the same name exists then it will be
      updated, otherwise a new one will be created for the VM instance with
      the same name. An attempt to create a per-instance config for a VM
      instance that either doesn't exist or is not part of the group will
      result in an error.
    preservedState: The intended preserved state for the given instance. Does
      not contain preserved state generated from a stateful policy.
  """

  fingerprint = _messages.BytesField(1)
  name = _messages.StringField(2)
  preservedState = _messages.MessageField('PreservedState', 3)


class Permission(_messages.Message):
  r"""[Deprecated] All fields defined in a permission are ANDed.

  Fields:
    constraints: Extra custom constraints. The constraints are ANDed together.
    hosts: Used in Ingress or Egress Gateway cases to specify hosts that the
      policy applies to. Exact match, prefix match, and suffix match are
      supported.
    methods: HTTP method.
    notHosts: Negate of hosts. Specifies exclusions.
    notMethods: Negate of methods. Specifies exclusions.
    notPaths: Negate of paths. Specifies exclusions.
    notPorts: Negate of ports. Specifies exclusions.
    paths: HTTP request paths or gRPC methods. Exact match, prefix match, and
      suffix match are supported.
    ports: Port names or numbers.
  """

  constraints = _messages.MessageField('PermissionConstraint', 1, repeated=True)
  hosts = _messages.StringField(2, repeated=True)
  methods = _messages.StringField(3, repeated=True)
  notHosts = _messages.StringField(4, repeated=True)
  notMethods = _messages.StringField(5, repeated=True)
  notPaths = _messages.StringField(6, repeated=True)
  notPorts = _messages.StringField(7, repeated=True)
  paths = _messages.StringField(8, repeated=True)
  ports = _messages.StringField(9, repeated=True)


class PermissionConstraint(_messages.Message):
  r"""Custom constraint that specifies a key and a list of allowed values for
  Istio attributes.

  Fields:
    key: Key of the constraint.
    values: A list of allowed values.
  """

  key = _messages.StringField(1)
  values = _messages.StringField(2, repeated=True)


class Policy(_messages.Message):
  r"""An Identity and Access Management (IAM) policy, which specifies access
  controls for Google Cloud resources.    A `Policy` is a collection of
  `bindings`. A `binding` binds one or more `members` to a single `role`.
  Members can be user accounts, service accounts, Google groups, and domains
  (such as G Suite). A `role` is a named list of permissions; each `role` can
  be an IAM predefined role or a user-created custom role.  Optionally, a
  `binding` can specify a `condition`, which is a logical expression that
  allows access to a resource only if the expression evaluates to `true`. A
  condition can add constraints based on attributes of the request, the
  resource, or both.  **JSON example:**  { "bindings": [ { "role":
  "roles/resourcemanager.organizationAdmin", "members": [
  "user:mike@example.com", "group:admins@example.com", "domain:google.com",
  "serviceAccount:my-project-id@appspot.gserviceaccount.com" ] }, { "role":
  "roles/resourcemanager.organizationViewer", "members":
  ["user:eve@example.com"], "condition": { "title": "expirable access",
  "description": "Does not grant access after Sep 2020", "expression":
  "request.time < timestamp('2020-10-01T00:00:00.000Z')", } } ], "etag":
  "BwWWja0YfJA=", "version": 3 }  **YAML example:**  bindings: - members: -
  user:mike@example.com - group:admins@example.com - domain:google.com -
  serviceAccount:my-project-id@appspot.gserviceaccount.com role:
  roles/resourcemanager.organizationAdmin - members: - user:eve@example.com
  role: roles/resourcemanager.organizationViewer condition: title: expirable
  access description: Does not grant access after Sep 2020 expression:
  request.time < timestamp('2020-10-01T00:00:00.000Z') - etag: BwWWja0YfJA= -
  version: 3  For a description of IAM and its features, see the [IAM
  documentation](https://cloud.google.com/iam/docs/).

  Fields:
    auditConfigs: Specifies cloud audit logging configuration for this policy.
    bindings: Associates a list of `members` to a `role`. Optionally, may
      specify a `condition` that determines how and when the `bindings` are
      applied. Each of the `bindings` must contain at least one member.
    etag: `etag` is used for optimistic concurrency control as a way to help
      prevent simultaneous updates of a policy from overwriting each other. It
      is strongly suggested that systems make use of the `etag` in the read-
      modify-write cycle to perform policy updates in order to avoid race
      conditions: An `etag` is returned in the response to `getIamPolicy`, and
      systems are expected to put that etag in the request to `setIamPolicy`
      to ensure that their change will be applied to the same version of the
      policy.  **Important:** If you use IAM Conditions, you must include the
      `etag` field whenever you call `setIamPolicy`. If you omit this field,
      then IAM allows you to overwrite a version `3` policy with a version `1`
      policy, and all of the conditions in the version `3` policy are lost.
    iamOwned:
    rules: If more than one rule is specified, the rules are applied in the
      following manner: - All matching LOG rules are always applied. - If any
      DENY/DENY_WITH_LOG rule matches, permission is denied. Logging will be
      applied if one or more matching rule requires logging. - Otherwise, if
      any ALLOW/ALLOW_WITH_LOG rule matches, permission is granted. Logging
      will be applied if one or more matching rule requires logging. -
      Otherwise, if no rule applies, permission is denied.
    version: Specifies the format of the policy.  Valid values are `0`, `1`,
      and `3`. Requests that specify an invalid value are rejected.  Any
      operation that affects conditional role bindings must specify version
      `3`. This requirement applies to the following operations:  * Getting a
      policy that includes a conditional role binding * Adding a conditional
      role binding to a policy * Changing a conditional role binding in a
      policy * Removing any role binding, with or without a condition, from a
      policy that includes conditions  **Important:** If you use IAM
      Conditions, you must include the `etag` field whenever you call
      `setIamPolicy`. If you omit this field, then IAM allows you to overwrite
      a version `3` policy with a version `1` policy, and all of the
      conditions in the version `3` policy are lost.  If a policy does not
      include any conditions, operations on that policy may specify any valid
      version or leave the field unset.
  """

  auditConfigs = _messages.MessageField('AuditConfig', 1, repeated=True)
  bindings = _messages.MessageField('Binding', 2, repeated=True)
  etag = _messages.BytesField(3)
  iamOwned = _messages.BooleanField(4)
  rules = _messages.MessageField('Rule', 5, repeated=True)
  version = _messages.IntegerField(6, variant=_messages.Variant.INT32)


class PreconfiguredWafSet(_messages.Message):
  r"""A PreconfiguredWafSet object.

  Fields:
    expressionSets: List of entities that are currently supported for WAF
      rules.
  """

  expressionSets = _messages.MessageField('WafExpressionSet', 1, repeated=True)


class PreservedState(_messages.Message):
  r"""Preserved state for a given instance.

  Messages:
    DisksValue: Preserved disks defined for this instance. This map is keyed
      with the device names of the disks.
    MetadataValue: Preserved metadata defined for this instance.

  Fields:
    disks: Preserved disks defined for this instance. This map is keyed with
      the device names of the disks.
    metadata: Preserved metadata defined for this instance.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class DisksValue(_messages.Message):
    r"""Preserved disks defined for this instance. This map is keyed with the
    device names of the disks.

    Messages:
      AdditionalProperty: An additional property for a DisksValue object.

    Fields:
      additionalProperties: Additional properties of type DisksValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a DisksValue object.

      Fields:
        key: Name of the additional property.
        value: A PreservedStatePreservedDisk attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('PreservedStatePreservedDisk', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  @encoding.MapUnrecognizedFields('additionalProperties')
  class MetadataValue(_messages.Message):
    r"""Preserved metadata defined for this instance.

    Messages:
      AdditionalProperty: An additional property for a MetadataValue object.

    Fields:
      additionalProperties: Additional properties of type MetadataValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a MetadataValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  disks = _messages.MessageField('DisksValue', 1)
  metadata = _messages.MessageField('MetadataValue', 2)


class PreservedStatePreservedDisk(_messages.Message):
  r"""A PreservedStatePreservedDisk object.

  Enums:
    AutoDeleteValueValuesEnum: These stateful disks will never be deleted
      during autohealing, update, instance recreate operations. This flag is
      used to configure if the disk should be deleted after it is no longer
      used by the group, e.g. when the given instance or the whole MIG is
      deleted. Note: disks attached in READ_ONLY mode cannot be auto-deleted.
    ModeValueValuesEnum: The mode in which to attach this disk, either
      READ_WRITE or READ_ONLY. If not specified, the default is to attach the
      disk in READ_WRITE mode.

  Fields:
    autoDelete: These stateful disks will never be deleted during autohealing,
      update, instance recreate operations. This flag is used to configure if
      the disk should be deleted after it is no longer used by the group, e.g.
      when the given instance or the whole MIG is deleted. Note: disks
      attached in READ_ONLY mode cannot be auto-deleted.
    mode: The mode in which to attach this disk, either READ_WRITE or
      READ_ONLY. If not specified, the default is to attach the disk in
      READ_WRITE mode.
    source: The URL of the disk resource that is stateful and should be
      attached to the VM instance.
  """

  class AutoDeleteValueValuesEnum(_messages.Enum):
    r"""These stateful disks will never be deleted during autohealing, update,
    instance recreate operations. This flag is used to configure if the disk
    should be deleted after it is no longer used by the group, e.g. when the
    given instance or the whole MIG is deleted. Note: disks attached in
    READ_ONLY mode cannot be auto-deleted.

    Values:
      NEVER: <no description>
      ON_PERMANENT_INSTANCE_DELETION: <no description>
    """
    NEVER = 0
    ON_PERMANENT_INSTANCE_DELETION = 1

  class ModeValueValuesEnum(_messages.Enum):
    r"""The mode in which to attach this disk, either READ_WRITE or READ_ONLY.
    If not specified, the default is to attach the disk in READ_WRITE mode.

    Values:
      READ_ONLY: <no description>
      READ_WRITE: <no description>
    """
    READ_ONLY = 0
    READ_WRITE = 1

  autoDelete = _messages.EnumField('AutoDeleteValueValuesEnum', 1)
  mode = _messages.EnumField('ModeValueValuesEnum', 2)
  source = _messages.StringField(3)


class Principal(_messages.Message):
  r"""[Deprecated] All fields defined in a principal are ANDed.

  Messages:
    PropertiesValue: A map of Istio attribute to expected values. Exact match,
      prefix match, and suffix match are supported for values. For example,
      `request.headers[version]: "v1"`. The properties are ANDed together.

  Fields:
    condition: An expression to specify custom condition.
    groups: The groups the principal belongs to. Exact match, prefix match,
      and suffix match are supported.
    ips: IPv4 or IPv6 address or range (In CIDR format)
    namespaces: The namespaces. Exact match, prefix match, and suffix match
      are supported.
    notGroups: Negate of groups. Specifies exclusions.
    notIps: Negate of IPs. Specifies exclusions.
    notNamespaces: Negate of namespaces. Specifies exclusions.
    notUsers: Negate of users. Specifies exclusions.
    properties: A map of Istio attribute to expected values. Exact match,
      prefix match, and suffix match are supported for values. For example,
      `request.headers[version]: "v1"`. The properties are ANDed together.
    users: The user names/IDs or service accounts. Exact match, prefix match,
      and suffix match are supported.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class PropertiesValue(_messages.Message):
    r"""A map of Istio attribute to expected values. Exact match, prefix
    match, and suffix match are supported for values. For example,
    `request.headers[version]: "v1"`. The properties are ANDed together.

    Messages:
      AdditionalProperty: An additional property for a PropertiesValue object.

    Fields:
      additionalProperties: Additional properties of type PropertiesValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a PropertiesValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  condition = _messages.StringField(1)
  groups = _messages.StringField(2, repeated=True)
  ips = _messages.StringField(3, repeated=True)
  namespaces = _messages.StringField(4, repeated=True)
  notGroups = _messages.StringField(5, repeated=True)
  notIps = _messages.StringField(6, repeated=True)
  notNamespaces = _messages.StringField(7, repeated=True)
  notUsers = _messages.StringField(8, repeated=True)
  properties = _messages.MessageField('PropertiesValue', 9)
  users = _messages.StringField(10, repeated=True)


class Project(_messages.Message):
  r"""Represents a Project resource.  A project is used to organize resources
  in a Google Cloud Platform environment. For more information, read about the
  Resource Hierarchy. (== resource_for {$api_version}.projects ==)

  Enums:
    DefaultNetworkTierValueValuesEnum: This signifies the default network tier
      used for configuring resources of the project and can only take the
      following values: PREMIUM, STANDARD. Initially the default network tier
      is PREMIUM.
    XpnProjectStatusValueValuesEnum: [Output Only] The role this project has
      in a shared VPC configuration. Currently only HOST projects are
      differentiated.

  Fields:
    commonInstanceMetadata: Metadata key/value pairs available to all
      instances contained in this project. See Custom metadata for more
      information.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    defaultNetworkTier: This signifies the default network tier used for
      configuring resources of the project and can only take the following
      values: PREMIUM, STANDARD. Initially the default network tier is
      PREMIUM.
    defaultServiceAccount: [Output Only] Default service account used by VMs
      running in this project.
    description: An optional textual description of the resource.
    enabledFeatures: Restricted features enabled for use on this project.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server. This is not the project ID, and is just a
      unique ID used by Compute Engine to identify resources.
    kind: [Output Only] Type of the resource. Always compute#project for
      projects.
    name: The project ID. For example: my-example-project. Use the project ID
      to make requests to Compute Engine.
    quotas: [Output Only] Quotas assigned to this project.
    selfLink: [Output Only] Server-defined URL for the resource.
    usageExportLocation: The naming prefix for daily usage reports and the
      Google Cloud Storage bucket where they are stored.
    xpnProjectStatus: [Output Only] The role this project has in a shared VPC
      configuration. Currently only HOST projects are differentiated.
  """

  class DefaultNetworkTierValueValuesEnum(_messages.Enum):
    r"""This signifies the default network tier used for configuring resources
    of the project and can only take the following values: PREMIUM, STANDARD.
    Initially the default network tier is PREMIUM.

    Values:
      PREMIUM: <no description>
      SELECT: <no description>
      STANDARD: <no description>
    """
    PREMIUM = 0
    SELECT = 1
    STANDARD = 2

  class XpnProjectStatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The role this project has in a shared VPC configuration.
    Currently only HOST projects are differentiated.

    Values:
      HOST: <no description>
      UNSPECIFIED_XPN_PROJECT_STATUS: <no description>
    """
    HOST = 0
    UNSPECIFIED_XPN_PROJECT_STATUS = 1

  commonInstanceMetadata = _messages.MessageField('Metadata', 1)
  creationTimestamp = _messages.StringField(2)
  defaultNetworkTier = _messages.EnumField('DefaultNetworkTierValueValuesEnum', 3)
  defaultServiceAccount = _messages.StringField(4)
  description = _messages.StringField(5)
  enabledFeatures = _messages.StringField(6, repeated=True)
  id = _messages.IntegerField(7, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(8, default=u'compute#project')
  name = _messages.StringField(9)
  quotas = _messages.MessageField('Quota', 10, repeated=True)
  selfLink = _messages.StringField(11)
  usageExportLocation = _messages.MessageField('UsageExportLocation', 12)
  xpnProjectStatus = _messages.EnumField('XpnProjectStatusValueValuesEnum', 13)


class ProjectsDisableXpnResourceRequest(_messages.Message):
  r"""A ProjectsDisableXpnResourceRequest object.

  Fields:
    xpnResource: Service resource (a.k.a service project) ID.
  """

  xpnResource = _messages.MessageField('XpnResourceId', 1)


class ProjectsEnableXpnResourceRequest(_messages.Message):
  r"""A ProjectsEnableXpnResourceRequest object.

  Fields:
    xpnResource: Service resource (a.k.a service project) ID.
  """

  xpnResource = _messages.MessageField('XpnResourceId', 1)


class ProjectsGetXpnResources(_messages.Message):
  r"""A ProjectsGetXpnResources object.

  Fields:
    kind: [Output Only] Type of resource. Always
      compute#projectsGetXpnResources for lists of service resources (a.k.a
      service projects)
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    resources: Service resources (a.k.a service projects) attached to this
      project as their shared VPC host.
  """

  kind = _messages.StringField(1, default=u'compute#projectsGetXpnResources')
  nextPageToken = _messages.StringField(2)
  resources = _messages.MessageField('XpnResourceId', 3, repeated=True)


class ProjectsListXpnHostsRequest(_messages.Message):
  r"""A ProjectsListXpnHostsRequest object.

  Fields:
    organization: Optional organization ID managed by Cloud Resource Manager,
      for which to list shared VPC host projects. If not specified, the
      organization will be inferred from the project.
  """

  organization = _messages.StringField(1)


class ProjectsSetDefaultNetworkTierRequest(_messages.Message):
  r"""A ProjectsSetDefaultNetworkTierRequest object.

  Enums:
    NetworkTierValueValuesEnum: Default network tier to be set.

  Fields:
    networkTier: Default network tier to be set.
  """

  class NetworkTierValueValuesEnum(_messages.Enum):
    r"""Default network tier to be set.

    Values:
      PREMIUM: <no description>
      SELECT: <no description>
      STANDARD: <no description>
    """
    PREMIUM = 0
    SELECT = 1
    STANDARD = 2

  networkTier = _messages.EnumField('NetworkTierValueValuesEnum', 1)


class ProjectsSetDefaultServiceAccountRequest(_messages.Message):
  r"""A ProjectsSetDefaultServiceAccountRequest object.

  Fields:
    email: Email address of the service account.
  """

  email = _messages.StringField(1)


class PublicAdvertisedPrefix(_messages.Message):
  r"""A public advertised prefix represents an aggregated IP prefix or
  netblock which customers bring to cloud. The IP prefix is a single unit of
  route advertisement and is announced globally to the internet.

  Enums:
    StatusValueValuesEnum: The status of the public advertised prefix.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    dnsVerificationIp: The IPv4 address to be used for reverse DNS
      verification.
    fingerprint: Fingerprint of this resource. A hash of the contents stored
      in this object. This field is used in optimistic locking. This field
      will be ignored when inserting a new PublicAdvertisedPrefix. An up-to-
      date fingerprint must be provided in order to update the
      PublicAdvertisedPrefix, otherwise the request will fail with error 412
      conditionNotMet.  To see the latest fingerprint, make a get() request to
      retrieve a PublicAdvertisedPrefix.
    id: [Output Only] The unique identifier for the resource type. The server
      generates this identifier.
    ipCidrRange: The IPv4 address range, in CIDR format, represented by this
      public advertised prefix.
    kind: [Output Only] Type of the resource. Always
      compute#publicAdvertisedPrefix for public advertised prefixes.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    publicDelegatedPrefixs: [Output Only] The list of public delegated
      prefixes that exist for this public advertised prefix.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL with id for the resource.
    sharedSecret: [Output Only] The shared secret to be used for reverse DNS
      verification.
    status: The status of the public advertised prefix.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""The status of the public advertised prefix.

    Values:
      INITIAL: <no description>
      PREFIX_CONFIGURATION_COMPLETE: <no description>
      PREFIX_CONFIGURATION_IN_PROGRESS: <no description>
      PREFIX_REMOVAL_IN_PROGRESS: <no description>
      PTR_CONFIGURED: <no description>
      REVERSE_DNS_LOOKUP_FAILED: <no description>
      VALIDATED: <no description>
    """
    INITIAL = 0
    PREFIX_CONFIGURATION_COMPLETE = 1
    PREFIX_CONFIGURATION_IN_PROGRESS = 2
    PREFIX_REMOVAL_IN_PROGRESS = 3
    PTR_CONFIGURED = 4
    REVERSE_DNS_LOOKUP_FAILED = 5
    VALIDATED = 6

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  dnsVerificationIp = _messages.StringField(3)
  fingerprint = _messages.BytesField(4)
  id = _messages.IntegerField(5, variant=_messages.Variant.UINT64)
  ipCidrRange = _messages.StringField(6)
  kind = _messages.StringField(7, default=u'compute#publicAdvertisedPrefix')
  name = _messages.StringField(8)
  publicDelegatedPrefixs = _messages.MessageField('PublicAdvertisedPrefixPublicDelegatedPrefix', 9, repeated=True)
  selfLink = _messages.StringField(10)
  selfLinkWithId = _messages.StringField(11)
  sharedSecret = _messages.StringField(12)
  status = _messages.EnumField('StatusValueValuesEnum', 13)


class PublicAdvertisedPrefixList(_messages.Message):
  r"""A PublicAdvertisedPrefixList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of PublicAdvertisedPrefix resources.
    kind: [Output Only] Type of the resource. Always
      compute#publicAdvertisedPrefix for public advertised prefixes.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('PublicAdvertisedPrefix', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#publicAdvertisedPrefixList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class PublicAdvertisedPrefixPublicDelegatedPrefix(_messages.Message):
  r"""Represents a CIDR range which can be used to assign addresses.

  Fields:
    name: The name of the public delegated prefix
    region: The region of the public delegated prefix if it is regional. If
      absent, the prefix is global.
    status: The status of the public delegated prefix. Possible values are:
      ACTIVE: The public delegated prefix is active DRAINED: The public
      delegated prefix is drained.
  """

  name = _messages.StringField(1)
  region = _messages.StringField(2)
  status = _messages.StringField(3)


class PublicDelegatedPrefix(_messages.Message):
  r"""A PublicDelegatedPrefix resource represents an IP block within a
  PublicAdvertisedPrefix that is configured within a single cloud scope
  (global or region). IPs in the block can be allocated to resources within
  that scope. Public delegated prefixes may be further broken up into smaller
  IP blocks in the same scope as the parent block.

  Enums:
    StatusValueValuesEnum: [Output Only] The status of the public delegated
      prefix.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    fingerprint: Fingerprint of this resource. A hash of the contents stored
      in this object. This field is used in optimistic locking. This field
      will be ignored when inserting a new PublicDelegatedPrefix. An up-to-
      date fingerprint must be provided in order to update the
      PublicDelegatedPrefix, otherwise the request will fail with error 412
      conditionNotMet.  To see the latest fingerprint, make a get() request to
      retrieve a PublicDelegatedPrefix.
    id: [Output Only] The unique identifier for the resource type. The server
      generates this identifier.
    ipCidrRange: The IPv4 address range, in CIDR format, represented by this
      public delegated prefix.
    kind: [Output Only] Type of the resource. Always
      compute#publicDelegatedPrefix for public delegated prefixes.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    parentPrefix: The URL of parent prefix. Either PublicAdvertisedPrefix or
      PublicDelegatedPrefix.
    publicDelegatedSubPrefixs: The list of sub public delegated prefixes that
      exist for this public delegated prefix.
    region: [Output Only] URL of the region where the public delegated prefix
      resides. This field applies only to the region resource. You must
      specify this field as part of the HTTP request URL. It is not settable
      as a field in the request body.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL with id for the resource.
    status: [Output Only] The status of the public delegated prefix.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the public delegated prefix.

    Values:
      ANNOUNCED: <no description>
      INITIALIZING: <no description>
    """
    ANNOUNCED = 0
    INITIALIZING = 1

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  fingerprint = _messages.BytesField(3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  ipCidrRange = _messages.StringField(5)
  kind = _messages.StringField(6, default=u'compute#publicDelegatedPrefix')
  name = _messages.StringField(7)
  parentPrefix = _messages.StringField(8)
  publicDelegatedSubPrefixs = _messages.MessageField('PublicDelegatedPrefixPublicDelegatedSubPrefix', 9, repeated=True)
  region = _messages.StringField(10)
  selfLink = _messages.StringField(11)
  selfLinkWithId = _messages.StringField(12)
  status = _messages.EnumField('StatusValueValuesEnum', 13)


class PublicDelegatedPrefixAggregatedList(_messages.Message):
  r"""A PublicDelegatedPrefixAggregatedList object.

  Messages:
    ItemsValue: A list of PublicDelegatedPrefixesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of PublicDelegatedPrefixesScopedList resources.
    kind: [Output Only] Type of the resource. Always
      compute#publicDelegatedPrefixAggregatedList for aggregated lists of
      public delegated prefixes.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of PublicDelegatedPrefixesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of PublicDelegatedPrefixes.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A PublicDelegatedPrefixesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('PublicDelegatedPrefixesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#publicDelegatedPrefixAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class PublicDelegatedPrefixList(_messages.Message):
  r"""A PublicDelegatedPrefixList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of PublicDelegatedPrefix resources.
    kind: [Output Only] Type of the resource. Always
      compute#publicDelegatedPrefixList for public delegated prefixes.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('PublicDelegatedPrefix', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#publicDelegatedPrefixList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class PublicDelegatedPrefixPublicDelegatedSubPrefix(_messages.Message):
  r"""Represents a sub PublicDelegatedPrefix.

  Enums:
    StatusValueValuesEnum: [Output Only] The status of the sub public
      delegated prefix.

  Fields:
    delegateeProject: Name of the project scoping this
      PublicDelegatedSubPrefix.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    ipCidrRange: The IPv4 address range, in CIDR format, represented by this
      sub public delegated prefix.
    isAddress: Whether the sub prefix is delegated to create Address resources
      in the delegatee project.
    name: The name of the sub public delegated prefix.
    region: [Output Only] The region of the sub public delegated prefix if it
      is regional. If absent, the sub prefix is global.
    status: [Output Only] The status of the sub public delegated prefix.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the sub public delegated prefix.

    Values:
      ACTIVE: <no description>
      INACTIVE: <no description>
    """
    ACTIVE = 0
    INACTIVE = 1

  delegateeProject = _messages.StringField(1)
  description = _messages.StringField(2)
  ipCidrRange = _messages.StringField(3)
  isAddress = _messages.BooleanField(4)
  name = _messages.StringField(5)
  region = _messages.StringField(6)
  status = _messages.EnumField('StatusValueValuesEnum', 7)


class PublicDelegatedPrefixesScopedList(_messages.Message):
  r"""A PublicDelegatedPrefixesScopedList object.

  Messages:
    WarningValue: [Output Only] Informational warning which replaces the list
      of public delegated prefixes when the list is empty.

  Fields:
    publicDelegatedPrefixes: [Output Only] A list of PublicDelegatedPrefixes
      contained in this scope.
    warning: [Output Only] Informational warning which replaces the list of
      public delegated prefixes when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning which replaces the list of public
    delegated prefixes when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  publicDelegatedPrefixes = _messages.MessageField('PublicDelegatedPrefix', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class Quota(_messages.Message):
  r"""A quotas entry.

  Enums:
    MetricValueValuesEnum: [Output Only] Name of the quota metric.

  Fields:
    limit: [Output Only] Quota limit for this metric.
    metric: [Output Only] Name of the quota metric.
    owner: [Output Only] Owning resource. This is the resource on which this
      quota is applied.
    usage: [Output Only] Current usage of this metric.
  """

  class MetricValueValuesEnum(_messages.Enum):
    r"""[Output Only] Name of the quota metric.

    Values:
      AFFINITY_GROUPS: <no description>
      ALIASES_PER_NETWORK_GLOBAL: <no description>
      AMD_S9300_GPUS: <no description>
      AUTOSCALERS: <no description>
      BACKEND_BUCKETS: <no description>
      BACKEND_SERVICES: <no description>
      C2_CPUS: <no description>
      COMMITMENTS: <no description>
      COMMITTED_C2_CPUS: <no description>
      COMMITTED_CPUS: <no description>
      COMMITTED_LICENSES: <no description>
      COMMITTED_LOCAL_SSD_TOTAL_GB: <no description>
      COMMITTED_N2D_CPUS: <no description>
      COMMITTED_N2_CPUS: <no description>
      COMMITTED_NVIDIA_K80_GPUS: <no description>
      COMMITTED_NVIDIA_P100_GPUS: <no description>
      COMMITTED_NVIDIA_P4_GPUS: <no description>
      COMMITTED_NVIDIA_T4_GPUS: <no description>
      COMMITTED_NVIDIA_V100_GPUS: <no description>
      CPUS: <no description>
      CPUS_ALL_REGIONS: <no description>
      DISKS_TOTAL_GB: <no description>
      EXTERNAL_VPN_GATEWAYS: <no description>
      FIREWALLS: <no description>
      FORWARDING_RULES: <no description>
      GLOBAL_INTERNAL_ADDRESSES: <no description>
      GPUS_ALL_REGIONS: <no description>
      HEALTH_CHECKS: <no description>
      IMAGES: <no description>
      INSTANCES: <no description>
      INSTANCES_PER_NETWORK_GLOBAL: <no description>
      INSTANCE_GROUPS: <no description>
      INSTANCE_GROUP_MANAGERS: <no description>
      INSTANCE_TEMPLATES: <no description>
      INTERCONNECTS: <no description>
      INTERCONNECT_ATTACHMENTS_PER_REGION: <no description>
      INTERCONNECT_ATTACHMENTS_TOTAL_MBPS: <no description>
      INTERCONNECT_TOTAL_GBPS: <no description>
      INTERNAL_ADDRESSES: <no description>
      INTERNAL_FORWARDING_RULES_PER_NETWORK: <no description>
      INTERNAL_FORWARDING_RULES_WITH_GLOBAL_ACCESS_PER_NETWORK: <no
        description>
      INTERNAL_FORWARDING_RULES_WITH_TARGET_INSTANCE_PER_NETWORK: <no
        description>
      INTERNAL_TARGET_INSTANCE_WITH_GLOBAL_ACCESS_PER_NETWORK: <no
        description>
      IN_PLACE_SNAPSHOTS: <no description>
      IN_USE_ADDRESSES: <no description>
      IN_USE_BACKUP_SCHEDULES: <no description>
      IN_USE_MAINTENANCE_WINDOWS: <no description>
      IN_USE_SNAPSHOT_SCHEDULES: <no description>
      LOCAL_SSD_TOTAL_GB: <no description>
      MACHINE_IMAGES: <no description>
      N2D_CPUS: <no description>
      N2_CPUS: <no description>
      NETWORKS: <no description>
      NETWORK_ENDPOINT_GROUPS: <no description>
      NODE_GROUPS: <no description>
      NODE_TEMPLATES: <no description>
      NVIDIA_K80_GPUS: <no description>
      NVIDIA_P100_GPUS: <no description>
      NVIDIA_P100_VWS_GPUS: <no description>
      NVIDIA_P4_GPUS: <no description>
      NVIDIA_P4_VWS_GPUS: <no description>
      NVIDIA_T4_GPUS: <no description>
      NVIDIA_T4_VWS_GPUS: <no description>
      NVIDIA_V100_GPUS: <no description>
      PACKET_MIRRORINGS: <no description>
      PREEMPTIBLE_CPUS: <no description>
      PREEMPTIBLE_LOCAL_SSD_GB: <no description>
      PREEMPTIBLE_NVIDIA_K80_GPUS: <no description>
      PREEMPTIBLE_NVIDIA_P100_GPUS: <no description>
      PREEMPTIBLE_NVIDIA_P100_VWS_GPUS: <no description>
      PREEMPTIBLE_NVIDIA_P4_GPUS: <no description>
      PREEMPTIBLE_NVIDIA_P4_VWS_GPUS: <no description>
      PREEMPTIBLE_NVIDIA_T4_GPUS: <no description>
      PREEMPTIBLE_NVIDIA_T4_VWS_GPUS: <no description>
      PREEMPTIBLE_NVIDIA_V100_GPUS: <no description>
      PRIVATE_V6_ACCESS_SUBNETWORKS: <no description>
      PSC_GOOGLE_APIS_FORWARDING_RULES_PER_NETWORK: <no description>
      PUBLIC_ADVERTISED_PREFIXES: <no description>
      PUBLIC_DELEGATED_PREFIXES: <no description>
      REGIONAL_AUTOSCALERS: <no description>
      REGIONAL_INSTANCE_GROUP_MANAGERS: <no description>
      RESERVATIONS: <no description>
      RESOURCE_POLICIES: <no description>
      ROUTERS: <no description>
      ROUTES: <no description>
      SECURITY_POLICIES: <no description>
      SECURITY_POLICY_CEVAL_RULES: <no description>
      SECURITY_POLICY_RULES: <no description>
      SNAPSHOTS: <no description>
      SSD_TOTAL_GB: <no description>
      SSL_CERTIFICATES: <no description>
      STATIC_ADDRESSES: <no description>
      STATIC_BYOIP_ADDRESSES: <no description>
      SUBNETWORKS: <no description>
      SUBNET_RANGES_PER_NETWORK: <no description>
      TARGET_HTTPS_PROXIES: <no description>
      TARGET_HTTP_PROXIES: <no description>
      TARGET_INSTANCES: <no description>
      TARGET_POOLS: <no description>
      TARGET_SSL_PROXIES: <no description>
      TARGET_TCP_PROXIES: <no description>
      TARGET_VPN_GATEWAYS: <no description>
      URL_MAPS: <no description>
      VPN_GATEWAYS: <no description>
      VPN_TUNNELS: <no description>
      XPN_SERVICE_PROJECTS: <no description>
    """
    AFFINITY_GROUPS = 0
    ALIASES_PER_NETWORK_GLOBAL = 1
    AMD_S9300_GPUS = 2
    AUTOSCALERS = 3
    BACKEND_BUCKETS = 4
    BACKEND_SERVICES = 5
    C2_CPUS = 6
    COMMITMENTS = 7
    COMMITTED_C2_CPUS = 8
    COMMITTED_CPUS = 9
    COMMITTED_LICENSES = 10
    COMMITTED_LOCAL_SSD_TOTAL_GB = 11
    COMMITTED_N2D_CPUS = 12
    COMMITTED_N2_CPUS = 13
    COMMITTED_NVIDIA_K80_GPUS = 14
    COMMITTED_NVIDIA_P100_GPUS = 15
    COMMITTED_NVIDIA_P4_GPUS = 16
    COMMITTED_NVIDIA_T4_GPUS = 17
    COMMITTED_NVIDIA_V100_GPUS = 18
    CPUS = 19
    CPUS_ALL_REGIONS = 20
    DISKS_TOTAL_GB = 21
    EXTERNAL_VPN_GATEWAYS = 22
    FIREWALLS = 23
    FORWARDING_RULES = 24
    GLOBAL_INTERNAL_ADDRESSES = 25
    GPUS_ALL_REGIONS = 26
    HEALTH_CHECKS = 27
    IMAGES = 28
    INSTANCES = 29
    INSTANCES_PER_NETWORK_GLOBAL = 30
    INSTANCE_GROUPS = 31
    INSTANCE_GROUP_MANAGERS = 32
    INSTANCE_TEMPLATES = 33
    INTERCONNECTS = 34
    INTERCONNECT_ATTACHMENTS_PER_REGION = 35
    INTERCONNECT_ATTACHMENTS_TOTAL_MBPS = 36
    INTERCONNECT_TOTAL_GBPS = 37
    INTERNAL_ADDRESSES = 38
    INTERNAL_FORWARDING_RULES_PER_NETWORK = 39
    INTERNAL_FORWARDING_RULES_WITH_GLOBAL_ACCESS_PER_NETWORK = 40
    INTERNAL_FORWARDING_RULES_WITH_TARGET_INSTANCE_PER_NETWORK = 41
    INTERNAL_TARGET_INSTANCE_WITH_GLOBAL_ACCESS_PER_NETWORK = 42
    IN_PLACE_SNAPSHOTS = 43
    IN_USE_ADDRESSES = 44
    IN_USE_BACKUP_SCHEDULES = 45
    IN_USE_MAINTENANCE_WINDOWS = 46
    IN_USE_SNAPSHOT_SCHEDULES = 47
    LOCAL_SSD_TOTAL_GB = 48
    MACHINE_IMAGES = 49
    N2D_CPUS = 50
    N2_CPUS = 51
    NETWORKS = 52
    NETWORK_ENDPOINT_GROUPS = 53
    NODE_GROUPS = 54
    NODE_TEMPLATES = 55
    NVIDIA_K80_GPUS = 56
    NVIDIA_P100_GPUS = 57
    NVIDIA_P100_VWS_GPUS = 58
    NVIDIA_P4_GPUS = 59
    NVIDIA_P4_VWS_GPUS = 60
    NVIDIA_T4_GPUS = 61
    NVIDIA_T4_VWS_GPUS = 62
    NVIDIA_V100_GPUS = 63
    PACKET_MIRRORINGS = 64
    PREEMPTIBLE_CPUS = 65
    PREEMPTIBLE_LOCAL_SSD_GB = 66
    PREEMPTIBLE_NVIDIA_K80_GPUS = 67
    PREEMPTIBLE_NVIDIA_P100_GPUS = 68
    PREEMPTIBLE_NVIDIA_P100_VWS_GPUS = 69
    PREEMPTIBLE_NVIDIA_P4_GPUS = 70
    PREEMPTIBLE_NVIDIA_P4_VWS_GPUS = 71
    PREEMPTIBLE_NVIDIA_T4_GPUS = 72
    PREEMPTIBLE_NVIDIA_T4_VWS_GPUS = 73
    PREEMPTIBLE_NVIDIA_V100_GPUS = 74
    PRIVATE_V6_ACCESS_SUBNETWORKS = 75
    PSC_GOOGLE_APIS_FORWARDING_RULES_PER_NETWORK = 76
    PUBLIC_ADVERTISED_PREFIXES = 77
    PUBLIC_DELEGATED_PREFIXES = 78
    REGIONAL_AUTOSCALERS = 79
    REGIONAL_INSTANCE_GROUP_MANAGERS = 80
    RESERVATIONS = 81
    RESOURCE_POLICIES = 82
    ROUTERS = 83
    ROUTES = 84
    SECURITY_POLICIES = 85
    SECURITY_POLICY_CEVAL_RULES = 86
    SECURITY_POLICY_RULES = 87
    SNAPSHOTS = 88
    SSD_TOTAL_GB = 89
    SSL_CERTIFICATES = 90
    STATIC_ADDRESSES = 91
    STATIC_BYOIP_ADDRESSES = 92
    SUBNETWORKS = 93
    SUBNET_RANGES_PER_NETWORK = 94
    TARGET_HTTPS_PROXIES = 95
    TARGET_HTTP_PROXIES = 96
    TARGET_INSTANCES = 97
    TARGET_POOLS = 98
    TARGET_SSL_PROXIES = 99
    TARGET_TCP_PROXIES = 100
    TARGET_VPN_GATEWAYS = 101
    URL_MAPS = 102
    VPN_GATEWAYS = 103
    VPN_TUNNELS = 104
    XPN_SERVICE_PROJECTS = 105

  limit = _messages.FloatField(1)
  metric = _messages.EnumField('MetricValueValuesEnum', 2)
  owner = _messages.StringField(3)
  usage = _messages.FloatField(4)


class RbacPolicy(_messages.Message):
  r"""A RbacPolicy object.

  Fields:
    name: Name of the RbacPolicy.
    permissions: The list of permissions.
    principals: The list of principals.
  """

  name = _messages.StringField(1)
  permissions = _messages.MessageField('Permission', 2, repeated=True)
  principals = _messages.MessageField('Principal', 3, repeated=True)


class Reference(_messages.Message):
  r"""Represents a reference to a resource.

  Fields:
    kind: [Output Only] Type of the resource. Always compute#reference for
      references.
    referenceType: A description of the reference type with no implied
      semantics. Possible values include:   - MEMBER_OF
    referrer: URL of the resource which refers to the target.
    target: URL of the resource to which this reference points.
  """

  kind = _messages.StringField(1, default=u'compute#reference')
  referenceType = _messages.StringField(2)
  referrer = _messages.StringField(3)
  target = _messages.StringField(4)


class Region(_messages.Message):
  r"""Represents a Region resource.  A region is a geographical area where a
  resource is located. For more information, read Regions and Zones. (==
  resource_for {$api_version}.regions ==)

  Enums:
    StatusValueValuesEnum: [Output Only] Status of the region, either UP or
      DOWN.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    deprecated: [Output Only] The deprecation status associated with this
      region.
    description: [Output Only] Textual description of the resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#region for
      regions.
    name: [Output Only] Name of the resource.
    quotas: [Output Only] Quotas assigned to this region.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    status: [Output Only] Status of the region, either UP or DOWN.
    zones: [Output Only] A list of zones available in this region, in the form
      of resource URLs.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] Status of the region, either UP or DOWN.

    Values:
      DOWN: <no description>
      UP: <no description>
    """
    DOWN = 0
    UP = 1

  creationTimestamp = _messages.StringField(1)
  deprecated = _messages.MessageField('DeprecationStatus', 2)
  description = _messages.StringField(3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default=u'compute#region')
  name = _messages.StringField(6)
  quotas = _messages.MessageField('Quota', 7, repeated=True)
  selfLink = _messages.StringField(8)
  selfLinkWithId = _messages.StringField(9)
  status = _messages.EnumField('StatusValueValuesEnum', 10)
  zones = _messages.StringField(11, repeated=True)


class RegionAutoscalerList(_messages.Message):
  r"""Contains a list of autoscalers.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Autoscaler resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Autoscaler', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#regionAutoscalerList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class RegionCommitmentsUpdateReservationsRequest(_messages.Message):
  r"""A RegionCommitmentsUpdateReservationsRequest object.

  Fields:
    reservations: A list of two reservations to transfer GPUs and local SSD
      between.
  """

  reservations = _messages.MessageField('Reservation', 1, repeated=True)


class RegionDiskTypeList(_messages.Message):
  r"""A RegionDiskTypeList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of DiskType resources.
    kind: [Output Only] Type of resource. Always compute#regionDiskTypeList
      for region disk types.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('DiskType', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#regionDiskTypeList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class RegionDisksAddResourcePoliciesRequest(_messages.Message):
  r"""A RegionDisksAddResourcePoliciesRequest object.

  Fields:
    resourcePolicies: Resource policies to be added to this disk.
  """

  resourcePolicies = _messages.StringField(1, repeated=True)


class RegionDisksRemoveResourcePoliciesRequest(_messages.Message):
  r"""A RegionDisksRemoveResourcePoliciesRequest object.

  Fields:
    resourcePolicies: Resource policies to be removed from this disk.
  """

  resourcePolicies = _messages.StringField(1, repeated=True)


class RegionDisksResizeRequest(_messages.Message):
  r"""A RegionDisksResizeRequest object.

  Fields:
    sizeGb: The new size of the regional persistent disk, which is specified
      in GB.
  """

  sizeGb = _messages.IntegerField(1)


class RegionInstanceGroupList(_messages.Message):
  r"""Contains a list of InstanceGroup resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InstanceGroup resources.
    kind: The resource type.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('InstanceGroup', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#regionInstanceGroupList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class RegionInstanceGroupManagerDeleteInstanceConfigReq(_messages.Message):
  r"""RegionInstanceGroupManagers.deletePerInstanceConfigs

  Fields:
    names: The list of instance names for which we want to delete per-instance
      configs on this managed instance group.
  """

  names = _messages.StringField(1, repeated=True)


class RegionInstanceGroupManagerList(_messages.Message):
  r"""Contains a list of managed instance groups.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InstanceGroupManager resources.
    kind: [Output Only] The resource type, which is always
      compute#instanceGroupManagerList for a list of managed instance groups
      that exist in th regional scope.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('InstanceGroupManager', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#regionInstanceGroupManagerList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class RegionInstanceGroupManagerPatchInstanceConfigReq(_messages.Message):
  r"""RegionInstanceGroupManagers.patchPerInstanceConfigs

  Fields:
    perInstanceConfigs: The list of per-instance configs to insert or patch on
      this managed instance group.
  """

  perInstanceConfigs = _messages.MessageField('PerInstanceConfig', 1, repeated=True)


class RegionInstanceGroupManagerUpdateInstanceConfigReq(_messages.Message):
  r"""RegionInstanceGroupManagers.updatePerInstanceConfigs

  Fields:
    perInstanceConfigs: The list of per-instance configs to insert or patch on
      this managed instance group.
  """

  perInstanceConfigs = _messages.MessageField('PerInstanceConfig', 1, repeated=True)


class RegionInstanceGroupManagersAbandonInstancesRequest(_messages.Message):
  r"""A RegionInstanceGroupManagersAbandonInstancesRequest object.

  Fields:
    instances: The URLs of one or more instances to abandon. This can be a
      full URL or a partial URL, such as
      zones/[ZONE]/instances/[INSTANCE_NAME].
  """

  instances = _messages.StringField(1, repeated=True)


class RegionInstanceGroupManagersApplyUpdatesRequest(_messages.Message):
  r"""InstanceGroupManagers.applyUpdatesToInstances

  Enums:
    MaximalActionValueValuesEnum: The maximal action that should be performed
      on the instances. By default REPLACE. This field is deprecated, please
      use most_disruptive_allowed_action.
    MinimalActionValueValuesEnum: The minimal action that you want to perform
      on each instance during the update:   - REPLACE: At minimum, delete the
      instance and create it again.  - RESTART: Stop the instance and start it
      again.  - REFRESH: Do not stop the instance.  - NONE: Do not disrupt the
      instance at all.  By default, the minimum action is NONE. If your update
      requires a more disruptive action than you set with this flag, the
      necessary action is performed to execute the update.
    MostDisruptiveAllowedActionValueValuesEnum: The most disruptive action
      that you want to perform on each instance during the update:   -
      REPLACE: Delete the instance and create it again.  - RESTART: Stop the
      instance and start it again.  - REFRESH: Do not stop the instance.  -
      NONE: Do not disrupt the instance at all.  By default, the most
      disruptive allowed action is REPLACE. If your update requires a more
      disruptive action than you set with this flag, the update request will
      fail.

  Fields:
    instances: The list of URLs of one or more instances for which you want to
      apply updates. Each URL can be a full URL or a partial URL, such as
      zones/[ZONE]/instances/[INSTANCE_NAME].
    maximalAction: The maximal action that should be performed on the
      instances. By default REPLACE. This field is deprecated, please use
      most_disruptive_allowed_action.
    minimalAction: The minimal action that you want to perform on each
      instance during the update:   - REPLACE: At minimum, delete the instance
      and create it again.  - RESTART: Stop the instance and start it again.
      - REFRESH: Do not stop the instance.  - NONE: Do not disrupt the
      instance at all.  By default, the minimum action is NONE. If your update
      requires a more disruptive action than you set with this flag, the
      necessary action is performed to execute the update.
    mostDisruptiveAllowedAction: The most disruptive action that you want to
      perform on each instance during the update:   - REPLACE: Delete the
      instance and create it again.  - RESTART: Stop the instance and start it
      again.  - REFRESH: Do not stop the instance.  - NONE: Do not disrupt the
      instance at all.  By default, the most disruptive allowed action is
      REPLACE. If your update requires a more disruptive action than you set
      with this flag, the update request will fail.
  """

  class MaximalActionValueValuesEnum(_messages.Enum):
    r"""The maximal action that should be performed on the instances. By
    default REPLACE. This field is deprecated, please use
    most_disruptive_allowed_action.

    Values:
      NONE: <no description>
      REFRESH: <no description>
      REPLACE: <no description>
      RESTART: <no description>
    """
    NONE = 0
    REFRESH = 1
    REPLACE = 2
    RESTART = 3

  class MinimalActionValueValuesEnum(_messages.Enum):
    r"""The minimal action that you want to perform on each instance during
    the update:   - REPLACE: At minimum, delete the instance and create it
    again.  - RESTART: Stop the instance and start it again.  - REFRESH: Do
    not stop the instance.  - NONE: Do not disrupt the instance at all.  By
    default, the minimum action is NONE. If your update requires a more
    disruptive action than you set with this flag, the necessary action is
    performed to execute the update.

    Values:
      NONE: <no description>
      REFRESH: <no description>
      REPLACE: <no description>
      RESTART: <no description>
    """
    NONE = 0
    REFRESH = 1
    REPLACE = 2
    RESTART = 3

  class MostDisruptiveAllowedActionValueValuesEnum(_messages.Enum):
    r"""The most disruptive action that you want to perform on each instance
    during the update:   - REPLACE: Delete the instance and create it again.
    - RESTART: Stop the instance and start it again.  - REFRESH: Do not stop
    the instance.  - NONE: Do not disrupt the instance at all.  By default,
    the most disruptive allowed action is REPLACE. If your update requires a
    more disruptive action than you set with this flag, the update request
    will fail.

    Values:
      NONE: <no description>
      REFRESH: <no description>
      REPLACE: <no description>
      RESTART: <no description>
    """
    NONE = 0
    REFRESH = 1
    REPLACE = 2
    RESTART = 3

  instances = _messages.StringField(1, repeated=True)
  maximalAction = _messages.EnumField('MaximalActionValueValuesEnum', 2)
  minimalAction = _messages.EnumField('MinimalActionValueValuesEnum', 3)
  mostDisruptiveAllowedAction = _messages.EnumField('MostDisruptiveAllowedActionValueValuesEnum', 4)


class RegionInstanceGroupManagersCreateInstancesRequest(_messages.Message):
  r"""RegionInstanceGroupManagers.createInstances

  Fields:
    instances: [Required] List of specifications of per-instance configs.
  """

  instances = _messages.MessageField('PerInstanceConfig', 1, repeated=True)


class RegionInstanceGroupManagersDeleteInstancesRequest(_messages.Message):
  r"""A RegionInstanceGroupManagersDeleteInstancesRequest object.

  Fields:
    instances: The URLs of one or more instances to delete. This can be a full
      URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
  """

  instances = _messages.StringField(1, repeated=True)


class RegionInstanceGroupManagersListErrorsResponse(_messages.Message):
  r"""A RegionInstanceGroupManagersListErrorsResponse object.

  Fields:
    items: [Output Only] The list of errors of the managed instance group.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
  """

  items = _messages.MessageField('InstanceManagedByIgmError', 1, repeated=True)
  nextPageToken = _messages.StringField(2)


class RegionInstanceGroupManagersListInstanceConfigsResp(_messages.Message):
  r"""A RegionInstanceGroupManagersListInstanceConfigsResp object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    items: [Output Only] The list of PerInstanceConfig.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  items = _messages.MessageField('PerInstanceConfig', 1, repeated=True)
  nextPageToken = _messages.StringField(2)
  warning = _messages.MessageField('WarningValue', 3)


class RegionInstanceGroupManagersListInstancesResponse(_messages.Message):
  r"""A RegionInstanceGroupManagersListInstancesResponse object.

  Fields:
    managedInstances: A list of managed instances.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
  """

  managedInstances = _messages.MessageField('ManagedInstance', 1, repeated=True)
  nextPageToken = _messages.StringField(2)


class RegionInstanceGroupManagersRecreateRequest(_messages.Message):
  r"""A RegionInstanceGroupManagersRecreateRequest object.

  Fields:
    instances: The URLs of one or more instances to recreate. This can be a
      full URL or a partial URL, such as
      zones/[ZONE]/instances/[INSTANCE_NAME].
  """

  instances = _messages.StringField(1, repeated=True)


class RegionInstanceGroupManagersSetAutoHealingRequest(_messages.Message):
  r"""A RegionInstanceGroupManagersSetAutoHealingRequest object.

  Fields:
    autoHealingPolicies: A InstanceGroupManagerAutoHealingPolicy attribute.
  """

  autoHealingPolicies = _messages.MessageField('InstanceGroupManagerAutoHealingPolicy', 1, repeated=True)


class RegionInstanceGroupManagersSetTargetPoolsRequest(_messages.Message):
  r"""A RegionInstanceGroupManagersSetTargetPoolsRequest object.

  Fields:
    fingerprint: Fingerprint of the target pools information, which is a hash
      of the contents. This field is used for optimistic locking when you
      update the target pool entries. This field is optional.
    targetPools: The URL of all TargetPool resources to which instances in the
      instanceGroup field are added. The target pools automatically apply to
      all of the instances in the managed instance group.
  """

  fingerprint = _messages.BytesField(1)
  targetPools = _messages.StringField(2, repeated=True)


class RegionInstanceGroupManagersSetTemplateRequest(_messages.Message):
  r"""A RegionInstanceGroupManagersSetTemplateRequest object.

  Fields:
    instanceTemplate: URL of the InstanceTemplate resource from which all new
      instances will be created.
  """

  instanceTemplate = _messages.StringField(1)


class RegionInstanceGroupsListInstances(_messages.Message):
  r"""A RegionInstanceGroupsListInstances object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of InstanceWithNamedPorts resources.
    kind: The resource type.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('InstanceWithNamedPorts', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#regionInstanceGroupsListInstances')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class RegionInstanceGroupsListInstancesRequest(_messages.Message):
  r"""A RegionInstanceGroupsListInstancesRequest object.

  Enums:
    InstanceStateValueValuesEnum: Instances in which state should be returned.
      Valid options are: 'ALL', 'RUNNING'. By default, it lists all instances.

  Fields:
    instanceState: Instances in which state should be returned. Valid options
      are: 'ALL', 'RUNNING'. By default, it lists all instances.
    portName: Name of port user is interested in. It is optional. If it is
      set, only information about this ports will be returned. If it is not
      set, all the named ports will be returned. Always lists all instances.
  """

  class InstanceStateValueValuesEnum(_messages.Enum):
    r"""Instances in which state should be returned. Valid options are: 'ALL',
    'RUNNING'. By default, it lists all instances.

    Values:
      ALL: <no description>
      RUNNING: <no description>
    """
    ALL = 0
    RUNNING = 1

  instanceState = _messages.EnumField('InstanceStateValueValuesEnum', 1)
  portName = _messages.StringField(2)


class RegionInstanceGroupsSetNamedPortsRequest(_messages.Message):
  r"""A RegionInstanceGroupsSetNamedPortsRequest object.

  Fields:
    fingerprint: The fingerprint of the named ports information for this
      instance group. Use this optional property to prevent conflicts when
      multiple users change the named ports settings concurrently. Obtain the
      fingerprint with the instanceGroups.get method. Then, include the
      fingerprint in your request to ensure that you do not overwrite changes
      that were applied from another concurrent request.
    namedPorts: The list of named ports to set for this instance group.
  """

  fingerprint = _messages.BytesField(1)
  namedPorts = _messages.MessageField('NamedPort', 2, repeated=True)


class RegionList(_messages.Message):
  r"""Contains a list of region resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Region resources.
    kind: [Output Only] Type of resource. Always compute#regionList for lists
      of regions.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Region', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#regionList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class RegionSetLabelsRequest(_messages.Message):
  r"""A RegionSetLabelsRequest object.

  Messages:
    LabelsValue: The labels to set for this resource.

  Fields:
    labelFingerprint: The fingerprint of the previous set of labels for this
      resource, used to detect conflicts. The fingerprint is initially
      generated by Compute Engine and changes after every request to modify or
      update labels. You must always provide an up-to-date fingerprint hash in
      order to update or change labels. Make a get() request to the resource
      to get the latest fingerprint.
    labels: The labels to set for this resource.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""The labels to set for this resource.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  labelFingerprint = _messages.BytesField(1)
  labels = _messages.MessageField('LabelsValue', 2)


class RegionSetPolicyRequest(_messages.Message):
  r"""A RegionSetPolicyRequest object.

  Fields:
    bindings: Flatten Policy to create a backwacd compatible wire-format.
      Deprecated. Use 'policy' to specify bindings.
    etag: Flatten Policy to create a backward compatible wire-format.
      Deprecated. Use 'policy' to specify the etag.
    policy: REQUIRED: The complete policy to be applied to the 'resource'. The
      size of the policy is limited to a few 10s of KB. An empty policy is in
      general a valid policy but certain services (like Projects) might reject
      them.
  """

  bindings = _messages.MessageField('Binding', 1, repeated=True)
  etag = _messages.BytesField(2)
  policy = _messages.MessageField('Policy', 3)


class RegionTargetHttpsProxiesSetSslCertificatesRequest(_messages.Message):
  r"""A RegionTargetHttpsProxiesSetSslCertificatesRequest object.

  Fields:
    sslCertificates: New set of SslCertificate resources to associate with
      this TargetHttpsProxy resource. Currently exactly one SslCertificate
      resource must be specified.
  """

  sslCertificates = _messages.StringField(1, repeated=True)


class RegionUrlMapsValidateRequest(_messages.Message):
  r"""A RegionUrlMapsValidateRequest object.

  Fields:
    resource: Content of the UrlMap to be validated.
  """

  resource = _messages.MessageField('UrlMap', 1)


class RequestMirrorPolicy(_messages.Message):
  r"""A policy that specifies how requests intended for the route's backends
  are shadowed to a separate mirrored backend service. Loadbalancer does not
  wait for responses from the shadow service. Prior to sending traffic to the
  shadow service, the host / authority header is suffixed with -shadow.

  Fields:
    backendService: The full or partial URL to the BackendService resource
      being mirrored to.
  """

  backendService = _messages.StringField(1)


class Reservation(_messages.Message):
  r"""Represents a reservation resource. A reservation ensures that capacity
  is held in a specific zone even if the reserved VMs are not running. For
  more information, read  Reserving zonal resources. (== resource_for
  {$api_version}.reservations ==)

  Enums:
    StatusValueValuesEnum: [Output Only] The status of the reservation.

  Fields:
    commitment: [Output Only] Full or partial URL to a parent commitment. This
      field displays for reservations that are tied to a commitment.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#reservations for
      reservations.
    name: The name of the resource, provided by the client when initially
      creating the resource. The resource name must be 1-63 characters long,
      and comply with RFC1035. Specifically, the name must be 1-63 characters
      long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which
      means the first character must be a lowercase letter, and all following
      characters must be a dash, lowercase letter, or digit, except the last
      character, which cannot be a dash.
    selfLink: [Output Only] Server-defined fully-qualified URL for this
      resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    specificReservation: Reservation for instances with specific machine
      shapes.
    specificReservationRequired: Indicates whether the reservation can be
      consumed by VMs with affinity for "any" reservation. If the field is
      set, then only VMs that target the reservation by name can consume from
      this reservation.
    status: [Output Only] The status of the reservation.
    zone: Zone in which the reservation resides. A zone must be provided if
      the reservation is created within a commitment.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the reservation.

    Values:
      CREATING: <no description>
      DELETING: <no description>
      INVALID: <no description>
      READY: <no description>
      UPDATING: <no description>
    """
    CREATING = 0
    DELETING = 1
    INVALID = 2
    READY = 3
    UPDATING = 4

  commitment = _messages.StringField(1)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default=u'compute#reservation')
  name = _messages.StringField(6)
  selfLink = _messages.StringField(7)
  selfLinkWithId = _messages.StringField(8)
  specificReservation = _messages.MessageField('AllocationSpecificSKUReservation', 9)
  specificReservationRequired = _messages.BooleanField(10)
  status = _messages.EnumField('StatusValueValuesEnum', 11)
  zone = _messages.StringField(12)


class ReservationAffinity(_messages.Message):
  r"""Specifies the reservations that this instance can consume from.

  Enums:
    ConsumeReservationTypeValueValuesEnum: Specifies the type of reservation
      from which this instance can consume resources: ANY_RESERVATION
      (default), SPECIFIC_RESERVATION, or NO_RESERVATION. See  Consuming
      reserved instances for examples.

  Fields:
    consumeReservationType: Specifies the type of reservation from which this
      instance can consume resources: ANY_RESERVATION (default),
      SPECIFIC_RESERVATION, or NO_RESERVATION. See  Consuming reserved
      instances for examples.
    key: Corresponds to the label key of a reservation resource. To target a
      SPECIFIC_RESERVATION by name, specify googleapis.com/reservation-name as
      the key and specify the name of your reservation as its value.
    values: Corresponds to the label values of a reservation resource.
  """

  class ConsumeReservationTypeValueValuesEnum(_messages.Enum):
    r"""Specifies the type of reservation from which this instance can consume
    resources: ANY_RESERVATION (default), SPECIFIC_RESERVATION, or
    NO_RESERVATION. See  Consuming reserved instances for examples.

    Values:
      ANY_RESERVATION: <no description>
      NO_RESERVATION: <no description>
      SPECIFIC_RESERVATION: <no description>
      SPECIFIC_THEN_ANY_RESERVATION: <no description>
      UNSPECIFIED: <no description>
    """
    ANY_RESERVATION = 0
    NO_RESERVATION = 1
    SPECIFIC_RESERVATION = 2
    SPECIFIC_THEN_ANY_RESERVATION = 3
    UNSPECIFIED = 4

  consumeReservationType = _messages.EnumField('ConsumeReservationTypeValueValuesEnum', 1)
  key = _messages.StringField(2)
  values = _messages.StringField(3, repeated=True)


class ReservationAggregatedList(_messages.Message):
  r"""Contains a list of reservations.

  Messages:
    ItemsValue: A list of Allocation resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Allocation resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of Allocation resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        reservations.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A ReservationsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('ReservationsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#reservationAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class ReservationList(_messages.Message):
  r"""A ReservationList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    items: [Output Only] A list of Allocation resources.
    kind: [Output Only] Type of resource.Always compute#reservationsList for
      listsof reservations
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Reservation', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#reservationList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class ReservationsResizeRequest(_messages.Message):
  r"""A ReservationsResizeRequest object.

  Fields:
    specificSkuCount: Number of allocated resources can be resized with
      minimum = 1 and maximum = 1000.
  """

  specificSkuCount = _messages.IntegerField(1)


class ReservationsScopedList(_messages.Message):
  r"""A ReservationsScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of
      reservations when the list is empty.

  Fields:
    reservations: A list of reservations contained in this scope.
    warning: Informational warning which replaces the list of reservations
      when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of reservations when the
    list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  reservations = _messages.MessageField('Reservation', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class ResourceCommitment(_messages.Message):
  r"""Commitment for a particular resource (a Commitment is composed of one or
  more of these).

  Enums:
    TypeValueValuesEnum: Type of resource for which this commitment applies.
      Possible values are VCPU and MEMORY

  Fields:
    acceleratorType: Name of the accelerator type resource. Applicable only
      when the type is ACCELERATOR.
    amount: The amount of the resource purchased (in a type-dependent unit,
      such as bytes). For vCPUs, this can just be an integer. For memory, this
      must be provided in MB. Memory must be a multiple of 256 MB, with up to
      6.5GB of memory per every vCPU.
    type: Type of resource for which this commitment applies. Possible values
      are VCPU and MEMORY
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""Type of resource for which this commitment applies. Possible values
    are VCPU and MEMORY

    Values:
      ACCELERATOR: <no description>
      LOCAL_SSD: <no description>
      MEMORY: <no description>
      UNSPECIFIED: <no description>
      VCPU: <no description>
    """
    ACCELERATOR = 0
    LOCAL_SSD = 1
    MEMORY = 2
    UNSPECIFIED = 3
    VCPU = 4

  acceleratorType = _messages.StringField(1)
  amount = _messages.IntegerField(2)
  type = _messages.EnumField('TypeValueValuesEnum', 3)


class ResourceGroupReference(_messages.Message):
  r"""A ResourceGroupReference object.

  Fields:
    group: A URI referencing one of the instance groups or network endpoint
      groups listed in the backend service.
  """

  group = _messages.StringField(1)


class ResourcePoliciesScopedList(_messages.Message):
  r"""A ResourcePoliciesScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of
      resourcePolicies when the list is empty.

  Fields:
    resourcePolicies: A list of resourcePolicies contained in this scope.
    warning: Informational warning which replaces the list of resourcePolicies
      when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of resourcePolicies when
    the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  resourcePolicies = _messages.MessageField('ResourcePolicy', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class ResourcePolicy(_messages.Message):
  r"""Represents a Resource Policy resource. You can use resource policies to
  schedule actions for some Compute Engine resources. For example, you can use
  them to schedule persistent disk snapshots.  (== resource_for
  {$api_version}.resourcePolicies ==)

  Enums:
    StatusValueValuesEnum: [Output Only] The status of resource policy
      creation.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: A string attribute.
    groupPlacementPolicy: Resource policy for instacnes for placement
      configuration.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#resource_policies
      for resource policies.
    name: The name of the resource, provided by the client when initially
      creating the resource. The resource name must be 1-63 characters long,
      and comply with RFC1035. Specifically, the name must be 1-63 characters
      long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which
      means the first character must be a lowercase letter, and all following
      characters must be a dash, lowercase letter, or digit, except the last
      character, which cannot be a dash.
    region: A string attribute.
    selfLink: [Output Only] Server-defined fully-qualified URL for this
      resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    snapshotSchedulePolicy: Resource policy for persistent disks for creating
      snapshots.
    status: [Output Only] The status of resource policy creation.
    vmMaintenancePolicy: Resource policy applicable to VMs for infrastructure
      maintenance.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of resource policy creation.

    Values:
      CREATING: <no description>
      DELETING: <no description>
      INVALID: <no description>
      READY: <no description>
    """
    CREATING = 0
    DELETING = 1
    INVALID = 2
    READY = 3

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  groupPlacementPolicy = _messages.MessageField('ResourcePolicyGroupPlacementPolicy', 3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default=u'compute#resourcePolicy')
  name = _messages.StringField(6)
  region = _messages.StringField(7)
  selfLink = _messages.StringField(8)
  selfLinkWithId = _messages.StringField(9)
  snapshotSchedulePolicy = _messages.MessageField('ResourcePolicySnapshotSchedulePolicy', 10)
  status = _messages.EnumField('StatusValueValuesEnum', 11)
  vmMaintenancePolicy = _messages.MessageField('ResourcePolicyVmMaintenancePolicy', 12)


class ResourcePolicyAggregatedList(_messages.Message):
  r"""Contains a list of resourcePolicies.

  Messages:
    ItemsValue: A list of ResourcePolicy resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of ResourcePolicy resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of ResourcePolicy resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        resourcePolicies.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A ResourcePoliciesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('ResourcePoliciesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('ItemsValue', 3)
  kind = _messages.StringField(4, default=u'compute#resourcePolicyAggregatedList')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  unreachables = _messages.StringField(7, repeated=True)
  warning = _messages.MessageField('WarningValue', 8)


class ResourcePolicyDailyCycle(_messages.Message):
  r"""Time window specified for daily operations.

  Fields:
    daysInCycle: Defines a schedule with units measured in months. The value
      determines how many months pass between the start of each cycle.
    duration: [Output only] A predetermined duration for the window,
      automatically chosen to be the smallest possible in the given scenario.
    startTime: Start time of the window. This must be in UTC format that
      resolves to one of 00:00, 04:00, 08:00, 12:00, 16:00, or 20:00. For
      example, both 13:00-5 and 08:00 are valid.
  """

  daysInCycle = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  duration = _messages.StringField(2)
  startTime = _messages.StringField(3)


class ResourcePolicyGroupPlacementPolicy(_messages.Message):
  r"""A GroupPlacementPolicy specifies resource placement configuration. It
  specifies the failure bucket separation as well as network locality

  Enums:
    CollocationValueValuesEnum: Specifies network collocation
    LocalityValueValuesEnum: Specifies network locality
    StyleValueValuesEnum: Specifies instances to hosts placement relationship

  Fields:
    availabilityDomainCount: The number of availability domains instances will
      be spread across. If two instances are in different availability domain,
      they will not be put in the same low latency network
    collocation: Specifies network collocation
    locality: Specifies network locality
    style: Specifies instances to hosts placement relationship
    vmCount: Number of vms in this placement group
  """

  class CollocationValueValuesEnum(_messages.Enum):
    r"""Specifies network collocation

    Values:
      COLLOCATED: <no description>
      UNSPECIFIED_COLLOCATION: <no description>
    """
    COLLOCATED = 0
    UNSPECIFIED_COLLOCATION = 1

  class LocalityValueValuesEnum(_messages.Enum):
    r"""Specifies network locality

    Values:
      BEST_EFFORT: <no description>
      STRICT: <no description>
      UNSPECIFIED_LOCALITY: <no description>
    """
    BEST_EFFORT = 0
    STRICT = 1
    UNSPECIFIED_LOCALITY = 2

  class StyleValueValuesEnum(_messages.Enum):
    r"""Specifies instances to hosts placement relationship

    Values:
      COMPACT: <no description>
      FULLY_SPREAD: <no description>
      UNSPECIFIED_PLACEMENT_TYPE: <no description>
    """
    COMPACT = 0
    FULLY_SPREAD = 1
    UNSPECIFIED_PLACEMENT_TYPE = 2

  availabilityDomainCount = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  collocation = _messages.EnumField('CollocationValueValuesEnum', 2)
  locality = _messages.EnumField('LocalityValueValuesEnum', 3)
  style = _messages.EnumField('StyleValueValuesEnum', 4)
  vmCount = _messages.IntegerField(5, variant=_messages.Variant.INT32)


class ResourcePolicyHourlyCycle(_messages.Message):
  r"""Time window specified for hourly operations.

  Fields:
    duration: [Output only] Duration of the time window, automatically chosen
      to be smallest possible in the given scenario.
    hoursInCycle: Defines a schedule with units measured in hours. The value
      determines how many hours pass between the start of each cycle.
    startTime: Time within the window to start the operations. It must be in
      format "HH:MM", where HH : [00-23] and MM : [00-00] GMT.
  """

  duration = _messages.StringField(1)
  hoursInCycle = _messages.IntegerField(2, variant=_messages.Variant.INT32)
  startTime = _messages.StringField(3)


class ResourcePolicyList(_messages.Message):
  r"""A ResourcePolicyList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    etag: A string attribute.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    items: [Output Only] A list of ResourcePolicy resources.
    kind: [Output Only] Type of resource.Always compute#resourcePoliciesList
      for listsof resourcePolicies
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  etag = _messages.StringField(1)
  id = _messages.StringField(2)
  items = _messages.MessageField('ResourcePolicy', 3, repeated=True)
  kind = _messages.StringField(4, default=u'compute#resourcePolicyList')
  nextPageToken = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  warning = _messages.MessageField('WarningValue', 7)


class ResourcePolicySnapshotSchedulePolicy(_messages.Message):
  r"""A snapshot schedule policy specifies when and how frequently snapshots
  are to be created for the target disk. Also specifies how many and how long
  these scheduled snapshots should be retained.

  Fields:
    retentionPolicy: Retention policy applied to snapshots created by this
      resource policy.
    schedule: A Vm Maintenance Policy specifies what kind of infrastructure
      maintenance we are allowed to perform on this VM and when. Schedule that
      is applied to disks covered by this policy.
    snapshotProperties: Properties with which snapshots are created such as
      labels, encryption keys.
  """

  retentionPolicy = _messages.MessageField('ResourcePolicySnapshotSchedulePolicyRetentionPolicy', 1)
  schedule = _messages.MessageField('ResourcePolicySnapshotSchedulePolicySchedule', 2)
  snapshotProperties = _messages.MessageField('ResourcePolicySnapshotSchedulePolicySnapshotProperties', 3)


class ResourcePolicySnapshotSchedulePolicyRetentionPolicy(_messages.Message):
  r"""Policy for retention of scheduled snapshots.

  Enums:
    OnPolicySwitchValueValuesEnum: Specifies the behavior to apply to
      existing, scheduled snapshots snapshots if the policy is changed.
    OnSourceDiskDeleteValueValuesEnum: Specifies the behavior to apply to
      scheduled snapshots when the source disk is deleted.

  Fields:
    maxRetentionDays: Maximum age of the snapshot that is allowed to be kept.
    onPolicySwitch: Specifies the behavior to apply to existing, scheduled
      snapshots snapshots if the policy is changed.
    onSourceDiskDelete: Specifies the behavior to apply to scheduled snapshots
      when the source disk is deleted.
  """

  class OnPolicySwitchValueValuesEnum(_messages.Enum):
    r"""Specifies the behavior to apply to existing, scheduled snapshots
    snapshots if the policy is changed.

    Values:
      DO_NOT_RETROACTIVELY_APPLY: <no description>
      RETROACTIVELY_APPLY: <no description>
      UNSPECIFIED_ON_POLICY_SWITCH: <no description>
    """
    DO_NOT_RETROACTIVELY_APPLY = 0
    RETROACTIVELY_APPLY = 1
    UNSPECIFIED_ON_POLICY_SWITCH = 2

  class OnSourceDiskDeleteValueValuesEnum(_messages.Enum):
    r"""Specifies the behavior to apply to scheduled snapshots when the source
    disk is deleted.

    Values:
      APPLY_RETENTION_POLICY: <no description>
      KEEP_AUTO_SNAPSHOTS: <no description>
      UNSPECIFIED_ON_SOURCE_DISK_DELETE: <no description>
    """
    APPLY_RETENTION_POLICY = 0
    KEEP_AUTO_SNAPSHOTS = 1
    UNSPECIFIED_ON_SOURCE_DISK_DELETE = 2

  maxRetentionDays = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  onPolicySwitch = _messages.EnumField('OnPolicySwitchValueValuesEnum', 2)
  onSourceDiskDelete = _messages.EnumField('OnSourceDiskDeleteValueValuesEnum', 3)


class ResourcePolicySnapshotSchedulePolicySchedule(_messages.Message):
  r"""A schedule for disks where the schedueled operations are performed.

  Fields:
    dailySchedule: A ResourcePolicyDailyCycle attribute.
    hourlySchedule: A ResourcePolicyHourlyCycle attribute.
    weeklySchedule: A ResourcePolicyWeeklyCycle attribute.
  """

  dailySchedule = _messages.MessageField('ResourcePolicyDailyCycle', 1)
  hourlySchedule = _messages.MessageField('ResourcePolicyHourlyCycle', 2)
  weeklySchedule = _messages.MessageField('ResourcePolicyWeeklyCycle', 3)


class ResourcePolicySnapshotSchedulePolicySnapshotProperties(_messages.Message):
  r"""Specified snapshot properties for scheduled snapshots created by this
  policy.

  Messages:
    LabelsValue: Labels to apply to scheduled snapshots. These can be later
      modified by the setLabels method. Label values may be empty.

  Fields:
    guestFlush: Indication to perform a 'guest aware' snapshot.
    labels: Labels to apply to scheduled snapshots. These can be later
      modified by the setLabels method. Label values may be empty.
    storageLocations: Cloud Storage bucket storage location of the auto
      snapshot (regional or multi-regional).
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels to apply to scheduled snapshots. These can be later modified by
    the setLabels method. Label values may be empty.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  guestFlush = _messages.BooleanField(1)
  labels = _messages.MessageField('LabelsValue', 2)
  storageLocations = _messages.StringField(3, repeated=True)


class ResourcePolicyVmMaintenancePolicy(_messages.Message):
  r"""A ResourcePolicyVmMaintenancePolicy object.

  Fields:
    concurrencyControlGroup: A
      ResourcePolicyVmMaintenancePolicyConcurrencyControl attribute.
    maintenanceWindow: Maintenance windows that are applied to VMs covered by
      this policy.
  """

  concurrencyControlGroup = _messages.MessageField('ResourcePolicyVmMaintenancePolicyConcurrencyControl', 1)
  maintenanceWindow = _messages.MessageField('ResourcePolicyVmMaintenancePolicyMaintenanceWindow', 2)


class ResourcePolicyVmMaintenancePolicyConcurrencyControl(_messages.Message):
  r"""A concurrency control configuration. Defines a group config that, when
  attached to an instance, recognizes that instance as part of a group of
  instances where only up the concurrency_limit of instances in that group can
  undergo simultaneous maintenance. For more information: go/concurrency-
  control-design-doc

  Fields:
    concurrencyLimit: A integer attribute.
  """

  concurrencyLimit = _messages.IntegerField(1, variant=_messages.Variant.INT32)


class ResourcePolicyVmMaintenancePolicyMaintenanceWindow(_messages.Message):
  r"""A maintenance window for VMs. When set, we restrict our maintenance
  operations to this window.

  Fields:
    dailyMaintenanceWindow: A ResourcePolicyDailyCycle attribute.
  """

  dailyMaintenanceWindow = _messages.MessageField('ResourcePolicyDailyCycle', 1)


class ResourcePolicyWeeklyCycle(_messages.Message):
  r"""Time window specified for weekly operations.

  Fields:
    dayOfWeeks: Up to 7 intervals/windows, one for each day of the week.
  """

  dayOfWeeks = _messages.MessageField('ResourcePolicyWeeklyCycleDayOfWeek', 1, repeated=True)


class ResourcePolicyWeeklyCycleDayOfWeek(_messages.Message):
  r"""A ResourcePolicyWeeklyCycleDayOfWeek object.

  Enums:
    DayValueValuesEnum: Defines a schedule that runs on specific days of the
      week. Specify one or more days. The following options are available:
      MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY.

  Fields:
    day: Defines a schedule that runs on specific days of the week. Specify
      one or more days. The following options are available: MONDAY, TUESDAY,
      WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY.
    duration: [Output only] Duration of the time window, automatically chosen
      to be smallest possible in the given scenario.
    startTime: Time within the window to start the operations. It must be in
      format "HH:MM", where HH : [00-23] and MM : [00-00] GMT.
  """

  class DayValueValuesEnum(_messages.Enum):
    r"""Defines a schedule that runs on specific days of the week. Specify one
    or more days. The following options are available: MONDAY, TUESDAY,
    WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY.

    Values:
      FRIDAY: <no description>
      INVALID: <no description>
      MONDAY: <no description>
      SATURDAY: <no description>
      SUNDAY: <no description>
      THURSDAY: <no description>
      TUESDAY: <no description>
      WEDNESDAY: <no description>
    """
    FRIDAY = 0
    INVALID = 1
    MONDAY = 2
    SATURDAY = 3
    SUNDAY = 4
    THURSDAY = 5
    TUESDAY = 6
    WEDNESDAY = 7

  day = _messages.EnumField('DayValueValuesEnum', 1)
  duration = _messages.StringField(2)
  startTime = _messages.StringField(3)


class Route(_messages.Message):
  r"""Represents a Route resource.  A route defines a path from VM instances
  in the VPC network to a specific destination. This destination can be inside
  or outside the VPC network. For more information, read the Routes overview.
  (== resource_for {$api_version}.routes ==)

  Messages:
    WarningsValueListEntry: A WarningsValueListEntry object.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this field
      when you create the resource.
    destRange: The destination range of outgoing packets that this route
      applies to. Only IPv4 is supported.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of this resource. Always compute#routes for Route
      resources.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?`. The first character
      must be a lowercase letter, and all following characters (except for the
      last character) must be a dash, lowercase letter, or digit. The last
      character must be a lowercase letter or digit.
    network: Fully-qualified URL of the network that this route applies to.
    nextHopGateway: The URL to a gateway that should handle matching packets.
      You can only specify the internet gateway using a full or partial valid
      URL:  projects/project/global/gateways/default-internet-gateway
    nextHopIlb: The URL to a forwarding rule of type
      loadBalancingScheme=INTERNAL that should handle matching packets. You
      can only specify the forwarding rule as a partial or full URL. For
      example, the following are all valid URLs:   - https://www.googleapis.co
      m/compute/v1/projects/project/regions/region/forwardingRules/forwardingR
      ule  - regions/region/forwardingRules/forwardingRule
    nextHopInstance: The URL to an instance that should handle matching
      packets. You can specify this as a full or partial URL. For example: htt
      ps://www.googleapis.com/compute/v1/projects/project/zones/zone/instances
      /
    nextHopInterconnectAttachment: [Output Only] The URL to an
      InterconnectAttachment which is the next hop for the route. This field
      will only be populated for the dynamic routes generated by Cloud Router
      with a linked interconnectAttachment.
    nextHopIp: The network IP address of an instance that should handle
      matching packets. Only IPv4 is supported.
    nextHopNetwork: The URL of the local network if it should handle matching
      packets.
    nextHopPeering: [Output Only] The network peering name that should handle
      matching packets, which should conform to RFC1035.
    nextHopVpnTunnel: The URL to a VpnTunnel that should handle matching
      packets.
    priority: The priority of this route. Priority is used to break ties in
      cases where there is more than one matching route of equal prefix
      length. In cases where multiple routes have equal prefix length, the one
      with the lowest-numbered priority value wins. The default value is
      `1000`. The priority value must be from `0` to `65535`, inclusive.
    selfLink: [Output Only] Server-defined fully-qualified URL for this
      resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    tags: A list of instance tags to which this route applies.
    warnings: [Output Only] If potential misconfigurations are detected for
      this route, this field will be populated with warning messages.
  """

  class WarningsValueListEntry(_messages.Message):
    r"""A WarningsValueListEntry object.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  destRange = _messages.StringField(3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default=u'compute#route')
  name = _messages.StringField(6)
  network = _messages.StringField(7)
  nextHopGateway = _messages.StringField(8)
  nextHopIlb = _messages.StringField(9)
  nextHopInstance = _messages.StringField(10)
  nextHopInterconnectAttachment = _messages.StringField(11)
  nextHopIp = _messages.StringField(12)
  nextHopNetwork = _messages.StringField(13)
  nextHopPeering = _messages.StringField(14)
  nextHopVpnTunnel = _messages.StringField(15)
  priority = _messages.IntegerField(16, variant=_messages.Variant.UINT32)
  selfLink = _messages.StringField(17)
  selfLinkWithId = _messages.StringField(18)
  tags = _messages.StringField(19, repeated=True)
  warnings = _messages.MessageField('WarningsValueListEntry', 20, repeated=True)


class RouteList(_messages.Message):
  r"""Contains a list of Route resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Route resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Route', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#routeList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class Router(_messages.Message):
  r"""Represents a Cloud Router resource.  For more information about Cloud
  Router, read the the Cloud Router overview.

  Fields:
    bgp: BGP information specific to this router.
    bgpPeers: BGP information that must be configured into the routing stack
      to establish BGP peering. This information must specify the peer ASN and
      either the interface name, IP address, or peer IP address. Please refer
      to RFC4273.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    interfaces: Router interfaces. Each interface requires either one linked
      resource, (for example, linkedVpnTunnel), or IP address and IP address
      range (for example, ipRange), or both.
    kind: [Output Only] Type of resource. Always compute#router for routers.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    nats: A list of NAT services created in this router.
    network: URI of the network to which this router belongs.
    region: [Output Only] URI of the region where the router resides. You must
      specify this field as part of the HTTP request URL. It is not settable
      as a field in the request body.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
  """

  bgp = _messages.MessageField('RouterBgp', 1)
  bgpPeers = _messages.MessageField('RouterBgpPeer', 2, repeated=True)
  creationTimestamp = _messages.StringField(3)
  description = _messages.StringField(4)
  id = _messages.IntegerField(5, variant=_messages.Variant.UINT64)
  interfaces = _messages.MessageField('RouterInterface', 6, repeated=True)
  kind = _messages.StringField(7, default=u'compute#router')
  name = _messages.StringField(8)
  nats = _messages.MessageField('RouterNat', 9, repeated=True)
  network = _messages.StringField(10)
  region = _messages.StringField(11)
  selfLink = _messages.StringField(12)
  selfLinkWithId = _messages.StringField(13)


class RouterAdvertisedIpRange(_messages.Message):
  r"""Description-tagged IP ranges for the router to advertise.

  Fields:
    description: User-specified description for the IP range.
    range: The IP range to advertise. The value must be a CIDR-formatted
      string.
  """

  description = _messages.StringField(1)
  range = _messages.StringField(2)


class RouterAggregatedList(_messages.Message):
  r"""Contains a list of routers.

  Messages:
    ItemsValue: A list of Router resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Router resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of Router resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of routers.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A RoutersScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('RoutersScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#routerAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class RouterBgp(_messages.Message):
  r"""A RouterBgp object.

  Enums:
    AdvertiseModeValueValuesEnum: User-specified flag to indicate which mode
      to use for advertisement. The options are DEFAULT or CUSTOM.
    AdvertisedGroupsValueListEntryValuesEnum:

  Fields:
    advertiseMode: User-specified flag to indicate which mode to use for
      advertisement. The options are DEFAULT or CUSTOM.
    advertisedGroups: User-specified list of prefix groups to advertise in
      custom mode. This field can only be populated if advertise_mode is
      CUSTOM and is advertised to all peers of the router. These groups will
      be advertised in addition to any specified prefixes. Leave this field
      blank to advertise no custom groups.
    advertisedIpRanges: User-specified list of individual IP ranges to
      advertise in custom mode. This field can only be populated if
      advertise_mode is CUSTOM and is advertised to all peers of the router.
      These IP ranges will be advertised in addition to any specified groups.
      Leave this field blank to advertise no custom IP ranges.
    asn: Local BGP Autonomous System Number (ASN). Must be an RFC6996 private
      ASN, either 16-bit or 32-bit. The value will be fixed for this router
      resource. All VPN tunnels that link to this router will have the same
      local ASN.
    keepaliveInterval: The interval in seconds between BGP keepalive messages
      that are sent to the peer. Hold time is three times the interval at
      which keepalive messages are sent, and the hold time is the maximum
      number of seconds allowed to elapse between successive keepalive
      messages that BGP receives from a peer. BGP will use the smaller of
      either the local hold time value or the peer's hold time value as the
      hold time for the BGP connection between the two peers. If set, this
      value must be between 1 and 120. The default is 20.
  """

  class AdvertiseModeValueValuesEnum(_messages.Enum):
    r"""User-specified flag to indicate which mode to use for advertisement.
    The options are DEFAULT or CUSTOM.

    Values:
      CUSTOM: <no description>
      DEFAULT: <no description>
    """
    CUSTOM = 0
    DEFAULT = 1

  class AdvertisedGroupsValueListEntryValuesEnum(_messages.Enum):
    r"""AdvertisedGroupsValueListEntryValuesEnum enum type.

    Values:
      ALL_PEER_VPC_SUBNETS: <no description>
      ALL_SUBNETS: <no description>
      ALL_VPC_SUBNETS: <no description>
    """
    ALL_PEER_VPC_SUBNETS = 0
    ALL_SUBNETS = 1
    ALL_VPC_SUBNETS = 2

  advertiseMode = _messages.EnumField('AdvertiseModeValueValuesEnum', 1)
  advertisedGroups = _messages.EnumField('AdvertisedGroupsValueListEntryValuesEnum', 2, repeated=True)
  advertisedIpRanges = _messages.MessageField('RouterAdvertisedIpRange', 3, repeated=True)
  asn = _messages.IntegerField(4, variant=_messages.Variant.UINT32)
  keepaliveInterval = _messages.IntegerField(5, variant=_messages.Variant.UINT32)


class RouterBgpPeer(_messages.Message):
  r"""A RouterBgpPeer object.

  Enums:
    AdvertiseModeValueValuesEnum: User-specified flag to indicate which mode
      to use for advertisement.
    AdvertisedGroupsValueListEntryValuesEnum:
    EnableValueValuesEnum: The status of the BGP peer connection. If set to
      FALSE, any active session with the peer is terminated and all associated
      routing information is removed. If set to TRUE, the peer connection can
      be established with routing information. The default is TRUE.
    ManagementTypeValueValuesEnum: [Output Only] The resource that configures
      and manages this BGP peer.  - MANAGED_BY_USER is the default value and
      can be managed by you or other users  - MANAGED_BY_ATTACHMENT is a BGP
      peer that is configured and managed by Cloud Interconnect, specifically
      by an InterconnectAttachment of type PARTNER. Google automatically
      creates, updates, and deletes this type of BGP peer when the PARTNER
      InterconnectAttachment is created, updated, or deleted.

  Fields:
    advertiseMode: User-specified flag to indicate which mode to use for
      advertisement.
    advertisedGroups: User-specified list of prefix groups to advertise in
      custom mode, which can take one of the following options:  -
      ALL_SUBNETS: Advertises all available subnets, including peer VPC
      subnets.  - ALL_VPC_SUBNETS: Advertises the router's own VPC subnets.  -
      ALL_PEER_VPC_SUBNETS: Advertises peer subnets of the router's VPC
      network. Note that this field can only be populated if advertise_mode is
      CUSTOM and overrides the list defined for the router (in the "bgp"
      message). These groups are advertised in addition to any specified
      prefixes. Leave this field blank to advertise no custom groups.
    advertisedIpRanges: User-specified list of individual IP ranges to
      advertise in custom mode. This field can only be populated if
      advertise_mode is CUSTOM and overrides the list defined for the router
      (in the "bgp" message). These IP ranges are advertised in addition to
      any specified groups. Leave this field blank to advertise no custom IP
      ranges.
    advertisedRoutePriority: The priority of routes advertised to this BGP
      peer. Where there is more than one matching route of maximum length, the
      routes with the lowest priority value win.
    bfd: BFD configuration for the BGP peering.
    enable: The status of the BGP peer connection. If set to FALSE, any active
      session with the peer is terminated and all associated routing
      information is removed. If set to TRUE, the peer connection can be
      established with routing information. The default is TRUE.
    interfaceName: Name of the interface the BGP peer is associated with.
    ipAddress: IP address of the interface inside Google Cloud Platform. Only
      IPv4 is supported.
    managementType: [Output Only] The resource that configures and manages
      this BGP peer.  - MANAGED_BY_USER is the default value and can be
      managed by you or other users  - MANAGED_BY_ATTACHMENT is a BGP peer
      that is configured and managed by Cloud Interconnect, specifically by an
      InterconnectAttachment of type PARTNER. Google automatically creates,
      updates, and deletes this type of BGP peer when the PARTNER
      InterconnectAttachment is created, updated, or deleted.
    name: Name of this BGP peer. The name must be 1-63 characters long, and
      comply with RFC1035. Specifically, the name must be 1-63 characters long
      and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which
      means the first character must be a lowercase letter, and all following
      characters must be a dash, lowercase letter, or digit, except the last
      character, which cannot be a dash.
    peerAsn: Peer BGP Autonomous System Number (ASN). Each BGP interface may
      use a different value.
    peerIpAddress: IP address of the BGP interface outside Google Cloud
      Platform. Only IPv4 is supported.
  """

  class AdvertiseModeValueValuesEnum(_messages.Enum):
    r"""User-specified flag to indicate which mode to use for advertisement.

    Values:
      CUSTOM: <no description>
      DEFAULT: <no description>
    """
    CUSTOM = 0
    DEFAULT = 1

  class AdvertisedGroupsValueListEntryValuesEnum(_messages.Enum):
    r"""AdvertisedGroupsValueListEntryValuesEnum enum type.

    Values:
      ALL_PEER_VPC_SUBNETS: <no description>
      ALL_SUBNETS: <no description>
      ALL_VPC_SUBNETS: <no description>
    """
    ALL_PEER_VPC_SUBNETS = 0
    ALL_SUBNETS = 1
    ALL_VPC_SUBNETS = 2

  class EnableValueValuesEnum(_messages.Enum):
    r"""The status of the BGP peer connection. If set to FALSE, any active
    session with the peer is terminated and all associated routing information
    is removed. If set to TRUE, the peer connection can be established with
    routing information. The default is TRUE.

    Values:
      FALSE: <no description>
      TRUE: <no description>
    """
    FALSE = 0
    TRUE = 1

  class ManagementTypeValueValuesEnum(_messages.Enum):
    r"""[Output Only] The resource that configures and manages this BGP peer.
    - MANAGED_BY_USER is the default value and can be managed by you or other
    users  - MANAGED_BY_ATTACHMENT is a BGP peer that is configured and
    managed by Cloud Interconnect, specifically by an InterconnectAttachment
    of type PARTNER. Google automatically creates, updates, and deletes this
    type of BGP peer when the PARTNER InterconnectAttachment is created,
    updated, or deleted.

    Values:
      MANAGED_BY_ATTACHMENT: <no description>
      MANAGED_BY_USER: <no description>
    """
    MANAGED_BY_ATTACHMENT = 0
    MANAGED_BY_USER = 1

  advertiseMode = _messages.EnumField('AdvertiseModeValueValuesEnum', 1)
  advertisedGroups = _messages.EnumField('AdvertisedGroupsValueListEntryValuesEnum', 2, repeated=True)
  advertisedIpRanges = _messages.MessageField('RouterAdvertisedIpRange', 3, repeated=True)
  advertisedRoutePriority = _messages.IntegerField(4, variant=_messages.Variant.UINT32)
  bfd = _messages.MessageField('RouterBgpPeerBfd', 5)
  enable = _messages.EnumField('EnableValueValuesEnum', 6)
  interfaceName = _messages.StringField(7)
  ipAddress = _messages.StringField(8)
  managementType = _messages.EnumField('ManagementTypeValueValuesEnum', 9)
  name = _messages.StringField(10)
  peerAsn = _messages.IntegerField(11, variant=_messages.Variant.UINT32)
  peerIpAddress = _messages.StringField(12)


class RouterBgpPeerBfd(_messages.Message):
  r"""A RouterBgpPeerBfd object.

  Enums:
    ModeValueValuesEnum: The BFD session initialization mode for this BGP
      peer. If set to ACTIVE, the Cloud Router will initiate the BFD session
      for this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
      peer router to initiate the BFD session for this BGP peer. If set to
      DISABLED, BFD is disabled for this BGP peer. The default is PASSIVE.
    PacketModeValueValuesEnum: The BFD packet mode for this BGP peer. If set
      to CONTROL_AND_ECHO, BFD echo mode is enabled for this BGP peer. In this
      mode, if the peer router also has BFD echo mode enabled, BFD echo
      packets will be sent to the other router. If the peer router does not
      have BFD echo mode enabled, only control packets will be sent. If set to
      CONTROL_ONLY, BFD echo mode is disabled for this BGP peer. If this
      router and the peer router have a multihop connection, this should be
      set to CONTROL_ONLY as BFD echo mode is only supported on singlehop
      connections. The default is CONTROL_AND_ECHO.
    SessionInitializationModeValueValuesEnum: The BFD session initialization
      mode for this BGP peer. If set to ACTIVE, the Cloud Router will initiate
      the BFD session for this BGP peer. If set to PASSIVE, the Cloud Router
      will wait for the peer router to initiate the BFD session for this BGP
      peer. If set to DISABLED, BFD is disabled for this BGP peer. The default
      is PASSIVE.

  Fields:
    minReceiveInterval: The minimum interval, in milliseconds, between BFD
      control packets received from the peer router. The actual value is
      negotiated between the two routers and is equal to the greater of this
      value and the transmit interval of the other router. If set, this value
      must be between 100 and 30000. The default is 300.
    minTransmitInterval: The minimum interval, in milliseconds, between BFD
      control packets transmitted to the peer router. The actual value is
      negotiated between the two routers and is equal to the greater of this
      value and the corresponding receive interval of the other router. If
      set, this value must be between 100 and 30000. The default is 300.
    mode: The BFD session initialization mode for this BGP peer. If set to
      ACTIVE, the Cloud Router will initiate the BFD session for this BGP
      peer. If set to PASSIVE, the Cloud Router will wait for the peer router
      to initiate the BFD session for this BGP peer. If set to DISABLED, BFD
      is disabled for this BGP peer. The default is PASSIVE.
    multiplier: The number of consecutive BFD packets that must be missed
      before BFD declares that a peer is unavailable. If set, the value must
      be a value between 2 and 16. The default is 3.
    packetMode: The BFD packet mode for this BGP peer. If set to
      CONTROL_AND_ECHO, BFD echo mode is enabled for this BGP peer. In this
      mode, if the peer router also has BFD echo mode enabled, BFD echo
      packets will be sent to the other router. If the peer router does not
      have BFD echo mode enabled, only control packets will be sent. If set to
      CONTROL_ONLY, BFD echo mode is disabled for this BGP peer. If this
      router and the peer router have a multihop connection, this should be
      set to CONTROL_ONLY as BFD echo mode is only supported on singlehop
      connections. The default is CONTROL_AND_ECHO.
    sessionInitializationMode: The BFD session initialization mode for this
      BGP peer. If set to ACTIVE, the Cloud Router will initiate the BFD
      session for this BGP peer. If set to PASSIVE, the Cloud Router will wait
      for the peer router to initiate the BFD session for this BGP peer. If
      set to DISABLED, BFD is disabled for this BGP peer. The default is
      PASSIVE.
    slowTimerInterval: The minimum interval, in milliseconds, between BFD
      control packets transmitted to and received from the peer router when
      BFD echo mode is enabled on both routers. The actual transmit and
      receive intervals are negotiated between the two routers and are equal
      to the greater of this value and the corresponding interval on the other
      router. If set, this value must be between 1000 and 30000. The default
      is 5000.
  """

  class ModeValueValuesEnum(_messages.Enum):
    r"""The BFD session initialization mode for this BGP peer. If set to
    ACTIVE, the Cloud Router will initiate the BFD session for this BGP peer.
    If set to PASSIVE, the Cloud Router will wait for the peer router to
    initiate the BFD session for this BGP peer. If set to DISABLED, BFD is
    disabled for this BGP peer. The default is PASSIVE.

    Values:
      ACTIVE: <no description>
      DISABLED: <no description>
      PASSIVE: <no description>
    """
    ACTIVE = 0
    DISABLED = 1
    PASSIVE = 2

  class PacketModeValueValuesEnum(_messages.Enum):
    r"""The BFD packet mode for this BGP peer. If set to CONTROL_AND_ECHO, BFD
    echo mode is enabled for this BGP peer. In this mode, if the peer router
    also has BFD echo mode enabled, BFD echo packets will be sent to the other
    router. If the peer router does not have BFD echo mode enabled, only
    control packets will be sent. If set to CONTROL_ONLY, BFD echo mode is
    disabled for this BGP peer. If this router and the peer router have a
    multihop connection, this should be set to CONTROL_ONLY as BFD echo mode
    is only supported on singlehop connections. The default is
    CONTROL_AND_ECHO.

    Values:
      CONTROL_AND_ECHO: <no description>
      CONTROL_ONLY: <no description>
    """
    CONTROL_AND_ECHO = 0
    CONTROL_ONLY = 1

  class SessionInitializationModeValueValuesEnum(_messages.Enum):
    r"""The BFD session initialization mode for this BGP peer. If set to
    ACTIVE, the Cloud Router will initiate the BFD session for this BGP peer.
    If set to PASSIVE, the Cloud Router will wait for the peer router to
    initiate the BFD session for this BGP peer. If set to DISABLED, BFD is
    disabled for this BGP peer. The default is PASSIVE.

    Values:
      ACTIVE: <no description>
      DISABLED: <no description>
      PASSIVE: <no description>
    """
    ACTIVE = 0
    DISABLED = 1
    PASSIVE = 2

  minReceiveInterval = _messages.IntegerField(1, variant=_messages.Variant.UINT32)
  minTransmitInterval = _messages.IntegerField(2, variant=_messages.Variant.UINT32)
  mode = _messages.EnumField('ModeValueValuesEnum', 3)
  multiplier = _messages.IntegerField(4, variant=_messages.Variant.UINT32)
  packetMode = _messages.EnumField('PacketModeValueValuesEnum', 5)
  sessionInitializationMode = _messages.EnumField('SessionInitializationModeValueValuesEnum', 6)
  slowTimerInterval = _messages.IntegerField(7, variant=_messages.Variant.UINT32)


class RouterInterface(_messages.Message):
  r"""A RouterInterface object.

  Enums:
    ManagementTypeValueValuesEnum: [Output Only] The resource that configures
      and manages this interface.  - MANAGED_BY_USER is the default value and
      can be managed directly by users.  - MANAGED_BY_ATTACHMENT is an
      interface that is configured and managed by Cloud Interconnect,
      specifically, by an InterconnectAttachment of type PARTNER. Google
      automatically creates, updates, and deletes this type of interface when
      the PARTNER InterconnectAttachment is created, updated, or deleted.

  Fields:
    ipRange: IP address and range of the interface. The IP range must be in
      the RFC3927 link-local IP address space. The value must be a CIDR-
      formatted string, for example: 169.254.0.1/30. NOTE: Do not truncate the
      address as it represents the IP address of the interface.
    linkedInterconnectAttachment: URI of the linked Interconnect attachment.
      It must be in the same region as the router. Each interface can have one
      linked resource, which can be a VPN tunnel, an Interconnect attachment,
      or a virtual machine instance.
    linkedVpnTunnel: URI of the linked VPN tunnel, which must be in the same
      region as the router. Each interface can have one linked resource, which
      can be a VPN tunnel, an Interconnect attachment, or a virtual machine
      instance.
    managementType: [Output Only] The resource that configures and manages
      this interface.  - MANAGED_BY_USER is the default value and can be
      managed directly by users.  - MANAGED_BY_ATTACHMENT is an interface that
      is configured and managed by Cloud Interconnect, specifically, by an
      InterconnectAttachment of type PARTNER. Google automatically creates,
      updates, and deletes this type of interface when the PARTNER
      InterconnectAttachment is created, updated, or deleted.
    name: Name of this interface entry. The name must be 1-63 characters long,
      and comply with RFC1035. Specifically, the name must be 1-63 characters
      long and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which
      means the first character must be a lowercase letter, and all following
      characters must be a dash, lowercase letter, or digit, except the last
      character, which cannot be a dash.
  """

  class ManagementTypeValueValuesEnum(_messages.Enum):
    r"""[Output Only] The resource that configures and manages this interface.
    - MANAGED_BY_USER is the default value and can be managed directly by
    users.  - MANAGED_BY_ATTACHMENT is an interface that is configured and
    managed by Cloud Interconnect, specifically, by an InterconnectAttachment
    of type PARTNER. Google automatically creates, updates, and deletes this
    type of interface when the PARTNER InterconnectAttachment is created,
    updated, or deleted.

    Values:
      MANAGED_BY_ATTACHMENT: <no description>
      MANAGED_BY_USER: <no description>
    """
    MANAGED_BY_ATTACHMENT = 0
    MANAGED_BY_USER = 1

  ipRange = _messages.StringField(1)
  linkedInterconnectAttachment = _messages.StringField(2)
  linkedVpnTunnel = _messages.StringField(3)
  managementType = _messages.EnumField('ManagementTypeValueValuesEnum', 4)
  name = _messages.StringField(5)


class RouterList(_messages.Message):
  r"""Contains a list of Router resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Router resources.
    kind: [Output Only] Type of resource. Always compute#router for routers.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Router', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#routerList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class RouterNat(_messages.Message):
  r"""Represents a Nat resource. It enables the VMs within the specified
  subnetworks to access Internet without external IP addresses. It specifies a
  list of subnetworks (and the ranges within) that want to use NAT. Customers
  can also provide the external IPs that would be used for NAT. GCP would
  auto-allocate ephemeral IPs if no external IPs are provided.

  Enums:
    NatIpAllocateOptionValueValuesEnum: Specify the NatIpAllocateOption, which
      can take one of the following values:  - MANUAL_ONLY: Uses only Nat IP
      addresses provided by customers. When there are not enough specified Nat
      IPs, the Nat service fails for new VMs.  - AUTO_ONLY: Nat IPs are
      allocated by Google Cloud Platform; customers can't specify any Nat IPs.
      When choosing AUTO_ONLY, then nat_ip should be empty.
    SourceSubnetworkIpRangesToNatValueValuesEnum: Specify the Nat option,
      which can take one of the following values:  -
      ALL_SUBNETWORKS_ALL_IP_RANGES: All of the IP ranges in every Subnetwork
      are allowed to Nat.  - ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES: All of the
      primary IP ranges in every Subnetwork are allowed to Nat.  -
      LIST_OF_SUBNETWORKS: A list of Subnetworks are allowed to Nat (specified
      in the field subnetwork below) The default is
      SUBNETWORK_IP_RANGE_TO_NAT_OPTION_UNSPECIFIED. Note that if this field
      contains ALL_SUBNETWORKS_ALL_IP_RANGES or
      ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES, then there should not be any
      other Router.Nat section in any Router for this network in this region.

  Fields:
    drainNatIps: A list of URLs of the IP resources to be drained. These IPs
      must be valid static external IPs that have been assigned to the NAT.
      These IPs should be used for updating/patching a NAT only.
    enableEndpointIndependentMapping: A boolean attribute.
    icmpIdleTimeoutSec: Timeout (in seconds) for ICMP connections. Defaults to
      30s if not set.
    logConfig: Configure logging on this NAT.
    minPortsPerVm: Minimum number of ports allocated to a VM from this NAT
      config. If not set, a default number of ports is allocated to a VM. This
      is rounded up to the nearest power of 2. For example, if the value of
      this field is 50, at least 64 ports are allocated to a VM.
    name: Unique name of this Nat service. The name must be 1-63 characters
      long and comply with RFC1035.
    natIpAllocateOption: Specify the NatIpAllocateOption, which can take one
      of the following values:  - MANUAL_ONLY: Uses only Nat IP addresses
      provided by customers. When there are not enough specified Nat IPs, the
      Nat service fails for new VMs.  - AUTO_ONLY: Nat IPs are allocated by
      Google Cloud Platform; customers can't specify any Nat IPs. When
      choosing AUTO_ONLY, then nat_ip should be empty.
    natIps: A list of URLs of the IP resources used for this Nat service.
      These IP addresses must be valid static external IP addresses assigned
      to the project.
    rules: A list of rules associated with this NAT.
    sourceSubnetworkIpRangesToNat: Specify the Nat option, which can take one
      of the following values:  - ALL_SUBNETWORKS_ALL_IP_RANGES: All of the IP
      ranges in every Subnetwork are allowed to Nat.  -
      ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES: All of the primary IP ranges in
      every Subnetwork are allowed to Nat.  - LIST_OF_SUBNETWORKS: A list of
      Subnetworks are allowed to Nat (specified in the field subnetwork below)
      The default is SUBNETWORK_IP_RANGE_TO_NAT_OPTION_UNSPECIFIED. Note that
      if this field contains ALL_SUBNETWORKS_ALL_IP_RANGES or
      ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES, then there should not be any
      other Router.Nat section in any Router for this network in this region.
    subnetworks: A list of Subnetwork resources whose traffic should be
      translated by NAT Gateway. It is used only when LIST_OF_SUBNETWORKS is
      selected for the SubnetworkIpRangeToNatOption above.
    tcpEstablishedIdleTimeoutSec: Timeout (in seconds) for TCP established
      connections. Defaults to 1200s if not set.
    tcpTimeWaitTimeoutSec: Timeout (in seconds) for TCP connections that are
      in TIME_WAIT state. Defaults to 120s if not set.
    tcpTransitoryIdleTimeoutSec: Timeout (in seconds) for TCP transitory
      connections. Defaults to 30s if not set.
    udpIdleTimeoutSec: Timeout (in seconds) for UDP connections. Defaults to
      30s if not set.
  """

  class NatIpAllocateOptionValueValuesEnum(_messages.Enum):
    r"""Specify the NatIpAllocateOption, which can take one of the following
    values:  - MANUAL_ONLY: Uses only Nat IP addresses provided by customers.
    When there are not enough specified Nat IPs, the Nat service fails for new
    VMs.  - AUTO_ONLY: Nat IPs are allocated by Google Cloud Platform;
    customers can't specify any Nat IPs. When choosing AUTO_ONLY, then nat_ip
    should be empty.

    Values:
      AUTO_ONLY: <no description>
      MANUAL_ONLY: <no description>
    """
    AUTO_ONLY = 0
    MANUAL_ONLY = 1

  class SourceSubnetworkIpRangesToNatValueValuesEnum(_messages.Enum):
    r"""Specify the Nat option, which can take one of the following values:  -
    ALL_SUBNETWORKS_ALL_IP_RANGES: All of the IP ranges in every Subnetwork
    are allowed to Nat.  - ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES: All of the
    primary IP ranges in every Subnetwork are allowed to Nat.  -
    LIST_OF_SUBNETWORKS: A list of Subnetworks are allowed to Nat (specified
    in the field subnetwork below) The default is
    SUBNETWORK_IP_RANGE_TO_NAT_OPTION_UNSPECIFIED. Note that if this field
    contains ALL_SUBNETWORKS_ALL_IP_RANGES or
    ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES, then there should not be any other
    Router.Nat section in any Router for this network in this region.

    Values:
      ALL_SUBNETWORKS_ALL_IP_RANGES: <no description>
      ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES: <no description>
      LIST_OF_SUBNETWORKS: <no description>
    """
    ALL_SUBNETWORKS_ALL_IP_RANGES = 0
    ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES = 1
    LIST_OF_SUBNETWORKS = 2

  drainNatIps = _messages.StringField(1, repeated=True)
  enableEndpointIndependentMapping = _messages.BooleanField(2)
  icmpIdleTimeoutSec = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  logConfig = _messages.MessageField('RouterNatLogConfig', 4)
  minPortsPerVm = _messages.IntegerField(5, variant=_messages.Variant.INT32)
  name = _messages.StringField(6)
  natIpAllocateOption = _messages.EnumField('NatIpAllocateOptionValueValuesEnum', 7)
  natIps = _messages.StringField(8, repeated=True)
  rules = _messages.MessageField('RouterNatRule', 9, repeated=True)
  sourceSubnetworkIpRangesToNat = _messages.EnumField('SourceSubnetworkIpRangesToNatValueValuesEnum', 10)
  subnetworks = _messages.MessageField('RouterNatSubnetworkToNat', 11, repeated=True)
  tcpEstablishedIdleTimeoutSec = _messages.IntegerField(12, variant=_messages.Variant.INT32)
  tcpTimeWaitTimeoutSec = _messages.IntegerField(13, variant=_messages.Variant.INT32)
  tcpTransitoryIdleTimeoutSec = _messages.IntegerField(14, variant=_messages.Variant.INT32)
  udpIdleTimeoutSec = _messages.IntegerField(15, variant=_messages.Variant.INT32)


class RouterNatLogConfig(_messages.Message):
  r"""Configuration of logging on a NAT.

  Enums:
    FilterValueValuesEnum: Specify the desired filtering of logs on this NAT.
      If unspecified, logs are exported for all connections handled by this
      NAT. This option can take one of the following values:  - ERRORS_ONLY:
      Export logs only for connection failures.  - TRANSLATIONS_ONLY: Export
      logs only for successful connections.  - ALL: Export logs for all
      connections, successful and unsuccessful.

  Fields:
    enable: Indicates whether or not to export logs. This is false by default.
    filter: Specify the desired filtering of logs on this NAT. If unspecified,
      logs are exported for all connections handled by this NAT. This option
      can take one of the following values:  - ERRORS_ONLY: Export logs only
      for connection failures.  - TRANSLATIONS_ONLY: Export logs only for
      successful connections.  - ALL: Export logs for all connections,
      successful and unsuccessful.
  """

  class FilterValueValuesEnum(_messages.Enum):
    r"""Specify the desired filtering of logs on this NAT. If unspecified,
    logs are exported for all connections handled by this NAT. This option can
    take one of the following values:  - ERRORS_ONLY: Export logs only for
    connection failures.  - TRANSLATIONS_ONLY: Export logs only for successful
    connections.  - ALL: Export logs for all connections, successful and
    unsuccessful.

    Values:
      ALL: <no description>
      ERRORS_ONLY: <no description>
      TRANSLATIONS_ONLY: <no description>
    """
    ALL = 0
    ERRORS_ONLY = 1
    TRANSLATIONS_ONLY = 2

  enable = _messages.BooleanField(1)
  filter = _messages.EnumField('FilterValueValuesEnum', 2)


class RouterNatRule(_messages.Message):
  r"""A RouterNatRule object.

  Fields:
    action: The action to be enforced for traffic that matches this rule.
    description: An optional description of this rule.
    match: CEL expression that specifies the match condition that egress
      traffic from a VM is evaluated against. If it evaluates to true, the
      corresponding ?action? is enforced.  The following examples are valid
      match expressions:  "inIpRange(destination.ip, '1.1.0.0/16') ||
      inIpRange(destination.ip, '2.2.0.0/16')"  "destination.ip == '1.1.0.1'
      || destination.ip == '8.8.8.8'"
    priority: An integer indicating the priority of a rule in the list. The
      priority must be a positive value between 0 and 65000. The priority must
      be unique among rules within a NAT.
  """

  action = _messages.MessageField('RouterNatRuleAction', 1)
  description = _messages.StringField(2)
  match = _messages.StringField(3)
  priority = _messages.IntegerField(4, variant=_messages.Variant.UINT32)


class RouterNatRuleAction(_messages.Message):
  r"""A RouterNatRuleAction object.

  Fields:
    sourceNatActiveIps: A list of URLs of the IP resources used for this NAT
      rule. These IP addresses must be valid static external IP addresses
      assigned to the project.
    sourceNatDrainIps: A list of URLs of the IP resources to be drained. These
      IPs must be valid static external IPs that have been assigned to the
      NAT. These IPs should be used for updating/patching a NAT rule only.
  """

  sourceNatActiveIps = _messages.StringField(1, repeated=True)
  sourceNatDrainIps = _messages.StringField(2, repeated=True)


class RouterNatSubnetworkToNat(_messages.Message):
  r"""Defines the IP ranges that want to use NAT for a subnetwork.

  Enums:
    SourceIpRangesToNatValueListEntryValuesEnum:

  Fields:
    name: URL for the subnetwork resource that will use NAT.
    secondaryIpRangeNames: A list of the secondary ranges of the Subnetwork
      that are allowed to use NAT. This can be populated only if
      "LIST_OF_SECONDARY_IP_RANGES" is one of the values in
      source_ip_ranges_to_nat.
    sourceIpRangesToNat: Specify the options for NAT ranges in the Subnetwork.
      All options of a single value are valid except
      NAT_IP_RANGE_OPTION_UNSPECIFIED. The only valid option with multiple
      values is: ["PRIMARY_IP_RANGE", "LIST_OF_SECONDARY_IP_RANGES"] Default:
      [ALL_IP_RANGES]
  """

  class SourceIpRangesToNatValueListEntryValuesEnum(_messages.Enum):
    r"""SourceIpRangesToNatValueListEntryValuesEnum enum type.

    Values:
      ALL_IP_RANGES: <no description>
      LIST_OF_SECONDARY_IP_RANGES: <no description>
      PRIMARY_IP_RANGE: <no description>
    """
    ALL_IP_RANGES = 0
    LIST_OF_SECONDARY_IP_RANGES = 1
    PRIMARY_IP_RANGE = 2

  name = _messages.StringField(1)
  secondaryIpRangeNames = _messages.StringField(2, repeated=True)
  sourceIpRangesToNat = _messages.EnumField('SourceIpRangesToNatValueListEntryValuesEnum', 3, repeated=True)


class RouterStatus(_messages.Message):
  r"""A RouterStatus object.

  Fields:
    bestRoutes: Best routes for this router's network.
    bestRoutesForRouter: Best routes learned by this router.
    bgpPeerStatus: A RouterStatusBgpPeerStatus attribute.
    natStatus: A RouterStatusNatStatus attribute.
    network: URI of the network to which this router belongs.
  """

  bestRoutes = _messages.MessageField('Route', 1, repeated=True)
  bestRoutesForRouter = _messages.MessageField('Route', 2, repeated=True)
  bgpPeerStatus = _messages.MessageField('RouterStatusBgpPeerStatus', 3, repeated=True)
  natStatus = _messages.MessageField('RouterStatusNatStatus', 4, repeated=True)
  network = _messages.StringField(5)


class RouterStatusBgpPeerStatus(_messages.Message):
  r"""A RouterStatusBgpPeerStatus object.

  Enums:
    StatusValueValuesEnum: Status of the BGP peer: {UP, DOWN}

  Fields:
    advertisedRoutes: Routes that were advertised to the remote BGP peer
    bfdStatus: A BfdStatus attribute.
    ipAddress: IP address of the local BGP interface.
    linkedVpnTunnel: URL of the VPN tunnel that this BGP peer controls.
    name: Name of this BGP peer. Unique within the Routers resource.
    numLearnedRoutes: Number of routes learned from the remote BGP Peer.
    peerIpAddress: IP address of the remote BGP interface.
    state: BGP state as specified in RFC1771.
    status: Status of the BGP peer: {UP, DOWN}
    uptime: Time this session has been up. Format: 14 years, 51 weeks, 6 days,
      23 hours, 59 minutes, 59 seconds
    uptimeSeconds: Time this session has been up, in seconds. Format: 145
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""Status of the BGP peer: {UP, DOWN}

    Values:
      DOWN: <no description>
      UNKNOWN: <no description>
      UP: <no description>
    """
    DOWN = 0
    UNKNOWN = 1
    UP = 2

  advertisedRoutes = _messages.MessageField('Route', 1, repeated=True)
  bfdStatus = _messages.MessageField('BfdStatus', 2)
  ipAddress = _messages.StringField(3)
  linkedVpnTunnel = _messages.StringField(4)
  name = _messages.StringField(5)
  numLearnedRoutes = _messages.IntegerField(6, variant=_messages.Variant.UINT32)
  peerIpAddress = _messages.StringField(7)
  state = _messages.StringField(8)
  status = _messages.EnumField('StatusValueValuesEnum', 9)
  uptime = _messages.StringField(10)
  uptimeSeconds = _messages.StringField(11)


class RouterStatusNatStatus(_messages.Message):
  r"""Status of a NAT contained in this router. Next tag: 9

  Fields:
    autoAllocatedNatIps: A list of IPs auto-allocated for NAT. Example:
      ["1.1.1.1", "129.2.16.89"]
    drainAutoAllocatedNatIps: A list of IPs auto-allocated for NAT that are in
      drain mode. Example: ["1.1.1.1", "179.12.26.133"].
    drainUserAllocatedNatIps: A list of IPs user-allocated for NAT that are in
      drain mode. Example: ["1.1.1.1", "179.12.26.133"].
    minExtraNatIpsNeeded: The number of extra IPs to allocate. This will be
      greater than 0 only if user-specified IPs are NOT enough to allow all
      configured VMs to use NAT. This value is meaningful only when auto-
      allocation of NAT IPs is *not* used.
    name: Unique name of this NAT.
    numVmEndpointsWithNatMappings: Number of VM endpoints (i.e., Nics) that
      can use NAT.
    userAllocatedNatIpResources: A list of fully qualified URLs of reserved IP
      address resources.
    userAllocatedNatIps: A list of IPs user-allocated for NAT. They will be
      raw IP strings like "179.12.26.133".
  """

  autoAllocatedNatIps = _messages.StringField(1, repeated=True)
  drainAutoAllocatedNatIps = _messages.StringField(2, repeated=True)
  drainUserAllocatedNatIps = _messages.StringField(3, repeated=True)
  minExtraNatIpsNeeded = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  name = _messages.StringField(5)
  numVmEndpointsWithNatMappings = _messages.IntegerField(6, variant=_messages.Variant.INT32)
  userAllocatedNatIpResources = _messages.StringField(7, repeated=True)
  userAllocatedNatIps = _messages.StringField(8, repeated=True)


class RouterStatusResponse(_messages.Message):
  r"""A RouterStatusResponse object.

  Fields:
    kind: Type of resource.
    result: A RouterStatus attribute.
  """

  kind = _messages.StringField(1, default=u'compute#routerStatusResponse')
  result = _messages.MessageField('RouterStatus', 2)


class RoutersPreviewResponse(_messages.Message):
  r"""A RoutersPreviewResponse object.

  Fields:
    resource: Preview of given router.
  """

  resource = _messages.MessageField('Router', 1)


class RoutersScopedList(_messages.Message):
  r"""A RoutersScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of routers
      when the list is empty.

  Fields:
    routers: A list of routers contained in this scope.
    warning: Informational warning which replaces the list of routers when the
      list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of routers when the list
    is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  routers = _messages.MessageField('Router', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class Rule(_messages.Message):
  r"""A rule to be applied in a Policy.

  Enums:
    ActionValueValuesEnum: Required

  Fields:
    action: Required
    conditions: Additional restrictions that must be met. All conditions must
      pass for the rule to match.
    description: Human-readable description of the rule.
    ins: If one or more 'in' clauses are specified, the rule matches if the
      PRINCIPAL/AUTHORITY_SELECTOR is in at least one of these entries.
    logConfigs: The config returned to callers of tech.iam.IAM.CheckPolicy for
      any entries that match the LOG action.
    notIns: If one or more 'not_in' clauses are specified, the rule matches if
      the PRINCIPAL/AUTHORITY_SELECTOR is in none of the entries.
    permissions: A permission is a string of form '..' (e.g.,
      'storage.buckets.list'). A value of '*' matches all permissions, and a
      verb part of '*' (e.g., 'storage.buckets.*') matches all verbs.
  """

  class ActionValueValuesEnum(_messages.Enum):
    r"""Required

    Values:
      ALLOW: <no description>
      ALLOW_WITH_LOG: <no description>
      DENY: <no description>
      DENY_WITH_LOG: <no description>
      LOG: <no description>
      NO_ACTION: <no description>
    """
    ALLOW = 0
    ALLOW_WITH_LOG = 1
    DENY = 2
    DENY_WITH_LOG = 3
    LOG = 4
    NO_ACTION = 5

  action = _messages.EnumField('ActionValueValuesEnum', 1)
  conditions = _messages.MessageField('Condition', 2, repeated=True)
  description = _messages.StringField(3)
  ins = _messages.StringField(4, repeated=True)
  logConfigs = _messages.MessageField('LogConfig', 5, repeated=True)
  notIns = _messages.StringField(6, repeated=True)
  permissions = _messages.StringField(7, repeated=True)


class SSLHealthCheck(_messages.Message):
  r"""A SSLHealthCheck object.

  Enums:
    PortSpecificationValueValuesEnum: Specifies how port is selected for
      health checking, can be one of following values: USE_FIXED_PORT: The
      port number in port is used for health checking. USE_NAMED_PORT: The
      portName is used for health checking. USE_SERVING_PORT: For
      NetworkEndpointGroup, the port specified for each network endpoint is
      used for health checking. For other backends, the port or named port
      specified in the Backend Service is used for health checking.   If not
      specified, SSL health check follows behavior specified in port and
      portName fields.
    ProxyHeaderValueValuesEnum: Specifies the type of proxy header to append
      before sending data to the backend, either NONE or PROXY_V1. The default
      is NONE.

  Fields:
    port: The TCP port number for the health check request. The default value
      is 443. Valid values are 1 through 65535.
    portName: Port name as defined in InstanceGroup#NamedPort#name. If both
      port and port_name are defined, port takes precedence.
    portSpecification: Specifies how port is selected for health checking, can
      be one of following values: USE_FIXED_PORT: The port number in port is
      used for health checking. USE_NAMED_PORT: The portName is used for
      health checking. USE_SERVING_PORT: For NetworkEndpointGroup, the port
      specified for each network endpoint is used for health checking. For
      other backends, the port or named port specified in the Backend Service
      is used for health checking.   If not specified, SSL health check
      follows behavior specified in port and portName fields.
    proxyHeader: Specifies the type of proxy header to append before sending
      data to the backend, either NONE or PROXY_V1. The default is NONE.
    request: The application data to send once the SSL connection has been
      established (default value is empty). If both request and response are
      empty, the connection establishment alone will indicate health. The
      request data can only be ASCII.
    response: The bytes to match against the beginning of the response data.
      If left empty (the default value), any response will indicate health.
      The response data can only be ASCII.
  """

  class PortSpecificationValueValuesEnum(_messages.Enum):
    r"""Specifies how port is selected for health checking, can be one of
    following values: USE_FIXED_PORT: The port number in port is used for
    health checking. USE_NAMED_PORT: The portName is used for health checking.
    USE_SERVING_PORT: For NetworkEndpointGroup, the port specified for each
    network endpoint is used for health checking. For other backends, the port
    or named port specified in the Backend Service is used for health
    checking.   If not specified, SSL health check follows behavior specified
    in port and portName fields.

    Values:
      USE_FIXED_PORT: <no description>
      USE_NAMED_PORT: <no description>
      USE_SERVING_PORT: <no description>
    """
    USE_FIXED_PORT = 0
    USE_NAMED_PORT = 1
    USE_SERVING_PORT = 2

  class ProxyHeaderValueValuesEnum(_messages.Enum):
    r"""Specifies the type of proxy header to append before sending data to
    the backend, either NONE or PROXY_V1. The default is NONE.

    Values:
      NONE: <no description>
      PROXY_V1: <no description>
    """
    NONE = 0
    PROXY_V1 = 1

  port = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  portName = _messages.StringField(2)
  portSpecification = _messages.EnumField('PortSpecificationValueValuesEnum', 3)
  proxyHeader = _messages.EnumField('ProxyHeaderValueValuesEnum', 4)
  request = _messages.StringField(5)
  response = _messages.StringField(6)


class SavedAttachedDisk(_messages.Message):
  r"""An instance-attached disk resource.

  Enums:
    InterfaceValueValuesEnum: Specifies the disk interface to use for
      attaching this disk, which is either SCSI or NVME.
    ModeValueValuesEnum: The mode in which this disk is attached to the source
      instance, either READ_WRITE or READ_ONLY.
    StorageBytesStatusValueValuesEnum: [Output Only] An indicator whether
      storageBytes is in a stable state or it is being adjusted as a result of
      shared storage reallocation. This status can either be UPDATING, meaning
      the size of the snapshot is being updated, or UP_TO_DATE, meaning the
      size of the snapshot is up-to-date.
    TypeValueValuesEnum: Specifies the type of the attached disk, either
      SCRATCH or PERSISTENT.

  Fields:
    autoDelete: Specifies whether the disk will be auto-deleted when the
      instance is deleted (but not when the disk is detached from the
      instance).
    boot: Indicates that this is a boot disk. The virtual machine will use the
      first partition of the disk for its root filesystem.
    deviceName: Specifies the name of the disk attached to the source
      instance.
    diskEncryptionKey: The encryption key for the disk.
    diskSizeGb: The size of the disk in base-2 GB.
    diskType: [Output Only] URL of the disk type resource. For example:
      projects/project/zones/zone/diskTypes/pd-standard or pd-ssd
    guestOsFeatures: A list of features to enable on the guest operating
      system. Applicable only for bootable images. Read  Enabling guest
      operating system features to see a list of available options.
    index: Specifies zero-based index of the disk that is attached to the
      source instance.
    interface: Specifies the disk interface to use for attaching this disk,
      which is either SCSI or NVME.
    kind: [Output Only] Type of the resource. Always compute#attachedDisk for
      attached disks.
    licenses: [Output Only] Any valid publicly visible licenses.
    mode: The mode in which this disk is attached to the source instance,
      either READ_WRITE or READ_ONLY.
    source: Specifies a URL of the disk attached to the source instance.
    storageBytes: [Output Only] A size of the storage used by the disk's
      snapshot by this machine image.
    storageBytesStatus: [Output Only] An indicator whether storageBytes is in
      a stable state or it is being adjusted as a result of shared storage
      reallocation. This status can either be UPDATING, meaning the size of
      the snapshot is being updated, or UP_TO_DATE, meaning the size of the
      snapshot is up-to-date.
    type: Specifies the type of the attached disk, either SCRATCH or
      PERSISTENT.
  """

  class InterfaceValueValuesEnum(_messages.Enum):
    r"""Specifies the disk interface to use for attaching this disk, which is
    either SCSI or NVME.

    Values:
      NVDIMM: <no description>
      NVME: <no description>
      SCSI: <no description>
    """
    NVDIMM = 0
    NVME = 1
    SCSI = 2

  class ModeValueValuesEnum(_messages.Enum):
    r"""The mode in which this disk is attached to the source instance, either
    READ_WRITE or READ_ONLY.

    Values:
      READ_ONLY: <no description>
      READ_WRITE: <no description>
    """
    READ_ONLY = 0
    READ_WRITE = 1

  class StorageBytesStatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] An indicator whether storageBytes is in a stable state
    or it is being adjusted as a result of shared storage reallocation. This
    status can either be UPDATING, meaning the size of the snapshot is being
    updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date.

    Values:
      UPDATING: <no description>
      UP_TO_DATE: <no description>
    """
    UPDATING = 0
    UP_TO_DATE = 1

  class TypeValueValuesEnum(_messages.Enum):
    r"""Specifies the type of the attached disk, either SCRATCH or PERSISTENT.

    Values:
      PERSISTENT: <no description>
      SCRATCH: <no description>
    """
    PERSISTENT = 0
    SCRATCH = 1

  autoDelete = _messages.BooleanField(1)
  boot = _messages.BooleanField(2)
  deviceName = _messages.StringField(3)
  diskEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 4)
  diskSizeGb = _messages.IntegerField(5)
  diskType = _messages.StringField(6)
  guestOsFeatures = _messages.MessageField('GuestOsFeature', 7, repeated=True)
  index = _messages.IntegerField(8, variant=_messages.Variant.INT32)
  interface = _messages.EnumField('InterfaceValueValuesEnum', 9)
  kind = _messages.StringField(10, default=u'compute#savedAttachedDisk')
  licenses = _messages.StringField(11, repeated=True)
  mode = _messages.EnumField('ModeValueValuesEnum', 12)
  source = _messages.StringField(13)
  storageBytes = _messages.IntegerField(14)
  storageBytesStatus = _messages.EnumField('StorageBytesStatusValueValuesEnum', 15)
  type = _messages.EnumField('TypeValueValuesEnum', 16)


class Scheduling(_messages.Message):
  r"""Sets the scheduling options for an Instance. NextID: 10

  Enums:
    OnHostMaintenanceValueValuesEnum: Defines the maintenance behavior for
      this instance. For standard instances, the default behavior is MIGRATE.
      For preemptible instances, the default and only possible behavior is
      TERMINATE. For more information, see Setting Instance Scheduling
      Options.

  Fields:
    automaticRestart: Specifies whether the instance should be automatically
      restarted if it is terminated by Compute Engine (not terminated by a
      user). You can only set the automatic restart option for standard
      instances. Preemptible instances cannot be automatically restarted.  By
      default, this is set to true so an instance is automatically restarted
      if it is terminated by Compute Engine.
    latencyTolerant: Defines whether the instance is tolerant of higher cpu
      latency. This can only be set during instance creation, or when the
      instance is not currently running. It must not be set if the preemptible
      option is also set.
    locationHint: An opaque location hint used to place the instance close to
      other resources. This field is for use by internal tools that use the
      public API.
    longTermRelease: Compute Engine Long Term Release. When specified, VMs
      that have this policy become long term release (internal: stable fleet)
      VMs.  For all VM shapes, this should result in fewer disruptions due to
      software updates and greater predictability via 1 week extended
      notifications.  For GPU VMs, this should also result in an 2 week uptime
      guarantee. See go/stable-fleet-gpus-design for more details.
    minNodeCpus: The minimum number of virtual CPUs this instance will consume
      when running on a sole-tenant node.
    nodeAffinities: A set of node affinity and anti-affinity configurations.
      Refer to Configuring node affinity for more information. Overrides
      reservationAffinity.
    onHostMaintenance: Defines the maintenance behavior for this instance. For
      standard instances, the default behavior is MIGRATE. For preemptible
      instances, the default and only possible behavior is TERMINATE. For more
      information, see Setting Instance Scheduling Options.
    preemptible: Defines whether the instance is preemptible. This can only be
      set during instance creation, it cannot be set or changed after the
      instance has been created.
  """

  class OnHostMaintenanceValueValuesEnum(_messages.Enum):
    r"""Defines the maintenance behavior for this instance. For standard
    instances, the default behavior is MIGRATE. For preemptible instances, the
    default and only possible behavior is TERMINATE. For more information, see
    Setting Instance Scheduling Options.

    Values:
      MIGRATE: <no description>
      TERMINATE: <no description>
    """
    MIGRATE = 0
    TERMINATE = 1

  automaticRestart = _messages.BooleanField(1)
  latencyTolerant = _messages.BooleanField(2)
  locationHint = _messages.StringField(3)
  longTermRelease = _messages.BooleanField(4)
  minNodeCpus = _messages.IntegerField(5, variant=_messages.Variant.INT32)
  nodeAffinities = _messages.MessageField('SchedulingNodeAffinity', 6, repeated=True)
  onHostMaintenance = _messages.EnumField('OnHostMaintenanceValueValuesEnum', 7)
  preemptible = _messages.BooleanField(8)


class SchedulingNodeAffinity(_messages.Message):
  r"""Node Affinity: the configuration of desired nodes onto which this
  Instance could be scheduled.

  Enums:
    OperatorValueValuesEnum: Defines the operation of node selection. Valid
      operators are IN for affinity and NOT_IN for anti-affinity.

  Fields:
    key: Corresponds to the label key of Node resource.
    operator: Defines the operation of node selection. Valid operators are IN
      for affinity and NOT_IN for anti-affinity.
    values: Corresponds to the label values of Node resource.
  """

  class OperatorValueValuesEnum(_messages.Enum):
    r"""Defines the operation of node selection. Valid operators are IN for
    affinity and NOT_IN for anti-affinity.

    Values:
      IN: <no description>
      NOT_IN: <no description>
      OPERATOR_UNSPECIFIED: <no description>
    """
    IN = 0
    NOT_IN = 1
    OPERATOR_UNSPECIFIED = 2

  key = _messages.StringField(1)
  operator = _messages.EnumField('OperatorValueValuesEnum', 2)
  values = _messages.StringField(3, repeated=True)


class Screenshot(_messages.Message):
  r"""An instance's screenshot.

  Fields:
    contents: [Output Only] The Base64-encoded screenshot data.
    kind: [Output Only] Type of the resource. Always compute#screenshot for
      the screenshots.
  """

  contents = _messages.StringField(1)
  kind = _messages.StringField(2, default=u'compute#screenshot')


class SdsConfig(_messages.Message):
  r"""[Deprecated] The configuration to access the SDS server. The
  configuration to access the SDS server.

  Fields:
    grpcServiceConfig: The configuration to access the SDS server over GRPC.
  """

  grpcServiceConfig = _messages.MessageField('GrpcServiceConfig', 1)


class SecurityPoliciesListPreconfiguredExpressionSetsResponse(_messages.Message):
  r"""A SecurityPoliciesListPreconfiguredExpressionSetsResponse object.

  Fields:
    preconfiguredExpressionSets: A SecurityPoliciesWafConfig attribute.
  """

  preconfiguredExpressionSets = _messages.MessageField('SecurityPoliciesWafConfig', 1)


class SecurityPoliciesWafConfig(_messages.Message):
  r"""A SecurityPoliciesWafConfig object.

  Fields:
    wafRules: A PreconfiguredWafSet attribute.
  """

  wafRules = _messages.MessageField('PreconfiguredWafSet', 1)


class SecurityPolicy(_messages.Message):
  r"""Represents a Cloud Armor Security Policy resource.  Only external
  backend services that use load balancers can reference a Security Policy.
  For more information, read  Cloud Armor Security Policy Concepts. (==
  resource_for {$api_version}.securityPolicies ==)

  Enums:
    TypeValueValuesEnum: The type indicates the intended use of the security
      policy. CLOUD_ARMOR policies apply to backend services. FIREWALL
      policies apply to organizations.

  Messages:
    LabelsValue: Labels for this resource. These can only be added or modified
      by the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.

  Fields:
    associations: A list of associations that belong to this policy.
    cloudArmorConfig: A SecurityPolicyCloudArmorConfig attribute.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    displayName: User-provided name of the Organization security plicy. The
      name should be unique in the organization in which the security policy
      is created. This should only be used when SecurityPolicyType is
      FIREWALL. The name must be 1-63 characters long, and comply with
      RFC1035. Specifically, the name must be 1-63 characters long and match
      the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the
      first character must be a lowercase letter, and all following characters
      must be a dash, lowercase letter, or digit, except the last character,
      which cannot be a dash.
    fingerprint: Specifies a fingerprint for this resource, which is
      essentially a hash of the metadata's contents and used for optimistic
      locking. The fingerprint is initially generated by Compute Engine and
      changes after every request to modify or update metadata. You must
      always provide an up-to-date fingerprint hash in order to update or
      change metadata, otherwise the request will fail with error 412
      conditionNotMet.  To see the latest fingerprint, make get() request to
      the security policy.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output only] Type of the resource. Always compute#securityPolicyfor
      security policies
    labelFingerprint: A fingerprint for the labels being applied to this
      security policy, which is essentially a hash of the labels set used for
      optimistic locking. The fingerprint is initially generated by Compute
      Engine and changes after every request to modify or update labels. You
      must always provide an up-to-date fingerprint hash in order to update or
      change labels.  To see the latest fingerprint, make get() request to the
      security policy.
    labels: Labels for this resource. These can only be added or modified by
      the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    parent: [Output Only] The parent of the security policy.
    ruleTupleCount: [Output Only] Total count of all security policy rule
      tuples. A security policy can not exceed a set number of tuples.
    rules: A list of rules that belong to this policy. There must always be a
      default rule (rule with priority 2147483647 and match "*"). If no rules
      are provided when creating a security policy, a default rule with action
      "allow" will be added.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    type: The type indicates the intended use of the security policy.
      CLOUD_ARMOR policies apply to backend services. FIREWALL policies apply
      to organizations.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""The type indicates the intended use of the security policy.
    CLOUD_ARMOR policies apply to backend services. FIREWALL policies apply to
    organizations.

    Values:
      CLOUD_ARMOR: <no description>
      FIREWALL: <no description>
    """
    CLOUD_ARMOR = 0
    FIREWALL = 1

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels for this resource. These can only be added or modified by the
    setLabels method. Each label key/value pair must comply with RFC1035.
    Label values may be empty.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  associations = _messages.MessageField('SecurityPolicyAssociation', 1, repeated=True)
  cloudArmorConfig = _messages.MessageField('SecurityPolicyCloudArmorConfig', 2)
  creationTimestamp = _messages.StringField(3)
  description = _messages.StringField(4)
  displayName = _messages.StringField(5)
  fingerprint = _messages.BytesField(6)
  id = _messages.IntegerField(7, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(8, default=u'compute#securityPolicy')
  labelFingerprint = _messages.BytesField(9)
  labels = _messages.MessageField('LabelsValue', 10)
  name = _messages.StringField(11)
  parent = _messages.StringField(12)
  ruleTupleCount = _messages.IntegerField(13, variant=_messages.Variant.INT32)
  rules = _messages.MessageField('SecurityPolicyRule', 14, repeated=True)
  selfLink = _messages.StringField(15)
  selfLinkWithId = _messages.StringField(16)
  type = _messages.EnumField('TypeValueValuesEnum', 17)


class SecurityPolicyAssociation(_messages.Message):
  r"""A SecurityPolicyAssociation object.

  Fields:
    attachmentId: The resource that the security policy is attached to.
    displayName: [Output Only] The display name of the security policy of the
      association.
    name: The name for an association.
    securityPolicyId: [Output Only] The security policy ID of the association.
  """

  attachmentId = _messages.StringField(1)
  displayName = _messages.StringField(2)
  name = _messages.StringField(3)
  securityPolicyId = _messages.StringField(4)


class SecurityPolicyCloudArmorConfig(_messages.Message):
  r"""Configuration options for Cloud Armor.

  Fields:
    enableMl: If set to true, enables Cloud Armor Machine Learning.
  """

  enableMl = _messages.BooleanField(1)


class SecurityPolicyList(_messages.Message):
  r"""A SecurityPolicyList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of SecurityPolicy resources.
    kind: [Output Only] Type of resource. Always compute#securityPolicyList
      for listsof securityPolicies
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('SecurityPolicy', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#securityPolicyList')
  nextPageToken = _messages.StringField(4)
  warning = _messages.MessageField('WarningValue', 5)


class SecurityPolicyReference(_messages.Message):
  r"""A SecurityPolicyReference object.

  Fields:
    securityPolicy: A string attribute.
  """

  securityPolicy = _messages.StringField(1)


class SecurityPolicyRule(_messages.Message):
  r"""Represents a rule that describes one or more match conditions along with
  the action to be taken when traffic matches this condition (allow or deny).

  Enums:
    DirectionValueValuesEnum: The direction in which this rule applies. This
      field may only be specified when versioned_expr is set to FIREWALL.

  Fields:
    action: The Action to preform when the client connection triggers the
      rule. Can currently be either "allow" or "deny()" where valid values for
      status are 403, 404, and 502.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    direction: The direction in which this rule applies. This field may only
      be specified when versioned_expr is set to FIREWALL.
    enableLogging: Denotes whether to enable logging for a particular rule. If
      logging is enabled, logs will be exported to the configured export
      destination in Stackdriver. Logs may be exported to BigQuery or Pub/Sub.
      Note: you cannot enable logging on "goto_next" rules.  This field may
      only be specified when the versioned_expr is set to FIREWALL.
    kind: [Output only] Type of the resource. Always
      compute#securityPolicyRule for security policy rules
    match: A match condition that incoming traffic is evaluated against. If it
      evaluates to true, the corresponding 'action' is enforced.
    preview: If set to true, the specified action is not enforced.
    priority: An integer indicating the priority of a rule in the list. The
      priority must be a positive value between 0 and 2147483647. Rules are
      evaluated from highest to lowest priority where 0 is the highest
      priority and 2147483647 is the lowest prority.
    rateLimitOptions: Must be specified if the action is
      "rate_based_blacklist" or "throttle". Cannot be specified for any other
      actions.
    ruleTupleCount: [Output Only] Calculation of the complexity of a single
      firewall security policy rule.
    targetResources: A list of network resource URLs to which this rule
      applies. This field allows you to control which network's VMs get this
      rule. If this field is left blank, all VMs within the organization will
      receive the rule.  This field may only be specified when versioned_expr
      is set to FIREWALL.
    targetServiceAccounts: A list of service accounts indicating the sets of
      instances that are applied with this rule.
  """

  class DirectionValueValuesEnum(_messages.Enum):
    r"""The direction in which this rule applies. This field may only be
    specified when versioned_expr is set to FIREWALL.

    Values:
      EGRESS: <no description>
      INGRESS: <no description>
    """
    EGRESS = 0
    INGRESS = 1

  action = _messages.StringField(1)
  description = _messages.StringField(2)
  direction = _messages.EnumField('DirectionValueValuesEnum', 3)
  enableLogging = _messages.BooleanField(4)
  kind = _messages.StringField(5, default=u'compute#securityPolicyRule')
  match = _messages.MessageField('SecurityPolicyRuleMatcher', 6)
  preview = _messages.BooleanField(7)
  priority = _messages.IntegerField(8, variant=_messages.Variant.INT32)
  rateLimitOptions = _messages.MessageField('SecurityPolicyRuleRateLimitOptions', 9)
  ruleTupleCount = _messages.IntegerField(10, variant=_messages.Variant.INT32)
  targetResources = _messages.StringField(11, repeated=True)
  targetServiceAccounts = _messages.StringField(12, repeated=True)


class SecurityPolicyRuleMatcher(_messages.Message):
  r"""Represents a match condition that incoming traffic is evaluated against.
  Exactly one field must be specified.

  Enums:
    VersionedExprValueValuesEnum: Preconfigured versioned expression. If this
      field is specified, config must also be specified. Available
      preconfigured expressions along with their requirements are: SRC_IPS_V1
      - must specify the corresponding src_ip_range field in config.

  Fields:
    config: The configuration options available when specifying
      versioned_expr. This field must be specified if versioned_expr is
      specified and cannot be specified if versioned_expr is not specified.
    expr: User defined CEVAL expression. A CEVAL expression is used to specify
      match criteria such as origin.ip, source.region_code and contents in the
      request header.
    versionedExpr: Preconfigured versioned expression. If this field is
      specified, config must also be specified. Available preconfigured
      expressions along with their requirements are: SRC_IPS_V1 - must specify
      the corresponding src_ip_range field in config.
  """

  class VersionedExprValueValuesEnum(_messages.Enum):
    r"""Preconfigured versioned expression. If this field is specified, config
    must also be specified. Available preconfigured expressions along with
    their requirements are: SRC_IPS_V1 - must specify the corresponding
    src_ip_range field in config.

    Values:
      FIREWALL: <no description>
      SRC_IPS_V1: <no description>
    """
    FIREWALL = 0
    SRC_IPS_V1 = 1

  config = _messages.MessageField('SecurityPolicyRuleMatcherConfig', 1)
  expr = _messages.MessageField('Expr', 2)
  versionedExpr = _messages.EnumField('VersionedExprValueValuesEnum', 3)


class SecurityPolicyRuleMatcherConfig(_messages.Message):
  r"""A SecurityPolicyRuleMatcherConfig object.

  Fields:
    destIpRanges: CIDR IP address range.  This field may only be specified
      when versioned_expr is set to FIREWALL.
    destPorts: Pairs of IP protocols and ports that the rule should match.
      This field may only be specified when versioned_expr is set to FIREWALL.
    layer4Configs: Pairs of IP protocols and ports that the rule should match.
      This field may only be specified when versioned_expr is set to FIREWALL.
    srcIpRanges: CIDR IP address range.
  """

  destIpRanges = _messages.StringField(1, repeated=True)
  destPorts = _messages.MessageField('SecurityPolicyRuleMatcherConfigDestinationPort', 2, repeated=True)
  layer4Configs = _messages.MessageField('SecurityPolicyRuleMatcherConfigLayer4Config', 3, repeated=True)
  srcIpRanges = _messages.StringField(4, repeated=True)


class SecurityPolicyRuleMatcherConfigDestinationPort(_messages.Message):
  r"""A SecurityPolicyRuleMatcherConfigDestinationPort object.

  Fields:
    ipProtocol: The IP protocol to which this rule applies. The protocol type
      is required when creating a firewall rule. This value can either be one
      of the following well known protocol strings (tcp, udp, icmp, esp, ah,
      ipip, sctp), or the IP protocol number.
    ports: An optional list of ports to which this rule applies. This field is
      only applicable for UDP or TCP protocol. Each entry must be either an
      integer or a range. If not specified, this rule applies to connections
      through any port.  Example inputs include: ["22"], ["80","443"], and
      ["12345-12349"].  This field may only be specified when versioned_expr
      is set to FIREWALL.
  """

  ipProtocol = _messages.StringField(1)
  ports = _messages.StringField(2, repeated=True)


class SecurityPolicyRuleMatcherConfigLayer4Config(_messages.Message):
  r"""A SecurityPolicyRuleMatcherConfigLayer4Config object.

  Fields:
    ipProtocol: The IP protocol to which this rule applies. The protocol type
      is required when creating a firewall rule. This value can either be one
      of the following well known protocol strings (tcp, udp, icmp, esp, ah,
      ipip, sctp), or the IP protocol number.
    ports: An optional list of ports to which this rule applies. This field is
      only applicable for UDP or TCP protocol. Each entry must be either an
      integer or a range. If not specified, this rule applies to connections
      through any port.  Example inputs include: ["22"], ["80","443"], and
      ["12345-12349"].  This field may only be specified when versioned_expr
      is set to FIREWALL.
  """

  ipProtocol = _messages.StringField(1)
  ports = _messages.StringField(2, repeated=True)


class SecurityPolicyRuleRateLimitOptions(_messages.Message):
  r"""A SecurityPolicyRuleRateLimitOptions object.

  Enums:
    EnforceOnKeyValueValuesEnum: Determines the key to enforce the
      threshold_rps limit on. If key is "IP", each IP has this limit enforced
      separately, whereas "ALL_IPs" means a single limit is applied to all
      requests matching this rule.

  Fields:
    blockDuration: Can only be specifed if the action for the rule is
      "rate_based_blacklist" If specified, determines the time (in seconds)
      the traffic will continue to be blocked by the rate limit after the rate
      falls below the threshold. The default value is 0 seconds.
    conformAction: Action to take when requests are under the given threshold.
      When requests are throttled, this is also the action for all requests
      which are not dropped. Valid options are "allow", "fairshare", and
      "drop_overload".
    enforceOnKey: Determines the key to enforce the threshold_rps limit on. If
      key is "IP", each IP has this limit enforced separately, whereas
      "ALL_IPs" means a single limit is applied to all requests matching this
      rule.
    exceedAction: When a request is denied, returns the HTTP response code
      specified. Valid options are "deny()" where valid values for status are
      403, 404, 429, and 502.
    thresholdRps: Rate in requests per second at which to begin ratelimiting.
  """

  class EnforceOnKeyValueValuesEnum(_messages.Enum):
    r"""Determines the key to enforce the threshold_rps limit on. If key is
    "IP", each IP has this limit enforced separately, whereas "ALL_IPs" means
    a single limit is applied to all requests matching this rule.

    Values:
      ALL_IPS: <no description>
      IP: <no description>
    """
    ALL_IPS = 0
    IP = 1

  blockDuration = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  conformAction = _messages.StringField(2)
  enforceOnKey = _messages.EnumField('EnforceOnKeyValueValuesEnum', 3)
  exceedAction = _messages.StringField(4)
  thresholdRps = _messages.IntegerField(5, variant=_messages.Variant.INT32)


class SecuritySettings(_messages.Message):
  r"""The authentication and authorization settings for a BackendService.

  Fields:
    authentication: A URL referring to a networksecurity.Authentication
      resource that describes how clients should authenticate with this
      service's backends. If left blank, communications between services are
      not encrypted (i.e., the TLS policy is set to OPEN). When sending
      traffic to this service's backends, the OriginationTls setting of
      Authentication.TransportAuthentication is applied. Refer to the
      Authentication and Authentication.TransportAuthentication.OriginationTls
      resources for additional details. authentication only applies to a
      global BackendService with the loadBalancingScheme set to
      INTERNAL_SELF_MANAGED.
    authenticationPolicy: [Deprecated] Authentication policy defines what
      authentication methods can be accepted on backends, and if
      authenticated, which method/certificate will set the request principal.
      request principal.
    authorizationConfig: [Deprecated] Authorization config defines the Role
      Based Access Control (RBAC) config. Authorization config defines the
      Role Based Access Control (RBAC) config.
    clientTlsSettings: [Deprecated] TLS Settings for the backend service.
    subjectAltNames: Optional. A list of subject alternate names to verify the
      subject identity (SAN) in the certificate presented by the server, to
      authorize the SAN list as identities to run the service represented by
      this BackendService. If specified, the client will verify that the
      server certificate's subject alt name matches one of the specified
      values. Only applies to a global BackendService with the
      loadBalancingScheme set to INTERNAL_SELF_MANAGED.
  """

  authentication = _messages.StringField(1)
  authenticationPolicy = _messages.MessageField('AuthenticationPolicy', 2)
  authorizationConfig = _messages.MessageField('AuthorizationConfig', 3)
  clientTlsSettings = _messages.MessageField('ClientTlsSettings', 4)
  subjectAltNames = _messages.StringField(5, repeated=True)


class SerialPortOutput(_messages.Message):
  r"""An instance's serial console output.

  Fields:
    contents: [Output Only] The contents of the console output.
    kind: [Output Only] Type of the resource. Always compute#serialPortOutput
      for serial port output.
    next: [Output Only] The position of the next byte of content from the
      serial console output. Use this value in the next request as the start
      parameter.
    selfLink: [Output Only] Server-defined URL for this resource.
    start: The starting byte position of the output that was returned. This
      should match the start parameter sent with the request. If the serial
      console output exceeds the size of the buffer, older output will be
      overwritten by newer content and the start values will be mismatched.
  """

  contents = _messages.StringField(1)
  kind = _messages.StringField(2, default=u'compute#serialPortOutput')
  next = _messages.IntegerField(3)
  selfLink = _messages.StringField(4)
  start = _messages.IntegerField(5)


class ServerBinding(_messages.Message):
  r"""A ServerBinding object.

  Enums:
    TypeValueValuesEnum:

  Fields:
    type: A TypeValueValuesEnum attribute.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""TypeValueValuesEnum enum type.

    Values:
      RESTART_NODE_ON_ANY_SERVER: <no description>
      RESTART_NODE_ON_MINIMAL_SERVERS: <no description>
      SERVER_BINDING_TYPE_UNSPECIFIED: <no description>
    """
    RESTART_NODE_ON_ANY_SERVER = 0
    RESTART_NODE_ON_MINIMAL_SERVERS = 1
    SERVER_BINDING_TYPE_UNSPECIFIED = 2

  type = _messages.EnumField('TypeValueValuesEnum', 1)


class ServerTlsSettings(_messages.Message):
  r"""The TLS settings for the server.

  Enums:
    TlsModeValueValuesEnum: Indicates whether connections should be secured
      using TLS. The value of this field determines how TLS is enforced. This
      field can be set to one of the following:   - SIMPLE Secure connections
      with standard TLS semantics.   - MUTUAL Secure connections to the
      backends using mutual TLS by presenting client certificates for
      authentication.

  Fields:
    proxyTlsContext: Configures the mechanism to obtain security certificates
      and identity information.
    subjectAltNames: A list of alternate names to verify the subject identity
      in the certificate presented by the client.
    tlsMode: Indicates whether connections should be secured using TLS. The
      value of this field determines how TLS is enforced. This field can be
      set to one of the following:   - SIMPLE Secure connections with standard
      TLS semantics.   - MUTUAL Secure connections to the backends using
      mutual TLS by presenting client certificates for authentication.
  """

  class TlsModeValueValuesEnum(_messages.Enum):
    r"""Indicates whether connections should be secured using TLS. The value
    of this field determines how TLS is enforced. This field can be set to one
    of the following:   - SIMPLE Secure connections with standard TLS
    semantics.   - MUTUAL Secure connections to the backends using mutual TLS
    by presenting client certificates for authentication.

    Values:
      INVALID: <no description>
      MUTUAL: <no description>
      SIMPLE: <no description>
    """
    INVALID = 0
    MUTUAL = 1
    SIMPLE = 2

  proxyTlsContext = _messages.MessageField('TlsContext', 1)
  subjectAltNames = _messages.StringField(2, repeated=True)
  tlsMode = _messages.EnumField('TlsModeValueValuesEnum', 3)


class ServiceAccount(_messages.Message):
  r"""A service account.

  Fields:
    email: Email address of the service account.
    scopes: The list of scopes to be made available for this service account.
  """

  email = _messages.StringField(1)
  scopes = _messages.StringField(2, repeated=True)


class ServiceAttachment(_messages.Message):
  r"""Represents a ServiceAttachment resource.  A service attachment
  represents a service that a producer has exposed. It encapsulates the load
  balancer which fronts the service runs and a list of NAT IP ranges that the
  producers uses to represent the consumers connecting to the service.

  Enums:
    ConnectionPreferenceValueValuesEnum:

  Fields:
    connectionPreference: A ConnectionPreferenceValueValuesEnum attribute.
    consumerForwardingRules: An array of forwarding rules for all the
      consumers connected to this service attachment.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    id: [Output Only] The unique identifier for the resource type. The server
      generates this identifier.
    kind: [Output Only] Type of the resource. Always compute#serviceAttachment
      for service attachments.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    natIpCidrRanges: An array of IP CIDR ranges where each range is the url of
      the address resource which represents the range provided by the service
      producer to use for NAT in this service attachment.
    producerForwardingRule: The URL of a forwarding rule with
      loadBalancingScheme INTERNAL* that is serving the endpoint identified by
      this service attachment.
    region: [Output Only] URL of the region where the service attachment
      resides. This field applies only to the region resource. You must
      specify this field as part of the HTTP request URL. It is not settable
      as a field in the request body.
    selfLink: [Output Only] Server-defined URL for the resource.
  """

  class ConnectionPreferenceValueValuesEnum(_messages.Enum):
    r"""ConnectionPreferenceValueValuesEnum enum type.

    Values:
      ACCEPT_AUTOMATIC: <no description>
      CONNECTION_PREFERENCE_UNSPECIFIED: <no description>
    """
    ACCEPT_AUTOMATIC = 0
    CONNECTION_PREFERENCE_UNSPECIFIED = 1

  connectionPreference = _messages.EnumField('ConnectionPreferenceValueValuesEnum', 1)
  consumerForwardingRules = _messages.MessageField('ServiceAttachmentConsumerForwardingRule', 2, repeated=True)
  creationTimestamp = _messages.StringField(3)
  description = _messages.StringField(4)
  id = _messages.IntegerField(5, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(6, default=u'compute#serviceAttachment')
  name = _messages.StringField(7)
  natIpCidrRanges = _messages.StringField(8, repeated=True)
  producerForwardingRule = _messages.StringField(9)
  region = _messages.StringField(10)
  selfLink = _messages.StringField(11)


class ServiceAttachmentConsumerForwardingRule(_messages.Message):
  r"""[Output Only] A consumer forwarding rule connected to this service
  attachment.

  Enums:
    StatusValueValuesEnum: The status of the forwarding rule.

  Fields:
    forwardingRule: The url of a consumer forwarding rule.
    status: The status of the forwarding rule.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""The status of the forwarding rule.

    Values:
      ACTIVE: <no description>
      INACTIVE: <no description>
      PENDING: <no description>
      STATUS_UNSPECIFIED: <no description>
    """
    ACTIVE = 0
    INACTIVE = 1
    PENDING = 2
    STATUS_UNSPECIFIED = 3

  forwardingRule = _messages.StringField(1)
  status = _messages.EnumField('StatusValueValuesEnum', 2)


class ServiceAttachmentList(_messages.Message):
  r"""A ServiceAttachmentList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of ServiceAttachment resources.
    kind: [Output Only] Type of the resource. Always compute#serviceAttachment
      for service attachments.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ServiceAttachment', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#serviceAttachmentList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class ShieldedInstanceConfig(_messages.Message):
  r"""A set of Shielded Instance options.

  Fields:
    enableIntegrityMonitoring: Defines whether the instance has integrity
      monitoring enabled. Enabled by default.
    enableSecureBoot: Defines whether the instance has Secure Boot enabled.
      Disabled by default.
    enableVtpm: Defines whether the instance has the vTPM enabled. Enabled by
      default.
  """

  enableIntegrityMonitoring = _messages.BooleanField(1)
  enableSecureBoot = _messages.BooleanField(2)
  enableVtpm = _messages.BooleanField(3)


class ShieldedInstanceIdentity(_messages.Message):
  r"""A shielded Instance identity entry.

  Fields:
    encryptionKey: An Endorsement Key (EK) made by the RSA 2048 algorithm
      issued to the Shielded Instance's vTPM.
    kind: [Output Only] Type of the resource. Always
      compute#shieldedInstanceIdentity for shielded Instance identity entry.
    signingKey: An Attestation Key (AK) made by the RSA 2048 algorithm issued
      to the Shielded Instance's vTPM.
  """

  encryptionKey = _messages.MessageField('ShieldedInstanceIdentityEntry', 1)
  kind = _messages.StringField(2, default=u'compute#shieldedInstanceIdentity')
  signingKey = _messages.MessageField('ShieldedInstanceIdentityEntry', 3)


class ShieldedInstanceIdentityEntry(_messages.Message):
  r"""A Shielded Instance Identity Entry.

  Fields:
    ekCert: A PEM-encoded X.509 certificate. This field can be empty.
    ekPub: A PEM-encoded public key.
  """

  ekCert = _messages.StringField(1)
  ekPub = _messages.StringField(2)


class ShieldedInstanceIntegrityPolicy(_messages.Message):
  r"""The policy describes the baseline against which Instance boot integrity
  is measured.

  Fields:
    updateAutoLearnPolicy: Updates the integrity policy baseline using the
      measurements from the VM instance's most recent boot.
  """

  updateAutoLearnPolicy = _messages.BooleanField(1)


class ShieldedVmConfig(_messages.Message):
  r"""A set of Shielded VM options.

  Fields:
    enableIntegrityMonitoring: Defines whether the instance has integrity
      monitoring enabled.
    enableSecureBoot: Defines whether the instance has Secure Boot enabled.
    enableVtpm: Defines whether the instance has the vTPM enabled.
  """

  enableIntegrityMonitoring = _messages.BooleanField(1)
  enableSecureBoot = _messages.BooleanField(2)
  enableVtpm = _messages.BooleanField(3)


class ShieldedVmIdentity(_messages.Message):
  r"""A shielded VM identity entry.

  Fields:
    encryptionKey: An Endorsement Key (EK) issued to the Shielded VM's vTPM.
    kind: [Output Only] Type of the resource. Always
      compute#shieldedVmIdentity for shielded VM identity entry.
    signingKey: An Attestation Key (AK) issued to the Shielded VM's vTPM.
  """

  encryptionKey = _messages.MessageField('ShieldedVmIdentityEntry', 1)
  kind = _messages.StringField(2, default=u'compute#shieldedVmIdentity')
  signingKey = _messages.MessageField('ShieldedVmIdentityEntry', 3)


class ShieldedVmIdentityEntry(_messages.Message):
  r"""A Shielded Instance Identity Entry.

  Fields:
    ekCert: A PEM-encoded X.509 certificate. This field can be empty.
    ekPub: A PEM-encoded public key.
  """

  ekCert = _messages.StringField(1)
  ekPub = _messages.StringField(2)


class ShieldedVmIntegrityPolicy(_messages.Message):
  r"""The policy describes the baseline against which VM instance boot
  integrity is measured.

  Fields:
    updateAutoLearnPolicy: Updates the integrity policy baseline using the
      measurements from the VM instance's most recent boot.
  """

  updateAutoLearnPolicy = _messages.BooleanField(1)


class SignedUrlKey(_messages.Message):
  r"""Represents a customer-supplied Signing Key used by Cloud CDN Signed URLs

  Fields:
    keyName: Name of the key. The name must be 1-63 characters long, and
      comply with RFC1035. Specifically, the name must be 1-63 characters long
      and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which
      means the first character must be a lowercase letter, and all following
      characters must be a dash, lowercase letter, or digit, except the last
      character, which cannot be a dash.
    keyValue: 128-bit key value used for signing the URL. The key value must
      be a valid RFC 4648 Section 5 base64url encoded string.
  """

  keyName = _messages.StringField(1)
  keyValue = _messages.StringField(2)


class Snapshot(_messages.Message):
  r"""Represents a Persistent Disk Snapshot resource.  You can use snapshots
  to back up data on a regular interval. For more information, read  Creating
  persistent disk snapshots. (== resource_for {$api_version}.snapshots ==)

  Enums:
    StatusValueValuesEnum: [Output Only] The status of the snapshot. This can
      be CREATING, DELETING, FAILED, READY, or UPLOADING.
    StorageBytesStatusValueValuesEnum: [Output Only] An indicator whether
      storageBytes is in a stable state or it is being adjusted as a result of
      shared storage reallocation. This status can either be UPDATING, meaning
      the size of the snapshot is being updated, or UP_TO_DATE, meaning the
      size of the snapshot is up-to-date.

  Messages:
    LabelsValue: Labels to apply to this snapshot. These can be later modified
      by the setLabels method. Label values may be empty.

  Fields:
    autoCreated: [Output Only] Set to true if snapshots are automatically
      created by applying resource policy on the target disk.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    diskSizeGb: [Output Only] Size of the source disk, specified in GB.
    downloadBytes: [Output Only] Number of bytes downloaded to restore a
      snapshot to a disk.
    guestOsFeatures: [Output Only] A list of features to enable on the guest
      operating system. Applicable only for bootable images. Read  Enabling
      guest operating system features to see a list of available options.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#snapshot for
      Snapshot resources.
    labelFingerprint: A fingerprint for the labels being applied to this
      snapshot, which is essentially a hash of the labels set used for
      optimistic locking. The fingerprint is initially generated by Compute
      Engine and changes after every request to modify or update labels. You
      must always provide an up-to-date fingerprint hash in order to update or
      change labels, otherwise the request will fail with error 412
      conditionNotMet.  To see the latest fingerprint, make a get() request to
      retrieve a snapshot.
    labels: Labels to apply to this snapshot. These can be later modified by
      the setLabels method. Label values may be empty.
    licenseCodes: [Output Only] Integer license codes indicating which
      licenses are attached to this snapshot.
    licenses: [Output Only] A list of public visible licenses that apply to
      this snapshot. This can be because the original image had licenses
      attached (such as a Windows image).
    name: Name of the resource; provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource's
      resource id.
    snapshotEncryptionKey: Encrypts the snapshot using a customer-supplied
      encryption key.  After you encrypt a snapshot using a customer-supplied
      key, you must provide the same key if you use the snapshot later. For
      example, you must provide the encryption key when you create a disk from
      the encrypted snapshot in a future request.  Customer-supplied
      encryption keys do not protect access to metadata of the snapshot.  If
      you do not provide an encryption key when creating the snapshot, then
      the snapshot will be encrypted using an automatically generated key and
      you do not need to provide a key to use the snapshot later.
    sourceDisk: [Output Only] The source disk used to create this snapshot.
    sourceDiskEncryptionKey: The customer-supplied encryption key of the
      source disk. Required if the source disk is protected by a customer-
      supplied encryption key.
    sourceDiskId: [Output Only] The ID value of the disk used to create this
      snapshot. This value may be used to determine whether the snapshot was
      taken from the current or a previous instance of a given disk name.
    status: [Output Only] The status of the snapshot. This can be CREATING,
      DELETING, FAILED, READY, or UPLOADING.
    storageBytes: [Output Only] A size of the storage used by the snapshot. As
      snapshots share storage, this number is expected to change with snapshot
      creation/deletion.
    storageBytesStatus: [Output Only] An indicator whether storageBytes is in
      a stable state or it is being adjusted as a result of shared storage
      reallocation. This status can either be UPDATING, meaning the size of
      the snapshot is being updated, or UP_TO_DATE, meaning the size of the
      snapshot is up-to-date.
    storageLocations: Cloud Storage bucket storage location of the snapshot
      (regional or multi-regional).
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the snapshot. This can be CREATING,
    DELETING, FAILED, READY, or UPLOADING.

    Values:
      CREATING: <no description>
      DELETING: <no description>
      FAILED: <no description>
      READY: <no description>
      UPLOADING: <no description>
    """
    CREATING = 0
    DELETING = 1
    FAILED = 2
    READY = 3
    UPLOADING = 4

  class StorageBytesStatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] An indicator whether storageBytes is in a stable state
    or it is being adjusted as a result of shared storage reallocation. This
    status can either be UPDATING, meaning the size of the snapshot is being
    updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date.

    Values:
      UPDATING: <no description>
      UP_TO_DATE: <no description>
    """
    UPDATING = 0
    UP_TO_DATE = 1

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels to apply to this snapshot. These can be later modified by the
    setLabels method. Label values may be empty.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  autoCreated = _messages.BooleanField(1)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  diskSizeGb = _messages.IntegerField(4)
  downloadBytes = _messages.IntegerField(5)
  guestOsFeatures = _messages.MessageField('GuestOsFeature', 6, repeated=True)
  id = _messages.IntegerField(7, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(8, default=u'compute#snapshot')
  labelFingerprint = _messages.BytesField(9)
  labels = _messages.MessageField('LabelsValue', 10)
  licenseCodes = _messages.IntegerField(11, repeated=True)
  licenses = _messages.StringField(12, repeated=True)
  name = _messages.StringField(13)
  selfLink = _messages.StringField(14)
  selfLinkWithId = _messages.StringField(15)
  snapshotEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 16)
  sourceDisk = _messages.StringField(17)
  sourceDiskEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 18)
  sourceDiskId = _messages.StringField(19)
  status = _messages.EnumField('StatusValueValuesEnum', 20)
  storageBytes = _messages.IntegerField(21)
  storageBytesStatus = _messages.EnumField('StorageBytesStatusValueValuesEnum', 22)
  storageLocations = _messages.StringField(23, repeated=True)


class SnapshotList(_messages.Message):
  r"""Contains a list of Snapshot resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Snapshot resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Snapshot', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#snapshotList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class SourceDiskEncryptionKey(_messages.Message):
  r"""A SourceDiskEncryptionKey object.

  Fields:
    diskEncryptionKey: The customer-supplied encryption key of the source
      disk. Required if the source disk is protected by a customer-supplied
      encryption key.
    sourceDisk: URL of the disk attached to the source instance. This can be a
      full or valid partial URL. For example, the following are valid values:
      - https://www.googleapis.com/compute/v1/projects/project/zones/zone/disk
      s/disk  - projects/project/zones/zone/disks/disk  -
      zones/zone/disks/disk
  """

  diskEncryptionKey = _messages.MessageField('CustomerEncryptionKey', 1)
  sourceDisk = _messages.StringField(2)


class SourceInstanceParams(_messages.Message):
  r"""A specification of the parameters to use when creating the instance
  template from a source instance.

  Fields:
    diskConfigs: Attached disks configuration. If not provided, defaults are
      applied: For boot disk and any other R/W disks, new custom images will
      be created from each disk. For read-only disks, they will be attached in
      read-only mode. Local SSD disks will be created as blank volumes.
  """

  diskConfigs = _messages.MessageField('DiskInstantiationConfig', 1, repeated=True)


class SourceInstanceProperties(_messages.Message):
  r"""SourceInstanceProperties message type.

  Messages:
    LabelsValue: Labels to apply to instances that are created from this
      machine image.

  Fields:
    canIpForward: Enables instances created based on this machine image to
      send packets with source IP addresses other than their own and receive
      packets with destination IP addresses other than their own. If these
      instances will be used as an IP gateway or it will be set as the next-
      hop in a Route resource, specify true. If unsure, leave this set to
      false. See the Enable IP forwarding documentation for more information.
    deletionProtection: Whether the instance created from this machine image
      should be protected against deletion.
    description: An optional text description for the instances that are
      created from this machine image.
    disks: An array of disks that are associated with the instances that are
      created from this machine image.
    guestAccelerators: A list of guest accelerator cards' type and count to
      use for instances created from this machine image.
    labels: Labels to apply to instances that are created from this machine
      image.
    machineType: The machine type to use for instances that are created from
      this machine image.
    metadata: The metadata key/value pairs to assign to instances that are
      created from this machine image. These pairs can consist of custom
      metadata or predefined keys. See Project and instance metadata for more
      information.
    minCpuPlatform: Minimum cpu/platform to be used by instances created from
      this machine image. The instance may be scheduled on the specified or
      newer cpu/platform. Applicable values are the friendly names of CPU
      platforms, such as minCpuPlatform: "Intel Haswell" or minCpuPlatform:
      "Intel Sandy Bridge". For more information, read Specifying a Minimum
      CPU Platform.
    networkInterfaces: An array of network access configurations for this
      interface.
    scheduling: Specifies the scheduling options for the instances that are
      created from this machine image.
    serviceAccounts: A list of service accounts with specified scopes. Access
      tokens for these service accounts are available to the instances that
      are created from this machine image. Use metadata queries to obtain the
      access tokens for these instances.
    tags: A list of tags to apply to the instances that are created from this
      machine image. The tags identify valid sources or targets for network
      firewalls. The setTags method can modify this list of tags. Each tag
      within the list must comply with RFC1035.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels to apply to instances that are created from this machine image.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  canIpForward = _messages.BooleanField(1)
  deletionProtection = _messages.BooleanField(2)
  description = _messages.StringField(3)
  disks = _messages.MessageField('SavedAttachedDisk', 4, repeated=True)
  guestAccelerators = _messages.MessageField('AcceleratorConfig', 5, repeated=True)
  labels = _messages.MessageField('LabelsValue', 6)
  machineType = _messages.StringField(7)
  metadata = _messages.MessageField('Metadata', 8)
  minCpuPlatform = _messages.StringField(9)
  networkInterfaces = _messages.MessageField('NetworkInterface', 10, repeated=True)
  scheduling = _messages.MessageField('Scheduling', 11)
  serviceAccounts = _messages.MessageField('ServiceAccount', 12, repeated=True)
  tags = _messages.MessageField('Tags', 13)


class SslCertificate(_messages.Message):
  r"""Represents an SSL Certificate resource.  Google Compute Engine has two
  SSL Certificate resources:  *
  [Global](/compute/docs/reference/rest/{$api_version}/sslCertificates) * [Reg
  ional](/compute/docs/reference/rest/{$api_version}/regionSslCertificates)
  The sslCertificates are used by:   - external HTTPS load balancers  - SSL
  proxy load balancers    The regionSslCertificates are used by internal HTTPS
  load balancers.  Optionally, certificate file contents that you upload can
  contain a set of up to five PEM-encoded certificates. The API call creates
  an object (sslCertificate) that holds this data. You can use SSL keys and
  certificates to secure connections to a load balancer. For more information,
  read  Creating and using SSL certificates and SSL certificates quotas and
  limits. (== resource_for {$api_version}.sslCertificates ==) (== resource_for
  {$api_version}.regionSslCertificates ==)

  Enums:
    TypeValueValuesEnum: (Optional) Specifies the type of SSL certificate,
      either "SELF_MANAGED" or "MANAGED". If not specified, the certificate is
      self-managed and the fields certificate and private_key are used.

  Fields:
    certificate: A local certificate file. The certificate must be in PEM
      format. The certificate chain must be no greater than 5 certs long. The
      chain must include at least one intermediate cert.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    expireTime: [Output Only] Expire time of the certificate. RFC3339
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#sslCertificate
      for SSL certificates.
    managed: Configuration and status of a managed SSL certificate.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    privateKey: A write-only private key in PEM format. Only insert requests
      will include this field.
    region: [Output Only] URL of the region where the regional SSL Certificate
      resides. This field is not applicable to global SSL Certificate.
    selfLink: [Output only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    selfManaged: Configuration and status of a self-managed SSL certificate.
    subjectAlternativeNames: [Output Only] Domains associated with the
      certificate via Subject Alternative Name.
    type: (Optional) Specifies the type of SSL certificate, either
      "SELF_MANAGED" or "MANAGED". If not specified, the certificate is self-
      managed and the fields certificate and private_key are used.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""(Optional) Specifies the type of SSL certificate, either
    "SELF_MANAGED" or "MANAGED". If not specified, the certificate is self-
    managed and the fields certificate and private_key are used.

    Values:
      MANAGED: <no description>
      SELF_MANAGED: <no description>
      TYPE_UNSPECIFIED: <no description>
    """
    MANAGED = 0
    SELF_MANAGED = 1
    TYPE_UNSPECIFIED = 2

  certificate = _messages.StringField(1)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  expireTime = _messages.StringField(4)
  id = _messages.IntegerField(5, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(6, default=u'compute#sslCertificate')
  managed = _messages.MessageField('SslCertificateManagedSslCertificate', 7)
  name = _messages.StringField(8)
  privateKey = _messages.StringField(9)
  region = _messages.StringField(10)
  selfLink = _messages.StringField(11)
  selfLinkWithId = _messages.StringField(12)
  selfManaged = _messages.MessageField('SslCertificateSelfManagedSslCertificate', 13)
  subjectAlternativeNames = _messages.StringField(14, repeated=True)
  type = _messages.EnumField('TypeValueValuesEnum', 15)


class SslCertificateAggregatedList(_messages.Message):
  r"""A SslCertificateAggregatedList object.

  Messages:
    ItemsValue: A list of SslCertificatesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of SslCertificatesScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#sslCertificateAggregatedList for lists of SSL Certificates.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of SslCertificatesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        SslCertificates.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A SslCertificatesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('SslCertificatesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#sslCertificateAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class SslCertificateList(_messages.Message):
  r"""Contains a list of SslCertificate resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of SslCertificate resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('SslCertificate', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#sslCertificateList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class SslCertificateManagedSslCertificate(_messages.Message):
  r"""Configuration and status of a managed SSL certificate.

  Enums:
    StatusValueValuesEnum: [Output only] Status of the managed certificate
      resource.

  Messages:
    DomainStatusValue: [Output only] Detailed statuses of the domains
      specified for managed certificate resource.

  Fields:
    domainStatus: [Output only] Detailed statuses of the domains specified for
      managed certificate resource.
    domains: The domains for which a managed SSL certificate will be
      generated. Currently only single-domain certs are supported.
    status: [Output only] Status of the managed certificate resource.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output only] Status of the managed certificate resource.

    Values:
      ACTIVE: <no description>
      MANAGED_CERTIFICATE_STATUS_UNSPECIFIED: <no description>
      PROVISIONING: <no description>
      PROVISIONING_FAILED: <no description>
      PROVISIONING_FAILED_PERMANENTLY: <no description>
      RENEWAL_FAILED: <no description>
    """
    ACTIVE = 0
    MANAGED_CERTIFICATE_STATUS_UNSPECIFIED = 1
    PROVISIONING = 2
    PROVISIONING_FAILED = 3
    PROVISIONING_FAILED_PERMANENTLY = 4
    RENEWAL_FAILED = 5

  @encoding.MapUnrecognizedFields('additionalProperties')
  class DomainStatusValue(_messages.Message):
    r"""[Output only] Detailed statuses of the domains specified for managed
    certificate resource.

    Messages:
      AdditionalProperty: An additional property for a DomainStatusValue
        object.

    Fields:
      additionalProperties: Additional properties of type DomainStatusValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a DomainStatusValue object.

      Enums:
        ValueValueValuesEnum:

      Fields:
        key: Name of the additional property.
        value: A ValueValueValuesEnum attribute.
      """

      class ValueValueValuesEnum(_messages.Enum):
        r"""ValueValueValuesEnum enum type.

        Values:
          ACTIVE: <no description>
          DOMAIN_STATUS_UNSPECIFIED: <no description>
          FAILED_CAA_CHECKING: <no description>
          FAILED_CAA_FORBIDDEN: <no description>
          FAILED_NOT_VISIBLE: <no description>
          FAILED_RATE_LIMITED: <no description>
          PROVISIONING: <no description>
        """
        ACTIVE = 0
        DOMAIN_STATUS_UNSPECIFIED = 1
        FAILED_CAA_CHECKING = 2
        FAILED_CAA_FORBIDDEN = 3
        FAILED_NOT_VISIBLE = 4
        FAILED_RATE_LIMITED = 5
        PROVISIONING = 6

      key = _messages.StringField(1)
      value = _messages.EnumField('ValueValueValuesEnum', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  domainStatus = _messages.MessageField('DomainStatusValue', 1)
  domains = _messages.StringField(2, repeated=True)
  status = _messages.EnumField('StatusValueValuesEnum', 3)


class SslCertificateSelfManagedSslCertificate(_messages.Message):
  r"""Configuration and status of a self-managed SSL certificate.

  Fields:
    certificate: A local certificate file. The certificate must be in PEM
      format. The certificate chain must be no greater than 5 certs long. The
      chain must include at least one intermediate cert.
    privateKey: A write-only private key in PEM format. Only insert requests
      will include this field.
  """

  certificate = _messages.StringField(1)
  privateKey = _messages.StringField(2)


class SslCertificatesScopedList(_messages.Message):
  r"""A SslCertificatesScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of backend
      services when the list is empty.

  Fields:
    sslCertificates: List of SslCertificates contained in this scope.
    warning: Informational warning which replaces the list of backend services
      when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of backend services when
    the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  sslCertificates = _messages.MessageField('SslCertificate', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class SslPoliciesList(_messages.Message):
  r"""A SslPoliciesList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of SslPolicy resources.
    kind: [Output Only] Type of the resource. Always compute#sslPoliciesList
      for lists of sslPolicies.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('SslPolicy', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#sslPoliciesList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class SslPoliciesListAvailableFeaturesResponse(_messages.Message):
  r"""A SslPoliciesListAvailableFeaturesResponse object.

  Fields:
    features: A string attribute.
  """

  features = _messages.StringField(1, repeated=True)


class SslPolicy(_messages.Message):
  r"""Represents a Cloud Armor Security Policy resource.  Only external
  backend services used by HTTP or HTTPS load balancers can reference a
  Security Policy. For more information, read read  Cloud Armor Security
  Policy Concepts. (== resource_for {$api_version}.sslPolicies ==)

  Enums:
    MinTlsVersionValueValuesEnum: The minimum version of SSL protocol that can
      be used by the clients to establish a connection with the load balancer.
      This can be one of TLS_1_0, TLS_1_1, TLS_1_2.
    ProfileValueValuesEnum: Profile specifies the set of SSL features that can
      be used by the load balancer when negotiating SSL with clients. This can
      be one of COMPATIBLE, MODERN, RESTRICTED, or CUSTOM. If using CUSTOM,
      the set of SSL features to enable must be specified in the
      customFeatures field.

  Messages:
    WarningsValueListEntry: A WarningsValueListEntry object.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    customFeatures: A list of features enabled when the selected profile is
      CUSTOM. The - method returns the set of features that can be specified
      in this list. This field must be empty if the profile is not CUSTOM.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    enabledFeatures: [Output Only] The list of features enabled in the SSL
      policy.
    fingerprint: Fingerprint of this resource. A hash of the contents stored
      in this object. This field is used in optimistic locking. This field
      will be ignored when inserting a SslPolicy. An up-to-date fingerprint
      must be provided in order to update the SslPolicy, otherwise the request
      will fail with error 412 conditionNotMet.  To see the latest
      fingerprint, make a get() request to retrieve an SslPolicy.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output only] Type of the resource. Always compute#sslPolicyfor SSL
      policies.
    minTlsVersion: The minimum version of SSL protocol that can be used by the
      clients to establish a connection with the load balancer. This can be
      one of TLS_1_0, TLS_1_1, TLS_1_2.
    name: Name of the resource. The name must be 1-63 characters long, and
      comply with RFC1035. Specifically, the name must be 1-63 characters long
      and match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which
      means the first character must be a lowercase letter, and all following
      characters must be a dash, lowercase letter, or digit, except the last
      character, which cannot be a dash.
    profile: Profile specifies the set of SSL features that can be used by the
      load balancer when negotiating SSL with clients. This can be one of
      COMPATIBLE, MODERN, RESTRICTED, or CUSTOM. If using CUSTOM, the set of
      SSL features to enable must be specified in the customFeatures field.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    tlsSettings: Security settings for the proxy. This field is only
      applicable to a global backend service with the loadBalancingScheme set
      to INTERNAL_SELF_MANAGED.
    warnings: [Output Only] If potential misconfigurations are detected for
      this SSL policy, this field will be populated with warning messages.
  """

  class MinTlsVersionValueValuesEnum(_messages.Enum):
    r"""The minimum version of SSL protocol that can be used by the clients to
    establish a connection with the load balancer. This can be one of TLS_1_0,
    TLS_1_1, TLS_1_2.

    Values:
      TLS_1_0: <no description>
      TLS_1_1: <no description>
      TLS_1_2: <no description>
    """
    TLS_1_0 = 0
    TLS_1_1 = 1
    TLS_1_2 = 2

  class ProfileValueValuesEnum(_messages.Enum):
    r"""Profile specifies the set of SSL features that can be used by the load
    balancer when negotiating SSL with clients. This can be one of COMPATIBLE,
    MODERN, RESTRICTED, or CUSTOM. If using CUSTOM, the set of SSL features to
    enable must be specified in the customFeatures field.

    Values:
      COMPATIBLE: <no description>
      CUSTOM: <no description>
      MODERN: <no description>
      RESTRICTED: <no description>
    """
    COMPATIBLE = 0
    CUSTOM = 1
    MODERN = 2
    RESTRICTED = 3

  class WarningsValueListEntry(_messages.Message):
    r"""A WarningsValueListEntry object.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  creationTimestamp = _messages.StringField(1)
  customFeatures = _messages.StringField(2, repeated=True)
  description = _messages.StringField(3)
  enabledFeatures = _messages.StringField(4, repeated=True)
  fingerprint = _messages.BytesField(5)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(7, default=u'compute#sslPolicy')
  minTlsVersion = _messages.EnumField('MinTlsVersionValueValuesEnum', 8)
  name = _messages.StringField(9)
  profile = _messages.EnumField('ProfileValueValuesEnum', 10)
  selfLink = _messages.StringField(11)
  selfLinkWithId = _messages.StringField(12)
  tlsSettings = _messages.MessageField('ServerTlsSettings', 13)
  warnings = _messages.MessageField('WarningsValueListEntry', 14, repeated=True)


class SslPolicyReference(_messages.Message):
  r"""A SslPolicyReference object.

  Fields:
    sslPolicy: URL of the SSL policy resource. Set this to empty string to
      clear any existing SSL policy associated with the target proxy resource.
  """

  sslPolicy = _messages.StringField(1)


class StandardQueryParameters(_messages.Message):
  r"""Query parameters accepted by all methods.

  Enums:
    AltValueValuesEnum: Data format for the response.

  Fields:
    alt: Data format for the response.
    fields: Selector specifying which fields to include in a partial response.
    key: API key. Your API key identifies your project and provides you with
      API access, quota, and reports. Required unless you provide an OAuth 2.0
      token.
    oauth_token: OAuth 2.0 token for the current user.
    prettyPrint: Returns response with indentations and line breaks.
    quotaUser: An opaque string that represents a user for quota purposes.
      Must not exceed 40 characters.
    trace: A tracing token of the form "token:<tokenid>" to include in api
      requests.
    userIp: Deprecated. Please use quotaUser instead.
  """

  class AltValueValuesEnum(_messages.Enum):
    r"""Data format for the response.

    Values:
      json: Responses with Content-Type of application/json
    """
    json = 0

  alt = _messages.EnumField('AltValueValuesEnum', 1, default=u'json')
  fields = _messages.StringField(2)
  key = _messages.StringField(3)
  oauth_token = _messages.StringField(4)
  prettyPrint = _messages.BooleanField(5, default=True)
  quotaUser = _messages.StringField(6)
  trace = _messages.StringField(7)
  userIp = _messages.StringField(8)


class StatefulPolicy(_messages.Message):
  r"""A StatefulPolicy object.

  Fields:
    preservedState: A StatefulPolicyPreservedState attribute.
  """

  preservedState = _messages.MessageField('StatefulPolicyPreservedState', 1)


class StatefulPolicyPreservedState(_messages.Message):
  r"""Configuration of preserved resources.

  Messages:
    DisksValue: Disks created on the instances that will be preserved on
      instance delete, update, etc. This map is keyed with the device names of
      the disks.

  Fields:
    disks: Disks created on the instances that will be preserved on instance
      delete, update, etc. This map is keyed with the device names of the
      disks.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class DisksValue(_messages.Message):
    r"""Disks created on the instances that will be preserved on instance
    delete, update, etc. This map is keyed with the device names of the disks.

    Messages:
      AdditionalProperty: An additional property for a DisksValue object.

    Fields:
      additionalProperties: Additional properties of type DisksValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a DisksValue object.

      Fields:
        key: Name of the additional property.
        value: A StatefulPolicyPreservedStateDiskDevice attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('StatefulPolicyPreservedStateDiskDevice', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  disks = _messages.MessageField('DisksValue', 1)


class StatefulPolicyPreservedStateDiskDevice(_messages.Message):
  r"""A StatefulPolicyPreservedStateDiskDevice object.

  Enums:
    AutoDeleteValueValuesEnum: These stateful disks will never be deleted
      during autohealing, update or VM instance recreate operations. This flag
      is used to configure if the disk should be deleted after it is no longer
      used by the group, e.g. when the given instance or the whole group is
      deleted. Note: disks attached in READ_ONLY mode cannot be auto-deleted.

  Fields:
    autoDelete: These stateful disks will never be deleted during autohealing,
      update or VM instance recreate operations. This flag is used to
      configure if the disk should be deleted after it is no longer used by
      the group, e.g. when the given instance or the whole group is deleted.
      Note: disks attached in READ_ONLY mode cannot be auto-deleted.
  """

  class AutoDeleteValueValuesEnum(_messages.Enum):
    r"""These stateful disks will never be deleted during autohealing, update
    or VM instance recreate operations. This flag is used to configure if the
    disk should be deleted after it is no longer used by the group, e.g. when
    the given instance or the whole group is deleted. Note: disks attached in
    READ_ONLY mode cannot be auto-deleted.

    Values:
      NEVER: <no description>
      ON_PERMANENT_INSTANCE_DELETION: <no description>
    """
    NEVER = 0
    ON_PERMANENT_INSTANCE_DELETION = 1

  autoDelete = _messages.EnumField('AutoDeleteValueValuesEnum', 1)


class Subnetwork(_messages.Message):
  r"""Represents a Subnetwork resource.  A subnetwork (also known as a subnet)
  is a logical partition of a Virtual Private Cloud network with one primary
  IP range and zero or more secondary IP ranges. For more information, read
  Virtual Private Cloud (VPC) Network. (== resource_for
  {$api_version}.subnetworks ==)

  Enums:
    AggregationIntervalValueValuesEnum: Can only be specified if VPC flow
      logging for this subnetwork is enabled. Sets the aggregation interval
      for collecting flow logs. Increasing the interval time reduces the
      amount of generated flow logs for long-lasting connections. Default is
      an interval of 5 seconds per connection. Valid values: INTERVAL_5_SEC,
      INTERVAL_30_SEC, INTERVAL_1_MIN, INTERVAL_5_MIN, INTERVAL_10_MIN,
      INTERVAL_15_MIN.
    MetadataValueValuesEnum: Can only be specified if VPC flow logging for
      this subnetwork is enabled. Configures whether metadata fields should be
      added to the reported VPC flow logs. Default is INCLUDE_ALL_METADATA.
    PrivateIpv6GoogleAccessValueValuesEnum: The private IPv6 google access
      type for the VMs in this subnet. This is an expanded field of
      enablePrivateV6Access. If both fields are set, privateIpv6GoogleAccess
      will take priority.  This field can be both set at resource creation
      time and updated using patch.
    PurposeValueValuesEnum: The purpose of the resource. This field can be
      either PRIVATE_RFC_1918 or INTERNAL_HTTPS_LOAD_BALANCER. A subnetwork
      with purpose set to INTERNAL_HTTPS_LOAD_BALANCER is a user-created
      subnetwork that is reserved for Internal HTTP(S) Load Balancing. If
      unspecified, the purpose defaults to PRIVATE_RFC_1918.
    RoleValueValuesEnum: The role of subnetwork. Currently, this field is only
      used when purpose = INTERNAL_HTTPS_LOAD_BALANCER. The value can be set
      to ACTIVE or BACKUP. An ACTIVE subnetwork is one that is currently being
      used for Internal HTTP(S) Load Balancing. A BACKUP subnetwork is one
      that is ready to be promoted to ACTIVE or is currently draining. This
      field can be updated with a patch request.
    StateValueValuesEnum: [Output Only] The state of the subnetwork, which can
      be one of READY or DRAINING. A subnetwork that is READY is ready to be
      used. The state of DRAINING is only applicable to subnetworks that have
      the purpose set to INTERNAL_HTTPS_LOAD_BALANCER and indicates that
      connections to the load balancer are being drained. A subnetwork that is
      draining cannot be used or modified until it reaches a status of READY.

  Fields:
    aggregationInterval: Can only be specified if VPC flow logging for this
      subnetwork is enabled. Sets the aggregation interval for collecting flow
      logs. Increasing the interval time reduces the amount of generated flow
      logs for long-lasting connections. Default is an interval of 5 seconds
      per connection. Valid values: INTERVAL_5_SEC, INTERVAL_30_SEC,
      INTERVAL_1_MIN, INTERVAL_5_MIN, INTERVAL_10_MIN, INTERVAL_15_MIN.
    allowSubnetCidrRoutesOverlap: Whether this subnetwork can conflict with
      static routes. Setting this to true allows this subnetwork's primary and
      secondary ranges to conflict with routes that have already been
      configured on the corresponding network. Static routes will take
      precedence over the subnetwork route if the route prefix length is at
      least as large as the subnetwork prefix length.  Also, packets destined
      to IPs within subnetwork may contain private/sensitive data and are
      prevented from leaving the virtual network. Setting this field to true
      will disable this feature.  The default value is false and applies to
      all existing subnetworks and automatically created subnetworks.  This
      field cannot be set to true at resource creation time.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource. This field can be set only at
      resource creation time.
    enableFlowLogs: Whether to enable flow logging for this subnetwork. If
      this field is not explicitly set, it will not appear in get listings. If
      not set the default behavior is to disable flow logging.
    enablePrivateV6Access: Deprecated in favor of enable in
      PrivateIpv6GoogleAccess. Whether the VMs in this subnet can directly
      access Google services via internal IPv6 addresses. This field can be
      both set at resource creation time and updated using patch.
    fingerprint: Fingerprint of this resource. A hash of the contents stored
      in this object. This field is used in optimistic locking. This field
      will be ignored when inserting a Subnetwork. An up-to-date fingerprint
      must be provided in order to update the Subnetwork, otherwise the
      request will fail with error 412 conditionNotMet.  To see the latest
      fingerprint, make a get() request to retrieve a Subnetwork.
    flowSampling: Can only be specified if VPC flow logging for this
      subnetwork is enabled. The value of the field must be in [0, 1]. Set the
      sampling rate of VPC flow logs within the subnetwork where 1.0 means all
      collected logs are reported and 0.0 means no logs are reported. Default
      is 0.5, which means half of all collected logs are reported.
    gatewayAddress: [Output Only] The gateway address for default routes to
      reach destination addresses outside this subnetwork.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    ipCidrRange: The range of internal addresses that are owned by this
      subnetwork. Provide this property when you create the subnetwork. For
      example, 10.0.0.0/8 or 192.168.0.0/16. Ranges must be unique and non-
      overlapping within a network. Only IPv4 is supported. This field can be
      set only at resource creation time.
    ipv6CidrRange: [Output Only] The range of internal IPv6 addresses that are
      owned by this subnetwork.
    kind: [Output Only] Type of the resource. Always compute#subnetwork for
      Subnetwork resources.
    logConfig: This field denotes the VPC flow logging options for this
      subnetwork. If logging is enabled, logs are exported to Stackdriver.
    metadata: Can only be specified if VPC flow logging for this subnetwork is
      enabled. Configures whether metadata fields should be added to the
      reported VPC flow logs. Default is INCLUDE_ALL_METADATA.
    name: The name of the resource, provided by the client when initially
      creating the resource. The name must be 1-63 characters long, and comply
      with RFC1035. Specifically, the name must be 1-63 characters long and
      match the regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means
      the first character must be a lowercase letter, and all following
      characters must be a dash, lowercase letter, or digit, except the last
      character, which cannot be a dash.
    network: The URL of the network to which this subnetwork belongs, provided
      by the client when initially creating the subnetwork. Only networks that
      are in the distributed mode can have subnetworks. This field can be set
      only at resource creation time.
    privateIpGoogleAccess: Whether the VMs in this subnet can access Google
      services without assigned external IP addresses. This field can be both
      set at resource creation time and updated using
      setPrivateIpGoogleAccess.
    privateIpv6GoogleAccess: The private IPv6 google access type for the VMs
      in this subnet. This is an expanded field of enablePrivateV6Access. If
      both fields are set, privateIpv6GoogleAccess will take priority.  This
      field can be both set at resource creation time and updated using patch.
    privateIpv6GoogleAccessServiceAccounts: Deprecated in favor of enable
      PrivateIpv6GoogleAccess on instance directly. The service accounts can
      be used to selectively turn on Private IPv6 Google Access only on the
      VMs primary service account matching the value. This value only takes
      effect when PrivateIpv6GoogleAccess is
      ENABLE_OUTBOUND_VM_ACCESS_TO_GOOGLE_FOR_SERVICE_ACCOUNTS or
      ENABLE_BIDIRECTIONAL_ACCESS_TO_GOOGLE_FOR_SERVICE_ACCOUNTS.
    purpose: The purpose of the resource. This field can be either
      PRIVATE_RFC_1918 or INTERNAL_HTTPS_LOAD_BALANCER. A subnetwork with
      purpose set to INTERNAL_HTTPS_LOAD_BALANCER is a user-created subnetwork
      that is reserved for Internal HTTP(S) Load Balancing. If unspecified,
      the purpose defaults to PRIVATE_RFC_1918.
    region: URL of the region where the Subnetwork resides. This field can be
      set only at resource creation time.
    role: The role of subnetwork. Currently, this field is only used when
      purpose = INTERNAL_HTTPS_LOAD_BALANCER. The value can be set to ACTIVE
      or BACKUP. An ACTIVE subnetwork is one that is currently being used for
      Internal HTTP(S) Load Balancing. A BACKUP subnetwork is one that is
      ready to be promoted to ACTIVE or is currently draining. This field can
      be updated with a patch request.
    secondaryIpRanges: An array of configurations for secondary IP ranges for
      VM instances contained in this subnetwork. The primary IP of such VM
      must belong to the primary ipCidrRange of the subnetwork. The alias IPs
      may belong to either primary or secondary ranges. This field can be
      updated with a patch request.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    state: [Output Only] The state of the subnetwork, which can be one of
      READY or DRAINING. A subnetwork that is READY is ready to be used. The
      state of DRAINING is only applicable to subnetworks that have the
      purpose set to INTERNAL_HTTPS_LOAD_BALANCER and indicates that
      connections to the load balancer are being drained. A subnetwork that is
      draining cannot be used or modified until it reaches a status of READY.
  """

  class AggregationIntervalValueValuesEnum(_messages.Enum):
    r"""Can only be specified if VPC flow logging for this subnetwork is
    enabled. Sets the aggregation interval for collecting flow logs.
    Increasing the interval time reduces the amount of generated flow logs for
    long-lasting connections. Default is an interval of 5 seconds per
    connection. Valid values: INTERVAL_5_SEC, INTERVAL_30_SEC, INTERVAL_1_MIN,
    INTERVAL_5_MIN, INTERVAL_10_MIN, INTERVAL_15_MIN.

    Values:
      INTERVAL_10_MIN: <no description>
      INTERVAL_15_MIN: <no description>
      INTERVAL_1_MIN: <no description>
      INTERVAL_30_SEC: <no description>
      INTERVAL_5_MIN: <no description>
      INTERVAL_5_SEC: <no description>
    """
    INTERVAL_10_MIN = 0
    INTERVAL_15_MIN = 1
    INTERVAL_1_MIN = 2
    INTERVAL_30_SEC = 3
    INTERVAL_5_MIN = 4
    INTERVAL_5_SEC = 5

  class MetadataValueValuesEnum(_messages.Enum):
    r"""Can only be specified if VPC flow logging for this subnetwork is
    enabled. Configures whether metadata fields should be added to the
    reported VPC flow logs. Default is INCLUDE_ALL_METADATA.

    Values:
      EXCLUDE_ALL_METADATA: <no description>
      INCLUDE_ALL_METADATA: <no description>
    """
    EXCLUDE_ALL_METADATA = 0
    INCLUDE_ALL_METADATA = 1

  class PrivateIpv6GoogleAccessValueValuesEnum(_messages.Enum):
    r"""The private IPv6 google access type for the VMs in this subnet. This
    is an expanded field of enablePrivateV6Access. If both fields are set,
    privateIpv6GoogleAccess will take priority.  This field can be both set at
    resource creation time and updated using patch.

    Values:
      DISABLE_GOOGLE_ACCESS: <no description>
      ENABLE_BIDIRECTIONAL_ACCESS_TO_GOOGLE: <no description>
      ENABLE_OUTBOUND_VM_ACCESS_TO_GOOGLE: <no description>
      ENABLE_OUTBOUND_VM_ACCESS_TO_GOOGLE_FOR_SERVICE_ACCOUNTS: <no
        description>
    """
    DISABLE_GOOGLE_ACCESS = 0
    ENABLE_BIDIRECTIONAL_ACCESS_TO_GOOGLE = 1
    ENABLE_OUTBOUND_VM_ACCESS_TO_GOOGLE = 2
    ENABLE_OUTBOUND_VM_ACCESS_TO_GOOGLE_FOR_SERVICE_ACCOUNTS = 3

  class PurposeValueValuesEnum(_messages.Enum):
    r"""The purpose of the resource. This field can be either PRIVATE_RFC_1918
    or INTERNAL_HTTPS_LOAD_BALANCER. A subnetwork with purpose set to
    INTERNAL_HTTPS_LOAD_BALANCER is a user-created subnetwork that is reserved
    for Internal HTTP(S) Load Balancing. If unspecified, the purpose defaults
    to PRIVATE_RFC_1918.

    Values:
      AGGREGATE: <no description>
      INTERNAL_HTTPS_LOAD_BALANCER: <no description>
      PRIVATE: <no description>
      PRIVATE_RFC_1918: <no description>
    """
    AGGREGATE = 0
    INTERNAL_HTTPS_LOAD_BALANCER = 1
    PRIVATE = 2
    PRIVATE_RFC_1918 = 3

  class RoleValueValuesEnum(_messages.Enum):
    r"""The role of subnetwork. Currently, this field is only used when
    purpose = INTERNAL_HTTPS_LOAD_BALANCER. The value can be set to ACTIVE or
    BACKUP. An ACTIVE subnetwork is one that is currently being used for
    Internal HTTP(S) Load Balancing. A BACKUP subnetwork is one that is ready
    to be promoted to ACTIVE or is currently draining. This field can be
    updated with a patch request.

    Values:
      ACTIVE: <no description>
      BACKUP: <no description>
    """
    ACTIVE = 0
    BACKUP = 1

  class StateValueValuesEnum(_messages.Enum):
    r"""[Output Only] The state of the subnetwork, which can be one of READY
    or DRAINING. A subnetwork that is READY is ready to be used. The state of
    DRAINING is only applicable to subnetworks that have the purpose set to
    INTERNAL_HTTPS_LOAD_BALANCER and indicates that connections to the load
    balancer are being drained. A subnetwork that is draining cannot be used
    or modified until it reaches a status of READY.

    Values:
      DRAINING: <no description>
      READY: <no description>
    """
    DRAINING = 0
    READY = 1

  aggregationInterval = _messages.EnumField('AggregationIntervalValueValuesEnum', 1)
  allowSubnetCidrRoutesOverlap = _messages.BooleanField(2)
  creationTimestamp = _messages.StringField(3)
  description = _messages.StringField(4)
  enableFlowLogs = _messages.BooleanField(5)
  enablePrivateV6Access = _messages.BooleanField(6)
  fingerprint = _messages.BytesField(7)
  flowSampling = _messages.FloatField(8, variant=_messages.Variant.FLOAT)
  gatewayAddress = _messages.StringField(9)
  id = _messages.IntegerField(10, variant=_messages.Variant.UINT64)
  ipCidrRange = _messages.StringField(11)
  ipv6CidrRange = _messages.StringField(12)
  kind = _messages.StringField(13, default=u'compute#subnetwork')
  logConfig = _messages.MessageField('SubnetworkLogConfig', 14)
  metadata = _messages.EnumField('MetadataValueValuesEnum', 15)
  name = _messages.StringField(16)
  network = _messages.StringField(17)
  privateIpGoogleAccess = _messages.BooleanField(18)
  privateIpv6GoogleAccess = _messages.EnumField('PrivateIpv6GoogleAccessValueValuesEnum', 19)
  privateIpv6GoogleAccessServiceAccounts = _messages.StringField(20, repeated=True)
  purpose = _messages.EnumField('PurposeValueValuesEnum', 21)
  region = _messages.StringField(22)
  role = _messages.EnumField('RoleValueValuesEnum', 23)
  secondaryIpRanges = _messages.MessageField('SubnetworkSecondaryRange', 24, repeated=True)
  selfLink = _messages.StringField(25)
  selfLinkWithId = _messages.StringField(26)
  state = _messages.EnumField('StateValueValuesEnum', 27)


class SubnetworkAggregatedList(_messages.Message):
  r"""A SubnetworkAggregatedList object.

  Messages:
    ItemsValue: A list of SubnetworksScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of SubnetworksScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#subnetworkAggregatedList for aggregated lists of subnetworks.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of SubnetworksScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        Subnetworks.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A SubnetworksScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('SubnetworksScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#subnetworkAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class SubnetworkList(_messages.Message):
  r"""Contains a list of Subnetwork resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Subnetwork resources.
    kind: [Output Only] Type of resource. Always compute#subnetworkList for
      lists of subnetworks.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Subnetwork', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#subnetworkList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class SubnetworkLogConfig(_messages.Message):
  r"""The available logging options for this subnetwork.

  Enums:
    AggregationIntervalValueValuesEnum: Can only be specified if VPC flow
      logging for this subnetwork is enabled. Toggles the aggregation interval
      for collecting flow logs. Increasing the interval time will reduce the
      amount of generated flow logs for long lasting connections. Default is
      an interval of 5 seconds per connection.
    MetadataValueValuesEnum: Can only be specified if VPC flow logs for this
      subnetwork is enabled. Configures whether all, none or a subset of
      metadata fields should be added to the reported VPC flow logs. Default
      is INCLUDE_ALL_METADATA.

  Fields:
    aggregationInterval: Can only be specified if VPC flow logging for this
      subnetwork is enabled. Toggles the aggregation interval for collecting
      flow logs. Increasing the interval time will reduce the amount of
      generated flow logs for long lasting connections. Default is an interval
      of 5 seconds per connection.
    enable: Whether to enable flow logging for this subnetwork. If this field
      is not explicitly set, it will not appear in get listings. If not set
      the default behavior is to disable flow logging.
    filterExpr: Can only be specified if VPC flow logs for this subnetwork is
      enabled. Export filter used to define which VPC flow logs should be
      logged.
    flowSampling: Can only be specified if VPC flow logging for this
      subnetwork is enabled. The value of the field must be in [0, 1]. Set the
      sampling rate of VPC flow logs within the subnetwork where 1.0 means all
      collected logs are reported and 0.0 means no logs are reported. Default
      is 0.5, which means half of all collected logs are reported.
    metadata: Can only be specified if VPC flow logs for this subnetwork is
      enabled. Configures whether all, none or a subset of metadata fields
      should be added to the reported VPC flow logs. Default is
      INCLUDE_ALL_METADATA.
    metadataFields: Can only be specified if VPC flow logs for this subnetwork
      is enabled and "metadata" was set to CUSTOM_METADATA.
  """

  class AggregationIntervalValueValuesEnum(_messages.Enum):
    r"""Can only be specified if VPC flow logging for this subnetwork is
    enabled. Toggles the aggregation interval for collecting flow logs.
    Increasing the interval time will reduce the amount of generated flow logs
    for long lasting connections. Default is an interval of 5 seconds per
    connection.

    Values:
      INTERVAL_10_MIN: <no description>
      INTERVAL_15_MIN: <no description>
      INTERVAL_1_MIN: <no description>
      INTERVAL_30_SEC: <no description>
      INTERVAL_5_MIN: <no description>
      INTERVAL_5_SEC: <no description>
    """
    INTERVAL_10_MIN = 0
    INTERVAL_15_MIN = 1
    INTERVAL_1_MIN = 2
    INTERVAL_30_SEC = 3
    INTERVAL_5_MIN = 4
    INTERVAL_5_SEC = 5

  class MetadataValueValuesEnum(_messages.Enum):
    r"""Can only be specified if VPC flow logs for this subnetwork is enabled.
    Configures whether all, none or a subset of metadata fields should be
    added to the reported VPC flow logs. Default is INCLUDE_ALL_METADATA.

    Values:
      CUSTOM_METADATA: <no description>
      EXCLUDE_ALL_METADATA: <no description>
      INCLUDE_ALL_METADATA: <no description>
    """
    CUSTOM_METADATA = 0
    EXCLUDE_ALL_METADATA = 1
    INCLUDE_ALL_METADATA = 2

  aggregationInterval = _messages.EnumField('AggregationIntervalValueValuesEnum', 1)
  enable = _messages.BooleanField(2)
  filterExpr = _messages.StringField(3)
  flowSampling = _messages.FloatField(4, variant=_messages.Variant.FLOAT)
  metadata = _messages.EnumField('MetadataValueValuesEnum', 5)
  metadataFields = _messages.StringField(6, repeated=True)


class SubnetworkSecondaryRange(_messages.Message):
  r"""Represents a secondary IP range of a subnetwork.

  Fields:
    ipCidrRange: The range of IP addresses belonging to this subnetwork
      secondary range. Provide this property when you create the subnetwork.
      Ranges must be unique and non-overlapping with all primary and secondary
      IP ranges within a network. Only IPv4 is supported.
    rangeName: The name associated with this subnetwork secondary range, used
      when adding an alias IP range to a VM instance. The name must be 1-63
      characters long, and comply with RFC1035. The name must be unique within
      the subnetwork.
  """

  ipCidrRange = _messages.StringField(1)
  rangeName = _messages.StringField(2)


class SubnetworksExpandIpCidrRangeRequest(_messages.Message):
  r"""A SubnetworksExpandIpCidrRangeRequest object.

  Fields:
    ipCidrRange: The IP (in CIDR format or netmask) of internal addresses that
      are legal on this Subnetwork. This range should be disjoint from other
      subnetworks within this network. This range can only be larger than
      (i.e. a superset of) the range previously defined before the update.
  """

  ipCidrRange = _messages.StringField(1)


class SubnetworksScopedList(_messages.Message):
  r"""A SubnetworksScopedList object.

  Messages:
    WarningValue: An informational warning that appears when the list of
      addresses is empty.

  Fields:
    subnetworks: A list of subnetworks contained in this scope.
    warning: An informational warning that appears when the list of addresses
      is empty.
  """

  class WarningValue(_messages.Message):
    r"""An informational warning that appears when the list of addresses is
    empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  subnetworks = _messages.MessageField('Subnetwork', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class SubnetworksSetPrivateIpGoogleAccessRequest(_messages.Message):
  r"""A SubnetworksSetPrivateIpGoogleAccessRequest object.

  Fields:
    privateIpGoogleAccess: A boolean attribute.
  """

  privateIpGoogleAccess = _messages.BooleanField(1)


class TCPHealthCheck(_messages.Message):
  r"""A TCPHealthCheck object.

  Enums:
    PortSpecificationValueValuesEnum: Specifies how port is selected for
      health checking, can be one of following values: USE_FIXED_PORT: The
      port number in port is used for health checking. USE_NAMED_PORT: The
      portName is used for health checking. USE_SERVING_PORT: For
      NetworkEndpointGroup, the port specified for each network endpoint is
      used for health checking. For other backends, the port or named port
      specified in the Backend Service is used for health checking.   If not
      specified, TCP health check follows behavior specified in port and
      portName fields.
    ProxyHeaderValueValuesEnum: Specifies the type of proxy header to append
      before sending data to the backend, either NONE or PROXY_V1. The default
      is NONE.

  Fields:
    port: The TCP port number for the health check request. The default value
      is 80. Valid values are 1 through 65535.
    portName: Port name as defined in InstanceGroup#NamedPort#name. If both
      port and port_name are defined, port takes precedence.
    portSpecification: Specifies how port is selected for health checking, can
      be one of following values: USE_FIXED_PORT: The port number in port is
      used for health checking. USE_NAMED_PORT: The portName is used for
      health checking. USE_SERVING_PORT: For NetworkEndpointGroup, the port
      specified for each network endpoint is used for health checking. For
      other backends, the port or named port specified in the Backend Service
      is used for health checking.   If not specified, TCP health check
      follows behavior specified in port and portName fields.
    proxyHeader: Specifies the type of proxy header to append before sending
      data to the backend, either NONE or PROXY_V1. The default is NONE.
    request: The application data to send once the TCP connection has been
      established (default value is empty). If both request and response are
      empty, the connection establishment alone will indicate health. The
      request data can only be ASCII.
    response: The bytes to match against the beginning of the response data.
      If left empty (the default value), any response will indicate health.
      The response data can only be ASCII.
  """

  class PortSpecificationValueValuesEnum(_messages.Enum):
    r"""Specifies how port is selected for health checking, can be one of
    following values: USE_FIXED_PORT: The port number in port is used for
    health checking. USE_NAMED_PORT: The portName is used for health checking.
    USE_SERVING_PORT: For NetworkEndpointGroup, the port specified for each
    network endpoint is used for health checking. For other backends, the port
    or named port specified in the Backend Service is used for health
    checking.   If not specified, TCP health check follows behavior specified
    in port and portName fields.

    Values:
      USE_FIXED_PORT: <no description>
      USE_NAMED_PORT: <no description>
      USE_SERVING_PORT: <no description>
    """
    USE_FIXED_PORT = 0
    USE_NAMED_PORT = 1
    USE_SERVING_PORT = 2

  class ProxyHeaderValueValuesEnum(_messages.Enum):
    r"""Specifies the type of proxy header to append before sending data to
    the backend, either NONE or PROXY_V1. The default is NONE.

    Values:
      NONE: <no description>
      PROXY_V1: <no description>
    """
    NONE = 0
    PROXY_V1 = 1

  port = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  portName = _messages.StringField(2)
  portSpecification = _messages.EnumField('PortSpecificationValueValuesEnum', 3)
  proxyHeader = _messages.EnumField('ProxyHeaderValueValuesEnum', 4)
  request = _messages.StringField(5)
  response = _messages.StringField(6)


class Tags(_messages.Message):
  r"""A set of instance tags.

  Fields:
    fingerprint: Specifies a fingerprint for this request, which is
      essentially a hash of the tags' contents and used for optimistic
      locking. The fingerprint is initially generated by Compute Engine and
      changes after every request to modify or update tags. You must always
      provide an up-to-date fingerprint hash in order to update or change
      tags.  To see the latest fingerprint, make get() request to the
      instance.
    items: An array of tags. Each tag must be 1-63 characters long, and comply
      with RFC1035.
  """

  fingerprint = _messages.BytesField(1)
  items = _messages.StringField(2, repeated=True)


class TargetGrpcProxy(_messages.Message):
  r"""Represents a Target gRPC Proxy resource.  A target gRPC proxy is a
  component of load balancers intended for load balancing gRPC traffic. Global
  forwarding rules reference a target gRPC proxy. The Target gRPC Proxy
  references a URL map which specifies how traffic routes to gRPC backend
  services.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    id: [Output Only] The unique identifier for the resource type. The server
      generates this identifier.
    kind: [Output Only] Type of the resource. Always compute#targetGrpcProxy
      for target grpc proxies.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL with id for the resource.
    urlMap: URL to the UrlMap resource that defines the mapping from URL to
      the BackendService. The protocol field in the BackendService must be set
      to GRPC.
    validateForProxyless: If true, indicates that the BackendServices
      referenced by the urlMap may be accessed by gRPC applications without
      using a sidecar proxy. This will enable configuration checks on urlMap
      and its referenced BackendServices to not allow unsupported features. A
      gRPC application must use "xds-experimental:///" scheme in the target
      URI of the service it is connecting to. If false, indicates that the
      BackendServices referenced by the urlMap will be accessed by gRPC
      applications via a sidecar proxy. In this case, a gRPC application must
      not use "xds-experimental:///" scheme in the target URI of the service
      it is connecting to
  """

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  id = _messages.IntegerField(3, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(4, default=u'compute#targetGrpcProxy')
  name = _messages.StringField(5)
  selfLink = _messages.StringField(6)
  selfLinkWithId = _messages.StringField(7)
  urlMap = _messages.StringField(8)
  validateForProxyless = _messages.BooleanField(9)


class TargetGrpcProxyList(_messages.Message):
  r"""A TargetGrpcProxyList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of TargetGrpcProxy resources.
    kind: [Output Only] Type of the resource. Always compute#targetGrpcProxy
      for target grpc proxies.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('TargetGrpcProxy', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#targetGrpcProxyList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class TargetHttpProxiesScopedList(_messages.Message):
  r"""A TargetHttpProxiesScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of backend
      services when the list is empty.

  Fields:
    targetHttpProxies: A list of TargetHttpProxies contained in this scope.
    warning: Informational warning which replaces the list of backend services
      when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of backend services when
    the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  targetHttpProxies = _messages.MessageField('TargetHttpProxy', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class TargetHttpProxy(_messages.Message):
  r"""Represents a Target HTTP Proxy resource.  Google Compute Engine has two
  Target HTTP Proxy resources:  *
  [Global](/compute/docs/reference/rest/{$api_version}/targetHttpProxies) * [R
  egional](/compute/docs/reference/rest/{$api_version}/regionTargetHttpProxies
  )  A target HTTP proxy is a component of GCP HTTP load balancers.  *
  targetHttpProxies are used by external HTTP load balancers and Traffic
  Director. * regionTargetHttpProxies are used by internal HTTP load
  balancers.  Forwarding rules reference a target HTTP proxy, and the target
  proxy then references a URL map. For more information, read Using Target
  Proxies and  Forwarding rule concepts. (== resource_for
  {$api_version}.targetHttpProxies ==) (== resource_for
  {$api_version}.regionTargetHttpProxies ==)

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    httpFilters: Urls to networkservices.HttpFilter resources enabled for xDS
      clients using this configuration. For example, https://networkservices.g
      oogleapis.com/v1alpha1/projects/project/locations/locationhttpFilters/ht
      tpFilter Only filters that handle outbound connection and stream events
      may be specified. These filters work in conjunction with a default set
      of HTTP filters that may already be configured by Traffic Director.
      Traffic Director will determine the final location of these filters
      within xDS configuration based on the name of the HTTP filter. If
      Traffic Director positions multiple filters at the same location, those
      filters will be in the same order as specified in this list. httpFilters
      only applies for loadbalancers with loadBalancingScheme set to
      INTERNAL_SELF_MANAGED. See ForwardingRule for more details.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of resource. Always compute#targetHttpProxy for
      target HTTP proxies.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    proxyBind: This field only applies when the loadBalancingScheme is
      INTERNAL_SELF_MANAGED. When set to true the Envoy binds on the IP
      address specified by the forwarding rule. Default is false.
    region: [Output Only] URL of the region where the regional Target HTTP
      Proxy resides. This field is not applicable to global Target HTTP
      Proxies.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    urlMap: URL to the UrlMap resource that defines the mapping from URL to
      the BackendService.
  """

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  httpFilters = _messages.StringField(3, repeated=True)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default=u'compute#targetHttpProxy')
  name = _messages.StringField(6)
  proxyBind = _messages.BooleanField(7)
  region = _messages.StringField(8)
  selfLink = _messages.StringField(9)
  selfLinkWithId = _messages.StringField(10)
  urlMap = _messages.StringField(11)


class TargetHttpProxyAggregatedList(_messages.Message):
  r"""A TargetHttpProxyAggregatedList object.

  Messages:
    ItemsValue: A list of TargetHttpProxiesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of TargetHttpProxiesScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#targetHttpProxyAggregatedList for lists of Target HTTP Proxies.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of TargetHttpProxiesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        TargetHttpProxies.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A TargetHttpProxiesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('TargetHttpProxiesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#targetHttpProxyAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class TargetHttpProxyList(_messages.Message):
  r"""A list of TargetHttpProxy resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of TargetHttpProxy resources.
    kind: Type of resource. Always compute#targetHttpProxyList for lists of
      target HTTP proxies.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('TargetHttpProxy', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#targetHttpProxyList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class TargetHttpsProxiesScopedList(_messages.Message):
  r"""A TargetHttpsProxiesScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of backend
      services when the list is empty.

  Fields:
    targetHttpsProxies: A list of TargetHttpsProxies contained in this scope.
    warning: Informational warning which replaces the list of backend services
      when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of backend services when
    the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  targetHttpsProxies = _messages.MessageField('TargetHttpsProxy', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class TargetHttpsProxiesSetCertificateMapRequest(_messages.Message):
  r"""A TargetHttpsProxiesSetCertificateMapRequest object.

  Fields:
    certificateMap: URL of the Certificate Map to associate with this
      TargetHttpsProxy.
  """

  certificateMap = _messages.StringField(1)


class TargetHttpsProxiesSetQuicOverrideRequest(_messages.Message):
  r"""A TargetHttpsProxiesSetQuicOverrideRequest object.

  Enums:
    QuicOverrideValueValuesEnum: QUIC policy for the TargetHttpsProxy
      resource.

  Fields:
    quicOverride: QUIC policy for the TargetHttpsProxy resource.
  """

  class QuicOverrideValueValuesEnum(_messages.Enum):
    r"""QUIC policy for the TargetHttpsProxy resource.

    Values:
      DISABLE: <no description>
      ENABLE: <no description>
      NONE: <no description>
    """
    DISABLE = 0
    ENABLE = 1
    NONE = 2

  quicOverride = _messages.EnumField('QuicOverrideValueValuesEnum', 1)


class TargetHttpsProxiesSetSslCertificatesRequest(_messages.Message):
  r"""A TargetHttpsProxiesSetSslCertificatesRequest object.

  Fields:
    sslCertificates: New set of SslCertificate resources to associate with
      this TargetHttpsProxy resource. Currently exactly one SslCertificate
      resource must be specified.
  """

  sslCertificates = _messages.StringField(1, repeated=True)


class TargetHttpsProxy(_messages.Message):
  r"""Represents a Target HTTPS Proxy resource.  Google Compute Engine has two
  Target HTTPS Proxy resources:  *
  [Global](/compute/docs/reference/rest/{$api_version}/targetHttpsProxies) * [
  Regional](/compute/docs/reference/rest/{$api_version}/regionTargetHttpsProxi
  es)  A target HTTPS proxy is a component of GCP HTTPS load balancers.  *
  targetHttpsProxies are used by external HTTPS load balancers. *
  regionTargetHttpsProxies are used by internal HTTPS load balancers.
  Forwarding rules reference a target HTTPS proxy, and the target proxy then
  references a URL map. For more information, read Using Target Proxies and
  Forwarding rule concepts. (== resource_for {$api_version}.targetHttpsProxies
  ==) (== resource_for {$api_version}.regionTargetHttpsProxies ==)

  Enums:
    QuicOverrideValueValuesEnum: Specifies the QUIC override policy for this
      TargetHttpsProxy resource. This setting determines whether the load
      balancer attempts to negotiate QUIC with clients. You can specify NONE,
      ENABLE, or DISABLE.   - When quic-override is set to NONE, Google
      manages whether QUIC is used.  - When quic-override is set to ENABLE,
      the load balancer uses QUIC when possible.  - When quic-override is set
      to DISABLE, the load balancer doesn't use QUIC.  - If the quic-override
      flag is not specified, NONE is implied. -

  Fields:
    authentication: A URL referring to a networksecurity.Authentication
      resource that describes how the proxy should authenticate inbound
      traffic. If left blank, communications between services are not
      encrypted (i.e., the TLS policy is set to OPEN). When terminating
      inbound traffic to this proxy, the TerminationTls setting of
      Authentication.TransportAuthentication is applied. Refer to the
      Authentication and Authentication.TransportAuthentication.TerminationTls
      resources for additional details. authentication only applies to a
      global TargetHttpsProxy attached to globalForwardingRules with the
      loadBalancingScheme set to INTERNAL_SELF_MANAGED.
    authorization: A URL referring to a networksecurity.Authorization resource
      that describes how the proxy should authorize inbound traffic. If left
      blank, access will not be restricted by an authorization policy. Refer
      to the Authorization resource for additional details. authorization only
      applies to a global TargetHttpsProxy attached to globalForwardingRules
      with the loadBalancingScheme set to INTERNAL_SELF_MANAGED.
    certificateMap: URL of a certificate map that identifies a certificate map
      associated with the given target proxy. This field can only be set for
      global target proxies. If set, sslCertificates will be ignored.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of resource. Always compute#targetHttpsProxy for
      target HTTPS proxies.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    proxyBind: This field only applies when the loadBalancingScheme is
      INTERNAL_SELF_MANAGED. When set to true the Envoy binds on the IP
      address specified by the forwarding rule. Default is false.
    quicOverride: Specifies the QUIC override policy for this TargetHttpsProxy
      resource. This setting determines whether the load balancer attempts to
      negotiate QUIC with clients. You can specify NONE, ENABLE, or DISABLE.
      - When quic-override is set to NONE, Google manages whether QUIC is
      used.  - When quic-override is set to ENABLE, the load balancer uses
      QUIC when possible.  - When quic-override is set to DISABLE, the load
      balancer doesn't use QUIC.  - If the quic-override flag is not
      specified, NONE is implied. -
    region: [Output Only] URL of the region where the regional
      TargetHttpsProxy resides. This field is not applicable to global
      TargetHttpsProxies.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    sslCertificates: URLs to SslCertificate resources that are used to
      authenticate connections between users and the load balancer. At least
      one SSL certificate must be specified. Currently, you may specify up to
      15 SSL certificates.
    sslPolicy: URL of SslPolicy resource that will be associated with the
      TargetHttpsProxy resource. If not set, the TargetHttpsProxy resource has
      no SSL policy configured.
    urlMap: A fully-qualified or valid partial URL to the UrlMap resource that
      defines the mapping from URL to the BackendService. For example, the
      following are all valid URLs for specifying a URL map:   -
      https://www.googleapis.compute/v1/projects/project/global/urlMaps/url-
      map  - projects/project/global/urlMaps/url-map  - global/urlMaps/url-map
  """

  class QuicOverrideValueValuesEnum(_messages.Enum):
    r"""Specifies the QUIC override policy for this TargetHttpsProxy resource.
    This setting determines whether the load balancer attempts to negotiate
    QUIC with clients. You can specify NONE, ENABLE, or DISABLE.   - When
    quic-override is set to NONE, Google manages whether QUIC is used.  - When
    quic-override is set to ENABLE, the load balancer uses QUIC when possible.
    - When quic-override is set to DISABLE, the load balancer doesn't use
    QUIC.  - If the quic-override flag is not specified, NONE is implied. -

    Values:
      DISABLE: <no description>
      ENABLE: <no description>
      NONE: <no description>
    """
    DISABLE = 0
    ENABLE = 1
    NONE = 2

  authentication = _messages.StringField(1)
  authorization = _messages.StringField(2)
  certificateMap = _messages.StringField(3)
  creationTimestamp = _messages.StringField(4)
  description = _messages.StringField(5)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(7, default=u'compute#targetHttpsProxy')
  name = _messages.StringField(8)
  proxyBind = _messages.BooleanField(9)
  quicOverride = _messages.EnumField('QuicOverrideValueValuesEnum', 10)
  region = _messages.StringField(11)
  selfLink = _messages.StringField(12)
  selfLinkWithId = _messages.StringField(13)
  sslCertificates = _messages.StringField(14, repeated=True)
  sslPolicy = _messages.StringField(15)
  urlMap = _messages.StringField(16)


class TargetHttpsProxyAggregatedList(_messages.Message):
  r"""A TargetHttpsProxyAggregatedList object.

  Messages:
    ItemsValue: A list of TargetHttpsProxiesScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of TargetHttpsProxiesScopedList resources.
    kind: [Output Only] Type of resource. Always
      compute#targetHttpsProxyAggregatedList for lists of Target HTTP Proxies.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of TargetHttpsProxiesScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of
        TargetHttpsProxies.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A TargetHttpsProxiesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('TargetHttpsProxiesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#targetHttpsProxyAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class TargetHttpsProxyList(_messages.Message):
  r"""Contains a list of TargetHttpsProxy resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of TargetHttpsProxy resources.
    kind: Type of resource. Always compute#targetHttpsProxyList for lists of
      target HTTPS proxies.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('TargetHttpsProxy', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#targetHttpsProxyList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class TargetInstance(_messages.Message):
  r"""Represents a Target Instance resource.  You can use a target instance to
  handle traffic for one or more forwarding rules, which is ideal for
  forwarding protocol traffic that is managed by a single source. For example,
  ESP, AH, TCP, or UDP. For more information, read Target instances. (==
  resource_for {$api_version}.targetInstances ==)

  Enums:
    NatPolicyValueValuesEnum: NAT option controlling how IPs are NAT'ed to the
      instance. Currently only NO_NAT (default value) is supported.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    instance: A URL to the virtual machine instance that handles traffic for
      this target instance. When creating a target instance, you can provide
      the fully-qualified URL or a valid partial URL to the desired virtual
      machine. For example, the following are all valid URLs:  - https://www.g
      oogleapis.com/compute/v1/projects/project/zones/zone/instances/instance
      - projects/project/zones/zone/instances/instance  -
      zones/zone/instances/instance
    kind: [Output Only] The type of the resource. Always
      compute#targetInstance for target instances.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    natPolicy: NAT option controlling how IPs are NAT'ed to the instance.
      Currently only NO_NAT (default value) is supported.
    network: The URL of the network this target instance uses to forward
      traffic. If not specified, the traffic will be forwarded to the network
      that the default network interface belongs to.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    zone: [Output Only] URL of the zone where the target instance resides. You
      must specify this field as part of the HTTP request URL. It is not
      settable as a field in the request body.
  """

  class NatPolicyValueValuesEnum(_messages.Enum):
    r"""NAT option controlling how IPs are NAT'ed to the instance. Currently
    only NO_NAT (default value) is supported.

    Values:
      NO_NAT: <no description>
    """
    NO_NAT = 0

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  id = _messages.IntegerField(3, variant=_messages.Variant.UINT64)
  instance = _messages.StringField(4)
  kind = _messages.StringField(5, default=u'compute#targetInstance')
  name = _messages.StringField(6)
  natPolicy = _messages.EnumField('NatPolicyValueValuesEnum', 7)
  network = _messages.StringField(8)
  selfLink = _messages.StringField(9)
  selfLinkWithId = _messages.StringField(10)
  zone = _messages.StringField(11)


class TargetInstanceAggregatedList(_messages.Message):
  r"""A TargetInstanceAggregatedList object.

  Messages:
    ItemsValue: A list of TargetInstance resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of TargetInstance resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of TargetInstance resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of target
        instances.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A TargetInstancesScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('TargetInstancesScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#targetInstanceAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class TargetInstanceList(_messages.Message):
  r"""Contains a list of TargetInstance resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of TargetInstance resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('TargetInstance', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#targetInstanceList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class TargetInstancesScopedList(_messages.Message):
  r"""A TargetInstancesScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of addresses
      when the list is empty.

  Fields:
    targetInstances: A list of target instances contained in this scope.
    warning: Informational warning which replaces the list of addresses when
      the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of addresses when the
    list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  targetInstances = _messages.MessageField('TargetInstance', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class TargetPool(_messages.Message):
  r"""Represents a Target Pool resource.  Target pools are used for network
  TCP/UDP load balancing. A target pool references member instances, an
  associated legacy HttpHealthCheck resource, and, optionally, a backup target
  pool. For more information, read Using target pools. (== resource_for
  {$api_version}.targetPools ==)

  Enums:
    SessionAffinityValueValuesEnum: Session affinity option, must be one of
      the following values: NONE: Connections from the same client IP may go
      to any instance in the pool. CLIENT_IP: Connections from the same client
      IP will go to the same instance in the pool while that instance remains
      healthy. CLIENT_IP_PROTO: Connections from the same client IP with the
      same IP protocol will go to the same instance in the pool while that
      instance remains healthy.

  Fields:
    backupPool: This field is applicable only when the containing target pool
      is serving a forwarding rule as the primary pool, and its failoverRatio
      field is properly set to a value between [0, 1].  backupPool and
      failoverRatio together define the fallback behavior of the primary
      target pool: if the ratio of the healthy instances in the primary pool
      is at or below failoverRatio, traffic arriving at the load-balanced IP
      will be directed to the backup pool.  In case where failoverRatio and
      backupPool are not set, or all the instances in the backup pool are
      unhealthy, the traffic will be directed back to the primary pool in the
      "force" mode, where traffic will be spread to the healthy instances with
      the best effort, or to all instances when no instance is healthy.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    failoverRatio: This field is applicable only when the containing target
      pool is serving a forwarding rule as the primary pool (i.e., not as a
      backup pool to some other target pool). The value of the field must be
      in [0, 1].  If set, backupPool must also be set. They together define
      the fallback behavior of the primary target pool: if the ratio of the
      healthy instances in the primary pool is at or below this number,
      traffic arriving at the load-balanced IP will be directed to the backup
      pool.  In case where failoverRatio is not set or all the instances in
      the backup pool are unhealthy, the traffic will be directed back to the
      primary pool in the "force" mode, where traffic will be spread to the
      healthy instances with the best effort, or to all instances when no
      instance is healthy.
    healthChecks: The URL of the HttpHealthCheck resource. A member instance
      in this pool is considered healthy if and only if the health checks
      pass. An empty list means all member instances will be considered
      healthy at all times. Only HttpHealthChecks are supported. Only one
      health check may be specified.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    instances: A list of resource URLs to the virtual machine instances
      serving this pool. They must live in zones contained in the same region
      as this pool.
    kind: [Output Only] Type of the resource. Always compute#targetPool for
      target pools.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    region: [Output Only] URL of the region where the target pool resides.
    selfLink: [Output Only] Server-defined URL for the resource.
    selfLinkWithId: [Output Only] Server-defined URL for this resource with
      the resource id.
    sessionAffinity: Session affinity option, must be one of the following
      values: NONE: Connections from the same client IP may go to any instance
      in the pool. CLIENT_IP: Connections from the same client IP will go to
      the same instance in the pool while that instance remains healthy.
      CLIENT_IP_PROTO: Connections from the same client IP with the same IP
      protocol will go to the same instance in the pool while that instance
      remains healthy.
  """

  class SessionAffinityValueValuesEnum(_messages.Enum):
    r"""Session affinity option, must be one of the following values: NONE:
    Connections from the same client IP may go to any instance in the pool.
    CLIENT_IP: Connections from the same client IP will go to the same
    instance in the pool while that instance remains healthy. CLIENT_IP_PROTO:
    Connections from the same client IP with the same IP protocol will go to
    the same instance in the pool while that instance remains healthy.

    Values:
      CLIENT_IP: <no description>
      CLIENT_IP_NO_DESTINATION: <no description>
      CLIENT_IP_PORT_PROTO: <no description>
      CLIENT_IP_PROTO: <no description>
      GENERATED_COOKIE: <no description>
      HEADER_FIELD: <no description>
      HTTP_COOKIE: <no description>
      NONE: <no description>
    """
    CLIENT_IP = 0
    CLIENT_IP_NO_DESTINATION = 1
    CLIENT_IP_PORT_PROTO = 2
    CLIENT_IP_PROTO = 3
    GENERATED_COOKIE = 4
    HEADER_FIELD = 5
    HTTP_COOKIE = 6
    NONE = 7

  backupPool = _messages.StringField(1)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  failoverRatio = _messages.FloatField(4, variant=_messages.Variant.FLOAT)
  healthChecks = _messages.StringField(5, repeated=True)
  id = _messages.IntegerField(6, variant=_messages.Variant.UINT64)
  instances = _messages.StringField(7, repeated=True)
  kind = _messages.StringField(8, default=u'compute#targetPool')
  name = _messages.StringField(9)
  region = _messages.StringField(10)
  selfLink = _messages.StringField(11)
  selfLinkWithId = _messages.StringField(12)
  sessionAffinity = _messages.EnumField('SessionAffinityValueValuesEnum', 13)


class TargetPoolAggregatedList(_messages.Message):
  r"""A TargetPoolAggregatedList object.

  Messages:
    ItemsValue: A list of TargetPool resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of TargetPool resources.
    kind: [Output Only] Type of resource. Always
      compute#targetPoolAggregatedList for aggregated lists of target pools.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of TargetPool resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of target
        pools.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A TargetPoolsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('TargetPoolsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#targetPoolAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class TargetPoolInstanceHealth(_messages.Message):
  r"""A TargetPoolInstanceHealth object.

  Fields:
    healthStatus: A HealthStatus attribute.
    kind: [Output Only] Type of resource. Always
      compute#targetPoolInstanceHealth when checking the health of an
      instance.
  """

  healthStatus = _messages.MessageField('HealthStatus', 1, repeated=True)
  kind = _messages.StringField(2, default=u'compute#targetPoolInstanceHealth')


class TargetPoolList(_messages.Message):
  r"""Contains a list of TargetPool resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of TargetPool resources.
    kind: [Output Only] Type of resource. Always compute#targetPoolList for
      lists of target pools.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('TargetPool', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#targetPoolList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class TargetPoolsAddHealthCheckRequest(_messages.Message):
  r"""A TargetPoolsAddHealthCheckRequest object.

  Fields:
    healthChecks: The HttpHealthCheck to add to the target pool.
  """

  healthChecks = _messages.MessageField('HealthCheckReference', 1, repeated=True)


class TargetPoolsAddInstanceRequest(_messages.Message):
  r"""A TargetPoolsAddInstanceRequest object.

  Fields:
    instances: A full or partial URL to an instance to add to this target
      pool. This can be a full or partial URL. For example, the following are
      valid URLs:   - https://www.googleapis.com/compute/v1/projects/project-
      id/zones/zone/instances/instance-name  - projects/project-
      id/zones/zone/instances/instance-name  - zones/zone/instances/instance-
      name
  """

  instances = _messages.MessageField('InstanceReference', 1, repeated=True)


class TargetPoolsRemoveHealthCheckRequest(_messages.Message):
  r"""A TargetPoolsRemoveHealthCheckRequest object.

  Fields:
    healthChecks: Health check URL to be removed. This can be a full or valid
      partial URL. For example, the following are valid URLs:   - https://www.
      googleapis.com/compute/beta/projects/project/global/httpHealthChecks
      /health-check  - projects/project/global/httpHealthChecks/health-check
      - global/httpHealthChecks/health-check
  """

  healthChecks = _messages.MessageField('HealthCheckReference', 1, repeated=True)


class TargetPoolsRemoveInstanceRequest(_messages.Message):
  r"""A TargetPoolsRemoveInstanceRequest object.

  Fields:
    instances: URLs of the instances to be removed from target pool.
  """

  instances = _messages.MessageField('InstanceReference', 1, repeated=True)


class TargetPoolsScopedList(_messages.Message):
  r"""A TargetPoolsScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of addresses
      when the list is empty.

  Fields:
    targetPools: A list of target pools contained in this scope.
    warning: Informational warning which replaces the list of addresses when
      the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of addresses when the
    list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  targetPools = _messages.MessageField('TargetPool', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class TargetReference(_messages.Message):
  r"""A TargetReference object.

  Fields:
    target: A string attribute.
  """

  target = _messages.StringField(1)


class TargetSslProxiesSetBackendServiceRequest(_messages.Message):
  r"""A TargetSslProxiesSetBackendServiceRequest object.

  Fields:
    service: The URL of the new BackendService resource for the
      targetSslProxy.
  """

  service = _messages.StringField(1)


class TargetSslProxiesSetCertificateMapRequest(_messages.Message):
  r"""A TargetSslProxiesSetCertificateMapRequest object.

  Fields:
    certificateMap: URL of the Certificate Map to associate with this
      TargetSslProxy.
  """

  certificateMap = _messages.StringField(1)


class TargetSslProxiesSetProxyHeaderRequest(_messages.Message):
  r"""A TargetSslProxiesSetProxyHeaderRequest object.

  Enums:
    ProxyHeaderValueValuesEnum: The new type of proxy header to append before
      sending data to the backend. NONE or PROXY_V1 are allowed.

  Fields:
    proxyHeader: The new type of proxy header to append before sending data to
      the backend. NONE or PROXY_V1 are allowed.
  """

  class ProxyHeaderValueValuesEnum(_messages.Enum):
    r"""The new type of proxy header to append before sending data to the
    backend. NONE or PROXY_V1 are allowed.

    Values:
      NONE: <no description>
      PROXY_V1: <no description>
    """
    NONE = 0
    PROXY_V1 = 1

  proxyHeader = _messages.EnumField('ProxyHeaderValueValuesEnum', 1)


class TargetSslProxiesSetSslCertificatesRequest(_messages.Message):
  r"""A TargetSslProxiesSetSslCertificatesRequest object.

  Fields:
    sslCertificates: New set of URLs to SslCertificate resources to associate
      with this TargetSslProxy. Currently exactly one ssl certificate must be
      specified.
  """

  sslCertificates = _messages.StringField(1, repeated=True)


class TargetSslProxy(_messages.Message):
  r"""Represents a Target SSL Proxy resource.  A target SSL proxy is a
  component of a SSL Proxy load balancer. Global forwarding rules reference a
  target SSL proxy, and the target proxy then references an external backend
  service. For more information, read Using Target Proxies. (== resource_for
  {$api_version}.targetSslProxies ==)

  Enums:
    ProxyHeaderValueValuesEnum: Specifies the type of proxy header to append
      before sending data to the backend, either NONE or PROXY_V1. The default
      is NONE.

  Fields:
    certificateMap: URL of a certificate map that identifies a certificate map
      associated with the given target proxy. This field can only be set for
      global target proxies. If set, sslCertificates will be ignored.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#targetSslProxy
      for target SSL proxies.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    proxyHeader: Specifies the type of proxy header to append before sending
      data to the backend, either NONE or PROXY_V1. The default is NONE.
    selfLink: [Output Only] Server-defined URL for the resource.
    service: URL to the BackendService resource.
    sslCertificates: URLs to SslCertificate resources that are used to
      authenticate connections to Backends. At least one SSL certificate must
      be specified. Currently, you may specify up to 15 SSL certificates.
    sslPolicy: URL of SslPolicy resource that will be associated with the
      TargetSslProxy resource. If not set, the TargetSslProxy resource will
      not have any SSL policy configured.
  """

  class ProxyHeaderValueValuesEnum(_messages.Enum):
    r"""Specifies the type of proxy header to append before sending data to
    the backend, either NONE or PROXY_V1. The default is NONE.

    Values:
      NONE: <no description>
      PROXY_V1: <no description>
    """
    NONE = 0
    PROXY_V1 = 1

  certificateMap = _messages.StringField(1)
  creationTimestamp = _messages.StringField(2)
  description = _messages.StringField(3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default=u'compute#targetSslProxy')
  name = _messages.StringField(6)
  proxyHeader = _messages.EnumField('ProxyHeaderValueValuesEnum', 7)
  selfLink = _messages.StringField(8)
  service = _messages.StringField(9)
  sslCertificates = _messages.StringField(10, repeated=True)
  sslPolicy = _messages.StringField(11)


class TargetSslProxyList(_messages.Message):
  r"""Contains a list of TargetSslProxy resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of TargetSslProxy resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('TargetSslProxy', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#targetSslProxyList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class TargetTcpProxiesSetBackendServiceRequest(_messages.Message):
  r"""A TargetTcpProxiesSetBackendServiceRequest object.

  Fields:
    service: The URL of the new BackendService resource for the
      targetTcpProxy.
  """

  service = _messages.StringField(1)


class TargetTcpProxiesSetProxyHeaderRequest(_messages.Message):
  r"""A TargetTcpProxiesSetProxyHeaderRequest object.

  Enums:
    ProxyHeaderValueValuesEnum: The new type of proxy header to append before
      sending data to the backend. NONE or PROXY_V1 are allowed.

  Fields:
    proxyHeader: The new type of proxy header to append before sending data to
      the backend. NONE or PROXY_V1 are allowed.
  """

  class ProxyHeaderValueValuesEnum(_messages.Enum):
    r"""The new type of proxy header to append before sending data to the
    backend. NONE or PROXY_V1 are allowed.

    Values:
      NONE: <no description>
      PROXY_V1: <no description>
    """
    NONE = 0
    PROXY_V1 = 1

  proxyHeader = _messages.EnumField('ProxyHeaderValueValuesEnum', 1)


class TargetTcpProxy(_messages.Message):
  r"""Represents a Target TCP Proxy resource.  A target TCP proxy is a
  component of a TCP Proxy load balancer. Global forwarding rules reference
  target TCP proxy, and the target proxy then references an external backend
  service. For more information, read TCP Proxy Load Balancing overview. (==
  resource_for {$api_version}.targetTcpProxies ==)

  Enums:
    ProxyHeaderValueValuesEnum: Specifies the type of proxy header to append
      before sending data to the backend, either NONE or PROXY_V1. The default
      is NONE.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#targetTcpProxy
      for target TCP proxies.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    proxyHeader: Specifies the type of proxy header to append before sending
      data to the backend, either NONE or PROXY_V1. The default is NONE.
    selfLink: [Output Only] Server-defined URL for the resource.
    service: URL to the BackendService resource.
  """

  class ProxyHeaderValueValuesEnum(_messages.Enum):
    r"""Specifies the type of proxy header to append before sending data to
    the backend, either NONE or PROXY_V1. The default is NONE.

    Values:
      NONE: <no description>
      PROXY_V1: <no description>
    """
    NONE = 0
    PROXY_V1 = 1

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  id = _messages.IntegerField(3, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(4, default=u'compute#targetTcpProxy')
  name = _messages.StringField(5)
  proxyHeader = _messages.EnumField('ProxyHeaderValueValuesEnum', 6)
  selfLink = _messages.StringField(7)
  service = _messages.StringField(8)


class TargetTcpProxyList(_messages.Message):
  r"""Contains a list of TargetTcpProxy resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of TargetTcpProxy resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('TargetTcpProxy', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#targetTcpProxyList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class TargetVpnGateway(_messages.Message):
  r"""Represents a Target VPN Gateway resource.  The target VPN gateway
  resource represents a Classic Cloud VPN gateway. For more information, read
  the the Cloud VPN Overview. (== resource_for
  {$api_version}.targetVpnGateways ==)

  Enums:
    StatusValueValuesEnum: [Output Only] The status of the VPN gateway, which
      can be one of the following: CREATING, READY, FAILED, or DELETING.

  Messages:
    LabelsValue: Labels for this resource. These can only be added or modified
      by the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    forwardingRules: [Output Only] A list of URLs to the ForwardingRule
      resources. ForwardingRules are created using
      compute.forwardingRules.insert and associated with a VPN gateway.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of resource. Always compute#targetVpnGateway for
      target VPN gateways.
    labelFingerprint: A fingerprint for the labels being applied to this
      TargetVpnGateway, which is essentially a hash of the labels set used for
      optimistic locking. The fingerprint is initially generated by Compute
      Engine and changes after every request to modify or update labels. You
      must always provide an up-to-date fingerprint hash in order to update or
      change labels, otherwise the request will fail with error 412
      conditionNotMet.  To see the latest fingerprint, make a get() request to
      retrieve a TargetVpnGateway.
    labels: Labels for this resource. These can only be added or modified by
      the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    network: URL of the network to which this VPN gateway is attached.
      Provided by the client when the VPN gateway is created.
    region: [Output Only] URL of the region where the target VPN gateway
      resides. You must specify this field as part of the HTTP request URL. It
      is not settable as a field in the request body.
    selfLink: [Output Only] Server-defined URL for the resource.
    status: [Output Only] The status of the VPN gateway, which can be one of
      the following: CREATING, READY, FAILED, or DELETING.
    tunnels: [Output Only] A list of URLs to VpnTunnel resources. VpnTunnels
      are created using the compute.vpntunnels.insert method and associated
      with a VPN gateway.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the VPN gateway, which can be one of the
    following: CREATING, READY, FAILED, or DELETING.

    Values:
      CREATING: <no description>
      DELETING: <no description>
      FAILED: <no description>
      READY: <no description>
    """
    CREATING = 0
    DELETING = 1
    FAILED = 2
    READY = 3

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels for this resource. These can only be added or modified by the
    setLabels method. Each label key/value pair must comply with RFC1035.
    Label values may be empty.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  forwardingRules = _messages.StringField(3, repeated=True)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(5, default=u'compute#targetVpnGateway')
  labelFingerprint = _messages.BytesField(6)
  labels = _messages.MessageField('LabelsValue', 7)
  name = _messages.StringField(8)
  network = _messages.StringField(9)
  region = _messages.StringField(10)
  selfLink = _messages.StringField(11)
  status = _messages.EnumField('StatusValueValuesEnum', 12)
  tunnels = _messages.StringField(13, repeated=True)


class TargetVpnGatewayAggregatedList(_messages.Message):
  r"""A TargetVpnGatewayAggregatedList object.

  Messages:
    ItemsValue: A list of TargetVpnGateway resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of TargetVpnGateway resources.
    kind: [Output Only] Type of resource. Always compute#targetVpnGateway for
      target VPN gateways.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of TargetVpnGateway resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of target VPN gateways.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A TargetVpnGatewaysScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('TargetVpnGatewaysScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#targetVpnGatewayAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class TargetVpnGatewayList(_messages.Message):
  r"""Contains a list of TargetVpnGateway resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of TargetVpnGateway resources.
    kind: [Output Only] Type of resource. Always compute#targetVpnGateway for
      target VPN gateways.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('TargetVpnGateway', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#targetVpnGatewayList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class TargetVpnGatewaysScopedList(_messages.Message):
  r"""A TargetVpnGatewaysScopedList object.

  Messages:
    WarningValue: [Output Only] Informational warning which replaces the list
      of addresses when the list is empty.

  Fields:
    targetVpnGateways: [Output Only] A list of target VPN gateways contained
      in this scope.
    warning: [Output Only] Informational warning which replaces the list of
      addresses when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning which replaces the list of
    addresses when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  targetVpnGateways = _messages.MessageField('TargetVpnGateway', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class TestFailure(_messages.Message):
  r"""A TestFailure object.

  Fields:
    actualService: A string attribute.
    expectedService: A string attribute.
    host: A string attribute.
    path: A string attribute.
  """

  actualService = _messages.StringField(1)
  expectedService = _messages.StringField(2)
  host = _messages.StringField(3)
  path = _messages.StringField(4)


class TestPermissionsRequest(_messages.Message):
  r"""A TestPermissionsRequest object.

  Fields:
    permissions: The set of permissions to check for the 'resource'.
      Permissions with wildcards (such as '*' or 'storage.*') are not allowed.
  """

  permissions = _messages.StringField(1, repeated=True)


class TestPermissionsResponse(_messages.Message):
  r"""A TestPermissionsResponse object.

  Fields:
    permissions: A subset of `TestPermissionsRequest.permissions` that the
      caller is allowed.
  """

  permissions = _messages.StringField(1, repeated=True)


class TlsCertificateContext(_messages.Message):
  r"""[Deprecated] Defines the mechanism to obtain the client or server
  certificate. Defines the mechanism to obtain the client or server
  certificate.

  Enums:
    CertificateSourceValueValuesEnum: Defines how TLS certificates are
      obtained.

  Fields:
    certificatePaths: Specifies the certificate and private key paths. This
      field is applicable only if tlsCertificateSource is set to USE_PATH.
    certificateSource: Defines how TLS certificates are obtained.
    sdsConfig: Specifies the config to retrieve certificates through SDS. This
      field is applicable only if tlsCertificateSource is set to USE_SDS.
  """

  class CertificateSourceValueValuesEnum(_messages.Enum):
    r"""Defines how TLS certificates are obtained.

    Values:
      INVALID: <no description>
      USE_PATH: <no description>
      USE_SDS: <no description>
    """
    INVALID = 0
    USE_PATH = 1
    USE_SDS = 2

  certificatePaths = _messages.MessageField('TlsCertificatePaths', 1)
  certificateSource = _messages.EnumField('CertificateSourceValueValuesEnum', 2)
  sdsConfig = _messages.MessageField('SdsConfig', 3)


class TlsCertificatePaths(_messages.Message):
  r"""[Deprecated] The paths to the mounted TLS Certificates and private key.
  The paths to the mounted TLS Certificates and private key.

  Fields:
    certificatePath: The path to the file holding the client or server TLS
      certificate to use.
    privateKeyPath: The path to the file holding the client or server private
      key.
  """

  certificatePath = _messages.StringField(1)
  privateKeyPath = _messages.StringField(2)


class TlsContext(_messages.Message):
  r"""[Deprecated] The TLS settings for the client or server. The TLS settings
  for the client or server.

  Fields:
    certificateContext: Defines the mechanism to obtain the client or server
      certificate.
    validationContext: Defines the mechanism to obtain the Certificate
      Authority certificate to validate the client/server certificate. If
      omitted, the proxy will not validate the server or client certificate.
  """

  certificateContext = _messages.MessageField('TlsCertificateContext', 1)
  validationContext = _messages.MessageField('TlsValidationContext', 2)


class TlsValidationContext(_messages.Message):
  r"""[Deprecated] Defines the mechanism to obtain the Certificate Authority
  certificate to validate the client/server certificate. validate the
  client/server certificate.

  Enums:
    ValidationSourceValueValuesEnum: Defines how TLS certificates are
      obtained.

  Fields:
    certificatePath: The path to the file holding the CA certificate to
      validate the client or server certificate.
    sdsConfig: Specifies the config to retrieve certificates through SDS. This
      field is applicable only if tlsCertificateSource is set to USE_SDS.
    validationSource: Defines how TLS certificates are obtained.
  """

  class ValidationSourceValueValuesEnum(_messages.Enum):
    r"""Defines how TLS certificates are obtained.

    Values:
      INVALID: <no description>
      USE_PATH: <no description>
      USE_SDS: <no description>
    """
    INVALID = 0
    USE_PATH = 1
    USE_SDS = 2

  certificatePath = _messages.StringField(1)
  sdsConfig = _messages.MessageField('SdsConfig', 2)
  validationSource = _messages.EnumField('ValidationSourceValueValuesEnum', 3)


class UDPHealthCheck(_messages.Message):
  r"""A UDPHealthCheck object.

  Fields:
    port: The UDP port number for the health check request. Valid values are 1
      through 65535.
    portName: Port name as defined in InstanceGroup#NamedPort#name. If both
      port and port_name are defined, port takes precedence.
    request: Raw data of request to send in payload of UDP packet. It is an
      error if this is empty. The request data can only be ASCII.
    response: The bytes to match against the beginning of the response data.
      It is an error if this is empty. The response data can only be ASCII.
  """

  port = _messages.IntegerField(1, variant=_messages.Variant.INT32)
  portName = _messages.StringField(2)
  request = _messages.StringField(3)
  response = _messages.StringField(4)


class UpcomingMaintenance(_messages.Message):
  r"""Upcoming Maintenance notification information.

  Enums:
    TypeValueValuesEnum: Defines the type of maintenance.

  Fields:
    date: [Output Only] The date when the maintenance will take place. This
      value is in RFC3339 text format.
    time: [Output Only] The time when the maintenance will take place. This
      value is in RFC3339 text format.
    type: Defines the type of maintenance.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""Defines the type of maintenance.

    Values:
      SCHEDULED: <no description>
      UNKNOWN_TYPE: <no description>
      UNSCHEDULED: <no description>
    """
    SCHEDULED = 0
    UNKNOWN_TYPE = 1
    UNSCHEDULED = 2

  date = _messages.StringField(1)
  time = _messages.StringField(2)
  type = _messages.EnumField('TypeValueValuesEnum', 3)


class UrlMap(_messages.Message):
  r"""Represents a URL Map resource.  Google Compute Engine has two URL Map
  resources:  * [Global](/compute/docs/reference/rest/{$api_version}/urlMaps)
  * [Regional](/compute/docs/reference/rest/{$api_version}/regionUrlMaps)  A
  URL map resource is a component of certain types of GCP load balancers and
  Traffic Director.  * urlMaps are used by external HTTP(S) load balancers and
  Traffic Director. * regionUrlMaps are used by internal HTTP(S) load
  balancers.  This resource defines mappings from host names and URL paths to
  either a backend service or a backend bucket.  To use the global urlMaps
  resource, the backend service must have a loadBalancingScheme of either
  EXTERNAL or INTERNAL_SELF_MANAGED. To use the regionUrlMaps resource, the
  backend service must have a loadBalancingScheme of INTERNAL_MANAGED. For
  more information, read URL Map Concepts.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    defaultRouteAction: defaultRouteAction takes effect when none of the
      hostRules match. The load balancer performs advanced routing actions
      like URL rewrites, header transformations, etc. prior to forwarding the
      request to the selected backend. If defaultRouteAction specifies any
      weightedBackendServices, defaultService must not be set. Conversely if
      defaultService is set, defaultRouteAction cannot contain any
      weightedBackendServices. Only one of defaultRouteAction or
      defaultUrlRedirect must be set.
    defaultService: The full or partial URL of the defaultService resource to
      which traffic is directed if none of the hostRules match. If
      defaultRouteAction is additionally specified, advanced routing actions
      like URL Rewrites, etc. take effect prior to sending the request to the
      backend. However, if defaultService is specified, defaultRouteAction
      cannot contain any weightedBackendServices. Conversely, if routeAction
      specifies any weightedBackendServices, service must not be specified.
      Only one of defaultService, defaultUrlRedirect  or
      defaultRouteAction.weightedBackendService must be set.
    defaultUrlRedirect: When none of the specified hostRules match, the
      request is redirected to a URL specified by defaultUrlRedirect. If
      defaultUrlRedirect is specified, defaultService or defaultRouteAction
      must not be set.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    fingerprint: Fingerprint of this resource. A hash of the contents stored
      in this object. This field is used in optimistic locking. This field
      will be ignored when inserting a UrlMap. An up-to-date fingerprint must
      be provided in order to update the UrlMap, otherwise the request will
      fail with error 412 conditionNotMet.  To see the latest fingerprint,
      make a get() request to retrieve a UrlMap.
    headerAction: Specifies changes to request and response headers that need
      to take effect for the selected backendService. The headerAction
      specified here take effect after headerAction specified under
      pathMatcher.
    hostRules: The list of HostRules to use against the URL.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#urlMaps for url
      maps.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    pathMatchers: The list of named PathMatchers to use against the URL.
    region: [Output Only] URL of the region where the regional URL map
      resides. This field is not applicable to global URL maps. You must
      specify this field as part of the HTTP request URL. It is not settable
      as a field in the request body.
    selfLink: [Output Only] Server-defined URL for the resource.
    tests: The list of expected URL mapping tests. Request to update this
      UrlMap will succeed only if all of the test cases pass. You can specify
      a maximum of 100 tests per UrlMap.
  """

  creationTimestamp = _messages.StringField(1)
  defaultRouteAction = _messages.MessageField('HttpRouteAction', 2)
  defaultService = _messages.StringField(3)
  defaultUrlRedirect = _messages.MessageField('HttpRedirectAction', 4)
  description = _messages.StringField(5)
  fingerprint = _messages.BytesField(6)
  headerAction = _messages.MessageField('HttpHeaderAction', 7)
  hostRules = _messages.MessageField('HostRule', 8, repeated=True)
  id = _messages.IntegerField(9, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(10, default=u'compute#urlMap')
  name = _messages.StringField(11)
  pathMatchers = _messages.MessageField('PathMatcher', 12, repeated=True)
  region = _messages.StringField(13)
  selfLink = _messages.StringField(14)
  tests = _messages.MessageField('UrlMapTest', 15, repeated=True)


class UrlMapList(_messages.Message):
  r"""Contains a list of UrlMap resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of UrlMap resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('UrlMap', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#urlMapList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class UrlMapReference(_messages.Message):
  r"""A UrlMapReference object.

  Fields:
    urlMap: A string attribute.
  """

  urlMap = _messages.StringField(1)


class UrlMapTest(_messages.Message):
  r"""Message for the expected URL mappings.

  Fields:
    backendServiceWeight: The weight to use for the supplied host and path
      when using advanced routing rules that involve traffic splitting.
    description: Description of this test case.
    expectedUrlRedirect: The expected URL that should be redirected to for the
      host and path being tested.
    host: Host portion of the URL.
    path: Path portion of the URL.
    service: Expected BackendService resource the given URL should be mapped
      to.
  """

  backendServiceWeight = _messages.IntegerField(1, variant=_messages.Variant.UINT32)
  description = _messages.StringField(2)
  expectedUrlRedirect = _messages.StringField(3)
  host = _messages.StringField(4)
  path = _messages.StringField(5)
  service = _messages.StringField(6)


class UrlMapValidationResult(_messages.Message):
  r"""Message representing the validation result for a UrlMap.

  Fields:
    loadErrors: A string attribute.
    loadSucceeded: Whether the given UrlMap can be successfully loaded. If
      false, 'loadErrors' indicates the reasons.
    testFailures: A TestFailure attribute.
    testPassed: If successfully loaded, this field indicates whether the test
      passed. If false, 'testFailures's indicate the reason of failure.
  """

  loadErrors = _messages.StringField(1, repeated=True)
  loadSucceeded = _messages.BooleanField(2)
  testFailures = _messages.MessageField('TestFailure', 3, repeated=True)
  testPassed = _messages.BooleanField(4)


class UrlMapsAggregatedList(_messages.Message):
  r"""A UrlMapsAggregatedList object.

  Messages:
    ItemsValue: A list of UrlMapsScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of UrlMapsScopedList resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of UrlMapsScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of UrlMaps.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A UrlMapsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('UrlMapsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#urlMapsAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class UrlMapsScopedList(_messages.Message):
  r"""A UrlMapsScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of backend
      services when the list is empty.

  Fields:
    urlMaps: A list of UrlMaps contained in this scope.
    warning: Informational warning which replaces the list of backend services
      when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of backend services when
    the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  urlMaps = _messages.MessageField('UrlMap', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class UrlMapsValidateRequest(_messages.Message):
  r"""A UrlMapsValidateRequest object.

  Fields:
    resource: Content of the UrlMap to be validated.
  """

  resource = _messages.MessageField('UrlMap', 1)


class UrlMapsValidateResponse(_messages.Message):
  r"""A UrlMapsValidateResponse object.

  Fields:
    result: A UrlMapValidationResult attribute.
  """

  result = _messages.MessageField('UrlMapValidationResult', 1)


class UrlRewrite(_messages.Message):
  r"""The spec for modifying the path before sending the request to the
  matched backend service.

  Fields:
    hostRewrite: Prior to forwarding the request to the selected service, the
      request's host header is replaced with contents of hostRewrite. The
      value must be between 1 and 255 characters.
    pathPrefixRewrite: Prior to forwarding the request to the selected backend
      service, the matching portion of the request's path is replaced by
      pathPrefixRewrite. The value must be between 1 and 1024 characters.
  """

  hostRewrite = _messages.StringField(1)
  pathPrefixRewrite = _messages.StringField(2)


class UsableSubnetwork(_messages.Message):
  r"""Subnetwork which the current user has compute.subnetworks.use permission
  on.

  Fields:
    ipCidrRange: The range of internal addresses that are owned by this
      subnetwork.
    network: Network URL.
    secondaryIpRanges: Secondary IP ranges.
    subnetwork: Subnetwork URL.
  """

  ipCidrRange = _messages.StringField(1)
  network = _messages.StringField(2)
  secondaryIpRanges = _messages.MessageField('UsableSubnetworkSecondaryRange', 3, repeated=True)
  subnetwork = _messages.StringField(4)


class UsableSubnetworkSecondaryRange(_messages.Message):
  r"""Secondary IP range of a usable subnetwork.

  Fields:
    ipCidrRange: The range of IP addresses belonging to this subnetwork
      secondary range.
    rangeName: The name associated with this subnetwork secondary range, used
      when adding an alias IP range to a VM instance. The name must be 1-63
      characters long, and comply with RFC1035. The name must be unique within
      the subnetwork.
  """

  ipCidrRange = _messages.StringField(1)
  rangeName = _messages.StringField(2)


class UsableSubnetworksAggregatedList(_messages.Message):
  r"""A UsableSubnetworksAggregatedList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    items: [Output] A list of usable subnetwork URLs.
    kind: [Output Only] Type of resource. Always
      compute#usableSubnetworksAggregatedList for aggregated lists of usable
      subnetworks.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('UsableSubnetwork', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#usableSubnetworksAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class UsageExportLocation(_messages.Message):
  r"""The location in Cloud Storage and naming method of the daily usage
  report. Contains bucket_name and report_name prefix.

  Fields:
    bucketName: The name of an existing bucket in Cloud Storage where the
      usage report object is stored. The Google Service Account is granted
      write access to this bucket. This can either be the bucket name by
      itself, such as example-bucket, or the bucket name with gs:// or
      https://storage.googleapis.com/ in front of it, such as gs://example-
      bucket.
    reportNamePrefix: An optional prefix for the name of the usage report
      object stored in bucketName. If not supplied, defaults to usage. The
      report is stored as a CSV file named report_name_prefix_gce_YYYYMMDD.csv
      where YYYYMMDD is the day of the usage according to Pacific Time. If you
      supply a prefix, it should conform to Cloud Storage object naming
      conventions.
  """

  bucketName = _messages.StringField(1)
  reportNamePrefix = _messages.StringField(2)


class VmEndpointNatMappings(_messages.Message):
  r"""Contain information of Nat mapping for a VM endpoint (i.e., NIC).

  Fields:
    instanceName: Name of the VM instance which the endpoint belongs to
    interfaceNatMappings: A VmEndpointNatMappingsInterfaceNatMappings
      attribute.
  """

  instanceName = _messages.StringField(1)
  interfaceNatMappings = _messages.MessageField('VmEndpointNatMappingsInterfaceNatMappings', 2, repeated=True)


class VmEndpointNatMappingsInterfaceNatMappings(_messages.Message):
  r"""Contain information of Nat mapping for an interface of this endpoint.

  Fields:
    drainNatIpPortRanges: List of all drain IP:port-range mappings assigned to
      this interface. These ranges are inclusive, that is, both the first and
      the last ports can be used for NAT. Example: ["2.2.2.2:12345-12355",
      "1.1.1.1:2234-2234"].
    natIpPortRanges: A list of all IP:port-range mappings assigned to this
      interface. These ranges are inclusive, that is, both the first and the
      last ports can be used for NAT. Example: ["2.2.2.2:12345-12355",
      "1.1.1.1:2234-2234"].
    numTotalDrainNatPorts: Total number of drain ports across all NAT IPs
      allocated to this interface. It equals to the aggregated port number in
      the field drain_nat_ip_port_ranges.
    numTotalNatPorts: Total number of ports across all NAT IPs allocated to
      this interface. It equals to the aggregated port number in the field
      nat_ip_port_ranges.
    sourceAliasIpRange: Alias IP range for this interface endpoint. It will be
      a private (RFC 1918) IP range. Examples: "10.33.4.55/32", or
      "192.168.5.0/24".
    sourceVirtualIp: Primary IP of the VM for this NIC.
  """

  drainNatIpPortRanges = _messages.StringField(1, repeated=True)
  natIpPortRanges = _messages.StringField(2, repeated=True)
  numTotalDrainNatPorts = _messages.IntegerField(3, variant=_messages.Variant.INT32)
  numTotalNatPorts = _messages.IntegerField(4, variant=_messages.Variant.INT32)
  sourceAliasIpRange = _messages.StringField(5)
  sourceVirtualIp = _messages.StringField(6)


class VmEndpointNatMappingsList(_messages.Message):
  r"""Contains a list of VmEndpointNatMappings.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of resource. Always
      compute#vmEndpointNatMappingsList for lists of Nat mappings of VM
      endpoints.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    result: [Output Only] A list of Nat mapping information of VM endpoints.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  kind = _messages.StringField(2, default=u'compute#vmEndpointNatMappingsList')
  nextPageToken = _messages.StringField(3)
  result = _messages.MessageField('VmEndpointNatMappings', 4, repeated=True)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class VpnGateway(_messages.Message):
  r"""Represents a HA VPN gateway.  HA VPN is a high-availability (HA) Cloud
  VPN solution that lets you securely connect your on-premises network to your
  Google Cloud Virtual Private Cloud network through an IPsec VPN connection
  in a single region. For more information about Cloud HA VPN solutions, see
  Cloud VPN topologies . (== resource_for {$api_version}.vpnGateways ==)

  Messages:
    LabelsValue: Labels for this resource. These can only be added or modified
      by the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of resource. Always compute#vpnGateway for VPN
      gateways.
    labelFingerprint: A fingerprint for the labels being applied to this
      VpnGateway, which is essentially a hash of the labels set used for
      optimistic locking. The fingerprint is initially generated by Compute
      Engine and changes after every request to modify or update labels. You
      must always provide an up-to-date fingerprint hash in order to update or
      change labels, otherwise the request will fail with error 412
      conditionNotMet.  To see the latest fingerprint, make a get() request to
      retrieve an VpnGateway.
    labels: Labels for this resource. These can only be added or modified by
      the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    network: URL of the network to which this VPN gateway is attached.
      Provided by the client when the VPN gateway is created.
    region: [Output Only] URL of the region where the VPN gateway resides.
    selfLink: [Output Only] Server-defined URL for the resource.
    vpnInterfaces: A list of interfaces on this VPN gateway.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels for this resource. These can only be added or modified by the
    setLabels method. Each label key/value pair must comply with RFC1035.
    Label values may be empty.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  id = _messages.IntegerField(3, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(4, default=u'compute#vpnGateway')
  labelFingerprint = _messages.BytesField(5)
  labels = _messages.MessageField('LabelsValue', 6)
  name = _messages.StringField(7)
  network = _messages.StringField(8)
  region = _messages.StringField(9)
  selfLink = _messages.StringField(10)
  vpnInterfaces = _messages.MessageField('VpnGatewayVpnGatewayInterface', 11, repeated=True)


class VpnGatewayAggregatedList(_messages.Message):
  r"""A VpnGatewayAggregatedList object.

  Messages:
    ItemsValue: A list of VpnGateway resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of VpnGateway resources.
    kind: [Output Only] Type of resource. Always compute#vpnGateway for VPN
      gateways.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of VpnGateway resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: [Output Only] Name of the scope containing this
        set of VPN gateways.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A VpnGatewaysScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('VpnGatewaysScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#vpnGatewayAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class VpnGatewayList(_messages.Message):
  r"""Contains a list of VpnGateway resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of VpnGateway resources.
    kind: [Output Only] Type of resource. Always compute#vpnGateway for VPN
      gateways.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('VpnGateway', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#vpnGatewayList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class VpnGatewayStatus(_messages.Message):
  r"""A VpnGatewayStatus object.

  Fields:
    vpnConnections: List of VPN connection for this VpnGateway.
  """

  vpnConnections = _messages.MessageField('VpnGatewayStatusVpnConnection', 1, repeated=True)


class VpnGatewayStatusHighAvailabilityRequirementState(_messages.Message):
  r"""Describes the high availability requirement state for the VPN connection
  between this Cloud VPN gateway and a peer gateway.

  Enums:
    StateValueValuesEnum: Indicates the high availability requirement state
      for the VPN connection. Valid values are CONNECTION_REDUNDANCY_MET,
      CONNECTION_REDUNDANCY_NOT_MET.
    UnsatisfiedReasonValueValuesEnum: Indicates the reason why the VPN
      connection does not meet the high availability redundancy
      criteria/requirement. Valid values is INCOMPLETE_TUNNELS_COVERAGE.

  Fields:
    state: Indicates the high availability requirement state for the VPN
      connection. Valid values are CONNECTION_REDUNDANCY_MET,
      CONNECTION_REDUNDANCY_NOT_MET.
    unsatisfiedReason: Indicates the reason why the VPN connection does not
      meet the high availability redundancy criteria/requirement. Valid values
      is INCOMPLETE_TUNNELS_COVERAGE.
  """

  class StateValueValuesEnum(_messages.Enum):
    r"""Indicates the high availability requirement state for the VPN
    connection. Valid values are CONNECTION_REDUNDANCY_MET,
    CONNECTION_REDUNDANCY_NOT_MET.

    Values:
      CONNECTION_REDUNDANCY_MET: <no description>
      CONNECTION_REDUNDANCY_NOT_MET: <no description>
    """
    CONNECTION_REDUNDANCY_MET = 0
    CONNECTION_REDUNDANCY_NOT_MET = 1

  class UnsatisfiedReasonValueValuesEnum(_messages.Enum):
    r"""Indicates the reason why the VPN connection does not meet the high
    availability redundancy criteria/requirement. Valid values is
    INCOMPLETE_TUNNELS_COVERAGE.

    Values:
      INCOMPLETE_TUNNELS_COVERAGE: <no description>
    """
    INCOMPLETE_TUNNELS_COVERAGE = 0

  state = _messages.EnumField('StateValueValuesEnum', 1)
  unsatisfiedReason = _messages.EnumField('UnsatisfiedReasonValueValuesEnum', 2)


class VpnGatewayStatusTunnel(_messages.Message):
  r"""Contains some information about a VPN tunnel.

  Fields:
    localGatewayInterface: The VPN gateway interface this VPN tunnel is
      associated with.
    peerGatewayInterface: The peer gateway interface this VPN tunnel is
      connected to, the peer gateway could either be an external VPN gateway
      or GCP VPN gateway.
    tunnelUrl: URL reference to the VPN tunnel.
  """

  localGatewayInterface = _messages.IntegerField(1, variant=_messages.Variant.UINT32)
  peerGatewayInterface = _messages.IntegerField(2, variant=_messages.Variant.UINT32)
  tunnelUrl = _messages.StringField(3)


class VpnGatewayStatusVpnConnection(_messages.Message):
  r"""A VPN connection contains all VPN tunnels connected from this VpnGateway
  to the same peer gateway. The peer gateway could either be a external VPN
  gateway or GCP VPN gateway.

  Fields:
    peerExternalGateway: URL reference to the peer external VPN gateways to
      which the VPN tunnels in this VPN connection are connected. This field
      is mutually exclusive with peer_gcp_gateway.
    peerGcpGateway: URL reference to the peer side VPN gateways to which the
      VPN tunnels in this VPN connection are connected. This field is mutually
      exclusive with peer_gcp_gateway.
    state: HighAvailabilityRequirementState for the VPN connection.
    tunnels: List of VPN tunnels that are in this VPN connection.
  """

  peerExternalGateway = _messages.StringField(1)
  peerGcpGateway = _messages.StringField(2)
  state = _messages.MessageField('VpnGatewayStatusHighAvailabilityRequirementState', 3)
  tunnels = _messages.MessageField('VpnGatewayStatusTunnel', 4, repeated=True)


class VpnGatewayVpnGatewayInterface(_messages.Message):
  r"""A VPN gateway interface.

  Fields:
    id: The numeric ID of this VPN gateway interface.
    ipAddress: [Output Only] The external IP address for this VPN gateway
      interface.
  """

  id = _messages.IntegerField(1, variant=_messages.Variant.UINT32)
  ipAddress = _messages.StringField(2)


class VpnGatewaysGetStatusResponse(_messages.Message):
  r"""A VpnGatewaysGetStatusResponse object.

  Fields:
    result: A VpnGatewayStatus attribute.
  """

  result = _messages.MessageField('VpnGatewayStatus', 1)


class VpnGatewaysScopedList(_messages.Message):
  r"""A VpnGatewaysScopedList object.

  Messages:
    WarningValue: [Output Only] Informational warning which replaces the list
      of addresses when the list is empty.

  Fields:
    vpnGateways: [Output Only] A list of VPN gateways contained in this scope.
    warning: [Output Only] Informational warning which replaces the list of
      addresses when the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning which replaces the list of
    addresses when the list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  vpnGateways = _messages.MessageField('VpnGateway', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class VpnTunnel(_messages.Message):
  r"""Represents a Cloud VPN Tunnel resource.  For more information about VPN,
  read the the Cloud VPN Overview. (== resource_for {$api_version}.vpnTunnels
  ==)

  Enums:
    StatusValueValuesEnum: [Output Only] The status of the VPN tunnel, which
      can be one of the following:  - PROVISIONING: Resource is being
      allocated for the VPN tunnel.  - WAITING_FOR_FULL_CONFIG: Waiting to
      receive all VPN-related configs from the user. Network,
      TargetVpnGateway, VpnTunnel, ForwardingRule, and Route resources are
      needed to setup the VPN tunnel.  - FIRST_HANDSHAKE: Successful first
      handshake with the peer VPN.  - ESTABLISHED: Secure session is
      successfully established with the peer VPN.  - NETWORK_ERROR:
      Deprecated, replaced by NO_INCOMING_PACKETS  - AUTHORIZATION_ERROR: Auth
      error (for example, bad shared secret).  - NEGOTIATION_FAILURE:
      Handshake failed.  - DEPROVISIONING: Resources are being deallocated for
      the VPN tunnel.  - FAILED: Tunnel creation has failed and the tunnel is
      not ready to be used.  - NO_INCOMING_PACKETS: No incoming packets from
      peer.  - REJECTED: Tunnel configuration was rejected, can be result of
      being blacklisted.  - ALLOCATING_RESOURCES: Cloud VPN is in the process
      of allocating all required resources.  - STOPPED: Tunnel is stopped due
      to its Forwarding Rules being deleted for Classic VPN tunnels or the
      project is in frozen state.  - PEER_IDENTITY_MISMATCH: Peer identity
      does not match peer IP, probably behind NAT.  -
      TS_NARROWING_NOT_ALLOWED: Traffic selector narrowing not allowed for an
      HA-VPN tunnel.

  Messages:
    LabelsValue: Labels for this resource. These can only be added or modified
      by the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.

  Fields:
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    description: An optional description of this resource. Provide this
      property when you create the resource.
    detailedStatus: [Output Only] Detailed status message for the VPN tunnel.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    ikeVersion: IKE protocol version to use when establishing the VPN tunnel
      with the peer VPN gateway. Acceptable IKE versions are 1 or 2. The
      default version is 2.
    kind: [Output Only] Type of resource. Always compute#vpnTunnel for VPN
      tunnels.
    labelFingerprint: A fingerprint for the labels being applied to this
      VpnTunnel, which is essentially a hash of the labels set used for
      optimistic locking. The fingerprint is initially generated by Compute
      Engine and changes after every request to modify or update labels. You
      must always provide an up-to-date fingerprint hash in order to update or
      change labels, otherwise the request will fail with error 412
      conditionNotMet.  To see the latest fingerprint, make a get() request to
      retrieve a VpnTunnel.
    labels: Labels for this resource. These can only be added or modified by
      the setLabels method. Each label key/value pair must comply with
      RFC1035. Label values may be empty.
    localTrafficSelector: Local traffic selector to use when establishing the
      VPN tunnel with the peer VPN gateway. The value should be a CIDR
      formatted string, for example: 192.168.0.0/16. The ranges must be
      disjoint. Only IPv4 is supported.
    name: Name of the resource. Provided by the client when the resource is
      created. The name must be 1-63 characters long, and comply with RFC1035.
      Specifically, the name must be 1-63 characters long and match the
      regular expression `[a-z]([-a-z0-9]*[a-z0-9])?` which means the first
      character must be a lowercase letter, and all following characters must
      be a dash, lowercase letter, or digit, except the last character, which
      cannot be a dash.
    peerExternalGateway: URL of the peer side external VPN gateway to which
      this VPN tunnel is connected. Provided by the client when the VPN tunnel
      is created. This field is exclusive with the field peerGcpGateway.
    peerExternalGatewayInterface: The interface ID of the external VPN gateway
      to which this VPN tunnel is connected. Provided by the client when the
      VPN tunnel is created.
    peerGcpGateway: URL of the peer side HA GCP VPN gateway to which this VPN
      tunnel is connected. Provided by the client when the VPN tunnel is
      created. This field can be used when creating highly available VPN from
      VPC network to VPC network, the field is exclusive with the field
      peerExternalGateway. If provided, the VPN tunnel will automatically use
      the same vpnGatewayInterface ID in the peer GCP VPN gateway.
    peerIp: IP address of the peer VPN gateway. Only IPv4 is supported.
    region: [Output Only] URL of the region where the VPN tunnel resides. You
      must specify this field as part of the HTTP request URL. It is not
      settable as a field in the request body.
    remoteTrafficSelector: Remote traffic selectors to use when establishing
      the VPN tunnel with the peer VPN gateway. The value should be a CIDR
      formatted string, for example: 192.168.0.0/16. The ranges should be
      disjoint. Only IPv4 is supported.
    router: URL of the router resource to be used for dynamic routing.
    selfLink: [Output Only] Server-defined URL for the resource.
    sharedSecret: Shared secret used to set the secure session between the
      Cloud VPN gateway and the peer VPN gateway.
    sharedSecretHash: Hash of the shared secret.
    status: [Output Only] The status of the VPN tunnel, which can be one of
      the following:  - PROVISIONING: Resource is being allocated for the VPN
      tunnel.  - WAITING_FOR_FULL_CONFIG: Waiting to receive all VPN-related
      configs from the user. Network, TargetVpnGateway, VpnTunnel,
      ForwardingRule, and Route resources are needed to setup the VPN tunnel.
      - FIRST_HANDSHAKE: Successful first handshake with the peer VPN.  -
      ESTABLISHED: Secure session is successfully established with the peer
      VPN.  - NETWORK_ERROR: Deprecated, replaced by NO_INCOMING_PACKETS  -
      AUTHORIZATION_ERROR: Auth error (for example, bad shared secret).  -
      NEGOTIATION_FAILURE: Handshake failed.  - DEPROVISIONING: Resources are
      being deallocated for the VPN tunnel.  - FAILED: Tunnel creation has
      failed and the tunnel is not ready to be used.  - NO_INCOMING_PACKETS:
      No incoming packets from peer.  - REJECTED: Tunnel configuration was
      rejected, can be result of being blacklisted.  - ALLOCATING_RESOURCES:
      Cloud VPN is in the process of allocating all required resources.  -
      STOPPED: Tunnel is stopped due to its Forwarding Rules being deleted for
      Classic VPN tunnels or the project is in frozen state.  -
      PEER_IDENTITY_MISMATCH: Peer identity does not match peer IP, probably
      behind NAT.  - TS_NARROWING_NOT_ALLOWED: Traffic selector narrowing not
      allowed for an HA-VPN tunnel.
    targetVpnGateway: URL of the Target VPN gateway with which this VPN tunnel
      is associated. Provided by the client when the VPN tunnel is created.
    vpnGateway: URL of the VPN gateway with which this VPN tunnel is
      associated. Provided by the client when the VPN tunnel is created. This
      must be used (instead of target_vpn_gateway) if a High Availability VPN
      gateway resource is created.
    vpnGatewayInterface: The interface ID of the VPN gateway with which this
      VPN tunnel is associated.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] The status of the VPN tunnel, which can be one of the
    following:  - PROVISIONING: Resource is being allocated for the VPN
    tunnel.  - WAITING_FOR_FULL_CONFIG: Waiting to receive all VPN-related
    configs from the user. Network, TargetVpnGateway, VpnTunnel,
    ForwardingRule, and Route resources are needed to setup the VPN tunnel.  -
    FIRST_HANDSHAKE: Successful first handshake with the peer VPN.  -
    ESTABLISHED: Secure session is successfully established with the peer VPN.
    - NETWORK_ERROR: Deprecated, replaced by NO_INCOMING_PACKETS  -
    AUTHORIZATION_ERROR: Auth error (for example, bad shared secret).  -
    NEGOTIATION_FAILURE: Handshake failed.  - DEPROVISIONING: Resources are
    being deallocated for the VPN tunnel.  - FAILED: Tunnel creation has
    failed and the tunnel is not ready to be used.  - NO_INCOMING_PACKETS: No
    incoming packets from peer.  - REJECTED: Tunnel configuration was
    rejected, can be result of being blacklisted.  - ALLOCATING_RESOURCES:
    Cloud VPN is in the process of allocating all required resources.  -
    STOPPED: Tunnel is stopped due to its Forwarding Rules being deleted for
    Classic VPN tunnels or the project is in frozen state.  -
    PEER_IDENTITY_MISMATCH: Peer identity does not match peer IP, probably
    behind NAT.  - TS_NARROWING_NOT_ALLOWED: Traffic selector narrowing not
    allowed for an HA-VPN tunnel.

    Values:
      ALLOCATING_RESOURCES: <no description>
      AUTHORIZATION_ERROR: <no description>
      DEPROVISIONING: <no description>
      ESTABLISHED: <no description>
      FAILED: <no description>
      FIRST_HANDSHAKE: <no description>
      NEGOTIATION_FAILURE: <no description>
      NETWORK_ERROR: <no description>
      NO_INCOMING_PACKETS: <no description>
      PROVISIONING: <no description>
      REJECTED: <no description>
      STOPPED: <no description>
      WAITING_FOR_FULL_CONFIG: <no description>
    """
    ALLOCATING_RESOURCES = 0
    AUTHORIZATION_ERROR = 1
    DEPROVISIONING = 2
    ESTABLISHED = 3
    FAILED = 4
    FIRST_HANDSHAKE = 5
    NEGOTIATION_FAILURE = 6
    NETWORK_ERROR = 7
    NO_INCOMING_PACKETS = 8
    PROVISIONING = 9
    REJECTED = 10
    STOPPED = 11
    WAITING_FOR_FULL_CONFIG = 12

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""Labels for this resource. These can only be added or modified by the
    setLabels method. Each label key/value pair must comply with RFC1035.
    Label values may be empty.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  creationTimestamp = _messages.StringField(1)
  description = _messages.StringField(2)
  detailedStatus = _messages.StringField(3)
  id = _messages.IntegerField(4, variant=_messages.Variant.UINT64)
  ikeVersion = _messages.IntegerField(5, variant=_messages.Variant.INT32)
  kind = _messages.StringField(6, default=u'compute#vpnTunnel')
  labelFingerprint = _messages.BytesField(7)
  labels = _messages.MessageField('LabelsValue', 8)
  localTrafficSelector = _messages.StringField(9, repeated=True)
  name = _messages.StringField(10)
  peerExternalGateway = _messages.StringField(11)
  peerExternalGatewayInterface = _messages.IntegerField(12, variant=_messages.Variant.INT32)
  peerGcpGateway = _messages.StringField(13)
  peerIp = _messages.StringField(14)
  region = _messages.StringField(15)
  remoteTrafficSelector = _messages.StringField(16, repeated=True)
  router = _messages.StringField(17)
  selfLink = _messages.StringField(18)
  sharedSecret = _messages.StringField(19)
  sharedSecretHash = _messages.StringField(20)
  status = _messages.EnumField('StatusValueValuesEnum', 21)
  targetVpnGateway = _messages.StringField(22)
  vpnGateway = _messages.StringField(23)
  vpnGatewayInterface = _messages.IntegerField(24, variant=_messages.Variant.INT32)


class VpnTunnelAggregatedList(_messages.Message):
  r"""A VpnTunnelAggregatedList object.

  Messages:
    ItemsValue: A list of VpnTunnelsScopedList resources.
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of VpnTunnelsScopedList resources.
    kind: [Output Only] Type of resource. Always compute#vpnTunnel for VPN
      tunnels.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    unreachables: [Output Only] Unreachable resources.
    warning: [Output Only] Informational warning message.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class ItemsValue(_messages.Message):
    r"""A list of VpnTunnelsScopedList resources.

    Messages:
      AdditionalProperty: An additional property for a ItemsValue object.

    Fields:
      additionalProperties: Name of the scope containing this set of VPN
        tunnels.
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a ItemsValue object.

      Fields:
        key: Name of the additional property.
        value: A VpnTunnelsScopedList attribute.
      """

      key = _messages.StringField(1)
      value = _messages.MessageField('VpnTunnelsScopedList', 2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('ItemsValue', 2)
  kind = _messages.StringField(3, default=u'compute#vpnTunnelAggregatedList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  unreachables = _messages.StringField(6, repeated=True)
  warning = _messages.MessageField('WarningValue', 7)


class VpnTunnelList(_messages.Message):
  r"""Contains a list of VpnTunnel resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of VpnTunnel resources.
    kind: [Output Only] Type of resource. Always compute#vpnTunnel for VPN
      tunnels.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('VpnTunnel', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#vpnTunnelList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class VpnTunnelsScopedList(_messages.Message):
  r"""A VpnTunnelsScopedList object.

  Messages:
    WarningValue: Informational warning which replaces the list of addresses
      when the list is empty.

  Fields:
    vpnTunnels: A list of VPN tunnels contained in this scope.
    warning: Informational warning which replaces the list of addresses when
      the list is empty.
  """

  class WarningValue(_messages.Message):
    r"""Informational warning which replaces the list of addresses when the
    list is empty.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  vpnTunnels = _messages.MessageField('VpnTunnel', 1, repeated=True)
  warning = _messages.MessageField('WarningValue', 2)


class WafExpressionSet(_messages.Message):
  r"""A WafExpressionSet object.

  Fields:
    aliases: A list of alternate IDs. The format should be: - E.g. XSS-stable
      Generic suffix like "stable" is particularly useful if a policy likes to
      avail newer set of expressions without having to change the policy. A
      given alias name can't be used for more than one entity set.
    expressions: List of available expressions.
    id: Google specified expression set ID. The format should be: - E.g.
      XSS-20170329
  """

  aliases = _messages.StringField(1, repeated=True)
  expressions = _messages.MessageField('WafExpressionSetExpression', 2, repeated=True)
  id = _messages.StringField(3)


class WafExpressionSetExpression(_messages.Message):
  r"""A WafExpressionSetExpression object.

  Fields:
    id: Expression ID should uniquely identify the origin of the expression.
      E.g. owasp-crs-v020901-id973337 identifies Owasp core rule set version
      2.9.1 rule id 973337. The ID could be used to determine the individual
      attack definition that has been detected. It could also be used to
      exclude it from the policy in case of false positive.
  """

  id = _messages.StringField(1)


class WeightedBackendService(_messages.Message):
  r"""In contrast to a single BackendService in  HttpRouteAction to which all
  matching traffic is directed to, WeightedBackendService allows traffic to be
  split across multiple BackendServices. The volume of traffic for each
  BackendService is proportional to the weight specified in each
  WeightedBackendService

  Fields:
    backendService: The full or partial URL to the default BackendService
      resource. Before forwarding the request to backendService, the
      loadbalancer applies any relevant headerActions specified as part of
      this backendServiceWeight.
    headerAction: Specifies changes to request and response headers that need
      to take effect for the selected backendService. headerAction specified
      here take effect before headerAction in the enclosing HttpRouteRule,
      PathMatcher and UrlMap.
    weight: Specifies the fraction of traffic sent to backendService, computed
      as weight / (sum of all weightedBackendService weights in routeAction) .
      The selection of a backend service is determined only for new traffic.
      Once a user's request has been directed to a backendService, subsequent
      requests will be sent to the same backendService as determined by the
      BackendService's session affinity policy. The value must be between 0
      and 1000
  """

  backendService = _messages.StringField(1)
  headerAction = _messages.MessageField('HttpHeaderAction', 2)
  weight = _messages.IntegerField(3, variant=_messages.Variant.UINT32)


class XpnHostList(_messages.Message):
  r"""A XpnHostList object.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: [Output Only] A list of shared VPC host project URLs.
    kind: [Output Only] Type of resource. Always compute#xpnHostList for lists
      of shared VPC hosts.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Project', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#xpnHostList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class XpnResourceId(_messages.Message):
  r"""Service resource (a.k.a service project) ID.

  Enums:
    TypeValueValuesEnum: The type of the service resource.

  Fields:
    id: The ID of the service resource. In the case of projects, this field
      supports project id (e.g., my-project-123) and project number (e.g.
      12345678).
    type: The type of the service resource.
  """

  class TypeValueValuesEnum(_messages.Enum):
    r"""The type of the service resource.

    Values:
      PROJECT: <no description>
      XPN_RESOURCE_TYPE_UNSPECIFIED: <no description>
    """
    PROJECT = 0
    XPN_RESOURCE_TYPE_UNSPECIFIED = 1

  id = _messages.StringField(1)
  type = _messages.EnumField('TypeValueValuesEnum', 2)


class Zone(_messages.Message):
  r"""Represents a Zone resource.  A zone is a deployment area. These
  deployment areas are subsets of a region. For example the zone us-east1-a is
  located in the us-east1 region. For more information, read Regions and
  Zones. (== resource_for {$api_version}.zones ==)

  Enums:
    StatusValueValuesEnum: [Output Only] Status of the zone, either UP or
      DOWN.

  Fields:
    availableCpuPlatforms: [Output Only] Available cpu/platform selections for
      the zone.
    creationTimestamp: [Output Only] Creation timestamp in RFC3339 text
      format.
    deprecated: [Output Only] The deprecation status associated with this
      zone.
    description: [Output Only] Textual description of the resource.
    id: [Output Only] The unique identifier for the resource. This identifier
      is defined by the server.
    kind: [Output Only] Type of the resource. Always compute#zone for zones.
    name: [Output Only] Name of the resource.
    region: [Output Only] Full URL reference to the region which hosts the
      zone.
    selfLink: [Output Only] Server-defined URL for the resource.
    status: [Output Only] Status of the zone, either UP or DOWN.
  """

  class StatusValueValuesEnum(_messages.Enum):
    r"""[Output Only] Status of the zone, either UP or DOWN.

    Values:
      DOWN: <no description>
      UP: <no description>
    """
    DOWN = 0
    UP = 1

  availableCpuPlatforms = _messages.StringField(1, repeated=True)
  creationTimestamp = _messages.StringField(2)
  deprecated = _messages.MessageField('DeprecationStatus', 3)
  description = _messages.StringField(4)
  id = _messages.IntegerField(5, variant=_messages.Variant.UINT64)
  kind = _messages.StringField(6, default=u'compute#zone')
  name = _messages.StringField(7)
  region = _messages.StringField(8)
  selfLink = _messages.StringField(9)
  status = _messages.EnumField('StatusValueValuesEnum', 10)


class ZoneList(_messages.Message):
  r"""Contains a list of zone resources.

  Messages:
    WarningValue: [Output Only] Informational warning message.

  Fields:
    id: [Output Only] Unique identifier for the resource; defined by the
      server.
    items: A list of Zone resources.
    kind: Type of resource.
    nextPageToken: [Output Only] This token allows you to get the next page of
      results for list requests. If the number of results is larger than
      maxResults, use the nextPageToken as a value for the query parameter
      pageToken in the next list request. Subsequent list requests will have
      their own nextPageToken to continue paging through the results.
    selfLink: [Output Only] Server-defined URL for this resource.
    warning: [Output Only] Informational warning message.
  """

  class WarningValue(_messages.Message):
    r"""[Output Only] Informational warning message.

    Enums:
      CodeValueValuesEnum: [Output Only] A warning code, if applicable. For
        example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no
        results in the response.

    Messages:
      DataValueListEntry: A DataValueListEntry object.

    Fields:
      code: [Output Only] A warning code, if applicable. For example, Compute
        Engine returns NO_RESULTS_ON_PAGE if there are no results in the
        response.
      data: [Output Only] Metadata about this warning in key: value format.
        For example: "data": [ { "key": "scope", "value": "zones/us-east1-d" }
      message: [Output Only] A human-readable description of the warning code.
    """

    class CodeValueValuesEnum(_messages.Enum):
      r"""[Output Only] A warning code, if applicable. For example, Compute
      Engine returns NO_RESULTS_ON_PAGE if there are no results in the
      response.

      Values:
        CLEANUP_FAILED: <no description>
        DEPRECATED_RESOURCE_USED: <no description>
        DEPRECATED_TYPE_USED: <no description>
        DISK_SIZE_LARGER_THAN_IMAGE_SIZE: <no description>
        EXPERIMENTAL_TYPE_USED: <no description>
        EXTERNAL_API_WARNING: <no description>
        FIELD_VALUE_OVERRIDEN: <no description>
        INJECTED_KERNELS_DEPRECATED: <no description>
        MISSING_TYPE_DEPENDENCY: <no description>
        NEXT_HOP_ADDRESS_NOT_ASSIGNED: <no description>
        NEXT_HOP_CANNOT_IP_FORWARD: <no description>
        NEXT_HOP_INSTANCE_NOT_FOUND: <no description>
        NEXT_HOP_INSTANCE_NOT_ON_NETWORK: <no description>
        NEXT_HOP_NOT_RUNNING: <no description>
        NOT_CRITICAL_ERROR: <no description>
        NO_RESULTS_ON_PAGE: <no description>
        PARTIAL_SUCCESS: <no description>
        REQUIRED_TOS_AGREEMENT: <no description>
        RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING: <no description>
        RESOURCE_NOT_DELETED: <no description>
        SCHEMA_VALIDATION_IGNORED: <no description>
        SINGLE_INSTANCE_PROPERTY_TEMPLATE: <no description>
        UNDECLARED_PROPERTIES: <no description>
        UNREACHABLE: <no description>
      """
      CLEANUP_FAILED = 0
      DEPRECATED_RESOURCE_USED = 1
      DEPRECATED_TYPE_USED = 2
      DISK_SIZE_LARGER_THAN_IMAGE_SIZE = 3
      EXPERIMENTAL_TYPE_USED = 4
      EXTERNAL_API_WARNING = 5
      FIELD_VALUE_OVERRIDEN = 6
      INJECTED_KERNELS_DEPRECATED = 7
      MISSING_TYPE_DEPENDENCY = 8
      NEXT_HOP_ADDRESS_NOT_ASSIGNED = 9
      NEXT_HOP_CANNOT_IP_FORWARD = 10
      NEXT_HOP_INSTANCE_NOT_FOUND = 11
      NEXT_HOP_INSTANCE_NOT_ON_NETWORK = 12
      NEXT_HOP_NOT_RUNNING = 13
      NOT_CRITICAL_ERROR = 14
      NO_RESULTS_ON_PAGE = 15
      PARTIAL_SUCCESS = 16
      REQUIRED_TOS_AGREEMENT = 17
      RESOURCE_IN_USE_BY_OTHER_RESOURCE_WARNING = 18
      RESOURCE_NOT_DELETED = 19
      SCHEMA_VALIDATION_IGNORED = 20
      SINGLE_INSTANCE_PROPERTY_TEMPLATE = 21
      UNDECLARED_PROPERTIES = 22
      UNREACHABLE = 23

    class DataValueListEntry(_messages.Message):
      r"""A DataValueListEntry object.

      Fields:
        key: [Output Only] A key that provides more detail on the warning
          being returned. For example, for warnings where there are no results
          in a list request for a particular zone, this key might be scope and
          the key value might be the zone name. Other examples might be a key
          indicating a deprecated resource and a suggested replacement, or a
          warning about invalid network settings (for example, if an instance
          attempts to perform IP forwarding but is not enabled for IP
          forwarding).
        value: [Output Only] A warning data value corresponding to the key.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    code = _messages.EnumField('CodeValueValuesEnum', 1)
    data = _messages.MessageField('DataValueListEntry', 2, repeated=True)
    message = _messages.StringField(3)

  id = _messages.StringField(1)
  items = _messages.MessageField('Zone', 2, repeated=True)
  kind = _messages.StringField(3, default=u'compute#zoneList')
  nextPageToken = _messages.StringField(4)
  selfLink = _messages.StringField(5)
  warning = _messages.MessageField('WarningValue', 6)


class ZoneSetLabelsRequest(_messages.Message):
  r"""A ZoneSetLabelsRequest object.

  Messages:
    LabelsValue: The labels to set for this resource.

  Fields:
    labelFingerprint: The fingerprint of the previous set of labels for this
      resource, used to detect conflicts. The fingerprint is initially
      generated by Compute Engine and changes after every request to modify or
      update labels. You must always provide an up-to-date fingerprint hash in
      order to update or change labels. Make a get() request to the resource
      to get the latest fingerprint.
    labels: The labels to set for this resource.
  """

  @encoding.MapUnrecognizedFields('additionalProperties')
  class LabelsValue(_messages.Message):
    r"""The labels to set for this resource.

    Messages:
      AdditionalProperty: An additional property for a LabelsValue object.

    Fields:
      additionalProperties: Additional properties of type LabelsValue
    """

    class AdditionalProperty(_messages.Message):
      r"""An additional property for a LabelsValue object.

      Fields:
        key: Name of the additional property.
        value: A string attribute.
      """

      key = _messages.StringField(1)
      value = _messages.StringField(2)

    additionalProperties = _messages.MessageField('AdditionalProperty', 1, repeated=True)

  labelFingerprint = _messages.BytesField(1)
  labels = _messages.MessageField('LabelsValue', 2)


class ZoneSetPolicyRequest(_messages.Message):
  r"""A ZoneSetPolicyRequest object.

  Fields:
    bindings: Flatten Policy to create a backwacd compatible wire-format.
      Deprecated. Use 'policy' to specify bindings.
    etag: Flatten Policy to create a backward compatible wire-format.
      Deprecated. Use 'policy' to specify the etag.
    policy: REQUIRED: The complete policy to be applied to the 'resource'. The
      size of the policy is limited to a few 10s of KB. An empty policy is in
      general a valid policy but certain services (like Projects) might reject
      them.
  """

  bindings = _messages.MessageField('Binding', 1, repeated=True)
  etag = _messages.BytesField(2)
  policy = _messages.MessageField('Policy', 3)


